Directory class

Implemented types

Constructors

Directory(String path)
Directory.fromUri(Uri uri)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent → Directory
no setteroverride
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri
no setteroverride

Methods

create({bool recursive = false}) → Future<Directory>
createSync({bool recursive = false}) → void
createTemp([String? prefix]) → Future<Directory>
createTempSync([String? prefix]) → Directory
delete({bool recursive = false}) → Future<FileSystemEntity>
override
deleteSync({bool recursive = false}) → void
exists() → Future<bool>
override
existsSync() → bool
override
list({bool recursive = false, bool followLinks = true}) → Stream<FileSystemEntity>
listSync({bool recursive = false, bool followLinks = true}) → List<FileSystemEntity>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rename(String newPath) → Future<Directory>
override
renameSync(String newPath) → Directory
override
resolveSymbolicLinksSync() → String
override
stat() → Future<FileStat>
override
statSync() → FileStat
override
toString() → String
A string representation of this object.
override
watch({int events = FileSystemEvent.all, bool recursive = false}) → Stream<FileSystemEvent>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

current ↔ Directory
getter/setter pair
systemTemp → Directory
no setter