FileSystemEntity class

Implementers

Constructors

FileSystemEntity()

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent → Directory
no setter
path → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri
no setter

Methods

delete({bool recursive = false}) → Future<FileSystemEntity>
exists() → Future<bool>
existsSync() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rename(String newPath) → Future<FileSystemEntity>
resolveSymbolicLinksSync() → String
stat() → Future<FileStat>
statSync() → FileStat
toString() → String
A string representation of this object.
inherited
watch({int events = FileSystemEvent.all, bool recursive = false}) → Stream<FileSystemEvent>

Operators

operator ==(Object other) → bool
The equality operator.
inherited