FileSystemException class

Implemented types
Implementers

Constructors

FileSystemException([String message = '', String? path, OSError? osError])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
osError OSError?
final
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited