HttpClient class

Constructors

HttpClient({SecurityContext? context})

Properties

authenticate Future<bool> Function(Uri, String, String?)?
no getter
autoUncompress bool
getter/setter pair
badCertificateCallback bool Function(dynamic, String, int)?
no getter
connectionTimeout Duration?
getter/setter pair
findProxy String Function(Uri)?
no getter
hashCode int
The hash code for this object.
no setterinherited
idleTimeout Duration
getter/setter pair
maxConnectionsPerHost int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userAgent String?
getter/setter pair

Methods

close({bool force = false}) → void
deleteUrl(Uri url) Future<HttpClientRequest>
getUrl(Uri url) Future<HttpClientRequest>
headUrl(Uri url) Future<HttpClientRequest>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openUrl(String method, Uri url) Future<HttpClientRequest>
postUrl(Uri url) Future<HttpClientRequest>
putUrl(Uri url) Future<HttpClientRequest>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited