IOSink class abstract
- Implemented types
- Implementers
Constructors
- IOSink()
Properties
Methods
-
add(
List< int> data) → void -
addError(
Object error, [StackTrace? stackTrace]) → void -
addStream(
Stream< List< stream) → Futureint> > -
close(
) → Future -
flush(
) → Future -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
Object? object) → void -
Writes the string representation of
object.inherited -
writeAll(
Iterable objects, [String separator = ""]) → void -
Writes the elements of
objectsseparated byseparator.inherited -
writeCharCode(
int charCode) → void -
Writes a string containing the character with code point
charCode.inherited -
writeln(
[Object? object = ""]) → void -
Writes the string representation of
objectfollowed by a newline.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited