Link class

Implemented types

Constructors

Link(String path)

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent → Directory
no setteroverride
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → Uri
no setteroverride

Methods

create(String target, {bool recursive = false}) → Future<Link>
createSync(String target, {bool recursive = false}) → void
delete({bool recursive = false}) → Future<FileSystemEntity>
override
deleteSync({bool recursive = false}) → void
exists() → Future<bool>
override
existsSync() → bool
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rename(String newPath) → Future<Link>
override
override
resolveSymbolicLinksSync() → String
override
stat() → Future<FileStat>
override
statSync() → FileStat
override
target() → Future<String>
targetSync() → String
toString() → String
A string representation of this object.
inherited
update(String target) → Future<Link>
updateSync(String target) → void
watch({int events = FileSystemEvent.all, bool recursive = false}) → Stream<FileSystemEvent>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromUri(Uri uri) → Link