Platform class

Constructors

Platform()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

environment → Map<String, String>
no setter
executable → String
no setter
executableArguments → List<String>
no setter
isAndroid → bool
no setter
isFuchsia → bool
no setter
isIOS → bool
no setter
isLinux → bool
no setter
isMacOS → bool
no setter
isWindows → bool
no setter
localHostname → String
no setter
numberOfProcessors → int
no setter
operatingSystem → String
no setter
operatingSystemVersion → String
no setter
packageConfig → Uri?
no setter
pathSeparator → String
no setter
resolvedExecutable → String
no setter
script → Uri
no setter
version → String
no setter