Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
path
→ String
-
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close()
→ Future<void>
-
-
closeSync()
→ void
-
-
flush()
→ Future<RandomAccessFile>
-
-
flushSync()
→ void
-
-
length()
→ Future<int>
-
-
lengthSync()
→ int
-
-
lock([FileLock mode = FileLock.exclusive, int start = 0, int end = -1])
→ Future<RandomAccessFile>
-
-
lockSync([FileLock mode = FileLock.exclusive, int start = 0, int end = -1])
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
position()
→ Future<int>
-
-
positionSync()
→ int
-
-
read(int count)
→ Future<Uint8List>
-
-
readByte()
→ Future<int>
-
-
readByteSync()
→ int
-
-
readInto(List<int> buffer, [int start = 0, int? end])
→ Future<int>
-
-
readIntoSync(List<int> buffer, [int start = 0, int? end])
→ int
-
-
readSync(int count)
→ Uint8List
-
-
setPosition(int position)
→ Future<RandomAccessFile>
-
-
setPositionSync(int position)
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
truncate(int length)
→ Future<RandomAccessFile>
-
-
truncateSync(int length)
→ void
-
-
unlock([int start = 0, int end = -1])
→ Future<RandomAccessFile>
-
-
unlockSync([int start = 0, int end = -1])
→ void
-
-
writeByte(int value)
→ Future<RandomAccessFile>
-
-
writeByteSync(int value)
→ void
-
-
writeFrom(List<int> buffer, [int start = 0, int? end])
→ Future<RandomAccessFile>
-
-
writeFromSync(List<int> buffer, [int start = 0, int? end])
→ void
-
-
writeString(String string, {Encoding encoding = utf8})
→ Future<RandomAccessFile>
-
-
writeStringSync(String string, {Encoding encoding = utf8})
→ void
-