ServerSocket class

Constructors

ServerSocket()

Properties

address → InternetAddress
no setter
hashCode → int
The hash code for this object.
no setterinherited
port → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

bind(dynamic address, int port, {int backlog = 0, bool v6Only = false, bool shared = false}) → Future<ServerSocket>