Stdout class

Implemented types

Properties

done Future
no setteroverride
encoding Encoding
getter/setter pairoverride
hashCode int
The hash code for this object.
no setterinherited
hasTerminal bool
no setter
nonBlocking IOSink
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsAnsiEscapes bool
no setter
terminalColumns int
no setter
terminalLines int
no setter

Methods

add(List<int> data) → void
override
addError(Object error, [StackTrace? stackTrace]) → void
override
addStream(Stream<List<int>> stream) Future
override
close() Future
override
flush() Future
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(Object? object) → void
Writes the string representation of object.
override
writeAll(Iterable objects, [String separator = '']) → void
Writes the elements of objects separated by separator.
override
writeCharCode(int charCode) → void
Writes a string containing the character with code point charCode.
override
writeln([Object? object = '']) → void
Writes the string representation of object followed by a newline.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited