FileChangeEvent class
A filesystem change notification.
Constructors
- FileChangeEvent({required String path, required FileChangeType type})
-
const
-
FileChangeEvent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → FileChangeType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited