PlatformFileStat class

Metadata about a filesystem entity.

Constructors

PlatformFileStat({required int size, required DateTime modified, required DateTime accessed, required FileEntityType type})
const
PlatformFileStat.fromJson(Map<String, dynamic> json)
factory

Properties

accessed DateTime
final
hashCode int
The hash code for this object.
no setterinherited
modified DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
type FileEntityType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited