PlatformHttpResponse class

An HTTP response.

Constructors

PlatformHttpResponse({required int statusCode, required Map<String, String> headers, required String body, required Uint8List bodyBytes})
const
PlatformHttpResponse.fromJson(Map<String, dynamic> json)
factory

Properties

body String
final
bodyBytes Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited