PlatformWebSocket class abstract

A bidirectional WebSocket channel.

Constructors

PlatformWebSocket()

Properties

closeCode int?
The close code once the connection has closed.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream
Incoming messages.
no setter

Methods

add(dynamic data) → void
Send a message.
close([int? code, String? reason]) Future<void>
Close the connection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited