ProcessOutput class

Result of running a process to completion.

Constructors

ProcessOutput({required int exitCode, required String stdout, required String stderr})
const
ProcessOutput.fromJson(Map<String, dynamic> json)
factory

Properties

exitCode int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr String
final
stdout String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited