ShellResult class
Result of a shell command execution.
Constructors
- ShellResult({required int exitCode, required String stdout, required String stderr, Duration? duration})
-
const
Properties
- duration → Duration?
-
final
- exitCode → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
no setter
- isTimeout → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderr → String
-
final
- stdout → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited