AnalyticsService class
Central analytics service — manages sinks and event routing.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attachSink(
AnalyticsSink sink) → void - Attach a sink for event routing.
-
dispose(
) → Future< void> - Dispose all sinks.
-
flush(
) → Future< void> - Flush all sinks.
-
logEvent(
String name, [Map< String, dynamic> metadata = const {}]) → void - Log an event synchronously (queued if no sink attached yet).
-
logEventAsync(
String name, [Map< String, dynamic> metadata = const {}]) → Future<void> - Log an event asynchronously.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited