AnalyticsSink class abstract

Sink interface for routing analytics events.

Implementers

Constructors

AnalyticsSink()

Properties

hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
Whether this sink is enabled.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Dispose resources.
flush() Future<void>
Flush pending events.
logEvent(AnalyticsEvent event) Future<void>
Send an event to this sink.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited