FeatureFlags class
Well-known feature flags (matching GrowthBook keys).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- analyticsKillswitch → const String
- buddyMode → const String
- datadogEnabled → const String
- eventSampling → const String
- explorePlanAgents → const String
- forkSubagent → const String
- promptSuggestions → const String
- teamMemory → const String
- toolSearch → const String
- verificationAgent → const String
- voiceMode → const String
- workflowScripts → const String