ApiProvider class abstract

Abstract provider interface — implemented by Anthropic and OpenAI shim.

Implementers

Constructors

ApiProvider()

Properties

config ApiConfig
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createMessage({required List<Message> messages, required String systemPrompt, List<ToolDefinition> tools = const [], int? maxTokens}) Future<Message>
Non-streaming message completion.
createMessageStream({required List<Message> messages, required String systemPrompt, List<ToolDefinition> tools = const [], int? maxTokens}) Stream<StreamEvent>
Stream a message completion.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited