ApiProviderType enum

Supported API provider types.

Inheritance
Available extensions

Values

gemini → const ApiProviderType

Google Gemini models.

qwen → const ApiProviderType

Alibaba Qwen (DashScope) models.

openai → const ApiProviderType

OpenAI and OpenAI-compatible APIs.

deepseek → const ApiProviderType

DeepSeek models.

anthropic → const ApiProviderType

Anthropic Claude models.

ollama → const ApiProviderType

Local Ollama instance.

bedrock → const ApiProviderType

AWS Bedrock.

vertex → const ApiProviderType

Google Vertex AI.

custom → const ApiProviderType

Custom OpenAI-compatible endpoint.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ApiProviderType>
A constant List of the values in this enum, in order of their declaration.