ContentBlockStartEvent class

Emitted when a new content block (text or tool use) starts.

Inheritance

Constructors

ContentBlockStartEvent({required int index, required ContentBlock block})
const

Properties

block ContentBlock
The initial content block data.
final
hashCode int
The hash code for this object.
no setterinherited
index int
Index of this content block within the message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited