MessageDeltaEvent class

Emitted with final message metadata (stop reason, token usage).

Inheritance

Constructors

MessageDeltaEvent({StopReason? stopReason, TokenUsage? usage})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopReason StopReason?
Why the model stopped generating.
final
usage TokenUsage?
Token usage statistics for this message.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited