MessageStartEvent class

Emitted when a new message begins streaming.

Inheritance

Constructors

MessageStartEvent({required String messageId, required String model})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
messageId String
Unique identifier for this message.
final
model String
The model that generated this message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited