RetryConfig class
Retry configuration.
Constructors
Properties
- baseDelayMs → int
-
Base delay in milliseconds for exponential backoff.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- max529Retries → int
-
Maximum consecutive 529 errors before giving up.
final
- maxDelayMs → int
-
Maximum delay in milliseconds.
final
- maxRetries → int
-
Maximum number of retry attempts.
final
- persistent → bool
-
Whether to retry indefinitely for unattended sessions.
final
- persistentMaxBackoffMs → int
-
Maximum backoff in milliseconds for persistent retries.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- backgroundConfig → const RetryConfig
- Conservative retry configuration for background tasks.
- defaultConfig → const RetryConfig
- Default retry configuration for interactive sessions.