RetryDecision class

Decision about whether to retry.

Constructors

RetryDecision.abort(String reason)
Create a decision to abort with the given reason.
factory
RetryDecision.retry(Duration delay)
Create a decision to retry after the given delay.
factory

Properties

abortReason String?
Reason for aborting (null if retrying).
final
delay Duration?
How long to wait before retrying (null if aborting).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldRetry bool
Whether the operation should be retried.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited