ImageAccumulator class
Holds image data received in a content block.
- Inheritance
-
- Object
- ContentBlockAccumulator
- ImageAccumulator
Constructors
- ImageAccumulator(int index, {required String mediaType, required String base64Data})
Properties
- base64Data → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
finalinherited
- mediaType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toContentBlock(
) → ContentBlock -
Build the final ContentBlock.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited