MessageStartUpdate class
Message started — carries model and message id metadata.
- Inheritance
-
- Object
- StreamUpdate
- MessageStartUpdate
Constructors
- MessageStartUpdate({required String messageId, required String model, TokenUsage? usage})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → String
-
final
- model → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- usage → TokenUsage?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited