TextAccumulator class

Accumulates text deltas into a complete TextBlock.

Inheritance

Constructors

TextAccumulator(int index, [String initial = ''])

Properties

currentText String
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

append(String text) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toContentBlock() ContentBlock
Build the final ContentBlock.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited