ToolUseInputDelta class

Partial JSON input delta for a tool_use block.

Inheritance

Constructors

ToolUseInputDelta({required String partialJson, required int blockIndex})
const

Properties

blockIndex int
final
hashCode int
The hash code for this object.
no setterinherited
partialJson String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited