AuthService class

Auth service — manages API keys and provider configuration. Uses Hive for key storage (cross-platform, no entitlements needed).

Constructors

AuthService()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearAllKeys() → Future<void>
getAnthropicApiKey() → Future<String?>
getApiKeyForProvider(ApiProviderType type) → Future<String?>
getDeepSeekApiKey() → Future<String?>
getGeminiApiKey() → Future<String?>
getOpenAiApiKey() → Future<String?>
getQwenApiKey() → Future<String?>
hasValidConfig() → Future<bool>
isOnboardingComplete() → Future<bool>
loadApiConfig() → Future<ApiConfig?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveProviderConfig({required ApiProviderType type, required String model, String? baseUrl}) → Future<void>
setAnthropicApiKey(String key) → Future<void>
setApiKeyForProvider(ApiProviderType type, String key) → Future<void>
setDeepSeekApiKey(String key) → Future<void>
setGeminiApiKey(String key) → Future<void>
setOnboardingComplete([bool complete = true]) → Future<void>
setOpenAiApiKey(String key) → Future<void>
setQwenApiKey(String key) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited