OAuthClient class
OAuth client for Anthropic authorization flows.
Constructors
- OAuthClient({required OAuthConfig config, Client? httpClient})
Properties
- config → OAuthConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildAuthUrl(
{required String codeChallenge, required String state, String? redirectUri, String? orgUuid, String? loginHint}) → Uri - Build the authorization URL for browser redirect.
-
dispose(
) → void -
exchangeCode(
{required String code, required String codeVerifier, required String state, String? redirectUri}) → Future< OAuthTokens> - Exchange authorization code for tokens.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
refreshToken(
{required String refreshToken, List< String> ? scopes}) → Future<OAuthTokens> - Refresh an expired access token.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited