OAuthConfig class

OAuth configuration for Anthropic endpoints.

Constructors

OAuthConfig({required String authorizeUrl, required String tokenUrl, required String clientId, required String redirectUrl, required List<String> scopes})
const

Properties

authorizeUrl → String
final
clientId → String
final
hashCode → int
The hash code for this object.
no setterinherited
redirectUrl → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → List<String>
final
tokenUrl → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

console → const OAuthConfig
Production Console OAuth config.
neomageAi → const OAuthConfig
Production Neomage.ai OAuth config.