Pkce class
PKCE (Proof Key for Code Exchange) utilities.
Constructors
- Pkce()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateCodeChallenge(
String verifier) → String - Generate code challenge from verifier (SHA256 hash, base64url-encoded).
-
generateCodeVerifier(
) → String - Generate a random code verifier (43+ chars, base64url-encoded).
-
generateState(
) → String - Generate CSRF state parameter.