BootstrapProgress class

Constructors

BootstrapProgress({required List<BootstrapStep> steps})

Properties

completedCount int
no setter
currentIndex int
no setter
currentStep BootstrapStep?
no setter
elapsed Duration
no setter
failedCount int
no setter
fraction double
no setter
hashCode int
The hash code for this object.
no setterinherited
isComplete bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skippedCount int
no setter
steps List<BootstrapStep>
final
totalSteps int
no setter

Methods

advanceStep() → void
format() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() → void
stop() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited