BootstrapService class

Constructors

BootstrapService({BootstrapConfig? config, void onLog(String message)?, void onProgress(BootstrapProgress progress)?})

Properties

config BootstrapConfig
final
hashCode int
The hash code for this object.
no setterinherited
onLog → void Function(String message)?
final
onProgress → void Function(BootstrapProgress progress)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() Future<BootstrapResult>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited