ProjectInfo class
Constructors
-
ProjectInfo({String? gitRoot, String? gitBranch, String? gitRemoteUrl, required String projectDir, List<
String> languages = const [], String? framework, String? packageManager, bool isGitRepo = false, bool hasPackageJson = false, bool hasPubspecYaml = false, bool hasCargoToml = false, bool hasGoMod = false, bool hasPyprojectToml = false, bool hasRequirementsTxt = false, Map<String, dynamic> extraInfo = const {}}) -
const
Properties
-
extraInfo
→ Map<
String, dynamic> -
final
- framework → String?
-
final
- gitBranch → String?
-
final
- gitRemoteUrl → String?
-
final
- gitRoot → String?
-
final
- hasCargoToml → bool
-
final
- hasGoMod → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasPackageJson → bool
-
final
- hasPubspecYaml → bool
-
final
- hasPyprojectToml → bool
-
final
- hasRequirementsTxt → bool
-
final
- isGitRepo → bool
-
final
-
languages
→ List<
String> -
final
- packageManager → String?
-
final
- projectDir → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited