BridgeError class

Error object in the bridge protocol (JSON-RPC 2.0 error shape).

Implemented types

Constructors

BridgeError({required int code, required String message, dynamic data})
const
BridgeError.fromJson(Map<String, dynamic> json)
factory
BridgeError.internalError([String? detail])
factory
BridgeError.invalidParams([String? detail])
factory
BridgeError.invalidRequest([String? detail])
factory
BridgeError.methodNotFound(String method)
factory
BridgeError.parseError([String? detail])
factory
BridgeError.requestCancelled()
factory
BridgeError.serverNotInitialized()
factory

Properties

code int
final
data → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited