BridgeHandshake class

Handshake payload sent during initialization.

Constructors

BridgeHandshake({required String clientName, required BridgeProtocolVersion clientVersion, required Set<BridgeCapability> capabilities, List<String> workspacePaths = const [], required int pid, String? sessionId, Map<String, dynamic> extensions = const {}})
BridgeHandshake.fromJson(Map<String, dynamic> json)
factory

Properties

capabilities Set<BridgeCapability>
final
clientName String
final
clientVersion BridgeProtocolVersion
final
extensions Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
pid int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
workspacePaths List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited