registerNotificationHandler method
Register a handler for incoming notifications with a specific method.
Implementation
void registerNotificationHandler(String method, NotificationHandler handler) {
_notificationHandlers[method] = handler;
}
Register a handler for incoming notifications with a specific method.
void registerNotificationHandler(String method, NotificationHandler handler) {
_notificationHandlers[method] = handler;
}