BridgeProtocolVersion class
Semantic version for the bridge protocol.
Constructors
- BridgeProtocolVersion({required int major, required int minor, required int patch})
-
const
-
BridgeProtocolVersion.fromJson(Map<
String, dynamic> json) -
factory
Properties
Methods
-
isCompatible(
BridgeProtocolVersion other) → bool -
Check if
otheris compatible with this version. -
isNewerThan(
BridgeProtocolVersion other) → bool -
Check if this version is strictly newer than
other. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- current → const BridgeProtocolVersion
- The current protocol version.