ProtocolMessage class

A parsed protocol message (tagged union).

Properties

hashCode int
The hash code for this object.
no setterinherited
notification BridgeNotification?
final
request BridgeRequest?
final
response BridgeResponse?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type MessageType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited