BridgeMessageType enum

Bridge message types (IDE <-> Neomage).

Inheritance
Available extensions

Values

openFile → const BridgeMessageType
showDiff → const BridgeMessageType
applyEdit → const BridgeMessageType
runCommand → const BridgeMessageType
getSelection → const BridgeMessageType
getOpenFiles → const BridgeMessageType
getDiagnostics → const BridgeMessageType
fileOpened → const BridgeMessageType
editApplied → const BridgeMessageType
selectionResponse → const BridgeMessageType
diagnosticsResponse → const BridgeMessageType
openFilesResponse → const BridgeMessageType
commandResult → const BridgeMessageType
ping → const BridgeMessageType
pong → const BridgeMessageType
error → const BridgeMessageType
status → const BridgeMessageType
handshake → const BridgeMessageType
handshakeAck → const BridgeMessageType
disconnect → const BridgeMessageType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
Wire name used in JSON serialization.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromWireName(String name) BridgeMessageType?
Parse from wire name.

Constants

values → const List<BridgeMessageType>
A constant List of the values in this enum, in order of their declaration.