BridgeServerInfo class

Information about a discovered bridge server.

Constructors

BridgeServerInfo({required String host, required int port, String? ideType, String? protocolVersion})
const

Properties

connectUrl String
no setter
hashCode int
The hash code for this object.
no setterinherited
host String
final
ideType String?
final
port int
final
protocolVersion String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited