EditorSelection class
Current editor selection.
Constructors
- EditorSelection({required String filePath, required int startLine, required int startColumn, required int endLine, required int endColumn, required String selectedText})
-
const
-
EditorSelection.fromJson(Map<
String, dynamic> json) -
factory
Properties
- endColumn → int
-
final
- endLine → int
-
final
- filePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
no setter
- isMultiLine → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedText → String
-
final
- startColumn → int
-
final
- startLine → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited