IdeCapabilities class
IDE capabilities — what the connected IDE supports.
Constructors
- IdeCapabilities({bool supportsDiff = false, bool supportsInlineEdit = false, bool supportsTerminal = false, bool supportsDiagnostics = false, bool supportsMultiRoot = false, bool supportsFileWatcher = false, bool supportsCodeLens = false, String? ideVersion, String? extensionVersion})
-
const
-
IdeCapabilities.fromJson(Map<
String, dynamic> json) -
factory
Properties
- extensionVersion → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ideVersion → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- supportsCodeLens → bool
-
final
- supportsDiagnostics → bool
-
final
- supportsDiff → bool
-
final
- supportsFileWatcher → bool
-
final
- supportsInlineEdit → bool
-
final
- supportsMultiRoot → bool
-
final
-
final
- supportsTerminal → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- full → const IdeCapabilities
- All capabilities enabled (VS Code full extension).
- minimal → const IdeCapabilities
- Minimal capabilities (basic terminal-only integration).