IdeDiagnostic class

A diagnostic (error, warning, info) from the IDE.

Constructors

IdeDiagnostic({required String filePath, required int line, required int column, required String message, required DiagnosticSeverity severity, String? source, String? code})
const
IdeDiagnostic.fromJson(Map<String, dynamic> json)
factory

Properties

code String?
final
column int
final
filePath String
final
hashCode int
The hash code for this object.
no setterinherited
line int
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity DiagnosticSeverity
final
source String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited