IdeType enum

IDE types supported by the bridge.

Inheritance
Available extensions

Values

vscode → const IdeType
jetbrains → const IdeType
neovim → const IdeType
emacs → const IdeType
sublime → const IdeType
custom → const IdeType

Properties

displayName String
Human-readable display name.
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String s) IdeType
Parse from string identifier.

Constants

values → const List<IdeType>
A constant List of the values in this enum, in order of their declaration.