StdioBridge class

A bridge connection over stdin/stdout, used for IDE extensions that launch Neomage as a subprocess.

Constructors

StdioBridge({required IdeType ideType, Stream<List<int>>? stdinStream, IOSink? stdoutSink})

Properties

bridge IdeBridge
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(BridgeMessage message) → void
Send a message to the IDE (via stdout).
start() → void
Start reading from stdin and writing responses to stdout.
stop() Future<void>
Stop the stdio bridge.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited