JetbrainsAction class

A registered JetBrains action (similar to VS Code commands).

Constructors

JetbrainsAction({required String id, required String text, String? description, String? shortcut, required Future handler(Map<String, dynamic>? context)})

Properties

description String?
final
handler Future Function(Map<String, dynamic>? context)
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortcut String?
final
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited