JetbrainsIdeType enum

Supported JetBrains IDE products.

Inheritance
Available extensions

Values

intellij → const JetbrainsIdeType
const JetbrainsIdeType('IntelliJ IDEA', 'idea')
webstorm → const JetbrainsIdeType
const JetbrainsIdeType('WebStorm', 'webstorm')
pycharm → const JetbrainsIdeType
const JetbrainsIdeType('PyCharm', 'pycharm')
goland → const JetbrainsIdeType
const JetbrainsIdeType('GoLand', 'goland')
rider → const JetbrainsIdeType
const JetbrainsIdeType('Rider', 'rider')
clion → const JetbrainsIdeType
const JetbrainsIdeType('CLion', 'clion')
phpstorm → const JetbrainsIdeType
const JetbrainsIdeType('PhpStorm', 'phpstorm')
rubymine → const JetbrainsIdeType
const JetbrainsIdeType('RubyMine', 'rubymine')
androidStudio → const JetbrainsIdeType
const JetbrainsIdeType('Android Studio', 'studio')

Properties

displayName String
Human-readable product name.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
productCode String
Short product code used in paths and configs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String s) JetbrainsIdeType
Parse from a product code or display name.

Constants

values → const List<JetbrainsIdeType>
A constant List of the values in this enum, in order of their declaration.