JetbrainsRunConfiguration class

A run/debug configuration.

Constructors

JetbrainsRunConfiguration({required String name, required String type, String? mainClass, String? module, String? workingDirectory, List<String> programArgs = const [], Map<String, String> envVars = const {}})
const
JetbrainsRunConfiguration.fromJson(Map<String, dynamic> json)
factory

Properties

envVars → Map<String, String>
final
hashCode → int
The hash code for this object.
no setterinherited
mainClass → String?
final
module → String?
final
name → String
final
programArgs → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final
workingDirectory → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited