VscodeCommand class

A registered VS Code command.

Constructors

VscodeCommand({required String id, required String title, String? keybinding, String? category, required Future handler(List? args)})

Properties

category → String?
final
handler → Future Function(List? args)
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
keybinding → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited