VscodeDiagnostic class

A single diagnostic entry.

Constructors

VscodeDiagnostic({required String uri, required int startLine, required int startCharacter, required int endLine, required int endCharacter, required String message, VscodeDiagnosticSeverity severity = VscodeDiagnosticSeverity.error, String? source, String? code})
const
VscodeDiagnostic.fromJson(Map<String, dynamic> json)
factory

Properties

code String?
final
endCharacter int
final
endLine int
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity VscodeDiagnosticSeverity
final
source String?
final
startCharacter int
final
startLine int
final
uri String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited