VscodeRange class

A text range (start/end position).

Implementers

Constructors

VscodeRange({required int startLine, required int startCharacter, required int endLine, required int endCharacter})
const
VscodeRange.fromJson(Map<String, dynamic> json)
factory

Properties

endCharacter → int
final
endLine → int
final
hashCode → int
The hash code for this object.
no setterinherited
isEmpty → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startCharacter → int
final
startLine → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited