ContentReplacementEntry class
Represents a content-replacement record from the transcript. Without these in the fork JSONL, resume reconstructs state with an empty replacements Map, causing prompt cache misses and permanent overages.
Constructors
-
ContentReplacementEntry({required String sessionId, required List<
Map< replacements})String, dynamic> > -
const
-
ContentReplacementEntry.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
replacements
→ List<
Map< String, dynamic> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited