ForkOrigin class

Represents the origin of a forked transcript message.

Constructors

ForkOrigin({required String sessionId, required String messageUuid})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
messageUuid String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited