ForkResult class
Result returned after successfully creating a fork.
Constructors
-
ForkResult({required String sessionId, String? title, required String forkPath, required List<
SerializedMessage> serializedMessages, required List<Map< contentReplacementRecords})String, dynamic> > -
const
Properties
-
contentReplacementRecords
→ List<
Map< String, dynamic> > -
final
- forkPath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serializedMessages
→ List<
SerializedMessage> -
final
- sessionId → String
-
final
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited