BridgePrerequisiteResult class

Result of checking bridge prerequisites.

Constructors

BridgePrerequisiteResult({required bool canConnect, String? errorMessage, BridgeDisabledReason? reason})
const
BridgePrerequisiteResult.failure({required String message, required BridgeDisabledReason failReason})
const
BridgePrerequisiteResult.success()
const

Properties

canConnect bool
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
reason BridgeDisabledReason?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited