ClearCommand class
Properties
-
aliases
→ List<String>
-
Alternative names for the command.
no setteroverride
-
argumentHint
→ String?
-
Hint text for arguments.
no setterinherited
-
description
→ String
-
User-visible description.
no setteroverride
-
displayName
→ String
-
Human-facing display name.
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
immediate
→ bool
-
Whether to execute immediately without waiting for stop point.
no setterinherited
-
isEnabled
→ bool
-
Whether this command is enabled (feature flags, etc).
no setterinherited
-
isHidden
→ bool
-
Whether this command is hidden from help/typeahead.
no setterinherited
-
name
→ String
-
Command name (without the
/ prefix).
no setteroverride
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
source
→ CommandSource
-
Where this command was loaded from.
no setterinherited
-
supportsNonInteractive
→ bool
-
Whether this command can run in non-interactive mode.
no setteroverride
-
type
→ CommandType
-
Execution type.
no setterinherited
-
whenToUse
→ String?
-
When to use this command (for skills discovery).
no setterinherited