InsightResults class

Results from all insight sections.

Constructors

InsightResults()

Properties

atAGlance Map<String, dynamic>?
getter/setter pair
frictionAnalysis Map<String, dynamic>?
getter/setter pair
funEnding Map<String, dynamic>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interactionStyle Map<String, dynamic>?
getter/setter pair
onTheHorizon Map<String, dynamic>?
getter/setter pair
projectAreas List<Map<String, dynamic>>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestions Map<String, dynamic>?
getter/setter pair
whatWorks Map<String, dynamic>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited