InsightSection class

Insight section definition for parallel generation.

Constructors

InsightSection({required String name, required String prompt, int maxTokens = 8192})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxTokens int
final
name String
final
prompt String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited