InsightsExport class

Export format for structured data.

Constructors

InsightsExport({required Map<String, dynamic> metadata, required AggregatedData aggregatedData, required InsightResults insights, Map<String, dynamic>? facetsSummary})
const

Properties

aggregatedData AggregatedData
final
facetsSummary Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
insights InsightResults
final
metadata Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited