LiteSessionInfo class

Lightweight session info from filesystem metadata.

Constructors

LiteSessionInfo({required String sessionId, required String path, required int mtimeMs, required int size})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mtimeMs int
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
size int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited