SessionFacets class
Facets extracted from a session by the model.
Constructors
-
SessionFacets({required String sessionId, required String underlyingGoal, required Map<
String, int> goalCategories, required String outcome, required Map<String, int> userSatisfactionCounts, required String neomageHelpfulness, required String sessionType, required Map<String, int> frictionCounts, required String frictionDetail, required String primarySuccess, required String briefSummary, List<String> ? userInstructionsToNeomage}) -
const
-
SessionFacets.fromJson(Map<
String, dynamic> json, {String? sessionId}) -
factory
Properties
- briefSummary → String
-
final
-
frictionCounts
→ Map<
String, int> -
final
- frictionDetail → String
-
final
-
goalCategories
→ Map<
String, int> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- neomageHelpfulness → String
-
final
- outcome → String
-
final
- primarySuccess → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
- sessionType → String
-
final
- underlyingGoal → String
-
final
-
userInstructionsToNeomage
→ List<
String> ? -
final
-
userSatisfactionCounts
→ Map<
String, int> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited