SessionMeta class
Metadata extracted from a single session.
Constructors
-
SessionMeta({required String sessionId, required String projectPath, required String startTime, required int durationMinutes, required int userMessageCount, required int assistantMessageCount, required Map<
String, int> toolCounts, required Map<String, int> languages, required int gitCommits, required int gitPushes, required int inputTokens, required int outputTokens, required String firstPrompt, String? summary, required int userInterruptions, required List<double> userResponseTimes, required int toolErrors, required Map<String, int> toolErrorCategories, required bool usesTaskAgent, required bool usesMcp, required bool usesWebSearch, required bool usesWebFetch, required int linesAdded, required int linesRemoved, required int filesModified, required List<int> messageHours, required List<String> userMessageTimestamps}) -
const
-
SessionMeta.fromJson(Map<
String, dynamic> json) -
Deserialize from JSON.
factory
Properties
- assistantMessageCount → int
-
final
- durationMinutes → int
-
final
- filesModified → int
-
final
- firstPrompt → String
-
final
- gitCommits → int
-
final
- gitPushes → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputTokens → int
-
final
-
languages
→ Map<
String, int> -
final
- linesAdded → int
-
final
- linesRemoved → int
-
final
-
messageHours
→ List<
int> -
final
- outputTokens → int
-
final
- projectPath → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
- startTime → String
-
final
- summary → String?
-
final
-
toolCounts
→ Map<
String, int> -
final
-
toolErrorCategories
→ Map<
String, int> -
final
- toolErrors → int
-
final
- userInterruptions → int
-
final
- userMessageCount → int
-
final
-
userMessageTimestamps
→ List<
String> -
final
-
userResponseTimes
→ List<
double> -
final
- usesMcp → bool
-
final
- usesTaskAgent → bool
-
final
- usesWebFetch → bool
-
final
- usesWebSearch → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serialize to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited