HttpMcpServerConfig class

HTTP-based MCP server configuration.

Implemented types

Constructors

HttpMcpServerConfig({required String url, Map<String, String>? headers, Map<String, dynamic>? oauth})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
final
oauth Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited