gitDiffCmd top-level constant
String
const gitDiffCmd
Shell command to get the full diff for the branch.
Implementation
const String gitDiffCmd = 'git diff origin/HEAD...';
Shell command to get the full diff for the branch.
const String gitDiffCmd = 'git diff origin/HEAD...';