InstallState class
State of the thinkback installation process.
Constructors
- InstallState({required InstallPhase phase, String? errorMessage, String? progressMessage})
-
const
Properties
- errorMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- phase → InstallPhase
-
final
- progressMessage → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{InstallPhase? phase, String? errorMessage, String? progressMessage}) → InstallState -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited