UltraplanPendingChoice class

Pending choice state when plan is ready for user decision.

Constructors

UltraplanPendingChoice({required String plan, required String sessionId, required String taskId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
plan String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
taskId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited