UltraplanPollError class
Error thrown during ultraplan polling.
- Implemented types
Constructors
- UltraplanPollError({required String reason, int rejectCount = 0, String? message})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String?
-
final
- reason → String
-
final
- rejectCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited