data/commands/command library
Classes
- Command
- Abstract base for all commands.
- CommandResult
- Result of a local command execution.
- CompactCommandResult
- LocalCommand
- A command that executes locally and returns a result.
- LocalUiCommand
- A command that renders Flutter UI (equivalent to local-jsx).
- PromptCommand
- A command that sends a prompt to the LLM.
- SkipCommandResult
- TextCommandResult
Enums
- CommandSource
- Where a command was loaded from.
- CommandType
- Command execution type.