CommandCategory enum

Logical category for grouping commands in help output and completions.

Inheritance
Available extensions

Values

Navigation commands (cd, open, etc.).

session → const CommandCategory

Session management (clear, compact, logout, etc.).

config → const CommandCategory

Configuration commands (config, model, permissions, etc.).

tools → const CommandCategory

Tool-related commands (tools, allowed-tools, etc.).

git → const CommandCategory

Git commands (commit, pr-comments, review, etc.).

debug → const CommandCategory

Debugging commands (debug, doctor, cost, etc.).

system → const CommandCategory

System commands (init, update-cli, etc.).

help → const CommandCategory

Help and documentation.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CommandCategory>
A constant List of the values in this enum, in order of their declaration.