CommandExecutionEvent class

Event emitted after a command execution.

Constructors

CommandExecutionEvent({required String commandName, required CommandCategory category, required String args, required bool isError, required DateTime timestamp})
const

Properties

args String
final
category CommandCategory
final
commandName String
final
hashCode int
The hash code for this object.
no setterinherited
isError bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited