CompactionStrategy enum

Strategy that triggered the compaction.

Inheritance
Available extensions

Values

auto → const CompactionStrategy

Triggered automatically when token usage crosses the threshold.

manual → const CompactionStrategy

Triggered explicitly by the user via /compact.

micro → const CompactionStrategy

Lightweight clearing of old tool results without summarization.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CompactionStrategy>
A constant List of the values in this enum, in order of their declaration.