TokenUsageUpdated class
- Inheritance
-
- Object
- ConversationEvent
- TokenUsageUpdated
Constructors
- TokenUsageUpdated(int inputTokens, int outputTokens, int cacheReadTokens, int cacheCreationTokens)
-
const
Properties
- cacheCreationTokens → int
-
final
- cacheReadTokens → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputTokens → int
-
final
- outputTokens → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited