ToolExecution class

Record of a tool execution within a turn.

Constructors

ToolExecution({required String toolName, required String toolUseId, required Map<String, dynamic> input, required String output, bool isError = false, required Duration duration, bool permissionGranted = true, String? permissionRule})
const

Properties

duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
input Map<String, dynamic>
final
isError bool
final
output String
final
permissionGranted bool
final
permissionRule String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolName String
final
toolUseId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited