QueryEngineConfig class

Configuration for the query engine.

Constructors

QueryEngineConfig({int maxTurns = 25, int contextWindow = 200000, bool enableCompaction = true, bool enableMicrocompact = true, bool enableSessionMemory = true})
const

Properties

contextWindow int
final
enableCompaction bool
final
enableMicrocompact bool
final
enableSessionMemory bool
final
hashCode int
The hash code for this object.
no setterinherited
maxTurns int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited