PromptSection class

System prompt section.

Constructors

PromptSection({required String name, required String content, int priority = 50, bool isConditional = false})
const

Properties

content → String
final
hashCode → int
The hash code for this object.
no setterinherited
isConditional → bool
final
name → String
final
priority → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited