CommandHook class

Shell command hook.

Inheritance

Constructors

CommandHook({required String command, String? shell, String? condition, int? timeoutSeconds, bool async_ = false, bool once = false})
const

Properties

async_ bool
finalinherited
command String
final
condition String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
once bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shell String?
final
timeoutSeconds int?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited