FunctionHook class

Function hook — in-process callback.

Inheritance

Constructors

FunctionHook({required Future<bool> callback(Map<String, dynamic> input), required String errorMessage, String? condition, int? timeoutSeconds})

Properties

async_ → bool
finalinherited
callback → Future<bool> Function(Map<String, dynamic> input)
final
condition → String?
finalinherited
errorMessage → String
final
hashCode → int
The hash code for this object.
no setterinherited
once → bool
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeoutSeconds → int?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited