HookManager class

Hook manager — registers and executes hooks.

Constructors

HookManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clear all hooks.
executeHooks({required HookEvent event, Map<String, dynamic> input = const {}}) Future<HookResult>
Execute all matching hooks for an event.
hasHooks(HookEvent event) bool
Check if any hooks are registered for an event.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(HookEvent event, HookMatcher matcher) → void
Register a hook matcher for an event.
registerAll(Map<HookEvent, List<HookMatcher>> hooks) → void
Register multiple matchers.
toString() String
A string representation of this object.
inherited
unregisterSource(String source) → void
Unregister all hooks from a source.

Operators

operator ==(Object other) bool
The equality operator.
inherited