HttpHook class

HTTP hook — makes HTTP request.

Inheritance

Constructors

HttpHook({required String url, Map<String, String> headers = const {}, String? condition, int? timeoutSeconds, bool async_ = false, bool once = false})
const

Properties

async_ bool
finalinherited
condition String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
once bool
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeoutSeconds int?
finalinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited