HookContinue class

Continue execution with optionally modified data.

If modifiedData is non-null, subsequent hooks and the main execution path will see the modified version.

Inheritance

Constructors

HookContinue({Map<String, dynamic>? modifiedData})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
modifiedData Map<String, dynamic>?
Optional modified data to pass forward. Null means no modification.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited