HookMatcher typedef
HookMatcher =
bool Function(HookContext context)
Signature for hook matchers that determine whether a hook should fire.
Implementation
typedef HookMatcher = bool Function(HookContext context);
Signature for hook matchers that determine whether a hook should fire.
typedef HookMatcher = bool Function(HookContext context);