HookRetry class
Request that the hooked operation be retried after a delay.
- Inheritance
-
- Object
- HookResult
- HookRetry
Properties
- delay → Duration
-
How long to wait before retrying.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAttempts → int
-
Maximum number of retry attempts (default: 1).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited