HookSkip class

Skip the current operation without error.

The hook chain continues, but the hooked operation itself may be skipped depending on the hook type.

Inheritance

Constructors

HookSkip(String reason)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
reason String
Human-readable reason for skipping.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited