AgentCompletedEvent class

Inheritance

Constructors

AgentCompletedEvent({required DateTime timestamp, String? sessionId, Map<String, dynamic> metadata = const {}, required String agentId, required String result, required Duration duration, int tokensUsed = 0})
const

Properties

agentId String
ID of the agent that completed.
final
duration Duration
Total duration of the agent's execution.
final
eventType String
Human-readable event type name.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
Arbitrary metadata attached to the event.
finalinherited
result String
The agent's result/output.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
The session ID this event belongs to.
finalinherited
timestamp DateTime
When this event occurred.
finalinherited
tokensUsed int
Total tokens used by the agent.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited