AgentErrorEvent class

Inheritance

Constructors

AgentErrorEvent({required DateTime timestamp, String? sessionId, Map<String, dynamic> metadata = const {}, required String agentId, required Object error, StackTrace? stackTrace, bool recoverable = false})
const

Properties

agentId String
ID of the agent that errored.
final
error Object
The error that occurred.
final
eventType String
Human-readable event type name.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
Arbitrary metadata attached to the event.
finalinherited
recoverable bool
Whether the error is recoverable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
The session ID this event belongs to.
finalinherited
stackTrace StackTrace?
Stack trace for the error.
final
timestamp DateTime
When this event occurred.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited