AgentMessageEvent class
- Inheritance
-
- Object
- LifecycleEvent
- AgentMessageEvent
Constructors
Properties
- agentId → String
-
ID of the agent that sent the message.
final
- eventType → String
-
Human-readable event type name.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The message content.
final
- messageType → String
-
Message type (progress, result, error).
final
-
metadata
→ Map<
String, dynamic> -
Arbitrary metadata attached to the event.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
The session ID this event belongs to.
finalinherited
- timestamp → DateTime
-
When this event occurred.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited