AgentSpawnedEvent class
- Inheritance
-
- Object
- LifecycleEvent
- AgentSpawnedEvent
Constructors
Properties
- agentId → String
-
Unique ID for the spawned agent.
final
- eventType → String
-
Human-readable event type name.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
Arbitrary metadata attached to the event.
finalinherited
- parentId → String?
-
Parent session or agent ID.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
The session ID this event belongs to.
finalinherited
- task → String
-
The task/prompt given to the agent.
final
- timestamp → DateTime
-
When this event occurred.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited