CompactionEvent class

Inheritance

Constructors

CompactionEvent({required DateTime timestamp, String? sessionId, Map<String, dynamic> metadata = const {}, required int messagesBefore, required int messagesAfter, required int tokensBefore, required int tokensAfter})
const

Properties

eventType String
Human-readable event type name.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
messagesAfter int
Number of messages after compaction.
final
messagesBefore int
Number of messages before compaction.
final
messagesRemoved int
Number of messages removed.
no setter
metadata Map<String, dynamic>
Arbitrary metadata attached to the event.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
The session ID this event belongs to.
finalinherited
timestamp DateTime
When this event occurred.
finalinherited
tokensAfter int
Token count after compaction.
final
tokensBefore int
Token count before compaction.
final
tokensSaved int
Number of tokens saved.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited