ConversationEndedEvent class

Inheritance

Constructors

ConversationEndedEvent({required DateTime timestamp, String? sessionId, Map<String, dynamic> metadata = const {}, required String conversationId, int turnCount = 0, int totalTokens = 0})
const

Properties

conversationId String
Unique conversation ID.
final
eventType String
Human-readable event type name.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
Arbitrary metadata attached to the event.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
The session ID this event belongs to.
finalinherited
timestamp DateTime
When this event occurred.
finalinherited
totalTokens int
Total tokens used in the conversation.
final
turnCount int
Number of turns in the conversation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited