dispose method
void
dispose()
Dispose the lifecycle manager and close the event stream.
Implementation
void dispose() {
unregisterAll();
_eventController.close();
}
Dispose the lifecycle manager and close the event stream.
void dispose() {
unregisterAll();
_eventController.close();
}