SessionEndedEvent class

Inheritance

Constructors

SessionEndedEvent({required DateTime timestamp, String? sessionId, Map<String, dynamic> metadata = const {}, required String reason, required Duration duration, int totalTokens = 0, double estimatedCost = 0.0})
const

Properties

duration Duration
Total duration of the session.
final
estimatedCost double
Estimated cost for the session.
final
eventType String
Human-readable event type name.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
Arbitrary metadata attached to the event.
finalinherited
reason String
Reason the session ended.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
The session ID this event belongs to.
finalinherited
timestamp DateTime
When this event occurred.
finalinherited
totalTokens int
Total tokens used during the session.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited