onSessionResume property
Fired when the session resumes from a paused state.
Implementation
final Future<void> Function(SessionResumedEvent event)? onSessionResume;
Fired when the session resumes from a paused state.
final Future<void> Function(SessionResumedEvent event)? onSessionResume;