SessionStartedEvent class

Inheritance

Constructors

SessionStartedEvent({required DateTime timestamp, String? sessionId, Map<String, dynamic> metadata = const {}, String? workingDirectory, String? profile, bool isResume = false})
const

Properties

eventType String
Human-readable event type name.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isResume bool
Whether this is a resumed session.
final
metadata Map<String, dynamic>
Arbitrary metadata attached to the event.
finalinherited
profile String?
Configuration profile name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
The session ID this event belongs to.
finalinherited
timestamp DateTime
When this event occurred.
finalinherited
workingDirectory String?
Working directory for this session.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited