ToolAfterExecutionEvent class

Inheritance

Constructors

ToolAfterExecutionEvent({required DateTime timestamp, String? sessionId, Map<String, dynamic> metadata = const {}, required String toolName, required Map<String, dynamic> input, required String output, bool isError = false, required Duration executionDuration})
const

Properties

eventType String
Human-readable event type name.
no setteroverride
executionDuration Duration
How long the tool took to execute.
final
hashCode int
The hash code for this object.
no setterinherited
input Map<String, dynamic>
Input arguments that were provided.
final
isError bool
Whether the output is an error.
final
metadata Map<String, dynamic>
Arbitrary metadata attached to the event.
finalinherited
output String
Output from the tool.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
The session ID this event belongs to.
finalinherited
timestamp DateTime
When this event occurred.
finalinherited
toolName String
Name of the tool that executed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited