ToolRecoveryAction enum

Actions available when recovering from a tool error.

Inheritance
Available extensions

Values

propagate → const ToolRecoveryAction

Let the error propagate normally.

retry → const ToolRecoveryAction

Retry the tool execution with the same input.

retryWithModifiedInput → const ToolRecoveryAction

Retry the tool execution with modified input.

suppress → const ToolRecoveryAction

Suppress the error and return a default/empty result.

abortTurn → const ToolRecoveryAction

Abort the current turn entirely.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ToolRecoveryAction>
A constant List of the values in this enum, in order of their declaration.