ToolRegisteredEvent class

Inheritance

Constructors

ToolRegisteredEvent({required DateTime timestamp, String? sessionId, Map<String, dynamic> metadata = const {}, required String toolName, required String source})
const

Properties

eventType String
Human-readable event type name.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
Arbitrary metadata attached to the event.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
The session ID this event belongs to.
finalinherited
source String
Source of the tool (e.g., "builtin", "mcp:server-name").
final
timestamp DateTime
When this event occurred.
finalinherited
toolName String
Name of the registered tool.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited