TurnEndedEvent class

Inheritance

Constructors

TurnEndedEvent({required DateTime timestamp, String? sessionId, Map<String, dynamic> metadata = const {}, required int turnIndex, int tokensUsed = 0, int toolInvocations = 0, required Duration duration})
const

Properties

duration Duration
Duration of the turn.
final
eventType String
Human-readable event type name.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
Arbitrary metadata attached to the event.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
The session ID this event belongs to.
finalinherited
timestamp DateTime
When this event occurred.
finalinherited
tokensUsed int
Tokens used during this turn.
final
toolInvocations int
Number of tool invocations during this turn.
final
turnIndex int
The turn number (0-indexed).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited