TurnStartedEvent class

Inheritance

Constructors

TurnStartedEvent({required DateTime timestamp, String? sessionId, Map<String, dynamic> metadata = const {}, required int turnIndex, required String userMessage})
const

Properties

eventType String
Human-readable event type name.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
Arbitrary metadata attached to the event.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
The session ID this event belongs to.
finalinherited
timestamp DateTime
When this event occurred.
finalinherited
turnIndex int
The turn number (0-indexed).
final
userMessage String
The user's input message for this turn.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited