GitPermissionChecker class

Checks permissions for git operations.

Constructors

GitPermissionChecker({required PermissionRuleSet ruleSet, PermissionCache? cache, List<String> protectedBranches = const ['main', 'master', 'develop', 'release']})

Properties

hashCode int
The hash code for this object.
no setterinherited
protectedBranches List<String>
Branches protected from destructive operations.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkGitOperation(GitOperation operation) PermissionDecision
Check whether a git operation is permitted.
checkPush(String remote, String branch, {bool force = false}) PermissionDecision
Check whether a push to a specific remote/branch is permitted.
isDestructiveGitOp(String command) → (bool, String)
Determine if a full git command string is destructive.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited