PermissionAuditEntry class

A single audit log entry.

Constructors

PermissionAuditEntry({required PermissionRequest request, required PermissionDecision decision, required DateTime timestamp})
const

Properties

decision PermissionDecision
final
hashCode int
The hash code for this object.
no setterinherited
request PermissionRequest
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited