isCacheable property
bool
get
isCacheable
Whether this level should be cached beyond the current check.
Implementation
bool get isCacheable => this == allowSession || this == allowAlways;
Whether this level should be cached beyond the current check.
bool get isCacheable => this == allowSession || this == allowAlways;