ToolPermissionChecker class

Checks permissions for tool execution, including input validation and dangerous command detection.

Constructors

ToolPermissionChecker({required PermissionRuleSet ruleSet, PermissionCache? cache})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkBashCommand(String command) PermissionDecision
Check a bash command string for dangerous patterns.
checkNetworkAccess(String url) PermissionDecision
Check whether network access to a URL is permitted.
checkToolExecution(String toolName, Map<String, dynamic> input) PermissionDecision
Check whether a tool execution is permitted.
isDangerousInput(String toolName, Map<String, dynamic> input) → (bool, String)
Determine if the input to a tool is dangerous.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited