McpSdkConfig class

In-process SDK transport.

Inheritance

Constructors

McpSdkConfig({required String name, Map<String, String> env = const {}})
const

Properties

env Map<String, String>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport McpTransportType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited