MemoryPromptResult class

Result of loading the memory prompt.

Constructors

MemoryPromptResult({required String prompt, required int memoryFileCount, required bool memoryDirExists})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
memoryDirExists bool
final
memoryFileCount int
final
prompt String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited