NativeCapabilities class

What the current platform supports at the native level.

Constructors

NativeCapabilities({bool clipboard = false, bool notifications = false, bool fileDialog = false, bool tray = false, bool globalHotkeys = false, bool biometrics = false})
const

Properties

biometrics bool
final
clipboard bool
final
fileDialog bool
final
globalHotkeys bool
final
hashCode int
The hash code for this object.
no setterinherited
notifications bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tray bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited