openInEditor method
Open path in the system editor, optionally jumping to line and
column.
Implementation
@override
Future<void> openInEditor(String path, {int? line, int? column}) async {
// Not available on web.
}
Open path in the system editor, optionally jumping to line and
column.
@override
Future<void> openInEditor(String path, {int? line, int? column}) async {
// Not available on web.
}