NeomageNotification class
A notification to display.
Constructors
-
NeomageNotification({required String id, required String title, required String body, NotificationPriority priority = NotificationPriority.normal, List<
NotificationAction> actions = const [], Duration? autoHide, String? category, Map<String, dynamic> ? data})
Properties
-
actions
→ List<
NotificationAction> -
final
- autoHide → Duration?
-
final
- body → String
-
final
- category → String?
-
final
- createdAt → DateTime
-
final
-
data
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- priority → NotificationPriority
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited