NotificationService class
Notification service — manages notifications across backends.
Constructors
-
NotificationService({List<
NotificationBackend> ? backends})
Properties
-
events
→ Stream<
NotificationEvent> -
Event stream.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
history
→ List<
NeomageNotification> -
Notification history.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dismiss(
String notificationId) → Future< void> - Dismiss a notification.
-
dismissAll(
) → Future< void> - Dismiss all notifications.
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notify(
{required String title, required String body, NotificationPriority priority = NotificationPriority.normal, List< NotificationAction> actions = const [], Duration? autoHide, String? category}) → Future<void> - Show a notification.
-
notifyAgentComplete(
String agentId, String description) → Future< void> - Show an agent completion notification.
-
notifyPermissionRequired(
String toolName) → Future< void> - Show a permission request notification.
-
notifyToolComplete(
String toolName, {bool isError = false}) → Future< void> - Show a tool completion notification.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited