PlatformPaths class

Platform-specific path utilities.

Constructors

PlatformPaths(PlatformBridge bridge)
const

Properties

analyticsDir String
Analytics directory.
no setter
bridge PlatformBridge
final
credentialsFile String
Credentials file.
no setter
hashCode int
The hash code for this object.
no setterinherited
keybindingsFile String
Keybindings file.
no setter
logFile String
Log file.
no setter
mcpConfigFile String
MCP config file.
no setter
memoryDir String
Memory directory.
no setter
pluginsDir String
Plugins directory.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionsDir String
Session storage directory.
no setter
settingsFile String
Global settings file.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
projectMcpConfig(String projectDir) String
Project-level MCP config.
projectSettings(String projectDir) String
Project-level settings.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited