RemoteMessage class

Remote message envelope.

Constructors

RemoteMessage({required String id, required String type, required String action, required Map<String, dynamic> payload, required DateTime timestamp, String? replyTo})
const
RemoteMessage.fromJson(Map<String, dynamic> json)
factory

Properties

action String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
payload Map<String, dynamic>
final
replyTo String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited