RemoteSessionInfo class
Remote session info.
Constructors
-
RemoteSessionInfo({required String sessionId, required String hostId, String? displayName, RemoteSessionState state = RemoteSessionState.disconnected, RemoteConnectionType connectionType = RemoteConnectionType.direct, required DateTime connectedAt, DateTime? lastActivity, String? remoteAddress, int? remotePort, String? model, String? workingDirectory, int messageCount = 0, Duration latency = Duration.zero, Map<
String, dynamic> ? metadata}) -
const
Properties
- connectedAt → DateTime
-
final
- connectionType → RemoteConnectionType
-
final
- displayName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hostId → String
-
final
- lastActivity → DateTime?
-
final
- latency → Duration
-
final
- messageCount → int
-
final
-
metadata
→ Map<
String, dynamic> ? -
final
- model → String?
-
final
- remoteAddress → String?
-
final
- remotePort → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
- state → RemoteSessionState
-
final
- workingDirectory → String?
-
final
Methods
-
copyWith(
{RemoteSessionState? state, DateTime? lastActivity, int? messageCount, Duration? latency}) → RemoteSessionInfo -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited