CompletionEvent class

Inheritance

Constructors

CompletionEvent({required int totalTokens, required int toolCalls, required Duration elapsed})

Properties

elapsed Duration
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
finalinherited
toolCalls int
final
totalTokens int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited