RemotePermissionRequest class

A permission request from the remote session.

Constructors

RemotePermissionRequest({required String id, required String toolName, required Map<String, dynamic> toolInput})

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
requestedAt DateTime
final
response Future<bool>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolInput Map<String, dynamic>
final
toolName String
final

Methods

approve() → void
deny() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited