RemoteSession class
Remote session — headless AI session driven by API calls.
Constructors
- RemoteSession({required String id, required QueryEngine engine})
Properties
-
events
→ Stream<
RemoteSessionEvent> -
Event stream for real-time updates.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
messages
→ List<
Message> -
All messages in the session.
no setter
-
pendingPermissions
→ List<
RemotePermissionRequest> -
Pending permission requests.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → RemoteSessionStatus
-
Current status.
no setter
- toolCalls → int
-
Total tool calls made.
no setter
- totalTokens → int
-
Total tokens used.
no setter
Methods
-
cancel(
) → void - Cancel the current operation.
-
dispose(
) → void - Dispose resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
respondToPermission(
String requestId, bool approved) → void - Respond to a permission request.
-
submit(
String prompt) → Future< Message> - Submit a user message and process the response.
-
toJson(
) → Map< String, dynamic> - Serialize session state for persistence.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited