ManifestValidationResult class

Manifest validation result.

Constructors

ManifestValidationResult({required bool isValid, List<String> errors = const [], List<String> warnings = const []})
const

Properties

errors List<String>
Validation errors (empty when valid).
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
Whether the manifest is valid.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warnings List<String>
Validation warnings (non-blocking).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited