PluginInstallationRecord class
Plugin installation record from the V2 on-disk format.
Constructors
- PluginInstallationRecord({required PluginScope scope, String? projectPath, String? installPath, String? version})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- installPath → String?
-
On-disk path to the installed plugin.
final
- projectPath → String?
-
Project path for project/local-scoped installations.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → PluginScope
-
The scope this installation belongs to.
final
- version → String?
-
Plugin version string.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited