PluginScope enum
Scopes at which a plugin can be installed.
Values
- user → const PluginScope
-
User-global scope (~/.neomage/plugins/).
- project → const PluginScope
-
Project scope (.neomage/plugins/).
- local → const PluginScope
-
Local-override scope (project, but gitignored).
- managed → const PluginScope
-
Managed by MDM/policy — cannot be manually installed.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PluginScope> - A constant List of the values in this enum, in order of their declaration.