CacheEntry class

A cached response with expiration metadata.

Constructors

CacheEntry({required ProxyResponse response, required DateTime cachedAt, required DateTime expiresAt, required String key})
const
CacheEntry.fromJson(Map<String, dynamic> json)
Deserializes a cache entry from JSON.
factory

Properties

cachedAt DateTime
final
expiresAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
isExpired bool
Whether this entry has expired.
no setter
key String
final
response ProxyResponse
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes the entry to JSON for disk storage.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited