ProxyResponse class

Response returned from the upstream proxy.

Constructors

ProxyResponse({required int statusCode, Map<String, String> headers = const {}, String body = '', bool cached = false, Duration latency = Duration.zero})
const

Properties

body String
final
cached bool
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
latency Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited