setResponseTransform method
Sets a transform function applied to responses before returning.
Implementation
void setResponseTransform(ProxyResponse Function(ProxyResponse) fn) {
_responseTransform = fn;
}
Sets a transform function applied to responses before returning.
void setResponseTransform(ProxyResponse Function(ProxyResponse) fn) {
_responseTransform = fn;
}