setTransform method
Sets a transform function applied to requests before forwarding.
Implementation
void setTransform(ProxyRequest Function(ProxyRequest) fn) {
_requestTransform = fn;
}
Sets a transform function applied to requests before forwarding.
void setTransform(ProxyRequest Function(ProxyRequest) fn) {
_requestTransform = fn;
}