createToolStub function

Tool createToolStub(
  1. String toolName
)

Create a minimal Tool stub for tools that are not loaded locally.

This happens when the remote CCR has tools (e.g. MCP tools) that the local client does not know about. The stub provides enough information for the permission dialog to render without crashing.

Implementation

Tool createToolStub(String toolName) => _RemoteToolStub(toolName);