RemoteMessageContent typedef

RemoteMessageContent = Object

Content payload sent to the remote session via HTTP POST.

Mirrors the RemoteMessageContent union from the TS teleport API. In practice this is either a text prompt or a list of content blocks.

Implementation

typedef RemoteMessageContent = Object;