RemotePermissionAllow class

Permission was granted with (possibly modified) input.

Inheritance

Constructors

RemotePermissionAllow({required Map<String, dynamic> updatedInput})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedInput Map<String, dynamic>
The (possibly updated) tool input to use.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited