onDisconnected property
void Function()?
onDisconnected
final
Called when connection is lost and cannot be restored.
Implementation
final void Function()? onDisconnected;
Called when connection is lost and cannot be restored.
final void Function()? onDisconnected;