hasInitialPrompt property
True if the session was created with an initial prompt that is being processed.
Implementation
final bool hasInitialPrompt;
True if the session was created with an initial prompt that is being processed.
final bool hasInitialPrompt;