convertToolResults property

bool convertToolResults
final

Convert user messages containing tool_result content blocks into display messages. Used by direct-connect mode where tool results come from the remote server and need to be rendered locally. CCR mode ignores user messages since they are handled differently.

Implementation

final bool convertToolResults;