ConvertedIgnored class
The SDK message was intentionally ignored (already handled locally, or not relevant for display).
- Inheritance
-
- Object
- ConvertedMessage
- ConvertedIgnored
Constructors
- ConvertedIgnored()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited