ConvertedStreamEvent class

The SDK message was a streaming event (partial assistant output).

Inheritance

Constructors

ConvertedStreamEvent(Map<String, dynamic> event)
const

Properties

event Map<String, dynamic>
The raw streaming event payload.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited