getResultText function
Extract the result text from a successful result message.
Implementation
String? getResultText(SessionsMessage msg) {
if (msg.raw['subtype'] == 'success') {
return msg.raw['result'] as String?;
}
return null;
}
Extract the result text from a successful result message.
String? getResultText(SessionsMessage msg) {
if (msg.raw['subtype'] == 'success') {
return msg.raw['result'] as String?;
}
return null;
}