RequestLog class

Lightweight record of an incoming request for the monitoring stream.

Constructors

RequestLog({required DateTime timestamp, required String method, required String path, required int statusCode, required Duration latency, String? clientIp})
const

Properties

clientIp String?
final
hashCode int
The hash code for this object.
no setterinherited
latency Duration
final
method String
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited