ServerEndpoint class

Describes a single API endpoint.

Constructors

ServerEndpoint({required String path, required HttpMethod method, required String description})
const

Properties

description String
Human-readable description of what this endpoint does.
final
hashCode int
The hash code for this object.
no setterinherited
method HttpMethod
HTTP method.
final
path String
URL path pattern (e.g. /api/chat).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited