AnalyticsConfig class

Check if analytics operations should be disabled.

Analytics is disabled when:

  • Test environment
  • Third-party cloud providers (Bedrock/Vertex/Foundry)
  • Privacy level is no-telemetry or essential-traffic

Constructors

AnalyticsConfig({required bool isTestEnvironment(), required bool isThirdPartyProvider(), required bool isTelemetryDisabled()})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAnalyticsDisabled → bool
no setter
isFeedbackSurveyDisabled → bool
Unlike isAnalyticsDisabled, this does NOT block on 3P providers. The feedback survey is a local UI prompt with no transcript data.
no setter
isTelemetryDisabled → bool Function()
final
isTestEnvironment → bool Function()
final
isThirdPartyProvider → bool Function()
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited