DatadogLog class

A single Datadog log entry.

Constructors

DatadogLog({required String ddsource, required String ddtags, required String message, required String service, required String hostname, Map<String, Object?> extra = const {}})
const

Properties

ddsource → String
final
ddtags → String
final
extra → Map<String, Object?>
final
hashCode → int
The hash code for this object.
no setterinherited
hostname → String
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited