DatadogService class

Datadog event tracking service with batched log dispatch.

Constructors

DatadogService({required Future<EventMetadata> getEventMetadata({Object? betas, Object? model}), required String getUserId(), required String getApiProvider(), required AnalyticsVerifiedString getCanonicalModelName(String toolName), required bool isKnownModel(String), required bool isAnalyticsDisabled(), required Future<void> httpPost(String url, Object body, Map<String, String> headers)})

Properties

getApiProvider → String Function()
final
getCanonicalModelName → AnalyticsVerifiedString Function(String toolName)
final
getEventMetadata → Future<EventMetadata> Function({Object? betas, Object? model})
final
getUserId → String Function()
final
hashCode → int
The hash code for this object.
no setterinherited
httpPost → Future<void> Function(String url, Object body, Map<String, String> headers)
final
isAnalyticsDisabled → bool Function()
final
isKnownModel → bool Function(String)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getUserBucket() → int
Get user bucket for cardinality reduction.
initialize() → bool
Initialise Datadog. Returns false if analytics is disabled.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shutdown() → Future<void>
Flush remaining logs and shut down.
toString() → String
A string representation of this object.
inherited
trackEvent(String eventName, Map<String, Object?> properties) → Future<void>
Track a Datadog event.

Operators

operator ==(Object other) → bool
The equality operator.
inherited