EnvContext class

Environment context metadata included with analytics events.

Constructors

EnvContext({required String platform, required String platformRaw, required String arch, String nodeVersion = '', String? terminal, String packageManagers = '', String runtimes = '', bool isCi = false, bool isRemote = false, bool isLocalAgentMode = false, String version = '', String? versionBase, String buildTime = '', String deploymentEnvironment = 'production', String? wslVersion, String? linuxDistroId, String? vcs})
const

Properties

arch → String
final
buildTime → String
final
deploymentEnvironment → String
final
hashCode → int
The hash code for this object.
no setterinherited
isCi → bool
final
isLocalAgentMode → bool
final
isRemote → bool
final
linuxDistroId → String?
final
nodeVersion → String
final
packageManagers → String
final
platform → String
final
platformRaw → String
final
runtimes → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terminal → String?
final
vcs → String?
final
version → String
final
versionBase → String?
final
wslVersion → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited