FirstPartyBatchConfig class

Batch configuration for the first-party event logger.

Constructors

FirstPartyBatchConfig({int scheduledDelayMillis = 10000, int maxExportBatchSize = 200, int maxQueueSize = 8192, bool skipAuth = false, int maxAttempts = 8, String? path, String? baseUrl})
const
FirstPartyBatchConfig.fromJson(Map<String, dynamic> json)
factory

Properties

baseUrl → String?
final
hashCode → int
The hash code for this object.
no setterinherited
maxAttempts → int
final
maxExportBatchSize → int
final
maxQueueSize → int
final
path → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledDelayMillis → int
final
skipAuth → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited