GrowthBookExperimentData class

GrowthBook experiment data for logging.

Constructors

GrowthBookExperimentData({required String experimentId, required int variationId, GrowthBookUserAttributes? userAttributes, Map<String, Object?>? experimentMetadata})
const

Properties

experimentId → String
final
experimentMetadata → Map<String, Object?>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAttributes → GrowthBookUserAttributes?
final
variationId → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited