ProcessMetrics class

Process metrics included with all analytics events.

Constructors

ProcessMetrics({required double uptime, required int rss, required int heapTotal, required int heapUsed, int external = 0, int arrayBuffers = 0})
const

Properties

arrayBuffers → int
final
external → int
final
hashCode → int
The hash code for this object.
no setterinherited
heapTotal → int
final
heapUsed → int
final
rss → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uptime → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, Object>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited