AutoDreamController class
Main auto-dream controller. Call initialize once at startup, then executeAutoDream from a post-sampling hook.
- Inheritance
-
- Object
- Listenable
- ListNotifier
- SintController
- AutoDreamController
Constructors
-
AutoDreamController({required AutoDreamEnabledCheck enabledCheck, required AutoDreamConfig getConfig(), required bool isKairosActive(), required bool isRemoteMode(), required bool isAutoMemoryEnabled(), required String getSessionId(), required String getAutoMemPath(), required String getOriginalCwd(), required String getProjectDir(String cwd), required ConsolidationLockService lockService, required void logEvent(String eventName, Map<
String, Object?> metadata), required void logDebug(String message), required Future<DreamRunResult> runDreamAgent({required void onMessage(DreamMessage), required String prompt})})
Properties
-
dreamTasks
→ RxMap<
String, DreamTaskState> -
Currently active dream tasks.
final
- enabledCheck → AutoDreamEnabledCheck
-
Feature gate + config retrieval.
final
- getAutoMemPath → String Function()
-
Get the auto-memory root path.
final
- getConfig → AutoDreamConfig Function()
-
Get the auto-dream config from feature flags.
final
- getOriginalCwd → String Function()
-
Get the original CWD.
final
- getProjectDir → String Function(String cwd)
-
Get the project directory for transcripts.
final
- getSessionId → String Function()
-
Get the current session ID.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized → bool
-
Checks whether the controller has already been initialized.
no setterinherited
- isAutoMemoryEnabled → bool Function()
-
Check if auto-memory is enabled.
final
- isClosed → bool
-
Checks whether the controller has already been closed.
no setterinherited
- isDisposed → bool
-
no setterinherited
- isKairosActive → bool Function()
-
Check if KAIROS mode is active.
final
- isRemoteMode → bool Function()
-
Check if remote mode is active.
final
- listenersLength → int
-
no setterinherited
- lockService → ConsolidationLockService
-
Consolidation lock service.
final
- logDebug → void Function(String message)
-
Debug logger.
final
-
logEvent
→ void Function(String eventName, Map<
String, Object?> metadata) -
Analytics event logger.
final
-
runDreamAgent
→ Future<
DreamRunResult> Function({required void onMessage(DreamMessage), required String prompt}) -
Run the forked dream agent.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
SintStateUpdate listener) → Disposer -
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(
Object? key, SintStateUpdate listener) → Disposer -
inherited
-
containsListener(
SintStateUpdate listener) → bool -
inherited
-
debounce<
T> (RxInterface< T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void -
Calls
callbackafterrxstops changing forduration. Useful for search-as-you-type, form validation, etc.inherited -
dispose(
) → void -
inherited
-
ever<
T> (RxInterface< T> rx, void callback(T)) → void -
Calls
callbackevery timerxchanges. Auto-cancels on controller disposal.inherited -
executeAutoDream(
) → Future< void> - Entry point from post-sampling hooks.
-
initialize(
) → void - Call once at startup.
-
interval<
T> (RxInterface< T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void -
Calls
callbackat most once perduration, ignoring intermediate changes. Useful for rate-limiting UI updates.inherited -
killDreamTask(
String taskId) → Future< void> - Kill a running dream task.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
once<
T> (RxInterface< T> rx, void callback(T)) → void -
Calls
callbackonly the first timerxchanges, then cancels.inherited -
onClose(
) → void -
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
-
onDelete(
) → void -
inherited
-
onInit(
) → void -
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
inherited
-
onReady(
) → void -
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
onStart(
) → void -
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclasses.
This method should be internal and is required to define the
lifetime cycle of the subclass.
inherited
-
refresh(
) → void -
inherited
-
refreshGroup(
Object id) → void -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(
Object id, VoidCallback listener) → void -
inherited
-
reportAdd(
VoidCallback disposer) → void -
inherited
-
reportRead(
) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
[List< Object> ? ids, bool condition = true]) → void -
Notifies listeners to update the UI.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited