DreamTaskState class

State of an in-progress or completed dream task.

Constructors

DreamTaskState({required String taskId, DreamTaskStatus status = DreamTaskStatus.running, int sessionsReviewing = 0, int priorMtime = 0, List<DreamTurn> turns = const [], List<String> filesTouched = const []})
const

Properties

filesTouched → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
priorMtime → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionsReviewing → int
final
status → DreamTaskStatus
final
taskId → String
final
turns → List<DreamTurn>
final

Methods

copyWith({DreamTaskStatus? status, List<DreamTurn>? turns, List<String>? filesTouched}) → DreamTaskState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited