CompletionProvider class abstract

Abstract completion provider. Multiple providers can be registered.

Implementers

Constructors

CompletionProvider()

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
priority → int
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → SuggestionType
no setter

Methods

canHandle(String query, SuggestionContext context) → bool
getSuggestions(String query, SuggestionContext context) → Future<List<CompletionSuggestion>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited