PromptCategory enum

Category for prompt suggestions.

Inheritance
Available extensions

Values

coding → const PromptCategory
debugging → const PromptCategory
refactoring → const PromptCategory
testing → const PromptCategory
documentation → const PromptCategory
git → const PromptCategory
devops → const PromptCategory
general → const PromptCategory

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PromptCategory>
A constant List of the values in this enum, in order of their declaration.