SnippetProvider class
Provides code snippet suggestions.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
no setteroverride
- priority → int
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → SuggestionType
-
no setteroverride
Methods
-
canHandle(
String query, SuggestionContext context) → bool -
override
-
getSuggestions(
String query, SuggestionContext context) → Future< List< CompletionSuggestion> > -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited