SuggestionContext class

Context for generating relevant suggestions.

Constructors

SuggestionContext({required String currentInput, required int cursorPosition, String? currentFile, String? currentDirectory, String? gitBranch, List<String> recentFiles = const [], List<String> recentCommands = const [], String? projectType, bool hasGit = false, List<String> availableCommands = const [], List<String> availableTools = const []})
const

Properties

availableCommands → List<String>
final
availableTools → List<String>
final
currentDirectory → String?
final
currentFile → String?
final
currentInput → String
final
cursorPosition → int
final
gitBranch → String?
final
hasGit → bool
final
hashCode → int
The hash code for this object.
no setterinherited
projectType → String?
final
recentCommands → List<String>
final
recentFiles → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited