SuggestionType enum

Type of auto-complete suggestion.

Inheritance
Available extensions

Values

file → const SuggestionType
directory → const SuggestionType
command → const SuggestionType
symbol → const SuggestionType
gitBranch → const SuggestionType
gitRef → const SuggestionType
model → const SuggestionType
mcpTool → const SuggestionType
mcpServer → const SuggestionType
historyEntry → const SuggestionType
snippet → const SuggestionType
variable → const SuggestionType
path → const SuggestionType
url → const SuggestionType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SuggestionType>
A constant List of the values in this enum, in order of their declaration.