AutoCompactTrackingState class

Autocompact tracking state.

Constructors

AutoCompactTrackingState({bool compacted = false, int turnCounter = 0, required String turnId, int consecutiveFailures = 0})

Properties

compacted ↔ bool
getter/setter pair
consecutiveFailures ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
turnCounter ↔ int
getter/setter pair
turnId ↔ String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited