MicrocompactResult class
Result of a microcompact operation.
Constructors
-
MicrocompactResult({required List<
CompactMessage> messages, Map<String, dynamic> ? compactionInfo}) -
const
Properties
-
compactionInfo
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
→ List<
CompactMessage> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited