TokenWarningState class

Token warning state result.

Constructors

TokenWarningState({required int percentLeft, required bool isAboveWarningThreshold, required bool isAboveErrorThreshold, required bool isAboveAutoCompactThreshold, required bool isAtBlockingLimit})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAboveAutoCompactThreshold → bool
final
isAboveErrorThreshold → bool
final
isAboveWarningThreshold → bool
final
isAtBlockingLimit → bool
final
percentLeft → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited