ConfigChangeEvent class

Emitted whenever a configuration value changes.

Constructors

ConfigChangeEvent({required String key, required dynamic oldValue, required dynamic newValue, required ConfigScope scope, required DateTime timestamp})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → String
final
newValue → dynamic
final
oldValue → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → ConfigScope
final
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited