ConfigDiff class

Represents a difference between two configuration values for the same key.

Constructors

ConfigDiff({required String key, required dynamic oldValue, required dynamic newValue, required ConfigScope scope})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
final
newValue → dynamic
final
oldValue → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope ConfigScope
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited