ConfigKeys class abstract final

Well-known configuration keys used throughout Neomage.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

allowedTools → const String
apiKey → const String
autoApprovePatterns → const String
baseUrl → const String
deniedTools → const String
diffTool → const String
editor → const String
historyDir → const String
locale → const String
logLevel → const String
maxTokens → const String
mcpServers → const String
model → const String
permissionMode → const String
projectRoot → const String
retryCount → const String
shell → const String
systemPrompt → const String
telemetryEnabled → const String
temperature → const String
theme → const String
timeout → const String
vimMode → const String