tryGet<T> method
Try to get a value, returning null instead of throwing.
Implementation
T? tryGet<T>(String key, {ConfigScope? scope}) {
try {
return get<T>(key, scope: scope);
} catch (_) {
return null;
}
}
Try to get a value, returning null instead of throwing.
T? tryGet<T>(String key, {ConfigScope? scope}) {
try {
return get<T>(key, scope: scope);
} catch (_) {
return null;
}
}