ConfigValidation class

Result of validating the entire configuration.

Constructors

ConfigValidation({required bool isValid, required List<String> errors})
const

Properties

errors List<String>
Human-readable error descriptions for invalid entries.
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
Whether all entries passed validation.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited