ConversationSummary class

Conversation summary for listing.

Constructors

ConversationSummary({required String sessionId, String? title, required DateTime startedAt, required DateTime lastActiveAt, required int messageCount, required int turnCount, required String model, int totalInputTokens = 0, int totalOutputTokens = 0, double totalCost = 0.0, List<String> toolsUsed = const [], String? lastUserMessage, String? lastAssistantMessage})
const
ConversationSummary.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
lastActiveAt DateTime
final
lastAssistantMessage String?
final
lastUserMessage String?
final
messageCount int
final
model String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
startedAt DateTime
final
title String?
final
toolsUsed List<String>
final
totalCost double
final
totalInputTokens int
final
totalOutputTokens int
final
turnCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited