ForkPoint class

Conversation fork point.

Constructors

ForkPoint({required String parentSessionId, required int messageIndex, required String forkSessionId, required DateTime forkedAt, String? reason})
const

Properties

forkedAt → DateTime
final
forkSessionId → String
final
hashCode → int
The hash code for this object.
no setterinherited
messageIndex → int
final
parentSessionId → String
final
reason → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited