TaskAssigned class

Inheritance

Constructors

TaskAssigned(CoordinatorTask task, CoordinatorAgent agent)
const

Properties

agent → CoordinatorAgent
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
task → CoordinatorTask
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited