data/services/diff_service
library
Classes
-
ConflictRegion
-
A region where a three-way merge encountered a conflict.
-
DiffHunk
-
A contiguous group of changes in a diff.
-
DiffLine
-
A single line within a diff hunk.
-
DiffService
-
Service for computing diffs, applying patches, and performing merges.
-
DiffStats
-
Statistics about additions and deletions in a diff.
-
FileDiff
-
Diff result for a single file.
-
InlineSpan
-
A span of text within a line, used for inline (word-level) highlighting.
-
MergeResult
-
Result of a three-way merge.