ConflictRegion class
A region where a three-way merge encountered a conflict.
Constructors
Properties
-
base
→ List<
String> -
Lines from the base version.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ours
→ List<
String> -
Lines from "ours".
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startLine → int
-
1-based start line in the merged output.
final
-
theirs
→ List<
String> -
Lines from "theirs".
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited