InlineSpan class

A span of text within a line, used for inline (word-level) highlighting.

Constructors

InlineSpan({required String text, required bool isChanged})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isChanged bool
Whether this span represents a changed region.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text fragment.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited