MergeResult class
Result of a three-way merge.
Constructors
-
MergeResult({required String merged, required List<
ConflictRegion> conflicts}) -
const
Properties
-
conflicts
→ List<
ConflictRegion> -
List of conflict regions (empty when the merge is clean).
final
- hasConflicts → bool
-
Whether the merge completed without conflicts.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- merged → String
-
The merged text. Contains conflict markers when hasConflicts is true.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited