AuthorStats class

Per-author commit statistics from git shortlog.

Constructors

AuthorStats({required String name, required String email, required int commitCount})
const

Properties

commitCount int
final
email String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited