GitBranch class

A local or remote branch.

Constructors

GitBranch({required String name, bool isRemote = false, bool isCurrent = false, String? upstream, int ahead = 0, int behind = 0})
const

Properties

ahead int
final
behind int
final
hashCode int
The hash code for this object.
no setterinherited
isCurrent bool
final
isRemote bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upstream String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited