GitCommit class

A commit object.

Constructors

GitCommit({required String hash, required String shortHash, required String author, required String email, required DateTime date, required String message, List<String> parents = const []})
const

Properties

author String
final
date DateTime
final
email String
final
hash String
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
parents List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortHash String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited