GitFileChange class

A single file change reported by git status.

Constructors

GitFileChange({required String path, String? oldPath, required GitFileStatus status, required bool staged})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
oldPath String?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staged bool
final
status GitFileStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited