GitStatusResult class

Result bundle from GitService.status.

Constructors

GitStatusResult({required GitStatus repoStatus, String? branch, String? upstream, int ahead = 0, int behind = 0, List<GitFileChange> changes = const [], int stashCount = 0})
const

Properties

ahead int
final
behind int
final
branch String?
final
changes List<GitFileChange>
final
hashCode int
The hash code for this object.
no setterinherited
isClean bool
no setter
repoStatus GitStatus
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stashCount int
final
upstream String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited