DailyUsage class

Single day usage breakdown.

Constructors

DailyUsage({required DateTime date, int sessions = 0, int messages = 0, int tokens = 0, double cost = 0.0})
const

Properties

cost double
final
date DateTime
final
hashCode int
The hash code for this object.
no setterinherited
messages int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessions int
final
tokens int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited