HistorySearchQuery class

History search query.

Constructors

HistorySearchQuery({String? text, String? sessionId, Set<HistoryEntryType>? types, Set<String>? roles, String? toolName, DateTime? after, DateTime? before, int? minTokens, int? maxTokens, int limit = 50, int offset = 0, bool sortDescending = true})
const

Properties

after → DateTime?
final
before → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
limit → int
final
maxTokens → int?
final
minTokens → int?
final
offset → int
final
roles → Set<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String?
final
sortDescending → bool
final
text → String?
final
toolName → String?
final
types → Set<HistoryEntryType>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited