ReplayState class

Replay state for stepping through history.

Constructors

ReplayState({required String sessionId, required List<HistoryEntry> entries, int currentIndex = 0, bool isPlaying = false, Duration playbackSpeed = const Duration(milliseconds: 500)})
const

Properties

currentEntry HistoryEntry?
no setter
currentIndex int
final
entries List<HistoryEntry>
final
hashCode int
The hash code for this object.
no setterinherited
isAtEnd bool
no setter
isAtStart bool
no setter
isPlaying bool
final
playbackSpeed Duration
final
progress double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final

Methods

copyWith({int? currentIndex, bool? isPlaying, Duration? playbackSpeed}) ReplayState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited