LspServerConfig class

LSP server configuration.

Constructors

LspServerConfig({required String name, required String command, List<String> args = const [], required Map<String, String> extensionToLanguage, Map<String, String> env = const {}, String? workspaceFolder, Map<String, dynamic>? initializationOptions, int maxRestarts = 3})
const

Properties

args List<String>
final
command String
final
env Map<String, String>
final
extensionToLanguage Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
initializationOptions Map<String, dynamic>?
final
maxRestarts int
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workspaceFolder String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited