DoNotDisturbSchedule class

A time window for do-not-disturb scheduling.

Constructors

DoNotDisturbSchedule({required int startHour, required int startMinute, required int endHour, required int endMinute, List<int> daysOfWeek = const [1, 2, 3, 4, 5, 6, 7]})
const

Properties

daysOfWeek List<int>
final
endHour int
final
endMinute int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startHour int
final
startMinute int
final

Methods

isActive([DateTime? time]) bool
Returns true if time falls within the DND window.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited