NotificationAction class

A button or action attached to a notification.

Constructors

NotificationAction({required String label, void callback()?, bool isPrimary = false})
const

Properties

callback → void Function()?
final
hashCode int
The hash code for this object.
no setterinherited
isPrimary bool
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited