OAuthConfig class

OAuth configuration URLs and client IDs.

Constructors

OAuthConfig({required String clientId, required String consoleAuthorizeUrl, required String neomageAiAuthorizeUrl, required String tokenUrl, required String rolesUrl, required String apiKeyUrl, required String manualRedirectUrl, required String consoleSuccessUrl, required String neomageAiSuccessUrl, required String profileUrl})
const

Properties

apiKeyUrl → String
final
clientId → String
final
consoleAuthorizeUrl → String
final
consoleSuccessUrl → String
final
hashCode → int
The hash code for this object.
no setterinherited
manualRedirectUrl → String
final
neomageAiAuthorizeUrl → String
final
neomageAiSuccessUrl → String
final
profileUrl → String
final
rolesUrl → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenUrl → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited