OAuthProfileAccount class

Account details in the profile response.

Constructors

OAuthProfileAccount({required String uuid, required String email, String? displayName, String? createdAt})
const
OAuthProfileAccount.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt String?
final
displayName String?
final
email String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited