OAuthProfileResponse class
Profile response from the OAuth profile endpoint.
Constructors
- OAuthProfileResponse({required OAuthProfileAccount account, required OAuthProfileOrganization organization})
-
const
-
OAuthProfileResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- account → OAuthProfileAccount
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- organization → OAuthProfileOrganization
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited