OAuthTokenAccount class
Account info from token exchange.
Constructors
- OAuthTokenAccount({required String uuid, required String emailAddress})
-
const
-
OAuthTokenAccount.fromJson(Map<
String, dynamic> json) -
factory
Properties
- emailAddress → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited