OAuthTokens class

Full OAuth tokens (client-side representation).

Constructors

OAuthTokens({required String accessToken, required String refreshToken, required int expiresAt, List<String> scopes = const [], SubscriptionType? subscriptionType, RateLimitTier? rateLimitTier, OAuthProfileResponse? profile, OAuthTokenAccountInfo? tokenAccount})
const

Properties

accessToken String
final
expiresAt int
final
hashCode int
The hash code for this object.
no setterinherited
profile OAuthProfileResponse?
final
rateLimitTier RateLimitTier?
final
refreshToken String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
final
subscriptionType SubscriptionType?
final
tokenAccount OAuthTokenAccountInfo?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited