UserRolesResponse class

User roles response from the roles endpoint.

Constructors

UserRolesResponse({String? organizationRole, String? workspaceRole, String? organizationName})
const
UserRolesResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
organizationName String?
final
organizationRole String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workspaceRole String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited