PluginActivationServiceImpl class

Default plugin activation service with topological dependency resolution.

Implemented types

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

listSetupCliBackendIds(List<PluginSetupDescriptor> descriptors) List<String>
Extract CLI backend IDs from a set of descriptors.
override
listSetupProviderIds(List<PluginSetupDescriptor> descriptors) List<String>
Extract provider IDs from a set of descriptors.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(List<PluginSetupDescriptor> descriptors) PluginActivationPlan
Resolve descriptors into an ordered activation plan.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited