data/services/plugin_service library

Classes

InstalledPluginsV2
V2 installed plugins data.
LoadedPlugin
A loaded plugin from the marketplace.
MarketplaceDiff
Result of diffing declared vs materialised marketplaces.
MarketplaceInstallStatus
A single marketplace installation status entry.
MarketplaceSourceChange
A marketplace whose source changed.
PluginCliResult
CLI command result for plugins.
PluginCliService
CLI command wrappers for plugin operations.
PluginIdentifier
Parsed plugin identifier.
PluginInstallationController
Background plugin and marketplace installation manager.
PluginInstallationRecord
Plugin installation record in V2 format.
PluginInstallationStatus
Overall installation status.
PluginInstallStatus
A single plugin installation status entry.
PluginMarketplaceEntry
A marketplace plugin entry.
PluginOperationResult
Result of a plugin operation (install, uninstall, enable, disable).
PluginOperationsService
Core plugin operations — library functions that can be used by both CLI commands and interactive UI.
PluginTelemetryFields
Telemetry field builder for plugin operations.
PluginUpdateResult
Result of a plugin update operation.
ReconciliationFailed
ReconciliationInstalled
ReconciliationInstalling
ReconciliationProgressEvent
Progress event during marketplace reconciliation.
ReconciliationResult
Result of a marketplace reconciliation run.

Enums

InstallationStatus
Status of a marketplace or plugin installation.
PluginScope
Scopes at which a plugin can be installed.

Constants

validInstallableScopes → const List<PluginScope>
Valid installable scopes (excludes 'managed' which can only come from managed-settings.json).
validUpdateScopes → const List<PluginScope>
Valid scopes for update operations (includes 'managed').

Functions

assertInstallableScope(PluginScope scope) → void
Assert that a scope is a valid installable scope.
buildPluginTelemetryFields(String name, String? marketplace, Set<String> managedPluginNames) PluginTelemetryFields
Build telemetry fields for a plugin CLI command.
classifyPluginCommandError(Object error) String
Classify a plugin command error for analytics.
isBuiltinPluginId(String pluginId) bool
Check if a plugin ID is a built-in plugin.
isInstallableScope(PluginScope scope) bool
Type guard for installable scopes.
parsePluginIdentifier(String plugin) PluginIdentifier
Parse a plugin identifier string into name and optional marketplace.
scopeToSettingSource(PluginScope scope) String
Convert a scope to a settings source key.