LoadedPlugin class
A loaded plugin from the marketplace.
Constructors
-
LoadedPlugin({required String name, String? source, String? version, bool enabled = true, PluginScope? scope, String? installPath, List<
String> dependencies = const []}) -
const
Properties
-
dependencies
→ List<
String> -
final
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- installPath → String?
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → PluginScope?
-
final
- source → String?
-
final
- version → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited