MarketplaceDiff class

Result of diffing declared vs materialised marketplaces.

Constructors

MarketplaceDiff({List<String> missing = const [], List<MarketplaceSourceChange> sourceChanged = const []})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
missing List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceChanged List<MarketplaceSourceChange>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited