MarketplaceSourceChange class

A marketplace whose source changed.

Constructors

MarketplaceSourceChange({required String name, required String oldSource, required String newSource})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
newSource String
final
oldSource String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited