PluginInstallStatus class

A single plugin installation status entry.

Constructors

PluginInstallStatus({required String name, required InstallationStatus status, String? error})
const

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status InstallationStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited