PluginInstallationRecord class

Plugin installation record in V2 format.

Constructors

PluginInstallationRecord({required PluginScope scope, String? projectPath, String? installPath, String? version})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
installPath String?
final
projectPath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope PluginScope
final
version String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited