PluginInstallationStatus class
Overall installation status.
Constructors
-
PluginInstallationStatus({List<
MarketplaceInstallStatus> marketplaces = const [], List<PluginInstallStatus> plugins = const []}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
marketplaces
→ List<
MarketplaceInstallStatus> -
final
-
plugins
→ List<
PluginInstallStatus> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{List< MarketplaceInstallStatus> ? marketplaces, List<PluginInstallStatus> ? plugins}) → PluginInstallationStatus -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited