PluginTelemetryFields class
Telemetry field builder for plugin operations.
Constructors
- PluginTelemetryFields({String? pluginName, String? marketplaceName, bool isManaged = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isManaged → bool
-
final
- marketplaceName → String?
-
final
- pluginName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited