ReconciliationResult class

Result of a marketplace reconciliation run.

Constructors

ReconciliationResult({List<String> installed = const [], List<String> updated = const [], List<String> failed = const [], List<String> upToDate = const []})
const

Properties

failed List<String>
final
hashCode int
The hash code for this object.
no setterinherited
installed List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updated List<String>
final
upToDate List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited