DependencyNode class

A node in a dependency tree.

Constructors

DependencyNode({required String name, String? version, List<DependencyNode> children = const []})
const

Properties

children → List<DependencyNode>
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited