LanguageStats class

Language statistics for a project.

Constructors

LanguageStats({required int fileCount, required int lineCount, required double percentage})
const

Properties

fileCount → int
final
hashCode → int
The hash code for this object.
no setterinherited
lineCount → int
final
percentage → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited