PackageManager enum

Package manager used by the project.

Inheritance
Available extensions

Values

pub → const PackageManager
npm → const PackageManager
yarn → const PackageManager
pnpm → const PackageManager
pip → const PackageManager
cargo → const PackageManager
goMod → const PackageManager
maven → const PackageManager
gradle → const PackageManager
bundler → const PackageManager
cocoapods → const PackageManager

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PackageManager>
A constant List of the values in this enum, in order of their declaration.