fallbackToLocal property
If true, fall back to locally cached settings when the endpoint is
unreachable.
Implementation
final bool fallbackToLocal;
If true, fall back to locally cached settings when the endpoint is
unreachable.
final bool fallbackToLocal;