SettingValue class

Resolved value with source information.

Constructors

SettingValue({required dynamic value, required SettingValueSource source, dynamic remoteValue, dynamic localOverride})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
localOverride → dynamic
The local override value, if any.
final
remoteValue → dynamic
The remote value (may differ from value if locally overridden).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source SettingValueSource
Where the effective value came from.
final
value → dynamic
The effective value after considering remote + local override.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited