SearchOptions class

Options that control a search operation.

Constructors

SearchOptions({bool caseSensitive = true, bool regex = false, bool wholeWord = false, List<String> includeGlobs = const [], List<String> excludeGlobs = const [], int? maxResults, int contextLines = 0})
const

Properties

caseSensitive → bool
Whether the search is case-sensitive.
final
contextLines → int
Number of context lines before and after each match.
final
excludeGlobs → List<String>
Glob patterns for files to exclude (e.g. ['*.g.dart']).
final
hashCode → int
The hash code for this object.
no setterinherited
includeGlobs → List<String>
Glob patterns for files to include (e.g. ['*.dart']).
final
maxResults → int?
Maximum number of matches to return. Null means unlimited.
final
regex → bool
Whether pattern should be interpreted as a regular expression.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wholeWord → bool
Whether to match whole words only.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited