SymbolMatch class

A symbol found by SearchService.findSymbol.

Constructors

SymbolMatch({required String name, required SymbolKind kind, required String file, required int line, String? containerName})
const

Properties

containerName String?
Name of the containing symbol (e.g. class name for a method).
final
file String
Absolute path of the file containing the symbol.
final
hashCode int
The hash code for this object.
no setterinherited
kind SymbolKind
Kind of symbol (function, class, etc.).
final
line int
1-based line number where the symbol is defined.
final
name String
Name of the symbol.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited