toolCallsBetweenUpdates property
int
get
toolCallsBetweenUpdates
Get the configured number of tool calls between updates.
Implementation
int get toolCallsBetweenUpdates => config.toolCallsBetweenUpdates;
Get the configured number of tool calls between updates.
int get toolCallsBetweenUpdates => config.toolCallsBetweenUpdates;