SessionMessage class

Simplified message for session memory processing.

Constructors

SessionMessage({required String uuid, required String type, List<SessionMessageBlock> content = const [], int? inputTokens, int? outputTokens, int? cacheReadInputTokens, int? cacheCreationInputTokens})
const

Properties

cacheCreationInputTokens int?
final
cacheReadInputTokens int?
final
content List<SessionMessageBlock>
final
hashCode int
The hash code for this object.
no setterinherited
inputTokens int?
final
outputTokens int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
uuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited