SettingsSyncFetchResult class

Result from fetching user settings.

Constructors

SettingsSyncFetchResult({required bool success, UserSyncData? data, bool isEmpty = false, String? error, bool skipRetry = false})
const

Properties

data UserSyncData?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipRetry bool
final
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited