SyncKeys class
Keys used for sync entries — mirrors the TS SYNC_KEYS constant.
Constructors
- SyncKeys()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
projectMemory(
String projectId) → String -
projectSettings(
String projectId) → String
Constants
- userMemory → const String
- userSettings → const String