StartupContextProvider class abstract

Provider interface for startup context sources.

Implementations supply memory entries from specific sources (BioChip profile, daily memories, active missions, etc.).

Constructors

StartupContextProvider()

Properties

hashCode int
The hash code for this object.
no setterinherited
priority int
Provider priority (lower runs first).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

loadEntries({required StartupContextConfig config, String? timezone}) Future<List<StartupContextEntry>>
Load memory entries for startup context.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited