TaskLogEntry class

Constructors

TaskLogEntry({required DateTime timestamp, required TaskLogLevel level, required String message, Object? data})
const

Properties

data Object?
final
hashCode int
The hash code for this object.
no setterinherited
level TaskLogLevel
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

format() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited