TaskManagerStats class

Constructors

TaskManagerStats({required int total, required int running, required int queued, required int completed, required int failed, required int cancelled, required int maxConcurrent})
const

Properties

cancelled int
final
completed int
final
failed int
final
hashCode int
The hash code for this object.
no setterinherited
maxConcurrent int
final
pending int
no setter
queued int
final
running int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited