TaskProgress class
Constructors
- TaskProgress({int current = 0, int total = 0, String message = '', double? percentage})
-
const
Properties
- current → int
-
final
- fraction → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isIndeterminate → bool
-
no setter
- message → String
-
final
- percentage → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int
-
final
Methods
-
copyWith(
{int? current, int? total, String? message, double? percentage}) → TaskProgress -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited