MemoryParser class

Parses markdown memory files into sections.

Constructors

MemoryParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

build(List<MemorySection> sections) String
Build sections back into markdown.
parse(String content) List<MemorySection>
Parse a markdown file into sections.