AbortController class

Abort controller for cancellation.

Constructors

AbortController()

Properties

hashCode int
The hash code for this object.
no setterinherited
isAborted bool
no setter
onAbort Stream<String>
no setter
reason String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

abort([String? reason]) → void
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited