AssistantMessage class

Assistant message (simplified).

Constructors

AssistantMessage({required String uuid, required String messageId, String? requestId, List content = const [], bool isApiErrorMessage = false, Map<String, dynamic>? usage})
const

Properties

content List
final
hashCode int
The hash code for this object.
no setterinherited
isApiErrorMessage bool
final
messageId String
final
requestId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage Map<String, dynamic>?
final
uuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited