ContextModifier class
A context modifier attached to a message update.
Constructors
- ContextModifier({required String toolUseID, required ToolUseContext modifyContext(ToolUseContext context)})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- modifyContext → ToolUseContext Function(ToolUseContext context)
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolUseID → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited