MessageUpdate class

A message update yielded during tool execution.

Constructors

MessageUpdate({ToolMessage? message, ToolUseContext? newContext, ContextModifier? contextModifier})
const

Properties

contextModifier ContextModifier?
final
hashCode int
The hash code for this object.
no setterinherited
message ToolMessage?
final
newContext ToolUseContext?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited