PermissionDecisionReason class

Reason for a permission decision.

Constructors

PermissionDecisionReason({required String type, String? hookName, String? hookSource, String? reason, PermissionRule? rule})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
hookName → String?
final
hookSource → String?
final
reason → String?
final
rule → PermissionRule?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited