ToolDefinition class

A tool definition.

Constructors

ToolDefinition({required String name, List<String> aliases = const [], bool isMcp = false, required bool isConcurrencySafe(Map<String, dynamic> input), bool requiresUserInteraction()?, String interruptBehavior()?, String getToolUseSummary(Map<String, dynamic>)?, required Future<ToolMessage> execute(Map<String, dynamic> input, ToolUseContext context), bool validateInput(Map<String, dynamic>)?})
const

Properties

aliases List<String>
final
execute Future<ToolMessage> Function(Map<String, dynamic> input, ToolUseContext context)
final
getToolUseSummary String Function(Map<String, dynamic>)?
final
hashCode int
The hash code for this object.
no setterinherited
interruptBehavior String Function()?
final
isConcurrencySafe bool Function(Map<String, dynamic> input)
final
isMcp bool
final
name String
final
requiresUserInteraction bool Function()?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validateInput bool Function(Map<String, dynamic>)?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited