ToolMessage class

A message returned from tool execution.

Constructors

ToolMessage({required String type, List<ToolResultBlock>? toolResults, String? toolUseResult, String? sourceToolAssistantUUID, Map<String, dynamic>? attachment, dynamic progressData})
const

Properties

attachment Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
progressData → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceToolAssistantUUID String?
final
toolResults List<ToolResultBlock>?
final
toolUseResult String?
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited