ToolResultBlock class

A tool result block within a message.

Constructors

ToolResultBlock({required String toolUseId, required String content, bool isError = false})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
isError bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolUseId String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited