ToolUseBlock class

Tool use block from the API response.

Constructors

ToolUseBlock({required String id, required String name, Map<String, dynamic> input = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
input Map<String, dynamic>
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited