ToolUseContext class

Context passed to tool execution.

Constructors

ToolUseContext({required List<ToolDefinition> tools, required String mainLoopModel, List mcpClients = const [], bool isNonInteractiveSession = false, String? querySource, String? agentId, bool requireCanUseTool = false, required AbortController abortController, void setInProgressToolUseIDs(Set<String> updater(Set<String>))?, void setHasInterruptibleToolInProgress(bool)?, void setStreamMode(String)?, void setResponseLength(int (int))?, void setSDKStatus(String?)?, void addNotification(Map<String, dynamic>)?, Future<Map<String, dynamic>> getAppState()?, Map<String, ({String content, int timestamp})>? readFileState, Set<String>? loadedNestedMemoryPaths, QueryTracking? queryTracking, String? requestPrompt})

Properties

abortController AbortController
final
addNotification → void Function(Map<String, dynamic>)?
final
agentId String?
final
getAppState Future<Map<String, dynamic>> Function()?
final
hashCode int
The hash code for this object.
no setterinherited
isNonInteractiveSession bool
final
loadedNestedMemoryPaths Set<String>?
final
mainLoopModel String
final
mcpClients List
final
querySource String?
final
queryTracking QueryTracking?
final
readFileState Map<String, ({String content, int timestamp})>
final
requestPrompt String?
final
requireCanUseTool bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setHasInterruptibleToolInProgress → void Function(bool)?
final
setInProgressToolUseIDs → void Function(Set<String> updater(Set<String>))?
final
setResponseLength → void Function(int (int))?
final
setSDKStatus → void Function(String?)?
final
setStreamMode → void Function(String)?
final
tools List<ToolDefinition>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited