AudioLevel class

Audio level data for visualization.

Constructors

AudioLevel({required double rms, required double peak, required DateTime timestamp})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
peak double
final
rms double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited