AudioRecorder class

Records audio from the microphone.

Constructors

AudioRecorder({int sampleRate = 16000, AudioFormat format = AudioFormat.wav})

Properties

format AudioFormat
final
hashCode int
The hash code for this object.
no setterinherited
isRecording bool
no setter
levelStream Stream<AudioLevel>
no setter
recordingDuration Duration
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int
final

Methods

cancel() Future<void>
Cancel recording without saving.
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() Future<void>
Start recording audio.
stop() Future<Uint8List>
Stop recording and return audio data.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited