SpeechLanguage class
Language for speech recognition.
Constructors
- SpeechLanguage({required String code, required String name, required String nativeName})
-
const
Properties
- code → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- nativeName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
all
→ const List<
SpeechLanguage> - chinese → const SpeechLanguage
- english → const SpeechLanguage
- french → const SpeechLanguage
- german → const SpeechLanguage
- japanese → const SpeechLanguage
- korean → const SpeechLanguage
- portuguese → const SpeechLanguage
- spanish → const SpeechLanguage