TtsEngine class abstract

Abstract text-to-speech provider.

Implementers

Constructors

TtsEngine()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
speak(String text, VoiceConfig config) → Future<void>
stop() → Future<void>
synthesize(String text, VoiceConfig config) → Future<Uint8List>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited