SessionHistoryManager class

Session history manager — saves and loads conversation transcripts.

Constructors

SessionHistoryManager({required String baseDir})

Properties

baseDir String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteSession(String sessionId) Future<bool>
Delete a session.
getMostRecentSession() Future<String?>
Get the most recent session ID, if any.
listSessions() Future<List<String>>
List all saved session IDs, newest first.
loadSession(String sessionId) Future<SessionSnapshot?>
Load a session snapshot from disk.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveSession(SessionSnapshot snapshot) Future<void>
Save a session snapshot to disk.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited