SessionSnapshot class

A serialized session that can be stored and restored.

Constructors

SessionSnapshot({required String sessionId, required DateTime createdAt, required DateTime updatedAt, required List<Message> messages, Map<String, dynamic> metadata = const {}})
const
SessionSnapshot.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
messages List<Message>
final
metadata Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
updatedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited