RestoredSession class

Restored session state.

Constructors

RestoredSession({required SessionSnapshot snapshot, List<TodoItem> todos = const [], Set<String> referencedFiles = const {}, String? lastWorkingDirectory, Map<String, dynamic> agentSettings = const {}})
const

Properties

agentSettings Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
lastWorkingDirectory String?
final
referencedFiles Set<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot SessionSnapshot
final
todos List<TodoItem>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited