SkillParameter class

Skill parameter definition.

Constructors

SkillParameter({required String name, required String description, String type = 'string', bool required = false, dynamic defaultValue, List<String>? enumValues, String? pattern})
const
SkillParameter.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue → dynamic
final
description String
final
enumValues List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
pattern String?
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited