AgentDefinition class

Agent definition — describes a type of sub-agent that can be spawned.

Constructors

AgentDefinition({required String agentType, required String name, required String description, String? systemPrompt, Set<String>? tools, Set<String>? disallowedTools, String? model, bool background = false, bool isBuiltIn = true})
const

Properties

agentType String
final
background bool
final
description String
final
disallowedTools Set<String>?
final
hashCode int
The hash code for this object.
no setterinherited
isBuiltIn bool
final
model String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemPrompt String?
final
tools Set<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited