AgentProgress class

Progress update from a running agent.

Constructors

AgentProgress({required String agentId, required String description, required int totalTokens, required int toolUses, String? lastToolName})
const

Properties

agentId String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
lastToolName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolUses int
final
totalTokens int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited