AgentResult class
Result of a sub-agent execution.
Constructors
- AgentResult({required String agentId, required String status, required String content, required int totalToolUseCount, required int totalDurationMs, required TokenUsage usage})
-
const
Properties
- agentId → String
-
final
- content → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
final
- totalDurationMs → int
-
final
- totalToolUseCount → int
-
final
- usage → TokenUsage
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited