BashSecurityCheckId class
Numeric identifiers for bash security checks (avoids logging strings).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- backslashEscapedOperators → const int
- backslashEscapedWhitespace → const int
- braceExpansion → const int
- commentQuoteDesync → const int
- controlCharacters → const int
- dangerousPatternsCommandSubstitution → const int
- dangerousPatternsInputRedirection → const int
- dangerousPatternsOutputRedirection → const int
- dangerousVariables → const int
- gitCommitSubstitution → const int
- ifsInjection → const int
- incompleteCommands → const int
- jqFileArguments → const int
- jqSystemFunction → const int
- malformedTokenInjection → const int
- midWordHash → const int
- newlines → const int
- obfuscatedFlags → const int
- procEnvironAccess → const int
- quotedNewline → const int
- shellMetacharacters → const int
- unicodeWhitespace → const int
- zshDangerousCommands → const int