QuoteExtraction class
Result of extracting quoted content from a command.
Constructors
- QuoteExtraction({required String withDoubleQuotes, required String fullyUnquoted, required String unquotedKeepQuoteChars})
-
const
Properties
- fullyUnquoted → String
-
Content with all quoted parts removed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unquotedKeepQuoteChars → String
-
Like fullyUnquoted but preserves quote characters ('/"): strips quoted
content while keeping the delimiters.
final
- withDoubleQuotes → String
-
Content with single-quoted parts removed.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited