SecurityResult class
Result of a security validation check.
Constructors
-
SecurityResult.allow({required String message, Map<
String, dynamic> ? updatedInput, String? decisionReason}) -
const
- SecurityResult.ask({required String message})
-
const
- SecurityResult.passthrough({required String message})
-
const
Properties
- behavior → String
-
The behavior: 'allow', 'ask', or 'passthrough'.
final
- decisionReason → String?
-
Reason for the decision.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAllow → bool
-
no setter
- isAsk → bool
-
no setter
- isPassthrough → bool
-
no setter
- message → String
-
Human-readable message explaining the decision.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
updatedInput
→ Map<
String, dynamic> ? -
Updated input if the command was modified.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited