ValidationContext class

Context passed to each security validator.

Constructors

ValidationContext({required String originalCommand, required String baseCommand, required String unquotedContent, required String fullyUnquotedContent, required String fullyUnquotedPreStrip, required String unquotedKeepQuoteChars})
const

Properties

baseCommand String
final
fullyUnquotedContent String
final
fullyUnquotedPreStrip String
final
hashCode int
The hash code for this object.
no setterinherited
originalCommand String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unquotedContent String
final
unquotedKeepQuoteChars String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited