BashSecurityCheck class

Dangerous shell patterns that should be blocked or warned about.

Constructors

BashSecurityCheck({required String id, required String description, required bool check(String command), bool blocking = true})
const

Properties

blocking bool
final
check bool Function(String command)
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited