BashToolInput class

Bash tool input.

Constructors

BashToolInput({required String command, int? timeoutMs, String? description, bool runInBackground = false, bool dangerouslyDisableSandbox = false})
const
BashToolInput.fromJson(Map<String, dynamic> json)
factory

Properties

command String
final
dangerouslyDisableSandbox bool
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
runInBackground bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeoutMs int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited