SandboxConfig class

Sandbox configuration.

Constructors

SandboxConfig({bool enabled = false, List<String> readAllowPaths = const [], List<String> writeAllowPaths = const [], bool networkEnabled = true, List<String> excludedCommands = const []})
const

Properties

enabled bool
final
excludedCommands List<String>
final
hashCode int
The hash code for this object.
no setterinherited
networkEnabled bool
final
readAllowPaths List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writeAllowPaths List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited