SecurityCheckResult class

Result of security validation.

Constructors

SecurityCheckResult({required bool passed, List<String> violations = const [], List<String> warnings = const []})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
passed bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
violations List<String>
final
warnings List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited