data/tools/config_tool library

Classes

ConfigTool
The ConfigTool — get or set application settings.
ConfigToolInput
Input for the ConfigTool.
ConfigToolOutput
Output for the ConfigTool.
GlobalConfigStore
Abstract interface for reading/writing global config.
InMemoryGlobalConfigStore
In-memory global config store for testing/default usage.
InMemorySettingsStore
In-memory settings store for testing/default usage.
SettingConfig
Configuration metadata for a single setting.
SettingsStore
Abstract interface for reading/writing project settings.
SettingValidation
Result of validating a setting value.
SupportedSettingsRegistry
Registry of all supported settings.

Enums

SettingSource
Storage source for a configuration setting.
SettingType
Type of a configuration setting value.
SyncableAppStateKey
AppState keys that can be synced for immediate UI effect.

Constants

configToolDescription → const String
configToolName → const String
defaultModelOptions → const List<String>
Default model options.
editorModes → const List<String>
Editor modes for key bindings.
notificationChannels → const List<String>
Notification channels.
permissionModes → const List<String>
Default permission modes.
teammateModes → const List<String>
Teammate modes.
themeNames → const List<String>
Theme names available in the application.

Functions

buildNestedObject(List<String> path, dynamic value) Map<String, dynamic>
Build a nested map from a path and value. E.g., 'permissions', 'defaultMode', 'plan' => {'permissions': {'defaultMode': 'plan'}}