ConfigToolInput class

Input for the ConfigTool.

Constructors

ConfigToolInput({required String setting, dynamic value})
const
ConfigToolInput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isGet bool
Whether this is a GET operation (no value provided).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setting String
final
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited