ConfigToolOutput class

Output for the ConfigTool.

Constructors

ConfigToolOutput({required bool success, String? operation, String? setting, dynamic value, dynamic previousValue, dynamic newValue, String? error})
const

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
newValue → dynamic
final
operation String?
final
previousValue → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setting String?
final
success bool
final
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited