GlobalConfigStore class abstract

Abstract interface for reading/writing global config.

Implementers

Constructors

GlobalConfigStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAll() Map<String, dynamic>
Get the full config map.
getValue(String key) → dynamic
Read a value from global config.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValue(String key, dynamic value) → void
Write a value to global config.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited