InMemoryGlobalConfigStore class
In-memory global config store for testing/default usage.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getAll(
) → Map< String, dynamic> -
Get the full config map.
override
-
getValue(
String key) → dynamic -
Read a value from global config.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setValue(
String key, dynamic value) → void -
Write a value to global config.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited