SettingConfig class
Configuration metadata for a single setting.
Constructors
-
SettingConfig({required SettingSource source, required SettingType type, required String description, List<
String> ? path, List<String> ? options, List<String> getOptions()?, SyncableAppStateKey? appStateKey, Future<SettingValidation> validateOnWrite(dynamic value)?, dynamic formatOnRead(dynamic value)?}) -
const
Properties
- appStateKey → SyncableAppStateKey?
-
AppState key to sync for immediate UI effect.
final
- description → String
-
Human-readable description.
final
-
effectiveOptions
→ List<
String> ? -
Get the effective options list.
no setter
- formatOnRead → dynamic Function(dynamic value)?
-
Format value when reading for display.
final
-
getOptions
→ List<
String> Function()? -
Dynamic options provider.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
options
→ List<
String> ? -
Static list of valid options.
final
-
path
→ List<
String> ? -
Path components for nested settings (defaults to key.split('.')).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → SettingSource
-
Where the setting is stored.
final
- type → SettingType
-
Type of the setting value.
final
-
validateOnWrite
→ Future<
SettingValidation> Function(dynamic value)? -
Async validation when writing a value.
final
Methods
-
getPath(
String key) → List< String> - Get the effective path for this setting key.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited