SupportedSettingsRegistry class

Registry of all supported settings.

Constructors

SupportedSettingsRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllKeys() List<String>
Get all setting keys.
getConfig(String key) SettingConfig?
Get the config for a setting.
getOptionsForSetting(String key) List<String>?
Get valid options for a setting.
getPath(String key) List<String>
Get the storage path for a setting.
isSupported(String key) bool
Check if a setting key is supported.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(String key, SettingConfig config) → void
Register a custom setting.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited