ComputerUseInput class

Constructors

ComputerUseInput({required String action, List<int>? coordinates, String? text, String? key, String? scrollDirection, int? scrollAmount})
ComputerUseInput.fromJson(Map<String, dynamic> json)
factory

Properties

action String
final
coordinates List<int>?
final
hashCode int
The hash code for this object.
no setterinherited
key String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollAmount int?
final
scrollDirection String?
final
text String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited