ConfigToolOutput class

Constructors

ConfigToolOutput({dynamic value, Map<String, dynamic>? allValues, required bool success})
const

Properties

allValues Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited