DiffApplyOutput class

Constructors

DiffApplyOutput({required bool success, required int linesChanged, required String newContent})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
linesChanged int
final
newContent String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited