LspToolInput class

Constructors

LspToolInput({required String action, required String filePath, int? line, int? column})
LspToolInput.fromJson(Map<String, dynamic> json)
factory

Properties

action → String
final
column → int?
final
filePath → String
final
hashCode → int
The hash code for this object.
no setterinherited
line → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited