MemoryToolInput class

Constructors

MemoryToolInput({required String action, String? path, String? content})
MemoryToolInput.fromJson(Map<String, dynamic> json)
factory

Properties

action String
final
content String?
final
hashCode int
The hash code for this object.
no setterinherited
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited