PowerShellOutput class

Constructors

PowerShellOutput({required String stdout, required String stderr, required int exitCode, required int durationMs})
const

Properties

durationMs int
final
exitCode int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr String
final
stdout String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited