ScreenshotInput class

Constructors

ScreenshotInput({String? url, String? selector, int viewportWidth = 1280, int viewportHeight = 800})
ScreenshotInput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector → String?
final
url → String?
final
viewportHeight → int
final
viewportWidth → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited