SubagentInput class

Constructors

SubagentInput({required String name, required String role, String? model, String? systemPrompt, List<String>? tools, required String task})
SubagentInput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
model String?
final
name String
final
role String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemPrompt String?
final
task String
final
tools List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited