SubagentOutput class

Constructors

SubagentOutput({required String agentId, required String result, required String status})
const

Properties

agentId → String
final
hashCode → int
The hash code for this object.
no setterinherited
result → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited