ValidateInput class

Constructors

ValidateInput({String? filePath, String? content, required String validatorType})
ValidateInput.fromJson(Map<String, dynamic> json)
factory

Properties

content → String?
final
filePath → String?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validatorType → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited