DesanitizeResult class

Normalize a match string by applying desanitization replacements. Returns the normalized string and which replacements were applied.

Constructors

DesanitizeResult({required String result, required List<MapEntry<String, String>> appliedReplacements})
const

Properties

appliedReplacements List<MapEntry<String, String>>
final
hashCode int
The hash code for this object.
no setterinherited
result String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited