FileEditInput class

Input parameters for the FileEditTool.

Constructors

FileEditInput({required String filePath, required String oldString, required String newString, bool replaceAll = false})
const
FileEditInput.fromMap(Map<String, dynamic> map)
factory

Properties

filePath String
final
hashCode int
The hash code for this object.
no setterinherited
newString String
final
oldString String
final
replaceAll bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() List<String>

Operators

operator ==(Object other) bool
The equality operator.
inherited