prompt property

  1. @override
String get prompt
override

Detailed prompt text sent in the system prompt for this tool.

Implementation

@override
String get prompt =>
    'Performs exact string replacements in files.\n\n'
    'Usage:\n'
    '- You must use your Read tool at least once before editing.\n'
    '- When editing text from Read tool output, ensure you preserve the '
    'exact indentation (tabs/spaces) as it appears AFTER the line number '
    'prefix.\n'
    '- ALWAYS prefer editing existing files. NEVER write new files unless '
    'explicitly required.\n'
    '- The edit will FAIL if old_string is not unique in the file. Either '
    'provide a larger string with more surrounding context to make it '
    'unique or use replace_all to change every instance.\n'
    '- Use replace_all for replacing and renaming strings across the file.';