FileReadMetadata class
Result of reading a file with metadata.
Constructors
- FileReadMetadata({required String content, required bool fileExists, required String encoding, required LineEndingType lineEndings})
-
const
Properties
- content → String
-
final
- encoding → String
-
final
- fileExists → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineEndings → LineEndingType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited