NormalizedEditInput class
Normalize the input for the FileEditTool. If the string to replace is not found in the file, try with a normalized version. Returns the normalized input if successful.
Constructors
-
NormalizedEditInput({required String filePath, required List<
FileEdit> edits}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited