FileReadInput class

Input parameters for the FileReadTool.

Constructors

FileReadInput({required String filePath, int? offset, int? limit, String? pages})
const
FileReadInput.fromMap(Map<String, dynamic> map)
factory

Properties

filePath String
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
final
offset int?
final
pages String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() List<String>

Operators

operator ==(Object other) bool
The equality operator.
inherited