FileReadOutput class

Output data from a file read operation.

Constructors

FileReadOutput({required String content, int lineCount = 0, bool truncated = false, bool binary = false, String encoding = 'utf-8', int size = 0, DateTime? modified})
const

Properties

binary bool
final
content String
final
encoding String
final
hashCode int
The hash code for this object.
no setterinherited
lineCount int
final
modified DateTime?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
truncated bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMetadata() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited