description property
Human-readable description.
Implementation
@override
String get description =>
'Reads a file from the local filesystem. You can access any file directly by using this tool.\n\n'
'Usage:\n'
'- The file_path parameter must be an absolute path, not a relative path.\n'
'- By default, it reads up to 2000 lines starting from the beginning of the file.\n'
'- When you already know which part of the file you need, only read that part using offset and limit.\n'
'- Results are returned using cat -n format, with line numbers starting at 1.\n'
'- This tool can read images (PNG, JPG, etc), PDFs (use pages parameter for large PDFs), '
'and Jupyter notebooks (.ipynb).\n'
'- This tool can only read files, not directories. To read a directory, use `ls` via the Bash tool.\n'
'- If the user provides a path to a file, assume that path is valid.';