prompt property
Detailed prompt text sent in the system prompt for this tool.
Implementation
@override
String get prompt =>
'Reads a file from the local filesystem. You can access any file '
'directly by using this tool.\n'
'Assume this tool is able to read all files on the machine. If the User '
'provides a path to a file assume that path is valid.\n\n'
'Usage:\n'
'- The file_path parameter must be an absolute path, not a relative path\n'
'- By default, it reads up to $defaultLimit lines from the beginning\n'
'- When you already know which part of the file you need, only read that '
'part. This can be important for larger files.\n'
'- Results are returned using cat -n format, with line numbers starting '
'at 1\n'
'- This tool can read images (PNG, JPG, etc). When reading an image '
'file the contents are presented visually.\n'
'- This tool can read PDF files (.pdf). For large PDFs (more than 10 '
'pages), you MUST provide the pages parameter to read specific page '
'ranges (e.g., pages: "1-5").\n'
'- This tool can read Jupyter notebooks (.ipynb files) and returns all '
'cells with their outputs.\n'
'- This tool can only read files, not directories.';