description property

  1. @override
String get description
override

Human-readable description.

Implementation

@override
String get description =>
    'Fast file pattern matching tool that works with any codebase size.\n\n'
    '- Supports glob patterns like "**/*.js" or "src/**/*.ts".\n'
    '- Returns matching file paths sorted by modification time.\n'
    '- Use this tool when you need to find files by name patterns.\n'
    '- When doing an open-ended search that may require multiple rounds of '
    'globbing and grepping, use the Agent tool instead.';