GrepOutput class
Structured output from GrepTool.
Constructors
Properties
- appliedLimit → int?
-
final
- appliedOffset → int?
-
final
- content → String?
-
final
-
filenames
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → String
-
final
- numFiles → int
-
final
- numLines → int?
-
final
- numMatches → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited