HeadLimitResult<T> class
Result of applying head_limit and offset to a list.
Constructors
-
HeadLimitResult({required List<
T> items, int? appliedLimit}) -
const
Properties
- appliedLimit → int?
-
Only set when truncation actually occurred, so the model knows
there may be more results and can paginate with offset.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
T> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited