LspHover class

LSP Hover result.

Constructors

LspHover({required dynamic contents, LspRange? range})
const
LspHover.fromJson(Map<String, dynamic> json)
factory

Properties

contents → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
range → LspRange?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited