LspIncomingCall class

LSP CallHierarchyIncomingCall.

Constructors

LspIncomingCall({required LspCallHierarchyItem from, required List<LspRange> fromRanges})
const
LspIncomingCall.fromJson(Map<String, dynamic> json)
factory

Properties

from LspCallHierarchyItem
final
fromRanges List<LspRange>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited