LspOutgoingCall class
LSP CallHierarchyOutgoingCall.
Constructors
-
LspOutgoingCall({required LspCallHierarchyItem to, required List<
LspRange> fromRanges}) -
const
-
LspOutgoingCall.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
fromRanges
→ List<
LspRange> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- to → LspCallHierarchyItem
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited