LspPosition class

LSP Position (0-based).

Constructors

LspPosition({required int line, required int character})
const
LspPosition.fromJson(Map<String, dynamic> json)
factory

Properties

character int
final
hashCode int
The hash code for this object.
no setterinherited
line int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited