LspRange class
LSP Range.
Constructors
- LspRange({required LspPosition start, required LspPosition end})
-
const
-
LspRange.fromJson(Map<
String, dynamic> json) -
factory
Properties
- end → LspPosition
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → LspPosition
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited