LspServerManager class abstract

Abstract LSP server manager interface.

Constructors

LspServerManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
initStatus LspInitStatus
Current initialization status.
no setter
isConnected bool
Whether the manager is connected and ready.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isFileOpen(String absolutePath) bool
Whether a file is already open in the server.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openFile(String absolutePath, String content) Future<void>
Open a file with the given content.
sendRequest(String absolutePath, String method, dynamic params) Future
Send a request to the LSP server.
toString() String
A string representation of this object.
inherited
waitForInitialization() Future<void>
Wait for initialization to complete.

Operators

operator ==(Object other) bool
The equality operator.
inherited