LspToolOutput class

Output of an LSP tool operation.

Constructors

LspToolOutput({required String operation, required String result, required String filePath, int? resultCount, int? fileCount})
const

Properties

fileCount int?
final
filePath String
final
hashCode int
The hash code for this object.
no setterinherited
operation String
final
result String
final
resultCount int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited