MCPServerInfo class
Information about an MCP server that provides a tool.
Constructors
- MCPServerInfo({required String serverName, String? serverVersion, String? serverUrl, String? transport})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverName → String
-
final
- serverUrl → String?
-
final
- serverVersion → String?
-
final
- transport → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited