isReadTool property
bool
get
isReadTool
Whether this tool is classified as a read operation.
Implementation
bool get isReadTool => classification.isRead;
Whether this tool is classified as a read operation.
bool get isReadTool => classification.isRead;