isSearchTool property
bool
get
isSearchTool
Whether this tool is classified as a search operation.
Implementation
bool get isSearchTool => classification.isSearch;
Whether this tool is classified as a search operation.
bool get isSearchTool => classification.isSearch;