prompt property
Detailed prompt text sent in the system prompt for this tool.
Implementation
@override
String get prompt =>
'Enter plan mode to design an implementation strategy before making '
'changes.\n\n'
'While in plan mode:\n'
'- Only read-only tools are available (Read, Glob, Grep, WebFetch, '
'WebSearch, ToolSearch, TodoWrite)\n'
'- Write, Edit, Bash, and other modifying tools are restricted\n'
'- Use ExitPlanMode to leave plan mode and begin execution\n\n'
'Provide a reason for entering plan mode.';