prompt property
Detailed prompt text sent in the system prompt for this tool.
Implementation
@override
String get prompt =>
'Exit plan mode and begin executing the plan that was developed.\n\n'
'Provide a summary of the plan to execute. All tools will be '
're-enabled after exiting plan mode.';