PlanModeInput class

Input for plan mode transitions.

Constructors

PlanModeInput({required String action, String? planText})
const
PlanModeInput.fromMap(Map<String, dynamic> map)
factory

Properties

action String
One of: enter, exit.
final
hashCode int
The hash code for this object.
no setterinherited
planText String?
Plan description when entering, or plan summary when exiting.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate(String expectedAction) List<String>

Operators

operator ==(Object other) bool
The equality operator.
inherited