PowerShellInput class

Parsed input for PowerShell command execution.

Constructors

PowerShellInput({required String command, String? workDir, Duration timeout = const Duration(minutes: 2), String? executionPolicy})
const
PowerShellInput.fromMap(Map<String, dynamic> map)
factory

Properties

command String
final
executionPolicy String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration
final
workDir String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
validate() List<String>

Operators

operator ==(Object other) bool
The equality operator.
inherited