MessageRouting class

Message routing information for display.

Constructors

MessageRouting({required String sender, String? senderColor, required String target, String? targetColor, String? summary, String? content})
const

Properties

content String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender String
final
senderColor String?
final
summary String?
final
target String
final
targetColor String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited