ParsedAddress class

Parsed peer address supporting teammate, UDS, and bridge schemes.

Constructors

ParsedAddress({required String scheme, required String target})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheme String
'other' (teammate name), 'bridge', or 'uds'
final
target String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited