ResponseOutput class

Output from a shutdown or plan response.

Constructors

ResponseOutput({required bool success, required String message, String? requestId})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
requestId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited