TeamMember class

A member of a team.

Constructors

TeamMember({required String name, String? color, String? agentId, String? tmuxPaneId, String? backendType})
const

Properties

agentId String?
final
backendType String?
final
color String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tmuxPaneId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited