PermissionSuggestion class
A suggestion for adding a permission rule.
Constructors
- PermissionSuggestion({required String toolName, required String ruleContent, required String behavior, required String destination})
-
const
Properties
- behavior → String
-
final
- destination → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ruleContent → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited