clearInvokedSkillsForAgent method
Clear invoked skills for a specific agent.
Implementation
void clearInvokedSkillsForAgent(String agentId) {
// In the full implementation this would be scoped by agent ID.
_invokedSkills.clear();
}
Clear invoked skills for a specific agent.
void clearInvokedSkillsForAgent(String agentId) {
// In the full implementation this would be scoped by agent ID.
_invokedSkills.clear();
}