SkillToolInput class

Input for the SkillTool.

Constructors

SkillToolInput({required String skill, String? args})
const
SkillToolInput.fromJson(Map<String, dynamic> json)
factory

Properties

args String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skill String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited