TrackedTask class

A tracked background task.

Constructors

TrackedTask({required String id, required TaskType type, required String description, TaskStatus status = TaskStatus.pending, String? output, String? error, int? exitCode})

Properties

description String
final
endTime DateTime?
getter/setter pair
error String?
getter/setter pair
exitCode int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
output String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime
getter/setter pair
status TaskStatus
getter/setter pair
type TaskType
final

Methods

complete({String? output, int? exitCode}) → void
fail(String error) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited