InMemoryTaskStore class
In-memory task store for default/testing usage.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addTask(
String taskListId, Task task) → void - Add a task (for testing).
-
blockTask(
String taskListId, String taskId, String blockedTaskId) → Future< void> -
Add a blocking relationship: taskId blocks blockedTaskId.
override
-
deleteTask(
String taskListId, String taskId) → Future< bool> -
Delete a task.
override
-
getTask(
String taskListId, String taskId) → Future< Task?> -
Get a task by ID.
override
-
getTaskListId(
) → String -
Get the current task list ID.
override
-
listTasks(
String taskListId) → Future< List< Task> > -
List all tasks.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateTask(
String taskListId, String taskId, Map< String, dynamic> updates) → Future<void> -
Update a task.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited