Task class
A task in the task list.
Constructors
-
Task({required String id, required String subject, String? description, String? activeForm, TaskStatus status = TaskStatus.pending, String? owner, List<
String> blocks = const [], List<String> blockedBy = const [], Map<String, dynamic> ? metadata, DateTime? createdAt, DateTime? updatedAt}) -
Task.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activeForm ↔ String?
-
getter/setter pair
-
blockedBy
↔ List<
String> -
getter/setter pair
-
blocks
↔ List<
String> -
getter/setter pair
- createdAt ↔ DateTime
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
-
metadata
↔ Map<
String, dynamic> ? -
getter/setter pair
- owner ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ TaskStatus
-
getter/setter pair
- subject ↔ String
-
getter/setter pair
- updatedAt ↔ DateTime
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited