TaskStatus enum

Valid task statuses.

Inheritance
Available extensions

Values

pending → const TaskStatus
inProgress → const TaskStatus
completed → const TaskStatus

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJsonString() String
Convert to JSON string.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String s) TaskStatus?
Parse from a JSON string.

Constants

values → const List<TaskStatus>
A constant List of the values in this enum, in order of their declaration.