TaskUpdateStatus class

Extended status that includes 'deleted' as a special action.

Constructors

TaskUpdateStatus.deleted()
const
TaskUpdateStatus.status(TaskStatus status)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isDeleted bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status TaskStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String s) TaskUpdateStatus?
Parse from string, supporting 'deleted' in addition to regular statuses.