onExpandTaskView property
void Function()?
onExpandTaskView
final
Callback for expanding the task view in the UI.
Implementation
final void Function()? onExpandTaskView;
Callback for expanding the task view in the UI.
final void Function()? onExpandTaskView;