TaskUpdateToolOutput class

Output for the TaskUpdateTool.

Constructors

TaskUpdateToolOutput({required bool success, required String taskId, required List<String> updatedFields, String? error, ({String from, String to})? statusChange, bool verificationNudgeNeeded = false})
const

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusChange → ({String from, String to})?
final
success bool
final
taskId String
final
updatedFields List<String>
final
verificationNudgeNeeded bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited