InterruptBehavior enum

Tool interrupt behavior when user sends a new message.

Inheritance
Available extensions

Values

interruptible → const InterruptBehavior

Tool can be interrupted immediately.

finishThenYield → const InterruptBehavior

Tool should finish current operation before yielding.

nonInterruptible → const InterruptBehavior

Tool cannot be interrupted.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InterruptBehavior>
A constant List of the values in this enum, in order of their declaration.