interruptBehavior property
How this tool behaves when interrupted by user input.
Implementation
InterruptBehavior get interruptBehavior => InterruptBehavior.interruptible;
How this tool behaves when interrupted by user input.
InterruptBehavior get interruptBehavior => InterruptBehavior.interruptible;