interruptBehavior property
How this tool behaves when interrupted by user input.
Implementation
@override
InterruptBehavior get interruptBehavior => InterruptBehavior.finishThenYield;
How this tool behaves when interrupted by user input.
@override
InterruptBehavior get interruptBehavior => InterruptBehavior.finishThenYield;