isAvailable property
bool
get
isAvailable
Whether this tool is available on the current platform.
Implementation
bool get isAvailable => true;
Whether this tool is available on the current platform.
bool get isAvailable => true;