isConcurrencySafe property
bool
get
isConcurrencySafe
Whether this tool is safe to run concurrently with other tools.
Implementation
bool get isConcurrencySafe => false;
Whether this tool is safe to run concurrently with other tools.
bool get isConcurrencySafe => false;