maxResultSizeChars property
int?
get
maxResultSizeChars
Maximum size in characters for tool results before disk persistence.
Implementation
int? get maxResultSizeChars => null;
Maximum size in characters for tool results before disk persistence.
int? get maxResultSizeChars => null;