prompt property
String
get
prompt
Detailed prompt text sent in the system prompt for this tool.
Implementation
String get prompt => description;
Detailed prompt text sent in the system prompt for this tool.
String get prompt => description;