ToolUseContext class

Context provided to tools during execution.

Constructors

ToolUseContext({required String cwd, bool debugMode = false, AbortSignal? abortSignal, void onProgress(String)?})
const

Properties

abortSignal AbortSignal?
final
cwd String
final
debugMode bool
final
hashCode int
The hash code for this object.
no setterinherited
onProgress → void Function(String)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited