ToolStats class

Aggregate statistics for a single tool.

Constructors

ToolStats({required String name, required ToolCategory category, required int executionCount, required double avgDurationMs, DateTime? lastExecutedAt, required bool enabled, required bool restricted})
const

Properties

avgDurationMs double
final
category ToolCategory
final
enabled bool
final
executionCount int
final
hashCode int
The hash code for this object.
no setterinherited
lastExecutedAt DateTime?
final
name String
final
restricted bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited