WebFetchOutput class

Web fetch output.

Constructors

WebFetchOutput({required int bytes, required int code, required String codeText, required String result, required int durationMs, required String url, String? persistedPath, int? persistedSize})
const

Properties

bytes int
final
code int
final
codeText String
final
durationMs int
final
hashCode int
The hash code for this object.
no setterinherited
persistedPath String?
final
persistedSize int?
final
result String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited