SearchResult class

A single search result.

Constructors

SearchResult({required String title, required String url, String? displayUrl, String? snippet})
const
SearchResult.fromJson(Map<String, dynamic> json)
factory

Properties

displayUrl String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snippet String?
final
title String
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited