WebSearchInput class
Web search input.
Constructors
-
WebSearchInput({required String query, List<
String> ? allowedDomains, List<String> ? blockedDomains}) -
const
-
WebSearchInput.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
allowedDomains
→ List<
String> ? -
final
-
blockedDomains
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- query → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited