SttLanguageResult class

Constructors

SttLanguageResult({required String code, String? fellBackFrom})
Creates an SttLanguageResult.
const

Properties

code String
The resolved BCP-47 language code.
final
fellBackFrom String?
If non-null, the original language string that could not be mapped to a supported code and was replaced with the default.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited