isFeatureEnabled property
bool
get
isFeatureEnabled
Whether the feature flag allows voice mode to be visible.
Implementation
bool get isFeatureEnabled => config.featureEnabled;
Whether the feature flag allows voice mode to be visible.
bool get isFeatureEnabled => config.featureEnabled;