featureEnabled property
Whether the feature flag allows voice mode to be shown / used. Replaces the GrowthBook kill-switch with a plain boolean.
Implementation
final bool featureEnabled;
Whether the feature flag allows voice mode to be shown / used. Replaces the GrowthBook kill-switch with a plain boolean.
final bool featureEnabled;