VoiceToggleError class

Voice mode could not be toggled.

Inheritance

Constructors

VoiceToggleError(String reason)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
reason String
Human-readable reason.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited