VoiceToggleSuccess class

Voice mode was successfully toggled.

Inheritance

Constructors

VoiceToggleSuccess({required bool enabled, required String message, SttLanguageResult? sttLanguage})
const

Properties

enabled bool
Whether voice mode is now enabled.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable status message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sttLanguage SttLanguageResult?
The resolved STT language (only present when enabled is true).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited