Command class

Full command definition — base + implementation.

Constructors

Command({required CommandBase base, required CommandType type, PromptCommand? promptCommand})
const

Properties

base CommandBase
final
description String
no setter
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
no setter
name String
no setter
promptCommand PromptCommand?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type CommandType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited