CommandBase class

Base command definition with metadata.

Constructors

CommandBase({required String name, required String description, List<String> aliases = const [], bool hidden = false, bool enabled = true, CommandAvailability availability = CommandAvailability.both, bool requiresMcp = false, String? version, bool sensitive = false})
const

Properties

aliases List<String>
final
availability CommandAvailability
final
description String
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
hidden bool
final
name String
final
requiresMcp bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensitive bool
final
version String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited