PromptCommand class

A prompt-based command configuration.

Constructors

PromptCommand({required String content, int? maxContentLength, List<String>? allowedTools, String? model, String? source, String? pluginName, bool fork = false})
const

Properties

allowedTools List<String>?
final
content String
final
fork bool
final
hashCode int
The hash code for this object.
no setterinherited
maxContentLength int?
final
model String?
final
pluginName String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited