HookEvent enum

Hook event types that can be registered.

Inheritance
Available extensions

Values

preToolUse → const HookEvent
postToolUse → const HookEvent
postToolUseFailure → const HookEvent
notification → const HookEvent
userPromptSubmit → const HookEvent
sessionStart → const HookEvent
sessionEnd → const HookEvent
stop → const HookEvent
stopFailure → const HookEvent
subagentStart → const HookEvent
subagentStop → const HookEvent
preCompact → const HookEvent
postCompact → const HookEvent
permissionRequest → const HookEvent
permissionDenied → const HookEvent
setup → const HookEvent
teammateIdle → const HookEvent
taskCreated → const HookEvent
taskCompleted → const HookEvent
elicitation → const HookEvent
elicitationResult → const HookEvent
configChange → const HookEvent
worktreeCreate → const HookEvent
worktreeRemove → const HookEvent
instructionsLoaded → const HookEvent
cwdChanged → const HookEvent
fileChanged → const HookEvent

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HookEvent>
A constant List of the values in this enum, in order of their declaration.