OutputStyleConfig class
Output style configuration.
Constructors
- OutputStyleConfig({required String name, required String description, required String prompt, required OutputStyleSource source, bool keepCodingInstructions = true})
-
const
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keepCodingInstructions → bool
-
final
- name → String
-
final
- prompt → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → OutputStyleSource
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited