SandboxFilesystemConfig class

Sandbox filesystem configuration.

Constructors

SandboxFilesystemConfig({List<String> readAllowPaths = const [], List<String> writeAllowPaths = const [], List<String> readDenyPaths = const [], List<String> writeDenyPaths = const []})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
readAllowPaths List<String>
final
readDenyPaths List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writeAllowPaths List<String>
final
writeDenyPaths List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited