SandboxSettings class

Overall sandbox settings.

Constructors

SandboxSettings({bool enabled = false, bool failIfUnavailable = false, bool autoAllowBashIfSandboxed = false, SandboxNetworkConfig? network, SandboxFilesystemConfig? filesystem, List<String> ignoredViolations = const []})
const

Properties

autoAllowBashIfSandboxed bool
final
enabled bool
final
failIfUnavailable bool
final
filesystem SandboxFilesystemConfig?
final
hashCode int
The hash code for this object.
no setterinherited
ignoredViolations List<String>
final
network SandboxNetworkConfig?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited