CliFlags class
All supported CLI flag definitions.
Constructors
- CliFlags()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
lookup(
String name) → CliFlagDef? - Lookup a flag by long or short name.
Constants
-
all
→ const List<
CliFlagDef>