EmbeddedConfig class

Configuration for embedded mode.

Constructors

EmbeddedConfig({required String parentApp, CommunicationChannel communicationChannel = CommunicationChannel.directCall, EmbeddedRestrictions restrictions = const EmbeddedRestrictions(), String? apiKey, String? model, String? systemPromptAddition})
const

Properties

apiKey → String?
API key (usually provided by parent app).
final
communicationChannel → CommunicationChannel
Communication channel to use.
final
hashCode → int
The hash code for this object.
no setterinherited
model → String?
Model override.
final
parentApp → String
Name of the parent application.
final
restrictions → EmbeddedRestrictions
Restrictions for the embedded session.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemPromptAddition → String?
System prompt additions from the parent app.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited