EmbeddedEntrypoint class
Embedded entrypoint — run inside another application.
Constructors
- EmbeddedEntrypoint()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attach(
EmbeddedConfig config) → EmbeddedSession - Attach to a host application and create an embedded session.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited