attach method
Attach to a host application and create an embedded session.
Implementation
EmbeddedSession attach(EmbeddedConfig config) {
return EmbeddedSession._(config);
}
Attach to a host application and create an embedded session.
EmbeddedSession attach(EmbeddedConfig config) {
return EmbeddedSession._(config);
}