EmbeddedRestrictions class
Restrictions applied in embedded mode.
Constructors
Properties
-
allowedTools
→ List<
String> -
Allowed tool names (empty = all).
final
- allowFileSystem → bool
-
Whether file system access is allowed.
final
- allowNetwork → bool
-
Whether network access is allowed.
final
- allowProcessSpawn → bool
-
Whether process spawning is allowed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxTokensPerRequest → int?
-
Maximum tokens per request.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited