EntryRouter class

Routes to the correct entrypoint based on arguments and environment.

Constructors

EntryRouter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

detect(List<String> args, Map<String, String> env) EntryMode
Detect the entry mode from command-line args and environment variables.
route(List<String> args, Map<String, String> env) Future<void>
Route to the appropriate entrypoint and run.