HeadlessConfig class

Configuration for headless mode.

Constructors

HeadlessConfig({required HeadlessInput input, HeadlessOutput output = const StdoutOutput(), HeadlessFormat format = HeadlessFormat.text, String? model, String? systemPrompt, List<String> allowedTools = const [], int? maxTokens})
const

Properties

allowedTools → List<String>
final
format → HeadlessFormat
final
hashCode → int
The hash code for this object.
no setterinherited
input → HeadlessInput
final
maxTokens → int?
final
model → String?
final
output → HeadlessOutput
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemPrompt → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited