HeadlessResult class

Result of a headless run.

Constructors

HeadlessResult({required String output, int inputTokens = 0, int outputTokens = 0, Duration duration = Duration.zero, bool success = true, String? error})
const

Properties

duration Duration
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
inputTokens int
final
output String
final
outputTokens int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited