McpServerEntrypoint class

MCP server entrypoint — runs Neomage as an MCP-compatible server.

Constructors

McpServerEntrypoint()

Properties

hashCode int
The hash code for this object.
no setterinherited
isRunning bool
Whether the server is currently running.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleRequest(Map<String, dynamic> request, McpEntrypointConfig config) Future<Map<String, dynamic>>
Handle a single MCP JSON-RPC request and produce a response.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serve(McpEntrypointConfig config, McpServerTransport transport) Future<void>
Start serving MCP requests using the given transport.
shutdown() → void
Stop the server.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited