SdkEntrypoint class

SDK entrypoint — programmatic access from Dart applications.

Constructors

SdkEntrypoint()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(SdkConfig config) SdkSession
Create a new SDK session with the given configuration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited