SdkSession class

An active SDK session — wraps an ongoing conversation.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isAborted → bool
Whether the session has been aborted.
no setter
isDisposed → bool
Whether the session has been disposed.
no setter
messages → Stream<Message>
Stream of messages as the conversation progresses.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

abort() → void
Abort the current request.
dispose() → void
Dispose the session, releasing all resources.
getHistory() → List<Message>
Get the full conversation history.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage(String text) → Future<Message>
Send a user message and receive assistant response(s).
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited