HookMatcher class

Hook matcher — pattern matching on tool names with associated hooks.

Constructors

HookMatcher({String? toolNamePattern, required List<HookConfig> hooks})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hooks List<HookConfig>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolNamePattern String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited