AggregatedHookResult class

Aggregated results from multiple hooks.

Constructors

AggregatedHookResult({required HookDecision decision, List<HookResult> results = const [], String? blockingMessage})
const

Properties

blockingMessage String?
final
decision HookDecision
final
hashCode int
The hash code for this object.
no setterinherited
results List<HookResult>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited