HookCallbackMatcher class
Matcher config for hook callbacks.
Constructors
- HookCallbackMatcher({String? toolName, RegExp? toolNamePattern})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolName → String?
-
final
- toolNamePattern → RegExp?
-
final
Methods
-
matches(
String name) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited