LogOption class

Session log option with metadata.

Constructors

LogOption({required String path, required DateTime created, required DateTime modified, int messageCount = 0, int? fileSize, String? title, String? summary, String? teamName, AgentId? agentId, List<String> tags = const []})
const

Properties

agentId → AgentId?
final
created → DateTime
final
fileSize → int?
final
hashCode → int
The hash code for this object.
no setterinherited
messageCount → int
final
modified → DateTime
final
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary → String?
final
tags → List<String>
final
teamName → String?
final
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited