PersistedWorktreeSession class

Worktree session state at session end.

Constructors

PersistedWorktreeSession({required String path, required String branch, SessionId? sessionId})
const

Properties

branch String
final
hashCode int
The hash code for this object.
no setterinherited
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited