TaskSummaryMessage class

Periodic fork-generated summary of agent activity.

Constructors

TaskSummaryMessage({required String summary, AgentId? agentId, required DateTime timestamp})
const

Properties

agentId → AgentId?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary → String
final
timestamp → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited