ImageBlock class
A base64-encoded image content block.
- Inheritance
-
- Object
- ContentBlock
- ImageBlock
Constructors
- ImageBlock({required String mediaType, required String base64Data})
-
const
Properties
- base64Data → String
-
Base64-encoded image data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mediaType → String
-
MIME type of the image (e.g., 'image/png').
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited