StopReason enum

Reason the model stopped generating output.

Inheritance
Available extensions

Values

endTurn → const StopReason

The model finished its response naturally.

maxTokens → const StopReason

The response was truncated due to token limits.

toolUse → const StopReason

The model invoked a tool and awaits the result.

stopSequence → const StopReason

A stop sequence was encountered.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StopReason>
A constant List of the values in this enum, in order of their declaration.