cacheCreationInputTokens property
Tokens used to create a new cache entry (Anthropic prompt caching).
Implementation
final int? cacheCreationInputTokens;
Tokens used to create a new cache entry (Anthropic prompt caching).
final int? cacheCreationInputTokens;