ToolResultBlock class

The result returned from a tool execution.

Inheritance

Constructors

ToolResultBlock({required String toolUseId, required String content, bool isError = false})
const

Properties

content → String
The textual output from the tool.
final
hashCode → int
The hash code for this object.
no setterinherited
isError → bool
Whether the tool execution resulted in an error.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolUseId → String
The ID of the tool call this result corresponds to.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited