fullText property
String
get
fullText
Returns all text parts joined as a single string.
Implementation
String get fullText => textParts.join('\n');
Returns all text parts joined as a single string.
String get fullText => textParts.join('\n');