AddRulesUpdate class
Adds new permission rules to the existing set.
- Inheritance
-
- Object
- PermissionUpdate
- AddRulesUpdate
Constructors
-
AddRulesUpdate({required List<
PermissionRule> rules, required PermissionUpdateDestination destination}) -
const
Properties
- destination → PermissionUpdateDestination
-
Where to persist the new rules.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
rules
→ List<
PermissionRule> -
The rules to add.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited