AdditionalWorkingDirectory class

Additional directory in permission scope.

Constructors

AdditionalWorkingDirectory({required String directory, required WorkingDirectorySource source})
const

Properties

directory String
The directory path.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source WorkingDirectorySource
How this directory was added.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited