ClassifierUsage class

Token usage from classifier API call.

Constructors

ClassifierUsage({required int inputTokens, required int outputTokens})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inputTokens int
Number of input tokens consumed by the classifier.
final
outputTokens int
Number of output tokens generated by the classifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited