ExternalPermissionMode enum

User-addressable permission modes.

Inheritance
Available extensions

Values

acceptEdits → const ExternalPermissionMode

Automatically accept file edits without prompting.

bypassPermissions → const ExternalPermissionMode

Skip all permission checks.

defaultMode → const ExternalPermissionMode

Standard interactive permission mode.

dontAsk → const ExternalPermissionMode

Suppress permission prompts and auto-allow.

plan → const ExternalPermissionMode

Plan-only mode: describe actions without executing.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ExternalPermissionMode>
A constant List of the values in this enum, in order of their declaration.