PermissionMode enum

Internal permission modes — superset of external modes.

Inheritance
Available extensions

Values

acceptEdits → const PermissionMode

Automatically accept file edits.

bypassPermissions → const PermissionMode

Skip all permission checks.

defaultMode → const PermissionMode

Standard interactive permission mode.

dontAsk → const PermissionMode

Suppress prompts and auto-allow.

plan → const PermissionMode

Plan-only mode.

auto → const PermissionMode

Automatic mode for background agents.

bubble → const PermissionMode

Bubble permission decisions up to the parent agent.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PermissionMode>
A constant List of the values in this enum, in order of their declaration.