LoadedPlugin class
A loaded plugin with resolved paths.
Constructors
- LoadedPlugin({required PluginManifest manifest, required String path, bool enabled = true})
-
const
Properties
- enabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- manifest → PluginManifest
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited