PluginActivationError class

Error during plugin activation planning.

Constructors

PluginActivationError({required String pluginId, required ActivationErrorType type, required String message})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
final
pluginId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → ActivationErrorType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited