PluginSetupStep class

A single step in a plugin's setup flow.

Constructors

PluginSetupStep({required SetupStepType type, required String label, bool required = true, Map<String, dynamic> config = const {}})
const

Properties

config Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SetupStepType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited