MessageNormalizerService class abstract

Abstract interface for normalizing provider-specific AI response formats into a unified NormalizedMessage.

Implementers

Constructors

MessageNormalizerService()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

normalize(Map<String, dynamic> providerResponse, String provider) NormalizedMessage
Normalizes a raw providerResponse map from the given provider into a NormalizedMessage.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited