HardwareProfiler class

Constructors

HardwareProfiler()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detect() Future<HardwareProfile>
Detects hardware specs. Works on all platforms (native + web). On web, values are estimated from browser APIs and isEstimated is true.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited