gitLogCmd top-level constant
String
const gitLogCmd
Shell command to get commit log for the branch.
Implementation
const String gitLogCmd = 'git log --no-decorate origin/HEAD...';
Shell command to get commit log for the branch.
const String gitLogCmd = 'git log --no-decorate origin/HEAD...';