planRejectionPrefix top-level constant

String const planRejectionPrefix

Implementation

const String planRejectionPrefix =
    'The agent proposed a plan that was rejected by the user. The user chose '
    'to stay in plan mode rather than proceed with implementation.\n\n'
    'Rejected plan:\n';