AppConnectionState class

Constructors

AppConnectionState({ConnectionStatus apiStatus = ConnectionStatus.disconnected, String? apiError, Map<String, McpServerState>? mcpServers, Map<String, IdeConnection>? ideConnections})

Properties

apiError ↔ String?
getter/setter pair
apiStatus ↔ ConnectionStatus
getter/setter pair
connectedIdes → List<String>
no setter
connectedMcpServers → List<String>
no setter
hashCode → int
The hash code for this object.
no setterinherited
ideConnections → Map<String, IdeConnection>
final
mcpServers → Map<String, McpServerState>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addIdeConnection(String name, IdeConnection connection) → void
addMcpServer(String name, McpServerState server) → void
getMcpServer(String name) → McpServerState?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeIdeConnection(String name) → void
removeMcpServer(String name) → void
setApiStatus(ConnectionStatus status, {String? error}) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited