ConnectionStatusChanged class

Inheritance

Constructors

ConnectionStatusChanged({required String service, required ConnectionStatus previousStatus, required ConnectionStatus newStatus})

Properties

hashCode int
The hash code for this object.
no setterinherited
newStatus ConnectionStatus
final
previousStatus ConnectionStatus
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service String
final
timestamp DateTime
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited