IdeConnection class

Constructors

IdeConnection({required String name, required String type, ConnectionStatus status = ConnectionStatus.disconnected, String? workspacePath, int? pid})

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → String
final
pid ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ ConnectionStatus
getter/setter pair
type → String
final
workspacePath ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited