McpServerState class

Constructors

McpServerState({required String name, required String uri, ConnectionStatus status = ConnectionStatus.disconnected, String? error, List<String>? tools, List<String>? resources, DateTime? connectedAt})

Properties

connectedAt DateTime?
getter/setter pair
error String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String
final
resources List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ConnectionStatus
getter/setter pair
tools List<String>
final
uri String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setConnected(List<String> availableTools, List<String> availableResources) → void
setDisconnected({String? reason}) → void
setError(String message) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited