NavigationState class

Constructors

Properties

final
currentView ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
history → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

canGoBack() → bool
canGoForward() → bool
goBack() → String?
goForward() → String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited