PermissionModeChanged class
- Inheritance
-
- Object
- StateEvent
- PermissionModeChanged
Constructors
- PermissionModeChanged({required PermissionMode previousMode, required PermissionMode newMode})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- newMode → PermissionMode
-
final
- previousMode → PermissionMode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited