ProviderChanged class
- Inheritance
-
- Object
- StateEvent
- ProviderChanged
Constructors
- ProviderChanged({required String previousProvider, required String newProvider})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- newProvider → String
-
final
- previousProvider → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited