onUserAction method
Record a user action so future suggestions can be context-aware.
Implementation
void onUserAction(UserAction action) {
_seenActions.add(action);
}
Record a user action so future suggestions can be context-aware.
void onUserAction(UserAction action) {
_seenActions.add(action);
}