BuddyState enum

Visual & logical state of the buddy avatar.

Inheritance
Available extensions

Values

idle → const BuddyState

No suggestion active — avatar is calm.

thinking → const BuddyState

Processing context to generate a suggestion.

suggesting → const BuddyState

A suggestion is being displayed.

helping → const BuddyState

Actively walking the user through something.

celebrating → const BuddyState

Celebrating a milestone (first commit, session complete, etc.).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BuddyState>
A constant List of the values in this enum, in order of their declaration.