BuddyWidget class
An animated buddy avatar with tooltip-style popup for contextual suggestions. Tap to dismiss the current suggestion; long-press for an options menu.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- BuddyWidget
Constructors
-
BuddyWidget({Key? key, required BuddyService service, Duration autoDismissDuration = const Duration(seconds: 8), VoidCallback? onDisabled, ValueChanged<
BuddyPersonality> ? onPersonalityChanged}) -
const
Properties
- autoDismissDuration → Duration
-
Duration before a suggestion auto-dismisses.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onDisabled → VoidCallback?
-
Called when the user disables the buddy from the long-press menu.
final
-
onPersonalityChanged
→ ValueChanged<
BuddyPersonality> ? -
Called when the user changes personality from the long-press menu.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service → BuddyService
-
The service that generates suggestions.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< BuddyWidget> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited