UserAction enum

User action events the buddy tracks to provide relevant tips.

Inheritance
Available extensions

Values

firstMessage → const UserAction
sentMessage → const UserAction
receivedError → const UserAction
usedTool → const UserAction
longSession → const UserAction
switchedModel → const UserAction
usedCommand → const UserAction
createdFile → const UserAction
ranTests → const UserAction
compacted → const UserAction

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<UserAction>
A constant List of the values in this enum, in order of their declaration.