hookExecutor property
HookExecutor
get
hookExecutor
Exposes the hook executor so callers can register custom hooks.
Implementation
HookExecutor get hookExecutor => _hookExecutor;
Exposes the hook executor so callers can register custom hooks.
HookExecutor get hookExecutor => _hookExecutor;