onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() {
super.onInit();
_hookExecutor = HookExecutor();
_telemetry = TelemetryService(config: TelemetryConfig.development());
_analytics.attachSink(InMemoryAnalyticsSink());
_commandRegistry = CommandRegistry();
_initializeIfConfigured();
}