KeybindingBlock class

A block of keybindings for a specific context (JSON config format).

Constructors

KeybindingBlock({required String context, required Map<String, String?> bindings})
const
KeybindingBlock.fromJson(Map<String, dynamic> json)
factory

Properties

bindings Map<String, String?>
final
context String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited