KeybindingWarning class

A warning or error about a keybinding configuration issue.

Constructors

KeybindingWarning({required KeybindingWarningType type, required ReservedSeverity severity, required String message, String? key, String? context, String? action, String? suggestion})
const

Properties

action String?
final
context String?
final
hashCode int
The hash code for this object.
no setterinherited
key String?
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity ReservedSeverity
final
suggestion String?
final
type KeybindingWarningType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited