ReservedShortcut class

A shortcut that is reserved by the OS, terminal, or application.

Constructors

ReservedShortcut({required String key, required String reason, required ReservedSeverity severity})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key String
final
reason String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity ReservedSeverity
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited