ParsedKeystroke class

A parsed keystroke.

Constructors

ParsedKeystroke({required String key, bool ctrl = false, bool alt = false, bool shift = false, bool meta = false, bool superKey = false})
const

Properties

alt bool
final
ctrl bool
final
hashCode int
The hash code for this object.
no setteroverride
key String
final
meta bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shift bool
final
superKey bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDisplayString({bool macOS = true}) String
Display string for the keystroke (platform-aware).
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override