SettingsController class

Inheritance

Constructors

SettingsController()

Properties

apiKeyController TextEditingController
final
autoCompactEnabled → RxBool
final
baseUrlController TextEditingController
final
changes → RxMap<String, dynamic>
final
defaultBaseUrl String
no setter
defaultModel String
no setter
diagnostics → RxList<Diagnostic>
final
fileCheckpointing → RxBool
final
hashCode int
The hash code for this object.
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDirty → RxBool
final
isDisposed bool
no setterinherited
isLoading → RxBool
final
isLoadingDiagnostics → RxBool
final
isLoadingUsage → RxBool
final
isSearchMode → RxBool
final
isTesting → RxBool
final
listenersLength int
no setterinherited
modelController TextEditingController
final
notificationsEnabled → RxBool
final
obscureKey → RxBool
final
reduceMotion → RxBool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchQuery → RxString
final
selectedProvider → Rx<ApiProviderType>
final
selectedTab → Rx<SettingsTab>
final
settingsItems List<SettingItem>
Get the list of configurable settings. Port of settingsItems array from Config.tsx.
no setter
showTips → RxBool
final
statusProperties List<StatusProperty>
Build status properties for display. Port of buildPrimarySection() + buildSecondarySection() from Status.tsx.
no setter
testError → Rxn<String>
final
testResult → Rxn<String>
final
thinkingEnabled → RxBool
final
usageError → Rxn<String>
final
utilization → Rxn<Utilization>
final
verboseMode → RxBool
final

Methods

addListener(SintStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, SintStateUpdate listener) → Disposer
inherited
containsListener(SintStateUpdate listener) bool
inherited
debounce<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void
Calls callback after rx stops changing for duration. Useful for search-as-you-type, form validation, etc.
inherited
dispose() → void
inherited
ever<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback every time rx changes. Auto-cancels on controller disposal.
inherited
interval<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void
Calls callback at most once per duration, ignoring intermediate changes. Useful for rate-limiting UI updates.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
once<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback only the first time rx changes, then cancels.
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
override
onDelete() → void
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
onStart() → void
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclasses. This method should be internal and is required to define the lifetime cycle of the subclass.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
refreshUsage() Future<void>
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
reportAdd(VoidCallback disposer) → void
inherited
reportRead() → void
inherited
saveProviderConfig() Future<void>
testConnection() Future<void>
Test the connection with the current provider settings. Sends a prompt asking the AI to introduce itself.
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Notifies listeners to update the UI.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited