NeomageTheme class

A complete Neomage theme containing colours, typography, component sizes, and syntax highlighting colours.

Constructors

NeomageTheme({required ThemeInfo info, required NeomageColorScheme colors, required NeomageTextTheme textTheme, required NeomageComponentTheme componentTheme, required SyntaxTheme syntaxTheme})
const
NeomageTheme.fromMap(Map<String, dynamic> m)
Reconstruct a NeomageTheme from a map produced by toMap.
factory

Properties

colors NeomageColorScheme
final
componentTheme NeomageComponentTheme
final
hashCode int
The hash code for this object.
no setterinherited
info ThemeInfo
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syntaxTheme SyntaxTheme
final
textTheme NeomageTextTheme
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serialise the entire theme to a map for export / persistence.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited