SyntaxTheme class

Colors used by the code syntax highlighter, customised per theme.

Constructors

SyntaxTheme({required Color keyword, required Color string, required Color comment, required Color number, required Color type, required Color function_, required Color variable, required Color operator_, required Color punctuation})
const
SyntaxTheme.fromMap(Map<String, dynamic> m)
factory

Properties

comment → Color
final
function_ → Color
final
hashCode → int
The hash code for this object.
no setterinherited
keyword → Color
final
number → Color
final
operator_ → Color
final
punctuation → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
string → Color
final
type → Color
final
variable → Color
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, int>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited