VimKeyHandler class

Constructors

VimKeyHandler({required VimState state, required List<String> lines, void onStatusMessage(String)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
lines List<String>
getter/setter pair
modified bool
no setter
onStatusMessage → void Function(String)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state VimState
final

Methods

handleKey(String key) bool
Main entry point — returns true if the key was consumed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited