VimRegister class

Constructors

VimRegister()

Properties

all Map<String, String>
no setter
hashCode int
The hash code for this object.
no setterinherited
lastYank String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
delete(String content) → void
get(String name) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paste(String? registerName) String
set(String name, String content) → void
toString() String
A string representation of this object.
inherited
yank(String content) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

alternateFile → const String
currentFile → const String
lastCommand → const String
lastInserted → const String
searchPattern → const String
selection → const String
smallDelete → const String
systemClipboard → const String
unnamed → const String