VimStatusLine class

Constructors

VimStatusLine({required VimState state, String fileName = '[No Name]', int totalLines = 0, bool modified = false})
const

Properties

fileName String
final
hashCode int
The hash code for this object.
no setterinherited
modified bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state VimState
final
totalLines int
final

Methods

format() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited