AgentDisplayInfo class

Agent info for display in the panel.

Constructors

AgentDisplayInfo({required String id, required String name, required String role, required String model, required AgentDisplayStatus status, String? currentTask, double? progress, Duration? elapsed, int tokensUsed = 0, double cost = 0.0, List<AgentLogEntry> logs = const [], List<TaskDisplayInfo> tasks = const []})
const

Properties

cost → double
final
currentTask → String?
final
elapsed → Duration?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
logs → List<AgentLogEntry>
final
model → String
final
name → String
final
progress → double?
final
role → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → AgentDisplayStatus
final
tasks → List<TaskDisplayInfo>
final
tokensUsed → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited