SwarmDisplayInfo class

Swarm overview data.

Constructors

SwarmDisplayInfo({required int totalAgents, required int activeAgents, required int completedTasks, required int totalTasks, required int failedTasks, required Duration elapsed, required double totalCost, required List<AgentDisplayInfo> agents, List<({String from, String to})> dependencies = const []})
const

Properties

activeAgents int
final
agents List<AgentDisplayInfo>
final
completedTasks int
final
completionRate double
no setter
dependencies List<({String from, String to})>
final
elapsed Duration
final
failedTasks int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalAgents int
final
totalCost double
final
totalTasks int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited