TaskDisplayInfo class

Task info for display.

Constructors

TaskDisplayInfo({required String id, required String name, required String status, double? progress, Duration? elapsed, String? result, List<String> dependencies = const []})
const

Properties

dependencies → List<String>
final
elapsed → Duration?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
name → String
final
progress → double?
final
result → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited