BackgroundTasksController class

Inheritance

Constructors

BackgroundTasksController()

Properties

agentTasks List<TaskListItem>
no setter
allSelectableItems List<TaskListItem>
no setter
bashTasks List<TaskListItem>
no setter
currentSelection TaskListItem?
no setter
detailTaskId → RxString
final
dreamTasks List<TaskListItem>
no setter
foregroundedTaskId → Rxn<String>
final
hashCode int
The hash code for this object.
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDisposed bool
no setterinherited
listenersLength int
no setterinherited
mcpMonitors List<TaskListItem>
no setter
remoteSessions List<TaskListItem>
no setter
runningAgentCount int
no setter
runningBashCount int
no setter
runningTeammateCount int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedIndex → RxInt
final
showSpinnerTree → RxBool
final
tasks → RxMap<String, BackgroundTaskState>
final
teammateTasks List<TaskListItem>
no setter
viewMode → RxString
final
workflowTasks List<TaskListItem>
no setter

Methods

addListener(SintStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, SintStateUpdate listener) → Disposer
inherited
containsListener(SintStateUpdate listener) bool
inherited
debounce<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void
Calls callback after rx stops changing for duration. Useful for search-as-you-type, form validation, etc.
inherited
dispose() → void
inherited
ever<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback every time rx changes. Auto-cancels on controller disposal.
inherited
goBackToList(VoidCallback onDismiss) → void
Go back to list, or close if we skipped list on mount.
interval<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void
Calls callback at most once per duration, ignoring intermediate changes. Useful for rate-limiting UI updates.
inherited
killTask(String taskId) Future<void>
Kill a task by ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
once<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback only the first time rx changes, then cancels.
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onDelete() → void
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
onStart() → void
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclasses. This method should be internal and is required to define the lifetime cycle of the subclass.
inherited
openCurrentDetail() → void
Open detail view for current selection.
openWithDetail(String taskId) → void
Open with a specific task detail view.
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
reportAdd(VoidCallback disposer) → void
inherited
reportRead() → void
inherited
selectNext() → void
Navigate selection down.
selectPrevious() → void
Navigate selection up.
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Notifies listeners to update the UI.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited