SelectController<T> class

Inheritance

Constructors

SelectController({required List<SelectOption<T>> options, T? defaultValue, int visibleOptionCount = 5, ValueChanged<T>? onChange, VoidCallback? onCancel, ValueChanged<T>? onFocus, T? defaultFocusValue, VoidCallback? onUpFromFirstItem, VoidCallback? onDownFromLastItem})

Properties

defaultFocusValue → T?
final
defaultValue → T?
final
focusedValue → Rxn<T>
final
hashCode int
The hash code for this object.
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
inputValues → RxMap<T, String>
final
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDisposed bool
no setterinherited
isInInput → RxBool
final
listenersLength int
no setterinherited
onCancel → VoidCallback?
final
onChange ValueChanged<T>?
final
onDownFromLastItem → VoidCallback?
final
onFocus ValueChanged<T>?
final
onUpFromFirstItem → VoidCallback?
final
optionMap OptionMap<T>
latefinal
options List<SelectOption<T>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedValue → Rxn<T>
final
showDownArrow bool
no setter
showUpArrow bool
no setter
visibleFromIndex → RxInt
final
visibleOptionCount int
final
visibleOptions List<_VisibleOption<T>>
Get the visible options for rendering.
no setter
visibleToIndex → RxInt
final

Methods

addListener(SintStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, SintStateUpdate listener) → Disposer
inherited
containsListener(SintStateUpdate listener) bool
inherited
debounce<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void
Calls callback after rx stops changing for duration. Useful for search-as-you-type, form validation, etc.
inherited
dispose() → void
inherited
ever<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback every time rx changes. Auto-cancels on controller disposal.
inherited
focusNextOption() → void
Focus next option and scroll down if needed. Port of focus-next-option action from use-select-navigation.ts reducer.
focusNextPage() → void
Focus next page (jump by visibleOptionCount). Port of focus-next-page action from use-select-navigation.ts reducer.
focusOption(T? value) → void
Focus a specific option by value.
focusPreviousOption() → void
Focus previous option and scroll up if needed. Port of focus-previous-option action from use-select-navigation.ts reducer.
focusPreviousPage() → void
Focus previous page. Port of focus-previous-page action from use-select-navigation.ts reducer.
interval<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void
Calls callback at most once per duration, ignoring intermediate changes. Useful for rate-limiting UI updates.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
once<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback only the first time rx changes, then cancels.
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onDelete() → void
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
onStart() → void
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclasses. This method should be internal and is required to define the lifetime cycle of the subclass.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
reportAdd(VoidCallback disposer) → void
inherited
reportRead() → void
inherited
selectFocusedOption() → void
Select the currently focused option.
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Notifies listeners to update the UI.
inherited
updateInputValue(T optionValue, String text) → void
Update an input option's value.

Operators

operator ==(Object other) bool
The equality operator.
inherited