SelectOption<T> class

An option in the select list.

Constructors

SelectOption({String? description, bool dimDescription = false, required Widget label, required T value, bool disabled = false, SelectOptionType type = SelectOptionType.text, ValueChanged<String>? onInputChange, String? placeholder, String? initialValue, bool allowEmptySubmitToCancel = false, bool showLabelWithValue = false, String labelValueSeparator = ', ', bool resetCursorOnUpdate = false})
const

Properties

allowEmptySubmitToCancel bool
final
description String?
final
dimDescription bool
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
initialValue String?
final
label Widget
final
labelValueSeparator String
final
onInputChange ValueChanged<String>?
final
placeholder String?
final
resetCursorOnUpdate bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showLabelWithValue bool
final
type SelectOptionType
final
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited