NeomageTextField class

Styled text field with label, hint, and error support.

Inheritance

Constructors

NeomageTextField({Key? key, TextEditingController? controller, FocusNode? focusNode, String? label, String? hint, String? errorText, int? maxLines = 1, int? minLines, bool obscureText = false, bool readOnly = false, IconData? prefixIcon, Widget? suffix, ValueChanged<String>? onChanged, ValueChanged<String>? onSubmitted, TextInputType? keyboardType})
const

Properties

controller → TextEditingController?
final
errorText → String?
final
focusNode → FocusNode?
final
hashCode → int
The hash code for this object.
no setterinherited
hint → String?
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardType → TextInputType?
final
label → String?
final
maxLines → int?
final
minLines → int?
final
obscureText → bool
final
onChanged → ValueChanged<String>?
final
onSubmitted → ValueChanged<String>?
final
prefixIcon → IconData?
final
readOnly → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffix → Widget?
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited