DiffHunk class

A parsed diff hunk.

Constructors

DiffHunk({required int oldStart, required int oldLines, required int newStart, required int newLines, required List<DiffLine> lines})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
lines List<DiffLine>
final
newLines int
final
newStart int
final
oldLines int
final
oldStart int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited