DiffLine class

A single diff line.

Constructors

DiffLine({required DiffLineType type, required String content, int? oldLineNumber, int? newLineNumber})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
newLineNumber int?
final
oldLineNumber int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type DiffLineType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited