DebouncedDigitInput class

Constructors

DebouncedDigitInput({required bool isValidDigit(String), required void onDigit(String), Duration debounceDelay = const Duration(milliseconds: 500), bool once = false})

Properties

debounceDelay Duration
final
hashCode int
The hash code for this object.
no setterinherited
isValidDigit bool Function(String)
final
once bool
final
onDigit → void Function(String)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
handleInput(String char) → void
Call when user types a character.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited