LogLevel enum

Severity levels for log entries, ordered from least to most severe.

Inheritance
Available extensions

Values

trace → const LogLevel
debug → const LogLevel
info → const LogLevel
warn → const LogLevel
error → const LogLevel
fatal → const LogLevel

Properties

color Color
no setter
hashCode int
The hash code for this object.
no setterinherited
icon IconData
no setter
index int
A numeric identifier for the enumerated value.
no setterinherited
label String
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LogLevel>
A constant List of the values in this enum, in order of their declaration.