LogService class

Singleton service that manages log collection, buffering, and export.

Properties

buffer → LogBuffer
no setter
countsByLevel → Map<LogLevel, int>
no setter
entries → List<LogEntry>
no setter
hashCode → int
The hash code for this object.
no setterinherited
knownSources → Set<String>
no setter
logStream → Stream<LogEntry>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addLog({required LogLevel level, required String source, required String message, String? stackTrace, Map<String, String>? metadata}) → void
clearLogs() → void
dispose() → void
exportLogs() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → LogService
final