MarkdownTheme class
Colour and style configuration for markdown rendering.
Constructors
- MarkdownTheme({Color headingColor = Colors.white, Color bodyColor = const Color(0xFFD4D4D4), Color codeBackground = const Color(0xFF1E1E1E), Color codeColor = const Color(0xFFCE9178), Color inlineCodeBackground = const Color(0xFF2D2D2D), Color inlineCodeColor = const Color(0xFFCE9178), Color linkColor = const Color(0xFF4FC3F7), Color blockquoteBorder = const Color(0xFF616161), Color blockquoteBackground = const Color(0xFF1A1A1A), Color tableBorder = const Color(0xFF424242), Color tableHeaderBackground = const Color(0xFF2D2D2D), Color hrColor = const Color(0xFF424242), Color noteColor = const Color(0xFF4FC3F7), Color warningColor = const Color(0xFFFFB74D), Color tipColor = const Color(0xFF81C784), Color cautionColor = const Color(0xFFE57373), Color importantColor = const Color(0xFFBA68C8)})
-
const
Properties
- blockquoteBackground → Color
-
final
- blockquoteBorder → Color
-
final
- bodyColor → Color
-
final
- cautionColor → Color
-
final
- codeBackground → Color
-
final
- codeColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headingColor → Color
-
final
- hrColor → Color
-
final
- importantColor → Color
-
final
- inlineCodeBackground → Color
-
final
- inlineCodeColor → Color
-
final
- linkColor → Color
-
final
- noteColor → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableBorder → Color
-
final
- tableHeaderBackground → Color
-
final
- tipColor → Color
-
final
- warningColor → Color
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited