ElicitationField class

Elicitation field from an MCP server.

Constructors

ElicitationField({required String name, required String type, String? description, String? defaultValue, List<String>? enumValues, bool required = false})
const

Properties

defaultValue String?
final
description String?
final
enumValues List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited