ElicitationRequest class

Elicitation request from an MCP server.

Constructors

ElicitationRequest({required String serverId, required String serverName, String? message, required List<ElicitationField> fields, required String requestId})
const

Properties

fields List<ElicitationField>
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverId String
final
serverName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited