McpServerCapabilities class

MCP server capability flags.

Constructors

McpServerCapabilities({bool hasTools = false, bool hasResources = false, bool hasPrompts = false, bool hasLogging = false, bool hasCompletion = false})
const

Properties

hasCompletion bool
final
hashCode int
The hash code for this object.
no setterinherited
hasLogging bool
final
hasPrompts bool
final
hasResources bool
final
hasTools bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited