McpToolViewsController class

Inheritance

Constructors

McpToolViewsController()

Properties

filteredTools List<McpToolInfo>
Filtered tools based on search query.
no setter
hashCode int
The hash code for this object.
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDisposed bool
no setterinherited
listenersLength int
no setterinherited
pendingElicitations → RxList<ElicitationRequest>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchQuery → RxString
final
selectedServer McpServerInfo?
no setter
selectedServerId → Rxn<String>
final
selectedTool McpToolInfo?
no setter
selectedToolIndex → RxInt
final
selectedToolName → Rxn<String>
final
servers → RxMap<String, McpServerInfo>
final

Methods

addListener(SintStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, SintStateUpdate listener) → Disposer
inherited
clearToolSelection() → void
Clear tool selection (back to list).
containsListener(SintStateUpdate listener) bool
inherited
debounce<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void
Calls callback after rx stops changing for duration. Useful for search-as-you-type, form validation, etc.
inherited
declineElicitation(String requestId) → void
Decline an elicitation request.
dispose() → void
inherited
ever<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback every time rx changes. Auto-cancels on controller disposal.
inherited
interval<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void
Calls callback at most once per duration, ignoring intermediate changes. Useful for rate-limiting UI updates.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
once<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback only the first time rx changes, then cancels.
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onDelete() → void
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
onStart() → void
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclasses. This method should be internal and is required to define the lifetime cycle of the subclass.
inherited
reconnectServer(String serverId) Future<void>
Attempt to reconnect a disconnected server.
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
reportAdd(VoidCallback disposer) → void
inherited
reportRead() → void
inherited
respondToElicitation(String requestId, Map<String, String> values) → void
Respond to an elicitation request.
selectNextTool() → void
Navigate tool selection down.
selectPreviousTool() → void
Navigate tool selection up.
selectServer(String serverId) → void
Select a server by ID.
selectTool(String toolName) → void
Select a tool by name.
toggleToolEnabled(String serverName, String toolName) → void
Toggle a tool's enabled state.
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Notifies listeners to update the UI.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited