MemoryFileInfo class

Constructors

MemoryFileInfo({required String path, required String type, String content = '', bool exists = true, String? parent, bool isNested = false})
const

Properties

content String
final
exists bool
final
hashCode int
The hash code for this object.
no setterinherited
isNested bool
final
parent String?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited