MemoryPanelController class
Methods
-
addListener(SintStateUpdate listener)
→ Disposer
-
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(Object? key, SintStateUpdate listener)
→ Disposer
-
inherited
-
containsListener(SintStateUpdate listener)
→ bool
-
inherited
-
debounce<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)})
→ void
-
Calls
callback after rx stops changing for duration.
Useful for search-as-you-type, form validation, etc.
inherited
-
deleteMemoryFileByName(String filename)
→ Future<bool>
-
Delete a memory file by filename.
-
dispose()
→ void
-
inherited
-
enterToggleMode()
→ void
-
Enter toggle mode from the select list.
-
ever<T>(RxInterface<T> rx, void callback(T))
→ void
-
Calls
callback every time rx changes.
Auto-cancels on controller disposal.
inherited
-
focusNextToggle()
→ void
-
Move toggle focus to next.
-
focusPreviousToggle()
→ void
-
Move toggle focus to previous.
-
handleSelect(String value)
→ void
-
Handle selecting a memory file or folder.
-
handleToggleConfirm()
→ void
-
Handle toggle focus (for keyboard navigation between toggles).
-
interval<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)})
→ void
-
Calls
callback at most once per duration, ignoring
intermediate changes. Useful for rate-limiting UI updates.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
once<T>(RxInterface<T> rx, void callback(T))
→ void
-
Calls
callback only the first time rx changes, then cancels.
inherited
-
onClose()
→ void
-
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
-
onDelete()
→ void
-
inherited
-
onInit()
→ void
-
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
override
-
onReady()
→ void
-
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
onStart()
→ void
-
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclasses.
This method should be internal and is required to define the
lifetime cycle of the subclass.
inherited
-
readMemoryFileContent(String filePath)
→ Future<String?>
-
Read a specific memory file's content.
-
refresh()
→ void
-
inherited
-
refreshGroup(Object id)
→ void
-
inherited
-
refreshMemories()
→ Future<void>
-
Refresh memory data from disk.
-
removeListener(VoidCallback listener)
→ void
-
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(Object id, VoidCallback listener)
→ void
-
inherited
-
reportAdd(VoidCallback disposer)
→ void
-
inherited
-
reportRead()
→ void
-
inherited
-
toggleAutoDream()
→ void
-
Toggle auto-dream on/off.
-
toggleAutoMemory()
→ void
-
Toggle auto-memory on/off.
-
toString()
→ String
-
A string representation of this object.
inherited
-
update([List<Object>? ids, bool condition = true])
→ void
-
Notifies listeners to update the UI.
inherited