Plan class

Top-level plan model.

Constructors

Plan({required String title, required List<PlanPhase> phases, DateTime? createdAt, Duration? estimatedDuration})

Properties

completedSteps → int
no setter
createdAt → DateTime
final
estimatedDuration → Duration?
final
estimatedTimeRemaining → Duration?
no setter
hashCode → int
The hash code for this object.
no setterinherited
overallProgress → double
no setter
phases → List<PlanPhase>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final
totalSteps → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited