PlanStep class

A single step in the plan, possibly with substeps and dependencies.

Constructors

PlanStep({required String id, required String title, String description = '', PlanStepStatus status = PlanStepStatus.pending, List<PlanStep>? substeps, List<String>? dependencies})

Properties

dependencies → List<String>
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
isTerminal → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ PlanStepStatus
getter/setter pair
substeps → List<PlanStep>
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited