FsReadConfig class

Filesystem read restriction config — mirrors TS sandbox adapter.

Constructors

FsReadConfig({List<String> denyOnly = const [], List<String> allowWithinDeny = const []})
const

Properties

allowWithinDeny List<String>
final
denyOnly List<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited