FsWriteConfig class

Filesystem write restriction config.

Constructors

FsWriteConfig({List<String> allowOnly = const [], List<String> denyWithinAllow = const []})
const

Properties

allowOnly → List<String>
final
denyWithinAllow → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited