OverrideMode enum
Override mode for unsandboxed fallback — mirrors TS OverrideMode.
Values
- open → const OverrideMode
-
const OverrideMode('open') - closed → const OverrideMode
-
const OverrideMode('closed')
Properties
- confirmationMessage → String
-
no setter
- description → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- label → String
-
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
OverrideMode> - A constant List of the values in this enum, in order of their declaration.