description property

String get description

Implementation

String get description {
  switch (this) {
    case OverrideMode.open:
      return 'When a command fails due to sandbox restrictions, Neomage can retry '
          'with dangerouslyDisableSandbox to run outside the sandbox (falling '
          'back to default permissions).';
    case OverrideMode.closed:
      return 'All bash commands invoked by the model must run in the sandbox '
          'unless they are explicitly listed in excludedCommands.';
  }
}