SandboxManagerAdapter class
Stub sandbox adapter — in production these would delegate to the actual
sandbox runtime. Mirrors the TS SandboxManager static API.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
areSandboxSettingsLockedByPolicy(
) → bool -
areUnsandboxedCommandsAllowed(
) → bool -
checkDependencies(
) → SandboxDependencyCheck -
getConfigSnapshot(
) → SandboxConfigSnapshot -
getCurrentMode(
) → SandboxMode -
isAutoAllowBashIfSandboxedEnabled(
) → bool -
isSandboxEnabledInSettings(
) → bool -
isSandboxingEnabled(
) → bool -
isSupportedPlatform(
) → bool -
setAllowUnsandboxedCommands(
bool allow) → Future< void> -
setSandboxMode(
SandboxMode mode) → Future< void>