SandboxTab enum
Tabs for the sandbox settings dialog — mirrors TS Tabs children.
Values
- mode → const SandboxTab
-
const SandboxTab('Mode') - overrides → const SandboxTab
-
const SandboxTab('Overrides') - config → const SandboxTab
-
const SandboxTab('Config') - dependencies → const SandboxTab
-
const SandboxTab('Dependencies')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SandboxTab> - A constant List of the values in this enum, in order of their declaration.