MemoryFileInfo class

Information about a memory file (NEOMAGE.md etc.).

Constructors

MemoryFileInfo({required String path, required String content})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
isLarge bool
Whether the file exceeds the size threshold.
no setter
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited