SlowOperationTracker class

Global slow operation tracker.

Properties

hashCode int
The hash code for this object.
no setterinherited
operations List<SlowOperation>
All recorded slow operations.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thresholdMs int
Current threshold.
getter/setter pair

Methods

addSlowOperation(String description, double durationMs) → void
Record a slow operation.
clear() → void
Clear all recorded operations.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recent([int count = 10]) List<SlowOperation>
Get recent operations (last N).
toString() String
A string representation of this object.
inherited
track(String description) SlowOperationTimer
Create a timer for tracking a potentially slow operation.

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SlowOperationTracker
final