evaluateNotices method
Evaluate notices against the given context and update state.
Implementation
void evaluateNotices(StatusNoticeContext context) {
activeNotices.value = getActiveNotices(context);
}
Evaluate notices against the given context and update state.
void evaluateNotices(StatusNoticeContext context) {
activeNotices.value = getActiveNotices(context);
}