StatusNoticeDefinition class

A definition of a status notice.

Constructors

StatusNoticeDefinition({required String id, required StatusNoticeType type, required bool isActive(StatusNoticeContext), required Widget render(StatusNoticeContext, BuildContext)})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
isActive bool Function(StatusNoticeContext)
final
render Widget Function(StatusNoticeContext, BuildContext)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type StatusNoticeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited