HighlightTokenType enum

Token types for syntax coloring.

Inheritance
Available extensions

Values

plain → const HighlightTokenType
keyword → const HighlightTokenType
string → const HighlightTokenType
comment → const HighlightTokenType
number → const HighlightTokenType
operator → const HighlightTokenType
punctuation → const HighlightTokenType
type → const HighlightTokenType
function_ → const HighlightTokenType
variable → const HighlightTokenType
constant → const HighlightTokenType
annotation → const HighlightTokenType
tag → const HighlightTokenType
attribute → const HighlightTokenType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HighlightTokenType>
A constant List of the values in this enum, in order of their declaration.