SyntaxColors class
Syntax highlight color theme.
Constructors
- SyntaxColors({Color plain = const Color(0xFFD4D4D4), Color keyword = const Color(0xFFC586C0), Color string = const Color(0xFFCE9178), Color comment = const Color(0xFF6A9955), Color number = const Color(0xFFB5CEA8), Color operator_ = const Color(0xFFD4D4D4), Color punctuation = const Color(0xFF808080), Color type = const Color(0xFF4EC9B0), Color function_ = const Color(0xFFDCDCAA), Color variable = const Color(0xFF9CDCFE), Color constant = const Color(0xFF4FC1FF), Color annotation = const Color(0xFFD7BA7D), Color tag = const Color(0xFF569CD6), Color attribute = const Color(0xFF9CDCFE)})
-
const
- SyntaxColors.light()
-
factory
Properties
- annotation → Color
-
final
- attribute → Color
-
final
- comment → Color
-
final
- constant → Color
-
final
- function_ → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyword → Color
-
final
- number → Color
-
final
- operator_ → Color
-
final
- plain → Color
-
final
- punctuation → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- string → Color
-
final
- tag → Color
-
final
- type → Color
-
final
- variable → Color
-
final
Methods
-
colorFor(
HighlightTokenType type) → Color -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited