onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() {
super.onInit();
_updateElapsed();
if (agent.status == TaskStatus.running) {
_elapsedTimer = Timer.periodic(
const Duration(seconds: 1),
(_) => _updateElapsed(),
);
}
}