ToolActivity class

Describes a tool use activity for display in task detail views.

Constructors

ToolActivity({required String toolName, Map<String, dynamic> input = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
input Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited