shouldHideTasksFooter function

bool shouldHideTasksFooter(
  1. Map<String, BackgroundTaskState> tasks,
  2. bool showSpinnerTree
)

Returns true when BackgroundTaskStatus would render nothing because the spinner tree is active and every visible background task is an in-process teammate. Port of shouldHideTasksFooter() from taskStatusUtils.tsx.

Implementation

bool shouldHideTasksFooter(
  Map<String, BackgroundTaskState> tasks,
  bool showSpinnerTree,
) {
  if (!showSpinnerTree) return false;
  bool hasVisibleTask = false;
  for (final t in tasks.values) {
    hasVisibleTask = true;
    if (t.type != BackgroundTaskType.inProcessTeammate) return false;
  }
  return hasVisibleTask;
}