PermissionMode enum

Inheritance
Available extensions

Values

defaultMode → const PermissionMode
plan → const PermissionMode
autoEdit → const PermissionMode
fullAutoMode → const PermissionMode
bypassPermissions → const PermissionMode

Properties

color Color

Available on PermissionMode, provided by the PermissionModeExt extension

no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
next PermissionMode

Available on PermissionMode, provided by the PermissionModeExt extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String

Available on PermissionMode, provided by the PermissionModeExt extension

no setter
title String

Available on PermissionMode, provided by the PermissionModeExt extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PermissionMode>
A constant List of the values in this enum, in order of their declaration.