TeamTask class

Task assigned to a teammate.

Constructors

TeamTask({required String id, required String title, String? owner, String status = 'pending'})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
final
owner → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final
title → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited