BundleUploadSuccess class

Inheritance

Constructors

BundleUploadSuccess({required String fileId, required int bundleSizeBytes, required BundleScope scope, required bool hasWip})
const

Properties

bundleSizeBytes → int
final
fileId → String
final
hashCode → int
The hash code for this object.
no setterinherited
hasWip → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → BundleScope
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited