CodeSession class

A code session (simplified view for lists).

Constructors

CodeSession({required String id, required String title, required String description, required String status, String? repoName, String? repoOwner, String? defaultBranch, required String createdAt, required String updatedAt})
const
CodeSession.fromSessionResource(SessionResource session)
factory

Properties

createdAt → String
final
defaultBranch → String?
final
description → String
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
repoName → String?
final
repoOwner → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
final
title → String
final
updatedAt → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited