EnvironmentSelectionInfo class

Information about environment selection.

Constructors

EnvironmentSelectionInfo({required List<EnvironmentResource> availableEnvironments, EnvironmentResource? selectedEnvironment, String? selectedEnvironmentSource})
const

Properties

availableEnvironments List<EnvironmentResource>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedEnvironment EnvironmentResource?
final
selectedEnvironmentSource String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited