GitSource class

Inheritance

Constructors

GitSource({required String url, String? revision, bool allowUnrestrictedGitPush = false})
const
GitSource.fromJson(Map<String, dynamic> json)
factory

Properties

allowUnrestrictedGitPush → bool
final
hashCode → int
The hash code for this object.
no setterinherited
revision → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited