RepoValidationResult class

Result of repo validation for teleport.

Constructors

RepoValidationResult({required RepoValidationStatus status, String? sessionRepo, String? currentRepo, String? sessionHost, String? currentHost, String? errorMessage})
const

Properties

currentHost String?
final
currentRepo String?
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionHost String?
final
sessionRepo String?
final
status RepoValidationStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited