SessionContext class

Session context containing sources, cwd, and outcomes.

Constructors

SessionContext({required List<SessionContextSource> sources, required String cwd, List<GitRepositoryOutcome>? outcomes, String? customSystemPrompt, String? appendSystemPrompt, String? model, String? seedBundleFileId})
const
SessionContext.fromJson(Map<String, dynamic> json)
factory

Properties

appendSystemPrompt → String?
final
customSystemPrompt → String?
final
cwd → String
final
hashCode → int
The hash code for this object.
no setterinherited
model → String?
final
outcomes → List<GitRepositoryOutcome>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seedBundleFileId → String?
final
sources → List<SessionContextSource>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited