AnsiStyle class

ANSI SGR (Select Graphic Rendition) attributes.

Constructors

AnsiStyle({Color? foreground, Color? background, bool bold = false, bool italic = false, bool underline = false, bool strikethrough = false, bool dim = false, bool inverse = false})
const

Properties

background Color?
final
bold bool
final
dim bool
final
foreground Color?
final
hashCode int
The hash code for this object.
no setterinherited
inverse bool
final
italic bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strikethrough bool
final
underline bool
final

Methods

copyWith({Color? foreground, Color? background, bool? bold, bool? italic, bool? underline, bool? strikethrough, bool? dim, bool? inverse}) AnsiStyle
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

reset → const AnsiStyle