TerminalBuffer class

Manages terminal output buffer with scrollback limit.

Constructors

TerminalBuffer({int maxLines = 10000})

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
no setter
lines List<TerminalLine>
no setter
maxLines int
final
onLineAdded Stream<TerminalLine>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addCommand(String command) → void
addLine(String text, {TerminalLineType type = TerminalLineType.stdout}) → void
addLines(String text, {TerminalLineType type = TerminalLineType.stdout}) → void
addSeparator() → void
addSystem(String message) → void
clear() → void
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPlainText() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited