TrustDialogController class

Inheritance

Constructors

TrustDialogController()

Properties

apiKeyHelperSources → RxList<TrustSettingSource>
final
awsCommandsSources → RxList<TrustSettingSource>
final
bashPermissionSources → RxList<TrustSettingSource>
final
concerns List<TrustConcernItem>
The list of security concern descriptions to show.
no setter
dangerousEnvVarsSources → RxList<TrustSettingSource>
final
gcpCommandsSources → RxList<TrustSettingSource>
final
hasAnyBashExecution bool
no setter
hasAnyConcern bool
no setter
hasApiKeyHelper bool
no setter
hasAwsCommands bool
no setter
hasBashPermission bool
no setter
hasDangerousEnvVars bool
no setter
hasGcpCommands bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasHooks bool
no setter
hasMcpServers bool
no setter
hasOtelHeaders bool
no setter
hasSkillsBash → RxBool
final
hasSlashCommandBash → RxBool
final
hasTrustAccepted → RxBool
final
hooksSources → RxList<TrustSettingSource>
final
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isDisposed bool
no setterinherited
isHomeDir → RxBool
final
listenersLength int
no setterinherited
mcpServerNames → RxList<String>
final
otelHeadersSources → RxList<TrustSettingSource>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept() → void
Accept trust and proceed.
addListener(SintStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, SintStateUpdate listener) → Disposer
inherited
containsListener(SintStateUpdate listener) bool
inherited
debounce<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void
Calls callback after rx stops changing for duration. Useful for search-as-you-type, form validation, etc.
inherited
dispose() → void
inherited
ever<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback every time rx changes. Auto-cancels on controller disposal.
inherited
interval<T>(RxInterface<T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void
Calls callback at most once per duration, ignoring intermediate changes. Useful for rate-limiting UI updates.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
once<T>(RxInterface<T> rx, void callback(T)) → void
Calls callback only the first time rx changes, then cancels.
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onDelete() → void
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
override
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
onStart() → void
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclasses. This method should be internal and is required to define the lifetime cycle of the subclass.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
reportAdd(VoidCallback disposer) → void
inherited
reportRead() → void
inherited
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Notifies listeners to update the UI.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited