ApiUsage class

API usage from last response.

Constructors

ApiUsage({required int inputTokens, required int outputTokens, required int cacheCreationInputTokens, required int cacheReadInputTokens})
const
ApiUsage.fromJson(Map<String, dynamic> json)
factory

Properties

cacheCreationInputTokens int
final
cacheReadInputTokens int
final
hashCode int
The hash code for this object.
no setterinherited
inputTokens int
final
outputTokens int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited