McpTool class

Information about an MCP tool in context.

Constructors

McpTool({required String name, required String serverName, required int tokens, bool isLoaded = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isLoaded bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverName String
final
tokens int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited