SkillInfo class

Information about skills included in the context window.

Constructors

SkillInfo({required int totalSkills, required int includedSkills, required int tokens, required List<SkillFrontmatter> skillFrontmatter})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
includedSkills int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skillFrontmatter List<SkillFrontmatter>
final
tokens int
final
totalSkills int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited