BudgetUsdAttachment class
Budget (USD) attachment.
- Inheritance
-
- Object
- Attachment
- BudgetUsdAttachment
Constructors
- BudgetUsdAttachment({required double used, required double total, required double remaining})
Properties
Methods
-
normalizeForAPI(
) → List< UserMessage> -
Normalize this attachment into user messages for the API.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited