DiagnosticsAttachment class

Diagnostics attachment (LSP or other diagnostic files).

Inheritance

Constructors

DiagnosticsAttachment({required List<Map<String, dynamic>> files, bool isNew = false})

Properties

files → List<Map<String, dynamic>>
final
hashCode → int
The hash code for this object.
no setterinherited
isNew → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setteroverride

Methods

normalizeForAPI() → List<UserMessage>
Normalize this attachment into user messages for the API.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited