EditedTextFileAttachment class

Edited text file attachment.

Inheritance

Constructors

EditedTextFileAttachment({required String filename, required String snippet})

Properties

filename → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet → String
final
type → String
no setteroverride

Methods

normalizeForAPI() → List<UserMessage>
Normalize this attachment into user messages for the API.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited