FileAttachment class
File attachment (user at-mentioned a file).
- Inheritance
-
- Object
- Attachment
- FileAttachment
Constructors
- FileAttachment({required String filename, required String content, bool truncated = false, required String displayPath})
Properties
Methods
-
normalizeForAPI(
) → List< UserMessage> -
Normalize this attachment into user messages for the API.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited