HookAttachment class abstract

Hook attachment base.

Inheritance
Implementers

Constructors

HookAttachment()

Properties

hashCode → int
The hash code for this object.
no setterinherited
hookEvent → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolUseID → String
no setter
type → String
no setterinherited

Methods

normalizeForAPI() → List<UserMessage>
Normalize this attachment into user messages for the API.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited