McpResourceAttachment class

MCP resource attachment.

Inheritance

Constructors

McpResourceAttachment({required String server, required String uri, required String name, String? description, required Map<String, dynamic> content})

Properties

content Map<String, dynamic>
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
server String
final
type String
no setteroverride
uri String
final

Methods

normalizeForAPI() List<UserMessage>
Normalize this attachment into user messages for the API.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited