normalizeForAPI method
Normalize this attachment into user messages for the API.
Implementation
@override
List<UserMessage> normalizeForAPI() => [];
Normalize this attachment into user messages for the API.
@override
List<UserMessage> normalizeForAPI() => [];