PDFReferenceAttachment class

PDF reference attachment.

Inheritance

Constructors

PDFReferenceAttachment({required String filename, required int pageCount, required int fileSize, required String displayPath})

Properties

displayPath → String
final
filename → String
final
fileSize → int
final
hashCode → int
The hash code for this object.
no setterinherited
pageCount → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setteroverride

Methods

normalizeForAPI() → List<UserMessage>
Normalize this attachment into user messages for the API.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited