PlanModeAttachment class

Plan mode attachment.

Inheritance

Constructors

PlanModeAttachment({required String reminderType, bool isSubAgent = false, required String planFilePath, required bool planExists})

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSubAgent → bool
final
planExists → bool
final
planFilePath → String
final
reminderType → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setteroverride

Methods

normalizeForAPI() → List<UserMessage>
Normalize this attachment into user messages for the API.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited