SelectedLinesInIdeAttachment class

IDE selection attachment (lines selected in an IDE).

Inheritance

Constructors

SelectedLinesInIdeAttachment({required String ideName, required int lineStart, required int lineEnd, required String filename, required String content, required String displayPath})

Properties

content String
final
displayPath String
final
filename String
final
hashCode int
The hash code for this object.
no setterinherited
ideName String
final
lineEnd int
final
lineStart int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
no setteroverride

Methods

normalizeForAPI() List<UserMessage>
Normalize this attachment into user messages for the API.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited