TodoReminderAttachment class
Todo reminder attachment.
- Inheritance
-
- Object
- Attachment
- TodoReminderAttachment
Constructors
-
TodoReminderAttachment({required List<
Map< content, required int itemCount})String, dynamic> >
Properties
Methods
-
normalizeForAPI(
) → List< UserMessage> -
Normalize this attachment into user messages for the API.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited