TokenUsageAttachment class

Token usage attachment.

Inheritance

Constructors

TokenUsageAttachment({required int used, required int total, required int remaining})

Properties

hashCode → int
The hash code for this object.
no setterinherited
remaining → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
total → int
final
type → String
no setteroverride
used → int
final

Methods

normalizeForAPI() → List<UserMessage>
Normalize this attachment into user messages for the API.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited