AuthTokenSourceResult class
Result of getAuthTokenSource.
Constructors
- AuthTokenSourceResult({required AuthTokenSourceKind source, required bool hasToken})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasToken → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → AuthTokenSourceKind
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited