UserAccountInfo class

User account info result.

Constructors

UserAccountInfo({String? subscription, String? tokenSource, ApiKeySource? apiKeySource, String? organization, String? email})
const

Properties

apiKeySource ApiKeySource?
final
email String?
final
hashCode int
The hash code for this object.
no setterinherited
organization String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscription String?
final
tokenSource String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited