AccessResult class

Result of checking access to a feature gate.

Constructors

AccessResult({required bool allowed, required String reason, String? upgradeUrl})
const

Properties

allowed bool
Whether access is allowed.
final
hashCode int
The hash code for this object.
no setterinherited
reason String
Human-readable reason for the access decision.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upgradeUrl String?
URL to upgrade if access is denied due to plan limitations.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited