FeatureGate enum

Available feature gates that can be toggled per plan or organization.

Inheritance
Available extensions

Values

betaFeatures → const FeatureGate
experimentalTools → const FeatureGate
mcpServers → const FeatureGate
agentMode → const FeatureGate
voiceInput → const FeatureGate
remoteSessions → const FeatureGate
customThemes → const FeatureGate
pluginSystem → const FeatureGate
teamSync → const FeatureGate
advancedAnalytics → const FeatureGate

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FeatureGate>
A constant List of the values in this enum, in order of their declaration.