FeatureGateConfig class

Snapshot of evaluated feature gate configuration.

Constructors

FeatureGateConfig({required Map<FeatureGate, bool> gates, String? organizationId, required Plan plan, required DateTime evaluatedAt})
const
FeatureGateConfig.fromJson(Map<String, dynamic> json)
Deserializes a config from a JSON map.
factory

Properties

enabledGates → Set<FeatureGate>
Returns all gates that are enabled.
no setter
evaluatedAt → DateTime
When this configuration was evaluated.
final
gates → Map<FeatureGate, bool>
Map of each gate to its enabled/disabled state.
final
hashCode → int
The hash code for this object.
no setterinherited
organizationId → String?
Organization identifier, if applicable.
final
plan → Plan
The plan tier this config was evaluated for.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isEnabled(FeatureGate gate) → bool
Whether a specific gate is enabled in this config.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Serializes the config to a JSON-encodable map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited