isEnabled method
Whether a specific gate is enabled in this config.
Implementation
bool isEnabled(FeatureGate gate) => gates[gate] ?? false;
Whether a specific gate is enabled in this config.
bool isEnabled(FeatureGate gate) => gates[gate] ?? false;