FeatureGateService constructor

FeatureGateService({
  1. Plan plan = Plan.free,
  2. String? configPath,
  3. String? organizationId,
})

Creates a new feature gate service.

plan sets the initial plan tier for default gate evaluation. configPath is the path to the local config file for persistence. organizationId is an optional organization identifier.

Implementation

FeatureGateService({
  Plan plan = Plan.free,
  String? configPath,
  String? organizationId,
}) : _plan = plan,
     _configPath = configPath,
     _organizationId = organizationId {
  _applyPlanDefaults();
}