BashToken class

A parsed bash token.

Constructors

BashToken(BashTokenType type, String value, int offset, int length)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
length int
final
offset int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type BashTokenType
final
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override