BashTokenType enum

Bash token types.

Inheritance
Available extensions

Values

word → const BashTokenType
operator_ → const BashTokenType
redirect → const BashTokenType
pipe → const BashTokenType
and_ → const BashTokenType
or_ → const BashTokenType
semicolon → const BashTokenType
background → const BashTokenType
newline → const BashTokenType
lparen → const BashTokenType
rparen → const BashTokenType
lbrace → const BashTokenType
rbrace → const BashTokenType
heredocMarker → const BashTokenType
comment → const BashTokenType
variable → const BashTokenType
subshell → const BashTokenType
backtick → const BashTokenType
singleQuote → const BashTokenType
doubleQuote → const BashTokenType
glob → const BashTokenType
assignment → const BashTokenType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BashTokenType>
A constant List of the values in this enum, in order of their declaration.