CommandCategory enum

Command category for security / display.

Inheritance
Available extensions

Values

fileSystem → const CommandCategory
git → const CommandCategory
packageManager → const CommandCategory
compiler → const CommandCategory
editor → const CommandCategory
network → const CommandCategory
process → const CommandCategory
shell → const CommandCategory
docker → const CommandCategory
database → const CommandCategory
testing → const CommandCategory
linting → const CommandCategory
other → const CommandCategory

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CommandCategory>
A constant List of the values in this enum, in order of their declaration.