CommandList class

Command list (connected by &&, ||, ;, &).

Constructors

CommandList({required List<CommandListEntry> entries})
const

Properties

allCommands List<SimpleCommand>
All simple commands across all pipelines.
no setter
entries List<CommandListEntry>
final
hashCode int
The hash code for this object.
no setterinherited
pipelines List<Pipeline>
All pipelines in this command list.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited