CommandSecurityAnalysis class
Security analysis of a command.
Constructors
-
CommandSecurityAnalysis({bool hasCommandSubstitution = false, bool hasVariableExpansion = false, bool hasGlobbing = false, bool hasRedirection = false, bool hasPiping = false, bool hasBackgroundExec = false, bool hasSubshell = false, bool hasEval = false, bool hasExec = false, bool hasSudo = false, bool hasChown = false, bool hasRemove = false, bool hasNetworkAccess = false, bool hasDiskWrite = false, List<
String> writtenPaths = const [], List<String> readPaths = const [], List<String> executables = const []}) -
const
Properties
-
executables
→ List<
String> -
final
- hasBackgroundExec → bool
-
final
- hasChown → bool
-
final
- hasCommandSubstitution → bool
-
final
- hasDiskWrite → bool
-
final
- hasEval → bool
-
final
- hasExec → bool
-
final
- hasGlobbing → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasNetworkAccess → bool
-
final
- hasPiping → bool
-
final
- hasRedirection → bool
-
final
- hasRemove → bool
-
final
- hasSubshell → bool
-
final
- hasSudo → bool
-
final
- hasVariableExpansion → bool
-
final
-
readPaths
→ List<
String> -
final
- riskLevel → SecurityRiskLevel
-
Compute the overall risk level.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
writtenPaths
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited