HeredocInfo class

Heredoc information.

Constructors

HeredocInfo({required String delimiter, required String content, bool stripTabs = false, bool quoted = false})
const

Properties

content String
final
delimiter String
final
hashCode int
The hash code for this object.
no setterinherited
quoted bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stripTabs bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited