Pipeline class

Pipeline (connected by |).

Constructors

Pipeline({required List<SimpleCommand> commands, bool negated = false})
const

Properties

commands List<SimpleCommand>
final
hashCode int
The hash code for this object.
no setterinherited
negated bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited