SecurityRiskLevel enum

Risk level.

Inheritance
Available extensions

Values

safe → const SecurityRiskLevel
low → const SecurityRiskLevel
medium → const SecurityRiskLevel
high → const SecurityRiskLevel
critical → const SecurityRiskLevel

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator <(SecurityRiskLevel other) bool
operator <=(SecurityRiskLevel other) bool
operator ==(Object other) bool
The equality operator.
inherited
operator >(SecurityRiskLevel other) bool
operator >=(SecurityRiskLevel other) bool

Constants

values → const List<SecurityRiskLevel>
A constant List of the values in this enum, in order of their declaration.