SimpleCommand class

Simple command representation.

Constructors

SimpleCommand({required String executable, List<String> arguments = const [], Map<String, String> assignments = const {}, List<Redirect> redirects = const []})
const

Properties

arguments List<String>
final
assignments Map<String, String>
final
executable String
final
hashCode int
The hash code for this object.
no setterinherited
redirects List<Redirect>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
words List<String>
All words: executable + arguments.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited