AttributionSettings class

Settings relevant to attribution.

Constructors

AttributionSettings({AttributionSettingOverride? attribution, bool? includeCoAuthoredBy})
const

Properties

attribution → AttributionSettingOverride?
final
hashCode → int
The hash code for this object.
no setterinherited
includeCoAuthoredBy → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited