AttributionState class

File state map for attribution tracking.

Constructors

AttributionState({required Map<String, dynamic> fileStates})
const

Properties

fileStates Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackedFiles List<String>
Get the list of tracked file paths.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited