FastModeChecker typedef
FastModeChecker =
bool Function()
Callback type for checking if fast mode is enabled.
Implementation
typedef FastModeChecker = bool Function();
Callback type for checking if fast mode is enabled.
typedef FastModeChecker = bool Function();