PrivacyLevel enum

Privacy level controls how much nonessential network traffic and telemetry the application generates.

Levels are ordered by restrictiveness: default < noTelemetry < essentialTraffic

  • defaultLevel: Everything enabled.
  • noTelemetry: Analytics/telemetry disabled.
  • essentialTraffic: ALL nonessential network traffic disabled (telemetry + auto-updates, grove, release notes, etc.).
Inheritance
Available extensions

Values

defaultLevel → const PrivacyLevel
noTelemetry → const PrivacyLevel
essentialTraffic → const PrivacyLevel

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PrivacyLevel>
A constant List of the values in this enum, in order of their declaration.