TranscriptEntry class
Transcript entry for memory access counting.
Constructors
-
TranscriptEntry({required String type, List<
Map< ? contentBlocks})String, dynamic> > -
const
Properties
-
contentBlocks
→ List<
Map< ?String, dynamic> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited