CleanupResult class

Result of a cleanup operation.

Constructors

CleanupResult({int messages = 0, int errors = 0})
const

Properties

errors → int
final
hashCode → int
The hash code for this object.
no setterinherited
messages → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator +(CleanupResult other) → CleanupResult
operator ==(Object other) → bool
The equality operator.
inherited