registerCleanup function
Register a cleanup function to run during graceful shutdown.
Implementation
void registerCleanup(CleanupCallback fn) {
_cleanupFunctions.add(fn);
}
Register a cleanup function to run during graceful shutdown.
void registerCleanup(CleanupCallback fn) {
_cleanupFunctions.add(fn);
}