AttachmentData class

Simplified attachment data.

Constructors

AttachmentData({required String type, String? taskType, String? status, int? count, List<Map<String, dynamic>>? memories})
const

Properties

count int?
final
hashCode int
The hash code for this object.
no setterinherited
memories List<Map<String, dynamic>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
taskType String?
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited