DetectedPr class

A detected PR operation.

Constructors

DetectedPr({required int number, String? url, required PrAction action})
const

Properties

action PrAction
final
hashCode int
The hash code for this object.
no setterinherited
number int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited