RenderableMessage class

A simplified renderable message for collapse processing.

Constructors

RenderableMessage({required String type, required String uuid, DateTime? timestamp, MessageData? message, String? subtype, String? hookLabel, int hookCount = 0, List<StopHookInfo> hookInfos = const [], List<String> hookErrors = const [], bool preventedContinuation = false, bool hasOutput = false, int? totalDurationMs, String? toolName, List<RenderableMessage>? messages, dynamic toolUseResult, AttachmentData? attachment, RenderableMessage? displayMessage})

Properties

attachment AttachmentData?
For attachment messages.
final
displayMessage RenderableMessage?
Display message for collapsed groups.
final
hashCode int
The hash code for this object.
no setterinherited
hasOutput bool
getter/setter pair
hookCount int
getter/setter pair
hookErrors List<String>
getter/setter pair
hookInfos List<StopHookInfo>
getter/setter pair
hookLabel String?
final
message MessageData?
For assistant/user messages.
final
messages List<RenderableMessage>?
final
preventedContinuation bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtype String?
For system messages.
final
timestamp DateTime?
final
toolName String?
For grouped_tool_use messages.
final
toolUseResult → dynamic
For user messages with tool results.
final
totalDurationMs int?
getter/setter pair
type String
final
uuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited