isAbsorbedSilently property
True for meta-operations that should be absorbed into a collapse group without incrementing any count (Snip, ToolSearch).
Implementation
final bool isAbsorbedSilently;
True for meta-operations that should be absorbed into a collapse group without incrementing any count (Snip, ToolSearch).
final bool isAbsorbedSilently;