StopHookInfo class

Information about a hook that was stopped.

Constructors

StopHookInfo({required String hookName, int? durationMs, String? output})
const

Properties

durationMs int?
final
hashCode int
The hash code for this object.
no setterinherited
hookName String
final
output String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited