AttributionState class

Attribution state for tracking Neomage's contributions to files.

Constructors

AttributionState({Map<String, FileAttributionState>? fileStates, Map<String, BaselineEntry>? sessionBaselines, String surface = 'cli', String? startingHeadSha, int promptCount = 0, int promptCountAtLastCommit = 0, int permissionPromptCount = 0, int permissionPromptCountAtLastCommit = 0, int escapeCount = 0, int escapeCountAtLastCommit = 0})

Properties

escapeCount int
ESC press tracking (user cancelled permission prompt).
getter/setter pair
escapeCountAtLastCommit int
getter/setter pair
fileStates Map<String, FileAttributionState>
File states keyed by relative path (from cwd).
final
hashCode int
The hash code for this object.
no setterinherited
permissionPromptCount int
Permission prompt tracking.
getter/setter pair
permissionPromptCountAtLastCommit int
getter/setter pair
promptCount int
Total prompts in session (for steer count calculation).
getter/setter pair
promptCountAtLastCommit int
Prompts at last commit (to calculate steers for current commit).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionBaselines Map<String, BaselineEntry>
Session baseline states for net change calculation.
final
startingHeadSha String?
HEAD SHA at session start (for detecting external commits).
final
surface String
Surface from which edits were made.
final

Methods

copyWith({Map<String, FileAttributionState>? fileStates, Map<String, BaselineEntry>? sessionBaselines, String? surface, String? startingHeadSha, int? promptCount, int? promptCountAtLastCommit, int? permissionPromptCount, int? permissionPromptCountAtLastCommit, int? escapeCount, int? escapeCountAtLastCommit}) AttributionState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited