createEmptyAttributionState method
Create an empty attribution state for a new session.
Implementation
AttributionState createEmptyAttributionState() {
return AttributionState(surface: getClientSurface());
}
Create an empty attribution state for a new session.
AttributionState createEmptyAttributionState() {
return AttributionState(surface: getClientSurface());
}