FileAttribution class
Per-file attribution details for git notes.
Constructors
- FileAttribution({required int neomageChars, required int humanChars, required int percent, required String surface})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- humanChars → int
-
final
- neomageChars → int
-
final
- percent → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surface → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited