FileChange class

A single file change for bulk tracking.

Constructors

FileChange({required String path, required String type, required String oldContent, required String newContent, int? mtime})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mtime int?
final
newContent String
final
oldContent String
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
'modified', 'created', or 'deleted'.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited