SurfaceBreakdownEntry class

Surface breakdown entry for attribution data.

Constructors

SurfaceBreakdownEntry({required int neomageChars, required int percent})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
neomageChars int
final
percent int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited