CliComputerExecutor class
macOS CLI executor that wraps native modules.
Uses @ant/computer-use-input (Rust/enigo) for mouse/keyboard and
@ant/computer-use-swift for screenshots, app management, TCC.
- Inheritance
-
- Object
- ComputerExecutor
- CliComputerExecutor
Constructors
- CliComputerExecutor({required bool getMouseAnimationEnabled(), required bool getHideBeforeActionEnabled()})
Properties
- capabilities → ComputerUseCapabilities
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appUnderPoint(
double x, double y) → Future< Map< String, String> ?> -
override
-
click(
double x, double y, String button, int count, [List< String> ? modifiers]) → Future<void> -
override
-
drag(
Map< String, double> ? from, Map<String, double> to) → Future<void> -
override
-
findWindowDisplays(
List< String> bundleIds) → Future<List< Map< >String, dynamic> > -
override
-
getAppIcon(
String path) → Future< String?> -
override
-
getCursorPosition(
) → Future< Map< String, double> > -
override
-
getDisplaySize(
[int? displayId]) → Future< DisplayGeometry> -
override
-
getFrontmostApp(
) → Future< FrontmostApp?> -
override
-
holdKey(
List< String> keyNames, int durationMs) → Future<void> -
override
-
key(
String keySequence, [int? repeat]) → Future< void> -
override
-
listDisplays(
) → Future< List< DisplayGeometry> > -
override
-
listInstalledApps(
) → Future< List< InstalledApp> > -
override
-
listRunningApps(
) → Future< List< RunningApp> > -
override
-
mouseDown(
) → Future< void> -
override
-
mouseUp(
) → Future< void> -
override
-
moveMouse(
double x, double y) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openApp(
String bundleId) → Future< void> -
override
-
prepareForAction(
List< String> allowlistBundleIds, [int? displayId]) → Future<List< String> > -
override
-
previewHideSet(
List< String> allowlistBundleIds, [int? displayId]) → Future<List< Map< >String, String> > -
override
-
readClipboard(
) → Future< String> -
override
-
resolvePrepareCapture(
{required List< String> allowedBundleIds, int? preferredDisplayId, required bool autoResolve, bool? doHide}) → Future<ResolvePrepareCaptureResult> -
override
-
screenshot(
{required List< String> allowedBundleIds, int? displayId}) → Future<ScreenshotResult> -
override
-
scroll(
double x, double y, double dx, double dy) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
type(
String text, {required bool viaClipboard}) → Future< void> -
override
-
writeClipboard(
String text) → Future< void> -
override
-
zoom(
{required Map< String, num> regionLogical, required List<String> allowedBundleIds, int? displayId}) → Future<ScreenshotResult> -
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited