ComputerUseCapabilities class

Capabilities of the CLI computer use executor.

Constructors

ComputerUseCapabilities({required String hostBundleId, bool supportsScreenshot = true, bool supportsClick = true, bool supportsType = true, bool supportsKey = true, bool supportsDrag = true, bool supportsScroll = true, bool supportsAppManagement = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hostBundleId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportsAppManagement bool
final
supportsClick bool
final
supportsDrag bool
final
supportsKey bool
final
supportsScreenshot bool
final
supportsScroll bool
final
supportsType bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited