ComputerUseController class
Sint controller managing computer use state.
- Inheritance
-
- Object
- Listenable
- ListNotifier
- SintController
- ComputerUseController
Constructors
Properties
- blockingSessionId → RxString
-
Blocking session ID if locked.
final
- executor → ComputerExecutor
-
Get or create the executor.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Hidden app bundle IDs (to restore on turn end).
final
- hideBeforeActionEnabled → RxBool
-
Whether hide-before-action is enabled.
final
- initialized → bool
-
Checks whether the controller has already been initialized.
no setterinherited
- isActive → RxBool
-
Whether computer use is currently active.
final
- isClosed → bool
-
Checks whether the controller has already been closed.
no setterinherited
- isDisposed → bool
-
no setterinherited
- isLockHeldLocally → bool
-
Whether lock is held locally (zero-syscall check).
no setter
- listenersLength → int
-
no setterinherited
- lockState → RxString
-
Current session's lock state.
final
- mouseAnimationEnabled → RxBool
-
Whether mouse animation is enabled.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
acquireLock(
) → Future< AcquireResult> - Acquire the computer use lock.
-
addListener(
SintStateUpdate listener) → Disposer -
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(
Object? key, SintStateUpdate listener) → Disposer -
inherited
-
checkLock(
) → Future< CheckResult> - Check lock state without acquiring.
-
containsListener(
SintStateUpdate listener) → bool -
inherited
-
debounce<
T> (RxInterface< T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void -
Calls
callbackafterrxstops changing forduration. Useful for search-as-you-type, form validation, etc.inherited -
dispose(
) → void -
inherited
-
ever<
T> (RxInterface< T> rx, void callback(T)) → void -
Calls
callbackevery timerxchanges. Auto-cancels on controller disposal.inherited -
getFilteredAppNames(
) → Future< List< String> > - Get filtered app names for description.
-
initialize(
{required String configHomeDir, required String sessionId}) → void - Initialize with session info.
-
interval<
T> (RxInterface< T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void -
Calls
callbackat most once perduration, ignoring intermediate changes. Useful for rate-limiting UI updates.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
once<
T> (RxInterface< T> rx, void callback(T)) → void -
Calls
callbackonly the first timerxchanges, then cancels.inherited -
onClose(
) → void -
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
-
onDelete(
) → void -
inherited
-
onInit(
) → void -
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
override
-
onReady(
) → void -
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
onStart(
) → void -
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclasses.
This method should be internal and is required to define the
lifetime cycle of the subclass.
inherited
-
refresh(
) → void -
inherited
-
refreshGroup(
Object id) → void -
inherited
-
releaseLock(
) → Future< bool> - Release the computer use lock.
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(
Object id, VoidCallback listener) → void -
inherited
-
reportAdd(
VoidCallback disposer) → void -
inherited
-
reportRead(
) → void -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
[List< Object> ? ids, bool condition = true]) → void -
Notifies listeners to update the UI.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited