ComputerUseLock class

Lock content stored in computer-use.lock.

Constructors

ComputerUseLock({required String sessionId, required int pid, required int acquiredAt})
const

Properties

acquiredAt int
final
hashCode int
The hash code for this object.
no setterinherited
pid int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) ComputerUseLock?