InstalledApp class

Information about an installed application.

Constructors

InstalledApp({required String bundleId, required String displayName, required String path, String? iconDataUrl})
const

Properties

bundleId String
final
displayName String
final
hashCode int
The hash code for this object.
no setterinherited
iconDataUrl String?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited