ResolvePrepareCaptureResult class

Result of preparing capture with display resolution.

Constructors

ResolvePrepareCaptureResult({ScreenshotResult? screenshot, List<String> hidden = const [], String? activated})
const

Properties

activated String?
final
hashCode int
The hash code for this object.
no setterinherited
hidden List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshot ScreenshotResult?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited