S1mAccessCacheEntry class

Constructors

S1mAccessCacheEntry({required bool hasAccess, bool? hasAccessNotAsDefault, required int timestamp})
const
S1mAccessCacheEntry.fromJson(Map<String, dynamic> json)
factory

Properties

hasAccess bool
final
hasAccessNotAsDefault bool?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited