AccountInfo class
Account info from OAuth.
Constructors
- AccountInfo({required String accountUuid, required String emailAddress, String? organizationUuid, String? organizationName, String? organizationRole, String? workspaceRole, String? displayName, bool? hasExtraUsageEnabled, String? billingType, String? accountCreatedAt, String? subscriptionCreatedAt})
-
const
-
AccountInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accountCreatedAt → String?
-
final
- accountUuid → String
-
final
- billingType → String?
-
final
- displayName → String?
-
final
- emailAddress → String
-
final
- hasExtraUsageEnabled → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- organizationName → String?
-
final
- organizationRole → String?
-
final
- organizationUuid → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscriptionCreatedAt → String?
-
final
- workspaceRole → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited