HistoryEntry class

History entry for prompt history.

Constructors

HistoryEntry({required String display, Map<int, PastedContent> pastedContents = const {}})
const
HistoryEntry.fromJson(Map<String, dynamic> json)
factory

Properties

display String
final
hashCode int
The hash code for this object.
no setterinherited
pastedContents Map<int, PastedContent>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited