PastedContent class
Image dimension info for coordinate mapping.
Constructors
- PastedContent({required int id, required String type, required String content, String? mediaType, String? filename, ImageDimensions? dimensions, String? sourcePath})
-
const
-
PastedContent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- content → String
-
final
- dimensions → ImageDimensions?
-
final
- filename → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
final
- mediaType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourcePath → String?
-
final
- type → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited