AppSettings class
App-wide settings — port of neomage's configuration system.
Constructors
- AppSettings(SharedPreferences _prefs)
Properties
- customSystemPrompt → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxTokens → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamingEnabled → bool
-
no setter
- themeMode → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setCustomSystemPrompt(
String? prompt) → Future< void> -
setMaxTokens(
int tokens) → Future< void> -
setStreamingEnabled(
bool enabled) → Future< void> -
setThemeMode(
String mode) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
load(
) → Future< AppSettings>
Constants
- defaultSystemPrompt → const String
- Default system prompt — matches neomage's system.ts.