utils/constants/api_limits library

Constants

apiImageMaxBase64Size → const int
Maximum base64-encoded image size (API enforced). 5 MB.
apiMaxMediaPerRequest → const int
Maximum number of media items (images + PDFs) per API request.
apiPdfMaxPages → const int
Maximum number of pages in a PDF accepted by the API.
imageMaxHeight → const int
Client-side maximum height for image resizing.
imageMaxWidth → const int
Client-side maximum width for image resizing.
imageTargetRawSize → const int
Target raw image size to stay under base64 limit after encoding. ~3.75 MB.
pdfAtMentionInlineThreshold → const int
PDFs with more pages than this get reference treatment on @ mention.
pdfExtractSizeThreshold → const int
Size threshold above which PDFs are extracted into page images. 3 MB.
pdfMaxExtractSize → const int
Maximum PDF file size for the page extraction path. 100 MB.
pdfMaxPagesPerRead → const int
Max pages the Read tool will extract in a single call.
pdfTargetRawSize → const int
Maximum raw PDF file size. 20 MB.