utils/constants/files library

Constants

binaryCheckSize → const int
Bytes to check for binary content detection.
binaryExtensions → const Set<String>
File extensions known to be binary.

Functions

hasBinaryExtension(String filePath) bool
Check if a file path has a known binary extension.
isBinaryContent(Uint8List buffer) bool
Detect binary content by checking for null bytes or >10% non-printable characters in the first binaryCheckSize bytes.