ErrorMessages class
Standard error messages.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- apiKeyInvalid → const String
- apiKeyMissing → const String
- commandNotFound → const String
- contextWindowExceeded → const String
- diskFull → const String
- fileNotFound → const String
- maxAgentsReached → const String
- mcpServerError → const String
- modelNotAvailable → const String
- networkError → const String
- permissionDenied → const String
- rateLimited → const String
- sandboxViolation → const String
- sessionCorrupted → const String
- timeoutError → const String
- toolNotFound → const String