PermissionPrompts class

Standard permission prompt templates.

Constructors

PermissionPrompts()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

format(String template, Map<String, String> params) String

Constants

agentSpawn → const String
fileDelete → const String
fileWrite → const String
mcpConnect → const String
networkAccess → const String
shellCommand → const String