ShortcutLabels class

Keyboard shortcut labels.

Constructors

ShortcutLabels()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

acceptSuggestion → const String
cancel → const String
clearChat → const String
commandPalette → const String
copy → const String
find → const String
focusInput → const String
newLine → const String
nextMessage → const String
paste → const String
previousMessage → const String
redo → const String
selectAll → const String
submit → const String
submitMultiline → const String
toggleSidebar → const String
toggleVim → const String
undo → const String