SizeConstants class
Size constants.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- avatarSize → const double
- chipHeight → const double
- desktopBreakpoint → const double
- iconSize → const double
- inputMaxHeight → const double
- inputMinHeight → const double
- maxChatWidth → const double
- maxCodeWidth → const double
- minWindowHeight → const double
- minWindowWidth → const double
- mobileBreakpoint → const double
- scrollbarWidth → const double
- statusBarHeight → const double
- tabletBreakpoint → const double
- toolbarHeight → const double