TelemetryEvents class

Telemetry event names.

Constructors

TelemetryEvents()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

agentComplete → const String
agentSpawn → const String
apiLatency → const String
commandRun → const String
compaction → const String
error → const String
mcpConnect → const String
mcpDisconnect → const String
memoryWrite → const String
messageReceive → const String
messageSubmit → const String
modelSwitch → const String
permissionDeny → const String
permissionGrant → const String
permissionRequest → const String
sessionEnd → const String
sessionStart → const String
toolResult → const String
toolUse → const String