ErrorMessages class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- apiKeyInvalid → const String
- apiKeyMissing → const String
- authRequired → const String
- binaryFileError → const String
- compactionFailed → const String
- configInvalid → const String
- connectionFailed → const String
- connectionTimeout → const String
- contextWindowExceeded → const String
- directoryNotFound → const String
- fileNotFound → const String
- fileReadError → const String
- fileWriteError → const String
- gitNotFound → const String
- gitNotRepo → const String
- hookFailed → const String
- invalidInput → const String
- maxTokensExceeded → const String
- maxTurnsExceeded → const String
- mcpConnectionFailed → const String
- mcpServerCrashed → const String
- modelNotFound → const String
- permissionDenied → const String
- rateLimited → const String
- sandboxViolation → const String
- sessionCorrupted → const String
- sessionNotFound → const String
- toolExecutionFailed → const String
- toolNotFound → const String
- toolTimedOut → const String