gitNotFound constant
String
const gitNotFound
Implementation
static const String gitNotFound =
'Git is not installed or not found in PATH. '
'Please install Git and try again.';
static const String gitNotFound =
'Git is not installed or not found in PATH. '
'Please install Git and try again.';