InfoMessages class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- commitCreated → const String
- compactionComplete → const String
- configUpdated → const String
- diagnosticsPassed → const String
- exportComplete → const String
- fileCreated → const String
- fileModified → const String
- hookRegistered → const String
- mcpConnected → const String
- modelSwitched → const String
- permissionDenied → const String
- permissionGranted → const String
- sessionEnded → const String
- sessionResumed → const String
- sessionStarted → const String
- toolRegistered → const String
- welcome → const String