WarningMessages class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- approachingContextLimit → const String
- deprecatedFeature → const String
- destructiveOperation → const String
- experimentalFeature → const String
- highTokenUsage → const String
- largeFile → const String
- longRunningCommand → const String
- outdatedConfig → const String
- unsavedChanges → const String
- unverifiedTool → const String