deprecatedFeature constant
String
const deprecatedFeature
Implementation
static const String deprecatedFeature =
'This feature is deprecated and will be removed in a future version.';
static const String deprecatedFeature =
'This feature is deprecated and will be removed in a future version.';