SystemConstants class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- cacheDir → String
-
no setter
- configDir → String
-
no setter
- credentialsFile → String
-
no setter
- logDir → String
-
no setter
- mcpConfigFile → String
-
no setter
- memoryFile → String
-
no setter
- projectMemoryFile → String
-
no setter
- sessionDir → String
-
no setter
- settingsFile → String
-
no setter
- tempDir → String
-
no setter
- todoFile → String
-
no setter
Constants
- apiBaseUrl → const String
- apiRequestTimeout → const int
- appBuildNumber → const String
- appDescription → const String
- appId → const String
- appName → const String
- appVersion → const String
-
binaryExtensions
→ const List<
String> -
cliPlatforms
→ const List<
String> - compactionThreshold → const int
- compactionTimeout → const int
- configDirName → const String
-
configFileNames
→ const List<
String> - connectionPoolSize → const int
- defaultApiVersion → const String
- defaultCommandTimeout → const int
- docsUrl → const String
- feedbackUrl → const String
- healthCheckTimeout → const int
- hookTimeout → const int
-
ignoredDirs
→ const List<
String> -
ignoredFiles
→ const List<
String> - keepAliveInterval → const int
- longCommandTimeout → const int
- maxConcurrentAgents → const int
- maxConcurrentRequests → const int
- maxContextTokens → const int
- maxConversationTurns → const int
- maxDiffLines → const int
- maxFileReadLines → const int
- maxFileSize → const int
- maxGlobResults → const int
- maxGrepResults → const int
- maxHistoryEntries → const int
- maxInputTokens → const int
- maxMcpServers → const int
- maxOutputLength → const int
- maxRetries → const int
- maxSearchResults → const int
- maxToolOutputLength → const int
- mcpConnectionTimeout → const int
- mcpRequestTimeout → const int
-
mobilePlatforms
→ const List<
String> - privacyUrl → const String
- productUrl → const String
- retryBackoffMultiplier → const double
- retryBaseDelay → const int
- retryMaxDelay → const int
- shortCommandTimeout → const int
-
supportedApiVersions
→ const List<
String> -
supportedPlatforms
→ const List<
String> - termsUrl → const String
-
textExtensions
→ const List<
String> - toolExecutionTimeout → const int