ContextItem class sealed

A piece of context to include in the prompt.

Implementers

Properties

content String
no setter
estimatedTokens int
no setter
hashCode int
The hash code for this object.
no setterinherited
label String
no setter
priority ContextPriority
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited