FileContext class

File content context.

Inheritance

Constructors

FileContext({required String path, required String fileContent, int startLine = 1, int endLine = -1, String? language})

Properties

content String
no setteroverride
endLine int
final
estimatedTokens int
no setteroverride
fileContent String
final
hashCode int
The hash code for this object.
no setterinherited
label String
no setteroverride
language String?
final
path String
final
priority ContextPriority
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startLine int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited