GitDiffContext class

Git diff context.

Inheritance

Constructors

GitDiffContext({required String diff, String? description})

Properties

content String
no setteroverride
description String?
final
diff String
final
estimatedTokens int
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
label String
no setteroverride
priority ContextPriority
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited