MemoryContext class
Memory file context (NEOMAGE.md).
- Inheritance
-
- Object
- ContextItem
- MemoryContext
Constructors
- MemoryContext({required String source, required String memoryContent})
Properties
- content → String
-
no setteroverride
- estimatedTokens → int
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
no setteroverride
- memoryContent → String
-
final
- priority → ContextPriority
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited