SearchResultsContext class
Search results context.
- Inheritance
-
- Object
- ContextItem
- SearchResultsContext
Constructors
-
SearchResultsContext({required String query, required List<
SearchHit> hits})
Properties
- content → String
-
no setteroverride
- estimatedTokens → int
-
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hits
→ List<
SearchHit> -
final
- label → String
-
no setteroverride
- priority → ContextPriority
-
no setteroverride
- query → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited