CronFields class

Expanded cron fields — each is a sorted list of matching values.

Constructors

CronFields({required List<int> minute, required List<int> hour, required List<int> dayOfMonth, required List<int> month, required List<int> dayOfWeek})
const

Properties

dayOfMonth → List<int>
final
dayOfWeek → List<int>
final
hashCode → int
The hash code for this object.
no setterinherited
hour → List<int>
final
minute → List<int>
final
month → List<int>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited