SchedulerLockOptions class

Options for out-of-REPL callers that don't have bootstrap state.

Constructors

SchedulerLockOptions({String? dir, String? lockIdentity})
const

Properties

dir String?
final
hashCode int
The hash code for this object.
no setterinherited
lockIdentity String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited