XorCipher class

Simple XOR encrypt/decrypt for local storage.

This is NOT cryptographically secure and should only be used for lightweight obfuscation of locally stored data.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decrypt(String ciphertext, String key) String
Decrypt a Base64-encoded ciphertext with key using XOR.
encrypt(String plaintext, String key) String
Encrypt plaintext with key using XOR, returning a Base64-encoded string.