DeepLinkBannerInfo class

Info needed to build the deep link origin banner.

Constructors

DeepLinkBannerInfo({required String cwd, int? prefillLength, String? repo, DateTime? lastFetch})
const

Properties

cwd String
final
hashCode int
The hash code for this object.
no setterinherited
lastFetch DateTime?
final
prefillLength int?
final
repo String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited