isDeepLinkSession property
RxBool
isDeepLinkSession
final
Whether the current session was opened by a deep link.
Implementation
final isDeepLinkSession = false.obs;
Whether the current session was opened by a deep link.
final isDeepLinkSession = false.obs;