onInit method
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
Implementation
@override
void onInit() {
super.onInit();
// Capture terminal preference on init
terminalPreference.value = captureTerminalPreference();
}