ChangeBlock class

A contiguous block of related changes.

Constructors

ChangeBlock({required List<LineDiff> lines})
const

Properties

endLine int
no setter
hashCode int
The hash code for this object.
no setterinherited
isModification bool
no setter
isPureAdd bool
no setter
isPureRemove bool
no setter
lines List<LineDiff>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startLine int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited