Hunk class

A single hunk in a patch.

Constructors

Hunk({required int oldStart, required int oldCount, required int newStart, required int newCount, required List<LineDiff> lines})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
no setter
lines List<LineDiff>
final
newCount int
final
newStart int
final
oldCount int
final
oldStart int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited