LineDiff class

A single line in a line-level diff.

Constructors

LineDiff({required int lineNumber, required String content, required DiffType type})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setteroverride
lineNumber int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type DiffType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override