PatchResult class

Result of applying a patch.

Constructors

PatchResult({required String text, required List<Hunk> appliedHunks, required List<Hunk> conflictHunks})
const

Properties

appliedHunks List<Hunk>
final
conflictHunks List<Hunk>
final
hashCode int
The hash code for this object.
no setterinherited
isClean bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited