PatchSet class

A set of hunks that together describe a transformation.

Constructors

PatchSet({required List<Hunk> hunks})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hunks List<Hunk>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(String text) PatchResult
Apply this patch to text.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reverse() PatchSet
Create a reversed patch that undoes this patch.
serialize() String
Serialize to a string representation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

deserialize(String text) PatchSet
Deserialize from a unified diff string.