SemanticDiff class

Groups related diff lines into logical change blocks.

Constructors

SemanticDiff({required List<ChangeBlock> blocks})
const
SemanticDiff.from(List<LineDiff> diffs)
Create a semantic diff from raw line diffs.
factory

Properties

blocks List<ChangeBlock>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary String
Summary of all blocks.
no setter

Methods

merge({int gapThreshold = 3}) SemanticDiff
Merge adjacent blocks that are within gapThreshold context lines.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited