EnvInfo class

Immutable snapshot of the environment at startup.

Properties

hashCode int
The hash code for this object.
no setterinherited
internetAccess Future<bool>
no setter
isCI bool
final
isSSH bool
no setter
packageManagers Future<List<String>>
no setter
platform NeomagePlatform
final
runtimes Future<List<String>>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminal String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance EnvInfo
final