ApiError class

API-related errors.

Inheritance

Constructors

ApiError({required String message, String errorId = 'api_error', String? suggestion, int? statusCode, String? errorType, Map<String, dynamic>? responseBody})
ApiError.fromStatus(int statusCode, {String? body})
Create from HTTP status code.
factory

Properties

context Map<String, dynamic>
no setteroverride
errorId String
final
errorType String?
final
hashCode int
The hash code for this object.
no setterinherited
isRetryable bool
no setter
message String
final
responseBody Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
final
suggestion String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited