FastModeResponse class

Response from the fast mode API endpoint.

Constructors

FastModeResponse({required bool enabled, FastModeDisabledReason? disabledReason})
const
FastModeResponse.fromJson(Map<String, dynamic> json)
factory

Properties

disabledReason FastModeDisabledReason?
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited