FileEdit class

Single edit operation within a file.

Constructors

FileEdit({required String oldText, required String newText, bool replaceAll = false})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
newText → String
final
oldText → String
final
replaceAll → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited