Dirent class

Directory entry with file type information.

Constructors

Dirent({required String name, required FileSystemEntityType type, bool isSymLink = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
isDirectory bool
no setter
isFile bool
no setter
no setter
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type FileSystemEntityType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited