FileTooLargeError class

Error thrown when a file exceeds the maximum allowed size.

Implemented types

Constructors

FileTooLargeError(int sizeInBytes, int maxSizeBytes)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxSizeBytes → int
final
message ↔ String
latefinal
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeInBytes → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited