ReadFileInRangeResult class

Result from readFileInRange.

Constructors

ReadFileInRangeResult({required String content, required int lineCount, required int totalLines, required int totalBytes, required int readBytes, required double mtimeMs, bool truncatedByBytes = false})

Properties

content → String
final
hashCode → int
The hash code for this object.
no setterinherited
lineCount → int
final
mtimeMs → double
final
readBytes → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalBytes → int
final
totalLines → int
final
truncatedByBytes → bool
True when output was clipped to maxBytes under truncate mode.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited