ReadFileRangeResult class

Result of reading a file range.

Constructors

ReadFileRangeResult({required String content, required int bytesRead, required int bytesTotal})

Properties

bytesRead int
final
bytesTotal int
final
content String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited