ReadSyncResult class

Read result for partial file reads.

Constructors

ReadSyncResult({required Uint8List buffer, required int bytesRead})

Properties

buffer Uint8List
final
bytesRead int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited