GitDiffResult class

Result of a git diff operation.

Constructors

GitDiffResult({required GitDiffStats stats, required Map<String, PerFileStats> perFileStats, required Map<String, List<StructuredPatchHunk>> hunks})

Properties

hashCode int
The hash code for this object.
no setterinherited
hunks Map<String, List<StructuredPatchHunk>>
final
perFileStats Map<String, PerFileStats>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats GitDiffStats
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited