GitDiffStats class
Git diff aggregate statistics.
Constructors
- GitDiffStats({required int filesCount, required int linesAdded, required int linesRemoved})
-
const
Properties
- filesCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- linesAdded → int
-
final
- linesRemoved → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited