GitRepoState class

Git repository state snapshot.

Constructors

GitRepoState({required String commitHash, required String branchName, required String? remoteUrl, required bool isHeadOnRemote, required bool isClean, required int worktreeCount})
const

Properties

branchName String
final
commitHash String
final
hashCode int
The hash code for this object.
no setterinherited
isClean bool
final
isHeadOnRemote bool
final
remoteUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
worktreeCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited