PerFileStats class

Per-file diff statistics.

Constructors

PerFileStats({required int added, required int removed, required bool isBinary, bool isUntracked = false})
const

Properties

added int
final
hashCode int
The hash code for this object.
no setterinherited
isBinary bool
final
isUntracked bool
final
removed int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited