PrStatus class

Pull request status.

Constructors

PrStatus({required int number, required String url, required PrReviewState reviewState})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
number int
final
reviewState PrReviewState
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited