ToolUseDiff class

Structured diff for a single file (tool use).

Constructors

ToolUseDiff({required String filename, required String status, required int additions, required int deletions, required int changes, required String patch, String? repository})
const

Properties

additions int
final
changes int
final
deletions int
final
filename String
final
hashCode int
The hash code for this object.
no setterinherited
patch String
final
repository String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited