LogMessage class

A message from the log for plan recovery.

Constructors

LogMessage({required String type, String? subtype, String? slug, String? planContent, Map<String, dynamic>? message, Map<String, dynamic>? attachment, List<FileSnapshotEntry>? snapshotFiles})
const

Properties

attachment Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
message Map<String, dynamic>?
final
planContent String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slug String?
final
snapshotFiles List<FileSnapshotEntry>?
final
subtype String?
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited