AsyncHookRegistry class

Registry for tracking async hooks awaiting completion.

Constructors

AsyncHookRegistry()

Properties

count int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
getPending() List<PendingAsyncHook>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(PendingAsyncHook hook) → void
removeDelivered(List<String> processIds) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited