CommandHook class

Shell command hook.

Implemented types

Constructors

CommandHook({required String command, String? shell, int? timeout, String? ifCondition})
const

Properties

command String
final
hashCode int
The hash code for this object.
no setterinherited
ifCondition String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shell String?
final
timeout int?
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited