FunctionHook class

Function hook (in-memory callback, session-scoped only).

Implemented types

Constructors

FunctionHook({required Future<bool> callback(List messages, {Object? signal}), required String errorMessage, String? id, int? timeout, String? statusMessage})

Properties

callback Future<bool> Function(List messages, {Object? signal})
final
errorMessage String
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
ifCondition String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusMessage String?
final
timeout int?
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited