FunctionHookMatcher class
Function hook matcher (for getSessionFunctionHooks).
Constructors
-
FunctionHookMatcher({required String matcher, required List<
FunctionHook> hooks}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hooks
→ List<
FunctionHook> -
final
- matcher → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited