HookEventMetadata class

Metadata for a hook event.

Constructors

HookEventMetadata({required String summary, required String description, MatcherMetadata? matcherMetadata})
const

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
matcherMetadata MatcherMetadata?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited