HookExecutionEvent class abstract

Base class for hook execution events.

Implementers

Constructors

HookExecutionEvent()

Properties

hashCode int
The hash code for this object.
no setterinherited
hookEvent String
no setter
hookId String
no setter
hookName String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type HookExecutionEventType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited