HookStartedEvent class

Emitted when a hook starts executing.

Implemented types

Constructors

HookStartedEvent({required String hookId, required String hookName, required String hookEvent})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hookEvent String
final
hookId String
final
hookName String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type HookExecutionEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited