HttpHook class

HTTP hook (sends request to URL).

Implemented types

Constructors

HttpHook({required String url, int? timeout, String? ifCondition})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
ifCondition String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout int?
final
type String
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited