PendingAsyncHook class
A pending async hook awaiting completion.
Constructors
Properties
- command → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hookEvent → String
-
final
- hookId → String
-
final
- hookName → String
-
final
- pluginId → String?
-
final
- processId → String
-
final
- responseAttachmentSent ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime → DateTime
-
final
- timeout → int
-
final
- toolName → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited