SessionHookMatcher class

A single matcher entry in the session hook store.

Constructors

SessionHookMatcher({required String matcher, String? skillRoot, required List<SessionHookEntry> hooks})

Properties

hashCode int
The hash code for this object.
no setterinherited
hooks List<SessionHookEntry>
final
matcher String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skillRoot String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited