DetectedIDEInfo class

Detected IDE info.

Constructors

DetectedIDEInfo({required String name, required int port, required List<String> workspaceFolders, required String url, required bool isValid, String? authToken, bool? ideRunningInWindows})
const

Properties

authToken String?
final
hashCode int
The hash code for this object.
no setterinherited
ideRunningInWindows bool?
final
isValid bool
final
name String
final
port int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final
workspaceFolders List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited