IDEExtensionInstallationStatus class

IDE extension installation status.

Constructors

IDEExtensionInstallationStatus({required bool installed, String? error, String? installedVersion, IdeType? ideType})
const

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
ideType IdeType?
final
installed bool
final
installedVersion String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited