IdeConfig class

Configuration for a supported IDE.

Constructors

IdeConfig({required IdeKind ideKind, required String displayName, List<String> processKeywordsMac = const [], List<String> processKeywordsWindows = const [], List<String> processKeywordsLinux = const []})
const

Properties

displayName String
final
hashCode int
The hash code for this object.
no setterinherited
ideKind IdeKind
final
processKeywordsLinux List<String>
final
processKeywordsMac List<String>
final
processKeywordsWindows List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited