IdeLockfileInfo class

Parsed IDE lockfile information.

Constructors

IdeLockfileInfo({required List<String> workspaceFolders, required int port, int? pid, String? ideName, bool useWebSocket = false, bool runningInWindows = false, String? authToken})
const

Properties

authToken String?
final
hashCode int
The hash code for this object.
no setterinherited
ideName String?
final
pid int?
final
port int
final
runningInWindows bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useWebSocket bool
final
workspaceFolders List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited