IdeType enum
Supported IDE types.
Values
- cursor → const IdeType
- windsurf → const IdeType
- vscode → const IdeType
- pycharm → const IdeType
- intellij → const IdeType
- webstorm → const IdeType
- phpstorm → const IdeType
- rubymine → const IdeType
- clion → const IdeType
- goland → const IdeType
- rider → const IdeType
- datagrip → const IdeType
- appcode → const IdeType
- dataspell → const IdeType
- aqua → const IdeType
- gateway → const IdeType
- fleet → const IdeType
- androidstudio → const IdeType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited