LockfileJsonContent class

JSON content of an IDE lockfile.

Constructors

LockfileJsonContent({List<String>? workspaceFolders, int? pid, String? ideName, String? transport, bool? runningInWindows, String? authToken})
const
LockfileJsonContent.fromJson(Map<String, dynamic> json)
factory

Properties

authToken String?
final
hashCode int
The hash code for this object.
no setterinherited
ideName String?
final
pid int?
final
runningInWindows bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport String?
final
workspaceFolders List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited