ImageSizeError class
Error thrown when one or more images exceed the API size limit.
- Implemented types
Constructors
-
ImageSizeError(List<
OversizedImage> oversizedImages, int maxSize)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxSize → int
-
final
- message ↔ String
-
latefinal
-
oversizedImages
→ List<
OversizedImage> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited