ImageWithDimensions class

Image with dimensions and base64 data.

Constructors

ImageWithDimensions({required String base64, required String mediaType, ImageDimensions? dimensions})
const

Properties

base64 String
final
dimensions ImageDimensions?
final
hashCode int
The hash code for this object.
no setterinherited
mediaType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited