pasteThreshold top-level constant
int
const pasteThreshold
Threshold in characters for when to consider text a "large paste".
Implementation
const int pasteThreshold = 800;
Threshold in characters for when to consider text a "large paste".
const int pasteThreshold = 800;