ConversationContext class

Extract key entities from a conversation for context.

Constructors

ConversationContext({Set<String> mentionedFiles = const {}, Set<String> mentionedUrls = const {}, Set<String> mentionedCommands = const {}, String? currentTopic, String? currentLanguage})
const

Properties

currentLanguage String?
final
currentTopic String?
final
hashCode int
The hash code for this object.
no setterinherited
mentionedCommands Set<String>
final
mentionedFiles Set<String>
final
mentionedUrls Set<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

merge(ConversationContext other) ConversationContext
Merge another context into this one, preferring the other's topic/language.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited