MentionSuggestion class

Autocomplete suggestion for @-mentions.

Constructors

MentionSuggestion({required String display, required String completion, required MentionType type, String? description})
const

Properties

completion String
final
description String?
final
display String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type MentionType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited