MdElement class

A parsed markdown element.

Constructors

MdElement({required MdElementType type, String content = '', Map<String, String> attributes = const {}, List<MdElement> children = const [], int level = 0})
const

Properties

attributes Map<String, String>
final
children List<MdElement>
final
content String
final
hashCode int
The hash code for this object.
no setterinherited
level int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type MdElementType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited