BlocksCommandValue class
A structured content block command value.
- Inheritance
-
- Object
- QueuedCommandValue
- BlocksCommandValue
Constructors
-
BlocksCommandValue(List<
ContentBlock> blocks) -
const
Properties
-
blocks
→ List<
ContentBlock> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited