isQueuedCommandEditable method
Whether this queued command can be pulled into the input buffer.
Implementation
bool isQueuedCommandEditable(QueuedCommand cmd) {
return isPromptInputModeEditable(cmd.mode) && !cmd.isMeta;
}
Whether this queued command can be pulled into the input buffer.
bool isQueuedCommandEditable(QueuedCommand cmd) {
return isPromptInputModeEditable(cmd.mode) && !cmd.isMeta;
}