isQueuedCommandVisible method
Whether this queued command should render in the queue preview.
Implementation
bool isQueuedCommandVisible(QueuedCommand cmd) {
if (cmd.origin?.kind == 'channel') return true;
return isQueuedCommandEditable(cmd);
}
Whether this queued command should render in the queue preview.
bool isQueuedCommandVisible(QueuedCommand cmd) {
if (cmd.origin?.kind == 'channel') return true;
return isQueuedCommandEditable(cmd);
}