PastedContent class

Represents pasted content (images) attached to a queued command.

Constructors

PastedContent({required int id, required String type, required String content, String? mediaType, String? filename})
const

Properties

content String
final
filename String?
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
mediaType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited