PopAllEditableResult class

Result of popping all editable commands from the queue.

Constructors

PopAllEditableResult({required String text, required int cursorOffset, required List<PastedContent> images})
const

Properties

cursorOffset int
final
hashCode int
The hash code for this object.
no setterinherited
images List<PastedContent>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited