QueueOperationMessage class

A logged queue operation message.

Constructors

QueueOperationMessage({String type = 'queue-operation', required QueueOperation operation, required String timestamp, required String sessionId, String? content})
const

Properties

content String?
final
hashCode int
The hash code for this object.
no setterinherited
operation QueueOperation
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
timestamp String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited