QueuedCommand class

A command in the unified command queue.

Constructors

QueuedCommand({required QueuedCommandValue value, required PromptInputMode mode, QueuePriority priority = QueuePriority.next, bool skipSlashCommands = false, bool isMeta = false, String? agentId, CommandOrigin? origin, Map<int, PastedContent>? pastedContents})
const

Properties

agentId String?
final
hashCode int
The hash code for this object.
no setterinherited
isMeta bool
final
mode PromptInputMode
final
origin CommandOrigin?
final
pastedContents Map<int, PastedContent>?
final
priority QueuePriority
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipSlashCommands bool
final
value QueuedCommandValue
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited