ToolUseInfo class
Information about a tool use extracted from a normalized message.
Constructors
- ToolUseInfo({required String messageId, required String toolUseId, required String toolName})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited