AttachmentMessage class

Attachment message.

Inheritance

Constructors

AttachmentMessage({String? uuid, String? timestamp, required Map<String, dynamic> attachment})

Properties

attachment → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → String
final
type → MessageType
no setteroverride
uuid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited