ProgressMessage class

Progress message for tool execution.

Inheritance

Constructors

ProgressMessage({String? uuid, String? timestamp, required String toolUseID, required String parentToolUseID, required Map<String, dynamic> data})

Properties

data → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
parentToolUseID → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → String
final
toolUseID → String
final
type → MessageType
no setteroverride
uuid → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited