ToolUseBlock class

Tool use content block.

Inheritance

Constructors

ToolUseBlock({required String id, required String name, required Map<String, dynamic> input, String? caller})

Properties

caller → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
input → Map<String, dynamic>
final
name → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setteroverride

Methods

copyWith({String? id, String? name, Map<String, dynamic>? input, String? caller}) → ToolUseBlock
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited