buildYoloRejectionMessage function

String buildYoloRejectionMessage(
  1. String reason
)

Build a rejection message for auto mode classifier denials.

Implementation

String buildYoloRejectionMessage(String reason) {
  return '$_autoModeRejectionPrefix$reason. '
      "If you have other tasks that don't depend on this action, continue "
      'working on those. $denialWorkaroundGuidance '
      'To allow this type of action in the future, the user can add a '
      'permission rule to their settings.';
}