Migration class

Migration step definition.

Constructors

Migration({required int fromVersion, required int toVersion, required String description, required Future<Map<String, dynamic>> migrate(Map<String, dynamic> data)})
const

Properties

description String
final
fromVersion int
final
hashCode int
The hash code for this object.
no setterinherited
migrate Future<Map<String, dynamic>> Function(Map<String, dynamic> data)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toVersion int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited