MigrationResult class

Result of running migrations.

Constructors

MigrationResult({required bool success, required int fromVersion, required int toVersion, List<String> migrationsApplied = const [], List<String> errors = const [], String? backupPath})
const

Properties

backupPath → String?
final
errors → List<String>
final
fromVersion → int
final
hashCode → int
The hash code for this object.
no setterinherited
migrationsApplied → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → bool
final
toVersion → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited