ModelConfig class

A model configuration across all providers.

Constructors

ModelConfig({required String id, required String displayName, required ModelFamily family, required Map<ModelProvider, String> providerIds, int maxInputTokens = 200000, int maxOutputTokens = 8192, bool supportsThinking = true, bool supportsImages = true, bool supportsComputerUse = false, bool supportsPdfInput = true, bool supportsWebSearch = false, bool supportsCaching = true, bool supports1mContext = false, DateTime? releaseDate, bool deprecated = false})
const

Properties

deprecated → bool
final
displayName → String
final
family → ModelFamily
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
maxInputTokens → int
final
maxOutputTokens → int
final
providerIds → Map<ModelProvider, String>
final
releaseDate → DateTime?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supports1mContext → bool
final
supportsCaching → bool
final
supportsComputerUse → bool
final
supportsImages → bool
final
supportsPdfInput → bool
final
supportsThinking → bool
final
supportsWebSearch → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited