ModelPricing class

Model pricing (per million tokens).

Constructors

ModelPricing({required double inputPerMillion, required double outputPerMillion, double? cacheCreationPerMillion, double? cacheReadPerMillion})
const

Properties

cacheCreationPerMillion double?
final
cacheReadPerMillion double?
final
hashCode int
The hash code for this object.
no setterinherited
inputPerMillion double
final
outputPerMillion double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited