LockInfo class

Diagnostic lock information.

Constructors

LockInfo({required String version, required int pid, required bool isProcessRunning, required String execPath, required DateTime acquiredAt, required String lockFilePath})
const

Properties

acquiredAt DateTime
final
execPath String
final
hashCode int
The hash code for this object.
no setterinherited
isProcessRunning bool
final
lockFilePath String
final
pid int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited