VersionLockContent class

Content stored in a version lock file.

Constructors

VersionLockContent({required int pid, required String version, required String execPath, required int acquiredAt})
const

Properties

acquiredAt int
final
execPath String
final
hashCode int
The hash code for this object.
no setterinherited
pid int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) VersionLockContent?