MemoryFileInfo class

Information about a loaded memory file.

Constructors

MemoryFileInfo({required String path, required MemoryType type, required String content, String? parent, List<String>? globs, bool contentDiffersFromDisk = false, String? rawContent})
const

Properties

content → String
The processed content of the file.
final
contentDiffersFromDisk → bool
True when auto-injection transformed content so it no longer matches disk bytes.
final
globs → List<String>?
Glob patterns for file paths this rule applies to (from frontmatter).
final
hashCode → int
The hash code for this object.
no setterinherited
parent → String?
Path of the file that included this one (via @include).
final
path → String
Absolute path to the file.
final
rawContent → String?
The unmodified disk bytes when contentDiffersFromDisk is true.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → MemoryType
The type of memory file.
final

Methods

copyWith({String? path, MemoryType? type, String? content, String? parent, List<String>? globs, bool? contentDiffersFromDisk, String? rawContent}) → MemoryFileInfo
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited