contentDiffersFromDisk property
True when auto-injection transformed content so it no longer matches disk bytes.
Implementation
final bool contentDiffersFromDisk;
True when auto-injection transformed content so it no longer matches disk bytes.
final bool contentDiffersFromDisk;