FileWatcher class

Watches a file or directory for changes, emitting FileEvents.

Constructors

FileWatcher()
Returns the singleton FileWatcher instance.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stopAll() Future<void>
Stops all active watchers.
toString() String
A string representation of this object.
inherited
watch(String path, {WatcherConfig config = const WatcherConfig()}) Stream<FileEvent>
Starts watching path with the provided config.

Operators

operator ==(Object other) bool
The equality operator.
inherited