GitignoreParser class
Parses .gitignore-style patterns and determines whether paths are ignored.
Constructors
- GitignoreParser.parse(String content)
-
Parses gitignore
content(the text of a.gitignorefile).factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isIgnored(
String path, {bool isDirectory = false}) → bool -
Returns
trueif the givenpathwould be ignored by the parsed rules. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
loadFromFile(
String path) → Future< GitignoreParser> -
Loads and parses a
.gitignorefile atpath.