GlobMatcher class

Compiles shell-style glob patterns to RegExp and matches paths.

Constructors

GlobMatcher.compile(String pattern)
Compiles a glob pattern into a GlobMatcher.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
pattern String
The original glob pattern string.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

match(String path) bool
Returns true if path matches this glob pattern.
matchAll(List<String> paths) List<String>
Filters paths, returning only those that match.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited