WatcherConfig class
Configuration for FileWatcher.
Constructors
Properties
- debounce → Duration
-
Minimum time between emitted events for the same path.
final
-
filters
→ List<
String> -
If non-empty, only events for paths matching one of these extensions
(e.g.
.dart,.ts) will be emitted.final - hashCode → int
-
The hash code for this object.
no setterinherited
- ignoreHidden → bool
-
If
true, hidden files (starting with.) are ignored.final -
ignorePatterns
→ List<
String> -
Glob patterns for paths to ignore entirely.
final
- recursive → bool
-
Whether to watch subdirectories recursively.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited