CommandMetadata class

Command metadata for plugin manifest or marketplace entry.

Constructors

CommandMetadata({String? source, String? content, String? description, String? argumentHint, String? model, List<String>? allowedTools})
const
CommandMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

allowedTools List<String>?
final
argumentHint String?
final
content String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
Validate that exactly one of source or content is present.
no setter
model String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited