PluginManifest class
Plugin manifest (plugin.json) data model.
Constructors
-
PluginManifest({required String name, String? version, String? description, PluginAuthor? author, String? homepage, String? repository, String? license, List<
String> ? keywords, List<String> ? dependencies, Map<String, dynamic> ? hooks, dynamic commands, dynamic agents, dynamic skills, dynamic outputStyles, Map<String, dynamic> ? mcpServers, Map<String, PluginUserConfigOption> ? userConfig, List<Map< ? channels})String, dynamic> > -
const
-
PluginManifest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- agents → dynamic
-
final
-
final
-
channels
→ List<
Map< ?String, dynamic> > -
final
- commands → dynamic
-
final
-
dependencies
→ List<
String> ? -
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- homepage → String?
-
final
-
hooks
→ Map<
String, dynamic> ? -
final
-
keywords
→ List<
String> ? -
final
- license → String?
-
final
-
mcpServers
→ Map<
String, dynamic> ? -
final
- name → String
-
final
- outputStyles → dynamic
-
final
- repository → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skills → dynamic
-
final
-
userConfig
→ Map<
String, PluginUserConfigOption> ? -
final
- version → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited