PluginMarketplace class

Marketplace manifest data model.

Constructors

PluginMarketplace({required String name, required List<PluginMarketplaceEntry> plugins, MarketplaceMetadata? metadata})
const
PluginMarketplace.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata MarketplaceMetadata?
final
name String
final
plugins List<PluginMarketplaceEntry>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited