PluginMarketplaceEntry class

Marketplace entry for a plugin.

Constructors

PluginMarketplaceEntry({required String name, String? description, String? version, dynamic source, String? category, List<String>? tags, bool? strict, String? id, bool? autoUpdate})
const
PluginMarketplaceEntry.fromJson(Map<String, dynamic> json)
factory

Properties

autoUpdate bool?
final
category String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
id String?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source → dynamic
final
strict bool?
final
tags List<String>?
final
version String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited