PluginSourceConfig class

Plugin source configuration for marketplace validation.

Constructors

PluginSourceConfig({required String type, String? repo, String? url})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
repo String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final
url String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited