PluginUserConfigOption class

User-configurable option in plugin manifest.

Constructors

PluginUserConfigOption({required String type, required String title, required String description, bool? required, dynamic defaultValue, bool? multiple, bool? sensitive, num? min, num? max})
const
PluginUserConfigOption.fromJson(Map<String, dynamic> json)
factory

Properties

defaultValue → dynamic
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
max num?
final
min num?
final
multiple bool?
final
required bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensitive bool?
final
title String
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

validTypes → const List<String>