ValidationResult class

Result of validating a plugin file.

Constructors

ValidationResult({required bool success, required List<ValidationError> errors, required List<ValidationWarning> warnings, required String filePath, required PluginFileType fileType})
const

Properties

errors List<ValidationError>
final
filePath String
final
fileType PluginFileType
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final
warnings List<ValidationWarning>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited