ProcessConfig class

Configuration for running a process.

Constructors

ProcessConfig({required String command, List<String> args = const [], String? workDir, Map<String, String>? env, Duration? timeout, String? stdin, bool captureStdout = true, bool captureStderr = true, bool runInShell = false})
const

Properties

args List<String>
final
captureStderr bool
final
captureStdout bool
final
command String
final
env Map<String, String>?
final
fullCommand String
Full command string for display purposes.
no setter
hashCode int
The hash code for this object.
no setterinherited
runInShell bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stdin String?
final
timeout Duration?
final
workDir String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited