ProcessInfo class

Information about a running or completed process.

Constructors

ProcessInfo({required int pid, required String command, required DateTime startTime, ProcessStatus status = ProcessStatus.running})

Properties

command String
final
hashCode int
The hash code for this object.
no setterinherited
pid int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime
final
status ProcessStatus
getter/setter pair
uptime Duration
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited