ManagedProcess class

A managed process with streaming I/O.

Properties

exitCode Future<int>
Wait for exit.
no setter
hashCode int
The hash code for this object.
no setterinherited
pid int
PID of the process.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr Stream<String>
Stderr stream.
no setter
stdout Stream<String>
Stdout stream.
no setter

Methods

closeStdin() Future<void>
Close stdin.
kill([ProcessSignal signal = ProcessSignal.sigterm]) bool
Kill the process.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shutdown({Duration grace = const Duration(seconds: 5)}) Future<int>
Graceful shutdown: SIGTERM, wait, then SIGKILL.
toString() String
A string representation of this object.
inherited
write(String data) → void
Write to stdin.
writeln(String data) → void
Write line to stdin.

Operators

operator ==(Object other) bool
The equality operator.
inherited