ProcessOutput class

Result of a process execution.

Constructors

ProcessOutput({required int exitCode, required String stdout, required String stderr, required Duration elapsed, bool timedOut = false})
const

Properties

combined String
no setter
elapsed Duration
final
exitCode int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr String
final
stdout String
final
success bool
no setter
timedOut bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited