BenchmarkedOllamaModel class
Benchmarked Ollama model with latency data.
- Inheritance
-
- Object
- OllamaModelDescriptor
- RankedOllamaModel
- BenchmarkedOllamaModel
Constructors
Properties
- benchmarkMs → int?
-
final
-
families
→ List<
String> ? -
finalinherited
- family → String?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
finalinherited
- parameterSize → String?
-
finalinherited
- quantizationLevel → String?
-
finalinherited
-
reasons
→ List<
String> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score → double
-
finalinherited
- sizeBytes → int?
-
finalinherited
- summary → String
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited