OllamaModelDescriptor class

Ollama model descriptor.

Implementers

Constructors

OllamaModelDescriptor({required String name, int? sizeBytes, String? family, List<String>? families, String? parameterSize, String? quantizationLevel})
const
OllamaModelDescriptor.fromJson(Map<String, dynamic> json)
factory

Properties

families List<String>?
final
family String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
parameterSize String?
final
quantizationLevel String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited