ProfileEnv class
Environment variables for a provider profile.
Constructors
Properties
- chatgptAccountId → String?
-
final
- codexAccountId → String?
-
final
- codexApiKey → String?
-
final
- geminiApiKey → String?
-
final
- geminiBaseUrl → String?
-
final
- geminiModel → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- openaiApiKey → String?
-
final
- openaiBaseUrl → String?
-
final
- openaiModel → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited