ProfileFile class

Persisted profile file structure.

Constructors

ProfileFile({required ProviderProfile profile, required ProfileEnv env, required String createdAt})
const
ProfileFile.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt → String
final
env → ProfileEnv
final
hashCode → int
The hash code for this object.
no setterinherited
profile → ProviderProfile
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited