RankedOllamaModel class

Ranked Ollama model with score and reasons.

Inheritance
Implementers

Constructors

RankedOllamaModel({required String name, int? sizeBytes, String? family, List<String>? families, String? parameterSize, String? quantizationLevel, required double score, required List<String> reasons, required String summary})
const

Properties

families List<String>?
finalinherited
family String?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
finalinherited
parameterSize String?
finalinherited
quantizationLevel String?
finalinherited
reasons List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double
final
sizeBytes int?
finalinherited
summary String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited