ProxyFetchOptions class

Proxy fetch options (Dart equivalent of the TS getProxyFetchOptions).

Constructors

ProxyFetchOptions({TLSConfig? tlsConfig, String? proxyUrl, String? unixSocket, bool keepAlive = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
keepAlive bool
final
proxyUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tlsConfig TLSConfig?
final
unixSocket String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited