TLSConfig class

TLS configuration (mTLS + CA certs).

Constructors

TLSConfig({String? cert, String? key, String? passphrase, List<String>? ca})
const

Properties

ca List<String>?
final
cert String?
final
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isNotEmpty bool
no setter
key String?
final
passphrase String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited