EditContext class
Result of scanning a file for an edit context.
Constructors
- EditContext({required String content, required int lineOffset, required bool truncated})
Properties
- content → String
-
Slice of the file around the match.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineOffset → int
-
1-based line number of content's first line.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- truncated → bool
-
True if maxScanBytes was hit without finding the needle.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited