assertMinVersion method

String? assertMinVersion(
  1. String minVersion
)

Checks if the current version meets the minimum required version.

Returns the minimum version string if the current version is too old, or null if the version is acceptable.

Implementation

String? assertMinVersion(String minVersion) {
  if (semverLt(appVersion, minVersion)) {
    return minVersion;
  }
  return null;
}