ReleaseNotesResult class
Result of checking for release notes.
Constructors
-
ReleaseNotesResult({required bool hasReleaseNotes, required List<
String> releaseNotes}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasReleaseNotes → bool
-
final
-
releaseNotes
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited