RipgrepConfig class

Configuration for how to invoke ripgrep.

Constructors

RipgrepConfig({required RipgrepMode mode, required String command, List<String> args = const [], String? argv0})
const

Properties

args List<String>
final
argv0 String?
final
command String
final
hashCode int
The hash code for this object.
no setterinherited
mode RipgrepMode
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited