RipgrepTimeoutError class

Custom error class for ripgrep timeouts. Allows callers to distinguish between "no matches" and "timed out".

Implemented types

Constructors

RipgrepTimeoutError(String message, List<String> partialResults)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
partialResults List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited