AgentMetadata class

Agent metadata for subagent transcripts.

Constructors

AgentMetadata({required String agentType, String? worktreePath, String? description})
const
AgentMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

agentType String
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
worktreePath String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited