RemoteAgentMetadata class

Remote agent metadata.

Constructors

RemoteAgentMetadata({required String taskId, required String remoteTaskType, required String sessionId, required String title, required String command, required int spawnedAt, String? toolUseId, bool? isLongRunning, bool? isUltraplan, bool? isRemoteReview, Map<String, dynamic>? remoteTaskMetadata})
const
RemoteAgentMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

command String
final
hashCode int
The hash code for this object.
no setterinherited
isLongRunning bool?
final
isRemoteReview bool?
final
isUltraplan bool?
final
remoteTaskMetadata Map<String, dynamic>?
final
remoteTaskType String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
spawnedAt int
final
taskId String
final
title String
final
toolUseId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited