SessionMetadata class

Metadata for a persisted session.

Constructors

SessionMetadata({required String sessionId, String? customTitle, String? aiTitle, String? firstPrompt, String? lastPrompt, String? tag, String? agentName, String? agentColor, String? agentSetting, String? mode, DateTime? lastModified, int? fileSize, WorktreeSessionInfo? worktreeSession, PrLink? prLink})
const

Properties

agentColor String?
final
agentName String?
final
agentSetting String?
final
aiTitle String?
final
customTitle String?
final
displayTitle String
Display title: custom > AI-generated > first prompt > session ID.
no setter
fileSize int?
final
firstPrompt String?
final
hashCode int
The hash code for this object.
no setterinherited
lastModified DateTime?
final
lastPrompt String?
final
mode String?
final
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
tag String?
final
worktreeSession WorktreeSessionInfo?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited