WorktreeSessionInfo class

Worktree session state.

Constructors

WorktreeSessionInfo({required String originalCwd, required String worktreePath, required String worktreeName, String? originalBranch, required String sessionId, bool? hookBased})
const
WorktreeSessionInfo.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hookBased bool?
final
originalBranch String?
final
originalCwd String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
worktreeName String
final
worktreePath String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited