HookResultMessage class

Hook result message from session start/setup hooks.

Constructors

HookResultMessage({String? content, String? hookName, String? toolUseId, String? hookEvent, List<String>? additionalContexts, String? initialUserMessage, List<String>? watchPaths})

Properties

additionalContexts List<String>?
final
content String?
final
hashCode int
The hash code for this object.
no setterinherited
hookEvent String?
final
hookName String?
final
initialUserMessage String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolUseId String?
final
watchPaths List<String>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited