ProcessedResume class
Result of processing a resumed conversation for rendering.
Constructors
Properties
- agentColor → String?
-
final
- agentName → String?
-
final
-
contentReplacements
→ List<
Map< ?String, dynamic> > -
final
-
fileHistorySnapshots
→ List<
Map< ?String, dynamic> > -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
initialState
→ Map<
String, dynamic> -
final
-
messages
→ List<
Map< String, dynamic> > -
final
-
restoredAgentDef
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited