RequiresActionDetails class

Context carried with requires_action transitions.

Constructors

RequiresActionDetails({required String toolName, required String actionDescription, required String toolUseId, required String requestId, Map<String, dynamic>? input})

Properties

actionDescription String
Human-readable summary, e.g. "Editing src/foo.ts".
final
hashCode int
The hash code for this object.
no setterinherited
input Map<String, dynamic>?
Raw tool input — frontend reads from external_metadata.pending_action.input.
final
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolName String
final
toolUseId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited