ResumeLoadResult class

Result of loading a conversation for resume.

Constructors

ResumeLoadResult({required List<Map<String, dynamic>> messages, List<Map<String, dynamic>>? fileHistorySnapshots, List<Map<String, dynamic>>? attributionSnapshots, List<Map<String, dynamic>>? contentReplacements, List<Map<String, dynamic>>? contextCollapseCommits, Map<String, dynamic>? contextCollapseSnapshot, String? sessionId, String? agentName, String? agentColor, String? agentSetting, String? customTitle, String? tag, String? mode, Map<String, dynamic>? worktreeSession, int? prNumber, String? prUrl, String? prRepository})

Properties

agentColor String?
final
agentName String?
final
agentSetting String?
final
attributionSnapshots List<Map<String, dynamic>>?
final
contentReplacements List<Map<String, dynamic>>?
final
contextCollapseCommits List<Map<String, dynamic>>?
final
contextCollapseSnapshot Map<String, dynamic>?
final
customTitle String?
final
fileHistorySnapshots List<Map<String, dynamic>>?
final
hashCode int
The hash code for this object.
no setterinherited
messages List<Map<String, dynamic>>
final
mode String?
final
prNumber int?
final
prRepository String?
final
prUrl String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
tag String?
final
worktreeSession Map<String, dynamic>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited