SessionStartHooksOptions class

Options for processing session start hooks.

Constructors

SessionStartHooksOptions({String? sessionId, String? agentType, String? model, bool? forceSyncExecution})

Properties

agentType String?
final
forceSyncExecution bool?
final
hashCode int
The hash code for this object.
no setterinherited
model String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited