HookSettingsEntry class

Hook settings entry.

Constructors

HookSettingsEntry({required String event, required List<Map<String, dynamic>> hooks})
const

Properties

event String
final
hashCode int
The hash code for this object.
no setterinherited
hooks List<Map<String, dynamic>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited