PermissionSettings class

Permission settings.

Constructors

PermissionSettings({List<String> allow = const [], List<String> deny = const [], List<String> ask = const [], String? defaultMode, bool? disableBypassPermissionsMode, List<String> additionalDirectories = const []})
const
PermissionSettings.fromJson(Map<String, dynamic> json)
factory

Properties

additionalDirectories List<String>
final
allow List<String>
final
ask List<String>
final
defaultMode String?
final
deny List<String>
final
disableBypassPermissionsMode bool?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited