SandboxSettings class

Sandbox settings.

Constructors

SandboxSettings({bool enabled = false, List<String> excludedCommands = const [], List<String> readPaths = const [], List<String> writePaths = const [], bool networkEnabled = true})
const
SandboxSettings.fromJson(Map<String, dynamic> json)
factory

Properties

enabled bool
final
excludedCommands List<String>
final
hashCode int
The hash code for this object.
no setterinherited
networkEnabled bool
final
readPaths List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writePaths List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited