SettingsChange class

Detect changes between two settings.

Constructors

SettingsChange({required String field, required dynamic oldValue, required dynamic newValue})
const

Properties

field String
final
hashCode int
The hash code for this object.
no setterinherited
newValue → dynamic
final
oldValue → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited