ShellConfig class

Shell provider configuration.

Constructors

ShellConfig({required ShellType type, required String shellPath, bool detached = false, Map<String, String> environmentOverrides = const {}})
const

Properties

detached bool
final
environmentOverrides Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shellPath String
final
type ShellType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited