DailyActivity class
Daily activity aggregate for heatmap / trend display.
Constructors
- DailyActivity({required String date, int messageCount = 0, int sessionCount = 0, int toolCallCount = 0})
-
DailyActivity.fromJson(Map<
String, dynamic> json) -
factory
Properties
- date → String
-
Date in YYYY-MM-DD format.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageCount ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionCount ↔ int
-
getter/setter pair
- toolCallCount ↔ int
-
getter/setter pair
Methods
-
copyWith(
{String? date, int? messageCount, int? sessionCount, int? toolCallCount}) → DailyActivity -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited