ModelUsage class
Aggregated model usage.
Constructors
Properties
- cacheCreationInputTokens ↔ int
-
getter/setter pair
- cacheReadInputTokens ↔ int
-
getter/setter pair
- contextWindow ↔ int
-
getter/setter pair
- costUSD ↔ double
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputTokens ↔ int
-
getter/setter pair
- maxOutputTokens ↔ int
-
getter/setter pair
- outputTokens ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webSearchRequests ↔ int
-
getter/setter pair
Methods
-
merge(
ModelUsage other) → ModelUsage - Merge another ModelUsage into this one (additive).
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited