NeomageStats class
Complete aggregated stats returned by aggregateNeomageStats.
Constructors
-
NeomageStats({int totalSessions = 0, int totalMessages = 0, int totalDays = 0, int activeDays = 0, StreakInfo streaks = const StreakInfo(), List<
DailyActivity> dailyActivity = const [], List<DailyModelTokens> dailyModelTokens = const [], SessionStats? longestSession, Map<String, ModelUsage> modelUsage = const {}, String? firstSessionDate, String? lastSessionDate, String? peakActivityDay, int? peakActivityHour, int totalSpeculationTimeSavedMs = 0, Map<int, int> ? shotDistribution, int? oneShotRate})
Properties
- activeDays → int
-
final
-
dailyActivity
→ List<
DailyActivity> -
final
-
dailyModelTokens
→ List<
DailyModelTokens> -
final
- firstSessionDate → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastSessionDate → String?
-
final
- longestSession → SessionStats?
-
final
-
modelUsage
→ Map<
String, ModelUsage> -
final
- oneShotRate → int?
-
final
- peakActivityDay → String?
-
final
- peakActivityHour → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shotDistribution
→ Map<
int, int> ? -
Shot distribution: map of shot count -> number of sessions (ant-only).
final
- streaks → StreakInfo
-
final
- totalDays → int
-
final
- totalMessages → int
-
final
- totalSessions → int
-
final
- totalSpeculationTimeSavedMs → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited