lastComputedDate property
Last date that was fully computed (YYYY-MM-DD format). Stats up to and including this date are considered complete.
Implementation
final String? lastComputedDate;
Last date that was fully computed (YYYY-MM-DD format). Stats up to and including this date are considered complete.
final String? lastComputedDate;