ProcessOptions class

Options for processing session files.

Constructors

ProcessOptions({String? fromDate, String? toDate})
const

Properties

fromDate String?
Only include data from dates >= this date (YYYY-MM-DD format).
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toDate String?
Only include data from dates <= this date (YYYY-MM-DD format).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited