ProcessedStats class
Result of processing session files — intermediate stats that can be merged.
Constructors
-
ProcessedStats({List<
DailyActivity> dailyActivity = const [], List<DailyModelTokens> dailyModelTokens = const [], Map<String, ModelUsage> modelUsage = const {}, List<SessionStats> sessionStats = const [], Map<int, int> hourCounts = const {}, int totalMessages = 0, int totalSpeculationTimeSavedMs = 0, Map<int, int> ? shotDistribution})
Properties
-
dailyActivity
→ List<
DailyActivity> -
final
-
dailyModelTokens
→ List<
DailyModelTokens> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hourCounts
→ Map<
int, int> -
final
-
modelUsage
→ Map<
String, ModelUsage> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessionStats
→ List<
SessionStats> -
final
-
shotDistribution
→ Map<
int, int> ? -
final
- totalMessages → int
-
final
- totalSpeculationTimeSavedMs → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited