StreakInfo class

Streak calculation results.

Constructors

StreakInfo({int currentStreak = 0, int longestStreak = 0, String? currentStreakStart, String? longestStreakStart, String? longestStreakEnd})
const

Properties

currentStreak int
final
currentStreakStart String?
final
hashCode int
The hash code for this object.
no setterinherited
longestStreak int
final
longestStreakEnd String?
final
longestStreakStart String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited