ModeSetRequestMessage class

Mode set request from leader to teammate.

Constructors

ModeSetRequestMessage({required String mode, required String from})
ModeSetRequestMessage.fromJson(Map<String, dynamic> json)
factory

Properties

from String
final
hashCode int
The hash code for this object.
no setterinherited
mode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

messageType → const String