PlanApprovalRequestMessage class
Plan approval request from teammate to leader.
Constructors
- PlanApprovalRequestMessage({required String from, required String timestamp, required String planFilePath, required String planContent, required String requestId})
-
PlanApprovalRequestMessage.fromJson(Map<
String, dynamic> json) -
factory
Properties
- from → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- planContent → String
-
final
- planFilePath → String
-
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- messageType → const String