PlanApprovalResponseMessage class

Plan approval response from leader to teammate.

Constructors

PlanApprovalResponseMessage({required String requestId, required bool approved, String? feedback, required String timestamp, String? permissionMode})
PlanApprovalResponseMessage.fromJson(Map<String, dynamic> json)
factory

Properties

approved bool
final
feedback String?
final
hashCode int
The hash code for this object.
no setterinherited
permissionMode String?
final
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

messageType → const String