SandboxPermissionRequestMessage class

Sandbox permission request from worker to leader.

Constructors

SandboxPermissionRequestMessage({required String requestId, required String workerId, required String workerName, String? workerColor, required Map<String, dynamic> hostPattern, required int createdAt})
SandboxPermissionRequestMessage.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt int
final
hashCode int
The hash code for this object.
no setterinherited
hostPattern Map<String, dynamic>
final
requestId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workerColor String?
final
workerId String
final
workerName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

messageType → const String