ConsoleTelemetrySink class

Prints telemetry events to stderr when running in debug mode.

Implemented types

Constructors

ConsoleTelemetrySink({bool verbose = false})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Human-readable name of this sink.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
final

Methods

dispose() Future<void>
Perform any necessary cleanup.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(List<TelemetryEvent> events) Future<bool>
Send a batch of events. Returns true on success.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited