PerformanceMetric class

Result of a timed operation.

Constructors

PerformanceMetric({required String operationId, required Duration duration, required DateTime startTime, Map<String, dynamic> metadata = const {}})

Properties

duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
metadata → Map<String, dynamic>
final
operationId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited