TelemetryEventType enum
Categories of telemetry events emitted throughout the application.
Values
- toolUse → const TelemetryEventType
- apiCall → const TelemetryEventType
- commandRun → const TelemetryEventType
- error → const TelemetryEventType
- sessionStart → const TelemetryEventType
- sessionEnd → const TelemetryEventType
- permissionGrant → const TelemetryEventType
- permissionDeny → const TelemetryEventType
- modelSwitch → const TelemetryEventType
- compaction → const TelemetryEventType
- memoryWrite → const TelemetryEventType
- mcpConnect → const TelemetryEventType
- hookRun → const TelemetryEventType
- featureFlag → const TelemetryEventType
- performance → const TelemetryEventType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TelemetryEventType> - A constant List of the values in this enum, in order of their declaration.