TelemetrySink class abstract

Destination for telemetry events.

Implementers

Constructors

TelemetrySink()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Human-readable name of this sink.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() Future<void>
Perform any necessary cleanup.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(List<TelemetryEvent> events) Future<bool>
Send a batch of events. Returns true on success.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited