Span class

A span of text optionally highlighted.

Constructors

Span(String text, {bool isHighlighted = false})
const

Properties

hashCode int
The hash code for this object.
no setteroverride
isHighlighted bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override