LayoutDimensions class

Layout dimensions for the Logo component.

Constructors

LayoutDimensions({required int leftWidth, required int rightWidth, required int totalWidth})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
leftWidth int
final
rightWidth int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalWidth int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited