ModelPricing class

Per-token pricing for a single model in USD.

Constructors

ModelPricing({required String name, required double inputPerMillion, required double outputPerMillion, double cacheReadPerMillion = 0, double cacheWritePerMillion = 0, int maxInputTokens = 200000, int maxOutputTokens = 8192})
const

Properties

cacheReadPerMillion double
final
cacheWritePerMillion double
final
hashCode int
The hash code for this object.
no setterinherited
inputPerMillion double
final
maxInputTokens int
final
maxOutputTokens int
final
name String
final
outputPerMillion double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited