ModelPricingTable class
Known model pricing constants (as of early 2025).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
forModel(
String model) → ModelPricing - Look up pricing by model name. Falls back to neomageSonnet.
Constants
- gpt4o → const ModelPricing
- gpt4oMini → const ModelPricing
- neomageHaiku → const ModelPricing
- neomageOpus → const ModelPricing
- neomageSonnet → const ModelPricing