PersistedToolResult class

Result of persisting a tool result to disk.

Constructors

PersistedToolResult({required String filepath, required int originalSize, required bool isJson, required String preview, required bool hasMore})
const

Properties

filepath String
final
hashCode int
The hash code for this object.
no setterinherited
hasMore bool
final
isJson bool
final
originalSize int
final
preview String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited