ToolResultBlock class

Simplified representation of a tool result content block.

Constructors

ToolResultBlock({required String toolUseId, dynamic content, bool isError = false})

Properties

content ↔ dynamic
Can be a String or a List<ContentBlock>.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isError bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolUseId String
final

Methods

copyWith({String? toolUseId, dynamic content, bool? isError}) ToolResultBlock
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited