getToolResultPath method
Get the filepath where a tool result would be persisted.
Implementation
String getToolResultPath(String id, {required bool isJson}) {
final ext = isJson ? 'json' : 'txt';
return '${getToolResultsDir()}/$id.$ext';
}
Get the filepath where a tool result would be persisted.
String getToolResultPath(String id, {required bool isJson}) {
final ext = isJson ? 'json' : 'txt';
return '${getToolResultsDir()}/$id.$ext';
}