DeferredToolsDelta class

Represents changes to the deferred tool pool.

Constructors

DeferredToolsDelta({required List<String> addedNames, required List<String> addedLines, required List<String> removedNames})
const

Properties

addedLines List<String>
final
addedNames List<String>
final
hashCode int
The hash code for this object.
no setterinherited
removedNames List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited