DeferredToolsDeltaScanContext class
Context for deferred tools delta scanning.
Constructors
- DeferredToolsDeltaScanContext({required DeferredToolsDeltaScanCallSite callSite, String? querySource})
-
const
Properties
- callSite → DeferredToolsDeltaScanCallSite
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- querySource → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited