ToolDefinition class

Represents a tool definition with metadata for search and filtering.

Constructors

ToolDefinition({required String name, String description = '', Map<String, dynamic>? inputSchema, Map<String, dynamic>? inputJsonSchema, bool isMcp = false, bool shouldDefer = false, bool renderGroupedToolUse = false})
const

Properties

description String
final
hashCode int
The hash code for this object.
no setteroverride
inputJsonSchema Map<String, dynamic>?
final
inputSchema Map<String, dynamic>?
final
isDeferred bool
Whether this tool is a deferred tool (MCP or shouldDefer).
no setter
isMcp bool
final
name String
final
renderGroupedToolUse bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldDefer bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override