onInit method

  1. @override
void onInit()
override

Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.

Implementation

@override
void onInit() {
  super.onInit();
  mode.value = getToolSearchMode();
  optimisticEnabled.value = isToolSearchEnabledOptimistic();
}