ToolSearchMessage class

Minimal message representation for tool reference extraction.

Constructors

ToolSearchMessage({required String type, String? subtype, Map<String, dynamic>? message, Map<String, dynamic>? compactMetadata, Map<String, dynamic>? attachment})
const

Properties

attachment Map<String, dynamic>?
final
compactMetadata Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
message Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtype String?
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited