ToolSearchMode enum

Tool search mode. Determines how deferrable tools (MCP + shouldDefer) are surfaced:

  • tst: Tool Search Tool -- deferred tools discovered via ToolSearchTool
  • tstAuto: auto -- tools deferred only when they exceed threshold
  • standard: tool search disabled -- all tools exposed inline
Inheritance
Available extensions

Values

tst → const ToolSearchMode
tstAuto → const ToolSearchMode
standard → const ToolSearchMode

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ToolSearchMode>
A constant List of the values in this enum, in order of their declaration.