WorktreeSession class
Represents an active worktree session.
Constructors
- WorktreeSession({required String originalCwd, required String worktreePath, required String worktreeName, String? worktreeBranch, String? originalBranch, String? originalHeadCommit, required String sessionId, String? tmuxSessionName, bool hookBased = false, int? creationDurationMs, bool usedSparsePaths = false})
-
const
-
WorktreeSession.fromJson(Map<
String, dynamic> json) -
factory
Properties
- creationDurationMs → int?
-
How long worktree creation took (unset when resuming an existing worktree).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hookBased → bool
-
final
- originalBranch → String?
-
final
- originalCwd → String
-
final
- originalHeadCommit → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
- tmuxSessionName → String?
-
final
- usedSparsePaths → bool
-
True if git sparse-checkout was applied via settings.worktree.sparsePaths.
final
- worktreeBranch → String?
-
final
- worktreeName → String
-
final
- worktreePath → String
-
final
Methods
-
copyWith(
{String? originalCwd, String? worktreePath, String? worktreeName, String? worktreeBranch, String? originalBranch, String? originalHeadCommit, String? sessionId, String? tmuxSessionName, bool? hookBased, int? creationDurationMs, bool? usedSparsePaths}) → WorktreeSession -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited