FileStat class

Properties

accessed DateTime
final
changed DateTime
final
hashCode int
The hash code for this object.
no setterinherited
mode int
final
modified DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
type FileSystemEntityType
final

Methods

modeString() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

stat(String path) Future<FileStat>
statSync(String path) FileStat