HttpClientRequest class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → HttpHeaders
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
List< int> data) → void -
close(
) → Future< HttpClientResponse> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
Object? obj) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited