HttpHeaders class abstract
Constructors
Properties
- contentLength ↔ int
-
getter/setter pair
- contentType ↔ ContentType?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
add(
String name, Object value, {bool preserveHeaderCase = false}) → void -
forEach(
void action(String name, List< String> values)) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
String name, Object value) → void -
removeAll(
String name) → void -
set(
String name, Object value, {bool preserveHeaderCase = false}) → void -
toString(
) → String -
A string representation of this object.
inherited
-
value(
String name) → String?
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String name) → List< String> ?
Constants
- acceptHeader → const String
- contentTypeHeader → const String