HttpResponse class abstract
- Implemented types
Constructors
Properties
- done → Future
-
no setterinherited
- encoding ↔ Encoding
-
getter/setter pairinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → HttpHeaders
-
no setter
- reasonPhrase ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode ↔ int
-
getter/setter pair
Methods
-
add(
List< int> data) → void -
inherited
-
addError(
Object error, [StackTrace? stackTrace]) → void -
inherited
-
addStream(
Stream< List< stream) → Futureint> > -
inherited
-
close(
) → Future -
override
-
flush(
) → Future -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
Object? object) → void -
Writes the string representation of
object.inherited -
writeAll(
Iterable objects, [String separator = ""]) → void -
Writes the elements of
objectsseparated byseparator.inherited -
writeCharCode(
int charCode) → void -
Writes a string containing the character with code point
charCode.inherited -
writeln(
[Object? object = ""]) → void -
Writes the string representation of
objectfollowed by a newline.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited