InternetAddress class
Constructors
- InternetAddress(String address)
-
factory
Properties
- address → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → InternetAddressType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- anyIPv4 → InternetAddress
-
final
- anyIPv6 → InternetAddress
-
final
- loopbackIPv4 → InternetAddress
-
final
- loopbackIPv6 → InternetAddress
-
final
Static Methods
-
lookup(
String host, {InternetAddressType type = InternetAddressType.any}) → Future< List< InternetAddress> >