ProcessException class

Implemented types

Constructors

ProcessException(String executable, List<String> arguments, [String message = '', int errorCode = 0])
const

Properties

arguments List<String>
final
errorCode int
final
executable String
final
hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited