ProcessSignal class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
watch(
) → Stream< ProcessSignal>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- sigcont → const ProcessSignal
- sighup → const ProcessSignal
- sigint → const ProcessSignal
- sigkill → const ProcessSignal
- sigterm → const ProcessSignal
- sigusr1 → const ProcessSignal
- sigusr2 → const ProcessSignal
- sigwinch → const ProcessSignal