SecurityContext class
Constructors
- SecurityContext({bool withTrustedRoots = false})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAlpnProtocols(
List< String> protocols, bool isServer) → void -
setClientAuthorities(
String file) → void -
setClientAuthoritiesBytes(
List< int> authCertBytes) → void -
setTrustedCertificates(
String file) → void -
setTrustedCertificatesBytes(
List< int> certBytes) → void -
toString(
) → String -
A string representation of this object.
inherited
-
useCertificateChain(
String file) → void -
useCertificateChainBytes(
List< int> chainBytes) → void -
usePrivateKey(
String file, {String? password}) → void -
usePrivateKeyBytes(
List< int> keyBytes, {String? password}) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- defaultContext → SecurityContext
-
no setter