Socket class

Constructors

Socket()

Properties

address InternetAddress
no setter
hashCode int
The hash code for this object.
no setterinherited
port int
no setter
remoteAddress InternetAddress
no setter
remotePort int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<Uint8List>
no setter

Methods

add(List<int> data) → void
close() Future
destroy() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
write(Object? object) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

connect(dynamic host, int port, {dynamic sourceAddress, int sourcePort = 0, Duration? timeout}) Future<Socket>