RunningProcess class abstract

Handle for a long-running process.

Constructors

RunningProcess()

Properties

exitCode Future<int>
Completes with the exit code when the process terminates.
no setter
hashCode int
The hash code for this object.
no setterinherited
pid int
Process identifier.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr Stream<String>
Standard error stream (line-based).
no setter
stdout Stream<String>
Standard output stream (line-based).
no setter

Methods

kill() bool
Send a signal to the process. Returns true if the signal was delivered.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeToStdin(String data) → void
Write to the process stdin.

Operators

operator ==(Object other) bool
The equality operator.
inherited