FileAnalyticsSink class
File-based analytics sink for offline storage.
- Implemented types
Constructors
- FileAnalyticsSink({required String filePath, int maxBufferSize = 100})
Properties
- filePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEnabled → bool
-
Whether this sink is enabled.
no setteroverride
- maxBufferSize → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
Dispose resources.
override
-
flush(
) → Future< void> -
Flush pending events.
override
-
logEvent(
AnalyticsEvent event) → Future< void> -
Send an event to this sink.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited