InMemoryAnalyticsSink class
In-memory analytics sink for local debugging.
- Implemented types
Constructors
Properties
-
events
→ List<
AnalyticsEvent> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEnabled → bool
-
Whether this sink is enabled.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void - Clear all events.
-
dispose(
) → Future< void> -
Dispose resources.
override
-
flush(
) → Future< void> -
Flush pending events.
override
-
getByName(
String name) → List< AnalyticsEvent> - Get events by name.
-
logEvent(
AnalyticsEvent event) → Future< void> -
Send an event to this sink.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited