FeatureFlag<T> class

Feature flag value.

Constructors

FeatureFlag({required String key, required T defaultValue})

Properties

defaultValue → T
final
hashCode int
The hash code for this object.
no setterinherited
isOverridden bool
Whether this flag has been overridden from default.
no setter
key String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value → T
Current value.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
Reset to default.
toString() String
A string representation of this object.
inherited
update(T newValue) → void
Set value from remote config.

Operators

operator ==(Object other) bool
The equality operator.
inherited