RetryContext class

Context tracked across retry attempts.

Constructors

RetryContext()
Creates a fresh retry context with zero attempts.

Properties

attempt int
Current attempt number (starts at 0).
getter/setter pair
consecutive529s int
Number of consecutive 529 (overloaded) errors.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastRetry DateTime?
Timestamp of the most recent retry.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited