StreamAssembler class
Stream assembler — processes raw SSE events into StreamUpdates and maintains a StreamingState that accumulates the full message.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → StreamingState
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
processEvent(
String eventType, Map< String, dynamic> data) → void - Process a raw SSE event type and JSON data payload.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited