ToolUseAccumulator class

Accumulates tool_use JSON input from partial_json deltas.

Inheritance

Constructors

ToolUseAccumulator(int index, {required String toolId, required String toolName})

Properties

currentJson String
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
finalinherited
parsedInput Map<String, dynamic>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolId String
final
toolName String
final

Methods

append(String partialJson) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toContentBlock() ContentBlock
Build the final ContentBlock.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited