UsageUpdate class
Token usage update.
- Inheritance
-
- Object
- StreamUpdate
- UsageUpdate
Constructors
- UsageUpdate({required int inputTokens, required int outputTokens, int? cacheCreationInputTokens, int? cacheReadInputTokens})
-
const
Properties
- cacheCreationInputTokens → int?
-
final
- cacheReadInputTokens → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputTokens → int
-
final
- outputTokens → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalTokens → int
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited