OAuthTokens class
OAuth tokens with expiration metadata.
Constructors
Properties
- accessToken → String
-
final
- expiresAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isExpired → bool
-
Check if token is expired (with 5-minute buffer).
no setter
- rateLimitTier → String?
-
final
- refreshToken → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
final
- subscriptionType → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited