AppState class
Application-wide bootstrap state.
Constructors
- AppState.initial({String? cwd})
-
Create initial app state.
factory
Properties
- cwd ↔ String
-
getter/setter pair
- fastModeEnabled ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- idleDuration → Duration
-
no setter
- initialMainLoopModel ↔ String?
-
getter/setter pair
- isInteractive ↔ bool
-
getter/setter pair
- kairosActive ↔ bool
-
getter/setter pair
- lastInteractionTime ↔ DateTime
-
getter/setter pair
- linesAdded ↔ int
-
getter/setter pair
- linesRemoved ↔ int
-
getter/setter pair
- mainLoopModelOverride ↔ String?
-
getter/setter pair
- originalCwd ↔ String?
-
getter/setter pair
- parentSessionId ↔ SessionId?
-
getter/setter pair
- projectRoot ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionDuration → Duration
-
no setter
- sessionId ↔ SessionId
-
getter/setter pair
- startTime → DateTime
-
final
- strictToolResultPairing ↔ bool
-
getter/setter pair
- totalApiCalls ↔ int
-
getter/setter pair
- totalApiDuration ↔ Duration
-
getter/setter pair
- totalCostUsd ↔ double
-
getter/setter pair
Methods
-
addApiDuration(
Duration duration) → void -
addCodeChanges(
{int added = 0, int removed = 0}) → void -
addCost(
double cost) → void -
markInteraction(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
regenerateSessionId(
) → void - Regenerate session ID (for new sessions without changing project).
-
switchSession(
{required String sessionId, required String projectDir}) → void - Switch session (atomically changes sessionId and projectDir).
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited