BootstrapConfig class

Constructors

BootstrapConfig({bool debugMode = false, Set<String> skipSteps = const {}, bool skipUpdateCheck = false, bool skipTelemetry = false, bool skipPlugins = false, bool skipMcpServers = false, bool skipDoctor = false, Duration stepTimeout = const Duration(seconds: 30), String? configDir, String? projectDir})
const

Properties

configDir String?
final
debugMode bool
final
hashCode int
The hash code for this object.
no setterinherited
projectDir String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipDoctor bool
final
skipMcpServers bool
final
skipPlugins bool
final
skipSteps Set<String>
final
skipTelemetry bool
final
skipUpdateCheck bool
final
stepTimeout Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shouldSkip(String stepId) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited