BootstrapResult class
Constructors
-
BootstrapResult({required BootstrapResultStatus status, required List<
BootstrapStep> steps, List<String> warnings = const [], List<String> errors = const [], ProjectInfo? projectInfo, List<MemoryFile> memoryFiles = const [], Duration totalDuration = Duration.zero, String? shell, Map<String, dynamic> settings = const {}}) -
const
Properties
-
errors
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
no setter
-
memoryFiles
→ List<
MemoryFile> -
final
- projectInfo → ProjectInfo?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
settings
→ Map<
String, dynamic> -
final
- shell → String?
-
final
- status → BootstrapResultStatus
-
final
-
steps
→ List<
BootstrapStep> -
final
- totalDuration → Duration
-
final
-
warnings
→ List<
String> -
final
Methods
-
formatReport(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited