BootstrapStep class

Constructors

BootstrapStep({required String id, required String name, BootstrapStepStatus status = BootstrapStepStatus.pending, Duration duration = Duration.zero, String? error, String? warning})

Properties

duration Duration
getter/setter pair
error String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status BootstrapStepStatus
getter/setter pair
warning String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited