BridgeProtocolVersion class

Semantic version for the bridge protocol.

Constructors

BridgeProtocolVersion({required int major, required int minor, required int patch})
const
BridgeProtocolVersion.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
major int
final
minor int
final
patch int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isCompatible(BridgeProtocolVersion other) bool
Check if other is compatible with this version.
isNewerThan(BridgeProtocolVersion other) bool
Check if this version is strictly newer than other.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

current → const BridgeProtocolVersion
The current protocol version.