ErrorCode class abstract final

Standard JSON-RPC 2.0 error codes plus custom protocol codes.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

describe(int code) String
Human-readable description of an error code.

Constants

contentModified → const int
internalError → const int
invalidParams → const int
invalidRequest → const int
methodNotFound → const int
parseError → const int
requestCancelled → const int
requestFailed → const int
serverCancelled → const int
serverNotInitialized → const int