MessageSerializer class

Handles serialization/deserialization of JSON-RPC 2.0 messages.

Constructors

MessageSerializer()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

classify(Map<String, dynamic> json) MessageType
Determine the type of a parsed message.
deserialize(String raw) Map<String, dynamic>
Deserialize a raw string into a JSON map.
deserializeBatch(String raw) List<Map<String, dynamic>>
Decode a batch response.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String raw) ProtocolMessage
Parse a raw string into a typed protocol object.
serialize(Map<String, dynamic> message) String
Serialize a message to JSON string.
serializeBatch(List<Map<String, dynamic>> messages) String
Encode a batch of messages for wire transport.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited