DiffRequest class

Diff display request — show a before/after diff in the IDE.

Constructors

DiffRequest({required String filePath, required String originalContent, required String modifiedContent, String? title, bool? readOnly})
const
DiffRequest.fromJson(Map<String, dynamic> json)
factory

Properties

filePath String
final
hashCode int
The hash code for this object.
no setterinherited
modifiedContent String
final
originalContent String
final
readOnly bool?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited