EditRequest class
File edit request — describes a text replacement in a file.
Constructors
- EditRequest({required String filePath, required int startLine, required int startColumn, required int endLine, required int endColumn, required String newText, String? description})
-
const
-
EditRequest.fromJson(Map<
String, dynamic> json) -
factory
- EditRequest.insert(String filePath, int line, int column, String text)
-
Convenience: create an insertion at a position.
factory
- EditRequest.replaceLine(String filePath, int line, String newText)
-
Convenience: create a full-line replacement.
factory
Properties
- description → String?
-
final
- endColumn → int
-
final
- endLine → int
-
final
- filePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- newText → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startColumn → int
-
final
- startLine → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited