JetbrainsModule class

A JetBrains project module.

Constructors

JetbrainsModule({required String name, required String path, String? type, List<String> sourceRoots = const [], List<String> testRoots = const [], List<String> resourceRoots = const [], List<JetbrainsDependency> dependencies = const []})
const
JetbrainsModule.fromJson(Map<String, dynamic> json)
factory

Properties

dependencies List<JetbrainsDependency>
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
path String
final
resourceRoots List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceRoots List<String>
final
testRoots List<String>
final
type String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited