JetbrainsVcsFileStatus class

VCS status of a single file.

Constructors

JetbrainsVcsFileStatus({required String filePath, required JetbrainsVcsStatus status, String? originalPath})
const
JetbrainsVcsFileStatus.fromJson(Map<String, dynamic> json)
factory

Properties

filePath String
final
hashCode int
The hash code for this object.
no setterinherited
originalPath String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status JetbrainsVcsStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited