VscodeSelection class

A text selection with active/anchor positions.

Inheritance

Constructors

VscodeSelection({required int anchorLine, required int anchorCharacter, required int activeLine, required int activeCharacter})
VscodeSelection.fromJson(Map<String, dynamic> json)
factory

Properties

activeCharacter int
final
activeLine int
final
anchorCharacter int
final
anchorLine int
final
endCharacter int
finalinherited
endLine int
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startCharacter int
finalinherited
startLine int
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited