VscodeStatusBarItem class
A VS Code status bar item configuration.
Constructors
- VscodeStatusBarItem({required String id, required String text, String? tooltip, String? command, int? priority, VscodeStatusBarAlignment alignment = VscodeStatusBarAlignment.left, String? color, String? backgroundColor})
-
const
Properties
- alignment → VscodeStatusBarAlignment
-
final
- backgroundColor → String?
-
final
- color → String?
-
final
- command → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- priority → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
- tooltip → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited