VscodeTheme class

Represents a VS Code color theme, usable for syncing the Neomage UI with the editor theme.

Constructors

VscodeTheme({required String name, required VscodeThemeKind kind, Map<String, String> colors = const {}, Map<String, _TokenColor> tokenColors = const {}})
VscodeTheme.fromJson(Map<String, dynamic> json)
factory

Properties

activityBarBackground String?
no setter
buttonBackground String?
no setter
buttonForeground String?
no setter
colors Map<String, String>
final
editorBackground String?
no setter
editorForeground String?
no setter
errorForeground String?
no setter
focusBorder String?
no setter
hashCode int
The hash code for this object.
no setterinherited
inputBackground String?
no setter
inputBorder String?
no setter
inputForeground String?
no setter
isDark bool
Whether this is a dark theme.
no setter
isHighContrast bool
Whether this is a high-contrast theme.
no setter
kind VscodeThemeKind
final
lineHighlightBackground String?
no setter
name String
final
panelBackground String?
no setter
panelBorder String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectionBackground String?
no setter
sideBarBackground String?
no setter
sideBarForeground String?
no setter
statusBarBackground String?
no setter
statusBarForeground String?
no setter
tabActiveBackground String?
no setter
tabInactiveBackground String?
no setter
terminalBackground String?
no setter
terminalForeground String?
no setter
titleBarBackground String?
no setter
tokenColors Map<String, _TokenColor>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toColorMap() Map<String, int>
Convert this theme to a map of color values (int ARGB).
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parseHexColor(String? hex) int?
Parse a CSS hex color string (#RRGGBB or #RRGGBBAA) to an int.