TranscriptEntry class
A transcript entry extended with fork provenance metadata.
Constructors
-
TranscriptEntry({required String sessionId, required String uuid, required String type, String? parentUuid, bool isSidechain = false, required Map<
String, dynamic> rawData, ForkOrigin? forkedFrom}) -
const
-
TranscriptEntry.fromJson(Map<
String, dynamic> json) -
Create from a raw JSON map.
factory
Properties
- forkedFrom → ForkOrigin?
-
Fork provenance: which session/message this was forked from.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSidechain → bool
-
final
- parentUuid → String?
-
final
-
rawData
→ Map<
String, dynamic> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
- type → String
-
final
- uuid → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{String? overrideSessionId, String? overrideParentUuid, bool? overrideIsSidechain, ForkOrigin? overrideForkedFrom}) → Map< String, dynamic> - Serialize to JSON map, applying fork overrides.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited