BridgeController class
Controller for the bridge command UI state.
- Inheritance
-
- Object
- Listenable
- ListNotifier
- SintController
- BridgeController
Constructors
Properties
-
config
→ Rx<
BridgeConfig> -
Current bridge configuration.
final
- dialogSubtitle → String
-
Get the dialog subtitle text.
no setter
- dialogTitle → String
-
Get the dialog title text.
no setter
-
errorMessage
→ Rxn<
String> -
The last error message.
final
- focusIndex → RxInt
-
Focus index for the disconnect dialog menu.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized → bool
-
Checks whether the controller has already been initialized.
no setterinherited
- isClosed → bool
-
Checks whether the controller has already been closed.
no setterinherited
- isConnecting → RxBool
-
Whether a connection attempt is in progress.
final
- isDisposed → bool
-
no setterinherited
- listenersLength → int
-
no setterinherited
-
Get menu options for the disconnect dialog.
no setter
- qrText → RxString
-
QR code text content.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showDisconnectDialog → RxBool
-
Whether the disconnect dialog is visible.
final
- showQR → RxBool
-
Whether QR code is displayed.
final
Methods
-
acceptFocused(
) → String? - Accept the currently focused menu item.
-
addListener(
SintStateUpdate listener) → Disposer -
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(
Object? key, SintStateUpdate listener) → Disposer -
inherited
-
containsListener(
SintStateUpdate listener) → bool -
inherited
-
continueSession(
) → void - Close the disconnect dialog and continue.
-
debounce<
T> (RxInterface< T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void -
Calls
callbackafterrxstops changing forduration. Useful for search-as-you-type, form validation, etc.inherited -
disconnect(
) → void - Disconnect the bridge.
-
dispose(
) → void -
inherited
-
ever<
T> (RxInterface< T> rx, void callback(T)) → void -
Calls
callbackevery timerxchanges. Auto-cancels on controller disposal.inherited -
focusNext(
) → void - Navigate menu focus down.
-
focusPrevious(
) → void - Navigate menu focus up.
-
handleCommand(
{String? name}) → Future< String?> - Handle the /remote-control command.
-
handleMenuSelection(
DisconnectMenuOption option) → String? - Handle menu selection in the disconnect dialog.
-
interval<
T> (RxInterface< T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void -
Calls
callbackat most once perduration, ignoring intermediate changes. Useful for rate-limiting UI updates.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
once<
T> (RxInterface< T> rx, void callback(T)) → void -
Calls
callbackonly the first timerxchanges, then cancels.inherited -
onClose(
) → void -
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
-
onDelete(
) → void -
inherited
-
onInit(
) → void -
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
inherited
-
onReady(
) → void -
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
onStart(
) → void -
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclasses.
This method should be internal and is required to define the
lifetime cycle of the subclass.
inherited
-
refresh(
) → void -
inherited
-
refreshGroup(
Object id) → void -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(
Object id, VoidCallback listener) → void -
inherited
-
reportAdd(
VoidCallback disposer) → void -
inherited
-
reportRead(
) → void -
inherited
-
toggleQR(
) → void - Toggle QR code display.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
[List< Object> ? ids, bool condition = true]) → void -
Notifies listeners to update the UI.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited