data/commands/builtin/init_verifiers_command library
Classes
- InitVerifiersCommand
- The /init-verifiers command — creates verifier skills for automated verification of code changes.
Enums
- VerifierType
- Supported verifier types.
Constants
-
apiAllowedTools
→ const List<
String> - Allowed tools for HTTP API verifiers.
-
apiFrameworkIndicators
→ const Map<
String, String> - API framework indicators (dependency names -> framework name).
-
cliAllowedTools
→ const List<
String> - Allowed tools for CLI/terminal verifiers using Tmux.
-
knownBrowserAutomationServers
→ const List<
String> - Known browser automation MCP server identifiers.
-
manifestFiles
→ const Map<
String, String> - Manifest file names and associated project types.
-
playwrightAllowedTools
→ const List<
String> - Allowed tools for Playwright-based web UI verifiers.
-
playwrightInstallCommands
→ const Map<
String, String> - Playwright installation commands by package manager.
-
webFrameworkIndicators
→ const Map<
String, String> - Web framework indicators (dependency names -> framework name).
Functions
-
allowedToolsYaml(
VerifierType type) → String - Get allowed tools YAML block for a verifier type.
-
defaultVerifierName(
VerifierType type) → String - Get the default verifier name for a type (single-project format).
-
generateVerifierSkillTemplate(
{required String verifierName, required String description, required VerifierType type, required String projectContext, required String setupInstructions, String? authenticationSection}) → String - Generate a SKILL.md template for a verifier.
-
multiProjectVerifierName(
String projectName, VerifierType type) → String - Get the default verifier name for a type in a multi-project repo.
-
verifierTypeLabel(
VerifierType type) → String - Get a human-readable label for a verifier type.