McpAddOptions class

Parsed options for the /mcp add command.

Constructors

McpAddOptions({required String name, required String commandOrUrl, List<String> args = const [], String scope = 'local', String? transport, List<String>? envVars, List<String>? headers, String? clientId, bool clientSecret = false, int? callbackPort, bool xaa = false})
const
McpAddOptions.parse(String rawArgs)
Parse from a raw argument string. Expected format mirrors the CLI: /mcp add [--scope <scope>] [--transport <t>] [-e KEY=val] [-H "Header: val"] [--client-id <id>] [--client-secret] [--callback-port <port>] [--xaa] <name> <command> [args...]
factory

Properties

args List<String>
final
callbackPort int?
final
clientId String?
final
clientSecret bool
final
commandOrUrl String
final
envVars List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
headers List<String>?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
final
transport String?
final
xaa bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited