data/commands/builtin/terminal_setup_command library
Classes
- TerminalSetupCommand
- The /terminal-setup command — configures terminal for Shift+Enter.
Constants
-
nativeCSIuTerminals
→ const Map<
String, String> - Terminals that natively support CSI u / Kitty keyboard protocol.
Functions
-
detectTerminal(
) → String? - Detect the current terminal emulator from environment variables.
-
disableAudioBellForProfile(
String profileName) → Future< bool> - Disable audio bell for a Terminal.app profile.
-
enableOptionAsMetaForProfile(
String profileName) → Future< bool> - Enable Option as Meta key for a Terminal.app profile.
-
enableOptionAsMetaForTerminal(
) → Future< String> - Enable Option as Meta key for Terminal.app.
-
getNativeCSIuTerminalDisplayName(
) → String? - Get display name for a terminal that natively supports CSI u.
-
getTerminalPlistPath(
) → String - Get the Terminal.app plist path.
-
installBindingsForAlacritty(
) → Future< String> - Install Shift+Enter keybinding for Alacritty.
-
installBindingsForVSCodeTerminal(
{String editor = 'VSCode'}) → Future< String> - Install Shift+Enter keybinding for VSCode, Cursor, or Windsurf.
-
installBindingsForZed(
) → Future< String> - Install Shift+Enter keybinding for Zed.
-
isVSCodeRemoteSSH(
) → bool - Detect if we're running in a VSCode Remote SSH session.
-
setupTerminal(
) → Future< String> - Run terminal setup for the detected terminal.
-
shouldOfferTerminalSetup(
) → bool - Whether terminal setup should be offered for the current terminal.