UltraplanPendingChoice class
Pending choice state when plan is ready for user decision.
Constructors
- UltraplanPendingChoice({required String plan, required String sessionId, required String taskId})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited