UltraplanTaskState class

Ultraplan task state tracked by the task framework.

Constructors

UltraplanTaskState({required String taskId, required String sessionId, String? sessionUrl, String status = 'running', UltraplanPhase? ultraplanPhase, int? startTime, int? endTime})
const

Properties

endTime int?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
sessionUrl String?
final
startTime int?
final
status String
final
taskId String
final
ultraplanPhase UltraplanPhase?
final

Methods

copyWith({String? status, UltraplanPhase? ultraplanPhase, int? endTime}) UltraplanTaskState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited