Command class abstract

Abstract base for all commands.

Implementers

Constructors

Command()

Properties

aliases List<String>
Alternative names for the command.
no setter
argumentHint String?
Hint text for arguments.
no setter
description String
User-visible description.
no setter
displayName String
Human-facing display name.
no setter
hashCode int
The hash code for this object.
no setterinherited
immediate bool
Whether to execute immediately without waiting for stop point.
no setter
isEnabled bool
Whether this command is enabled (feature flags, etc).
no setter
isHidden bool
Whether this command is hidden from help/typeahead.
no setter
name String
Command name (without the / prefix).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source CommandSource
Where this command was loaded from.
no setter
type CommandType
Execution type.
no setter
whenToUse String?
When to use this command (for skills discovery).
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited