CompactProgressEvent class
Progress event emitted during compaction.
Constructors
- CompactProgressEvent({required CompactProgressType type, CompactHookType? hookType})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hookType → CompactHookType?
-
Which hook phase this event relates to (only for
hooksStart).final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → CompactProgressType
-
The type of progress event.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited