RecompactionInfo class
Diagnosis context for recompaction tracking.
Constructors
- RecompactionInfo({required bool isRecompactionInChain, required int turnsSincePreviousCompact, String? previousCompactTurnId, required int autoCompactThreshold})
-
const
Properties
- autoCompactThreshold → int
-
Token threshold that triggered auto-compact.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRecompactionInChain → bool
-
Whether this is a recompaction within the same chain.
final
- previousCompactTurnId → String?
-
Turn ID of the previous compaction boundary.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- turnsSincePreviousCompact → int
-
Turns since the previous compaction.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited