ConversationConfig class
Configuration for the conversation engine.
Constructors
-
ConversationConfig({required String model, String? systemPrompt, int maxTurns = 100, int maxTokens = 16000, bool enableThinking = false, int? thinkingBudget, bool enableCaching = true, List<
int> cacheBreakpoints = const [], Duration toolTimeout = const Duration(minutes: 2), bool planMode = false, List<String> ? allowedTools, Map<String, String> ? toolAliases}) -
const
Properties
-
allowedTools
→ List<
String> ? -
final
-
cacheBreakpoints
→ List<
int> -
final
- enableCaching → bool
-
final
- enableThinking → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxTokens → int
-
final
- maxTurns → int
-
final
- model → String
-
final
- planMode → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemPrompt → String?
-
final
- thinkingBudget → int?
-
final
-
toolAliases
→ Map<
String, String> ? -
final
- toolTimeout → Duration
-
final
Methods
-
copyWith(
{String? model, String? systemPrompt, int? maxTurns, int? maxTokens, bool? enableThinking, int? thinkingBudget, bool? enableCaching, List< int> ? cacheBreakpoints, Duration? toolTimeout, bool? planMode, List<String> ? allowedTools}) → ConversationConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited