ConversationTurn class

Turn in a conversation.

Constructors

ConversationTurn({required Message userMessage, required Message assistantMessage, required List<ToolExecution> toolExecutions, required Duration duration, required int inputTokens, required int outputTokens, required double cost, required int turnIndex})
const

Properties

assistantMessage Message
final
cost double
final
duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
inputTokens int
final
outputTokens int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolExecutions List<ToolExecution>
final
turnIndex int
final
userMessage Message
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited