executeBatch method

Future<List<HookResult>> executeBatch(
  1. HookType type,
  2. List<HookContext> contexts
)

Execute hooks for a batch of contexts, returning one result per context.

Each context is processed independently through the full hook chain.

Implementation

Future<List<HookResult>> executeBatch(
  HookType type,
  List<HookContext> contexts,
) async {
  final results = <HookResult>[];
  for (final context in contexts) {
    results.add(await executeAsync(type, context));
  }
  return results;
}