HookStats class
Aggregate statistics about hook executions.
Constructors
-
HookStats({required int totalExecutions, required Map<
HookType, int> executionsByType, required Duration avgDuration, required int failureCount, required int abortCount, DateTime? lastExecution, Map<String, int> executionsByHookId = const {}}) -
const
- HookStats.empty()
-
Empty stats for initialization.
factory
Properties
- abortCount → int
-
Total number of aborted chains.
final
- avgDuration → Duration
-
Average execution duration across all hooks.
final
-
executionsByHookId
→ Map<
String, int> -
Execution count broken down by individual hook ID.
final
-
executionsByType
→ Map<
HookType, int> -
Execution count broken down by hook type.
final
- failureCount → int
-
Total number of failed executions (exceptions thrown).
final
- failureRate → double
-
Failure rate as a percentage (0.0 to 1.0).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastExecution → DateTime?
-
Timestamp of the most recent execution.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalExecutions → int
-
Total number of hook executions across all types.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited