HookResult class
Result of hook execution.
Constructors
- HookResult({bool shouldContinue = true, String? output, String? stopReason, String? systemMessage})
-
const
- HookResult.block(String reason)
-
factory
- HookResult.pass([String? output])
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- output → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shouldContinue → bool
-
final
- stopReason → String?
-
final
- systemMessage → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited