GitOperation enum
Git operations tracked by GitHookContext.
Values
- commit → const GitOperation
- push → const GitOperation
- pull → const GitOperation
- fetch → const GitOperation
- merge → const GitOperation
- rebase → const GitOperation
- checkout → const GitOperation
- branch → const GitOperation
- tag → const GitOperation
- stash → const GitOperation
- reset → const GitOperation
- revert → const GitOperation
- cherryPick → const GitOperation
- clone → const GitOperation
- init → const GitOperation
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
GitOperation> - A constant List of the values in this enum, in order of their declaration.