HookSkip class
Skip the current operation without error.
The hook chain continues, but the hooked operation itself may be skipped depending on the hook type.
- Inheritance
-
- Object
- HookResult
- HookSkip
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited