LifecycleEvent class sealed
Base class for all lifecycle events.
Uses Dart's sealed class feature to provide exhaustive pattern matching across all event types.
- Implementers
- AgentCompletedEvent
- AgentErrorEvent
- AgentMessageEvent
- AgentSpawnedEvent
- AgentTimeoutEvent
- CompactionEvent
- ConversationEndedEvent
- ConversationStartedEvent
- SessionEndedEvent
- SessionPausedEvent
- SessionResumedEvent
- SessionStartedEvent
- ToolAfterExecutionEvent
- ToolBeforeExecutionEvent
- ToolErrorEvent
- ToolRegisteredEvent
- ToolTimeoutEvent
- TurnEndedEvent
- TurnStartedEvent
Properties
- eventType → String
-
Human-readable event type name.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> -
Arbitrary metadata attached to the event.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
The session ID this event belongs to.
final
- timestamp → DateTime
-
When this event occurred.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited