ConnectedMcpServer class
- Inheritance
-
- Object
- McpServerConnection
- ConnectedMcpServer
Constructors
-
ConnectedMcpServer({required String serverName, required McpServerConfig config, required List<
McpToolInfo> tools, List<McpResource> resources = const []})
Properties
- config → McpServerConfig
-
finalinherited
- connectedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resources
→ List<
McpResource> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverName → String
-
finalinherited
-
tools
→ List<
McpToolInfo> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited