CliArgs class

Parsed CLI arguments.

Constructors

CliArgs({String? prompt, String? model, String? apiKey, String? apiEndpoint, bool headless = false, bool verbose = false, bool version = false, bool help = false, bool noColor = false, String? sessionId, String? resumeSession, String? workingDir, List<String> files = const [], Map<String, String> env = const {}, bool stdinPipe = false, String? outputFormat, int? maxTokens, bool dangerouslySkipPermissions = false})
const

Properties

apiEndpoint String?
final
apiKey String?
final
dangerouslySkipPermissions bool
final
env Map<String, String>
final
files List<String>
final
hashCode int
The hash code for this object.
no setterinherited
headless bool
final
help bool
final
maxTokens int?
final
model String?
final
noColor bool
final
outputFormat String?
final
prompt String?
final
resumeSession String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
stdinPipe bool
final
verbose bool
final
version bool
final
workingDir String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited