SystemInfo class

System information snapshot.

Constructors

SystemInfo({required String os, required String version, required String arch, required String hostname, required int cpuCores, required int memoryBytes, required String shell})
const

Properties

arch String
final
cpuCores int
final
hashCode int
The hash code for this object.
no setterinherited
hostname String
final
memoryBytes int
Total physical memory in bytes.
final
os String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shell String
Default shell (e.g. /bin/zsh, cmd.exe).
final
version String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited