InAppNotificationBackend class
In-app notification backend (always available).
- Implemented types
Constructors
Properties
-
activeNotifications
→ List<
NeomageNotification> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
notifications
→ Stream<
NeomageNotification> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dismiss(
String notificationId) → Future< void> -
override
-
dismissAll(
) → Future< void> -
override
-
dispose(
) → void -
isSupported(
) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
requestPermission(
) → Future< bool> -
override
-
show(
NeomageNotification notification) → Future< void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited