PlatformCapabilities class
Platform capabilities — what the current platform supports.
Constructors
- PlatformCapabilities({bool hasFileSystem = true, bool hasProcessSpawn = true, bool hasStdin = true, bool hasClipboard = true, bool hasNotifications = true, bool hasWindowManagement = true, bool hasTouchInput = false, bool hasKeyboard = true, bool hasVoiceInput = false, bool hasBiometrics = false})
-
const
- PlatformCapabilities.cli()
-
factory
- PlatformCapabilities.desktop()
-
factory
- PlatformCapabilities.mobile()
-
factory
- PlatformCapabilities.web()
-
factory
Properties
- hasBiometrics → bool
-
final
- hasClipboard → bool
-
final
- hasFileSystem → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasKeyboard → bool
-
final
- hasNotifications → bool
-
final
- hasProcessSpawn → bool
-
final
- hasStdin → bool
-
final
- hasTouchInput → bool
-
final
- hasVoiceInput → bool
-
final
- hasWindowManagement → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited