RemoteDiscovery class

Discovers remote sessions on the local network.

Constructors

RemoteDiscovery()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateConnectionUrl({required String host, required int port, String? token, bool secure = false}) String
Generate a connection URL for sharing.
parseConnectionUrl(String url) → ({String host, int port, String? token})
Parse a connection URL.
scan({String subnet = '127.0.0.1', List<int> ports = const [3100, 3101, 3102, 3103, 3104], Duration timeout = const Duration(seconds: 2)}) Future<List<RemoteSessionInfo>>
Scan for remote sessions on common ports.