RemoteServer class
HTTP/WebSocket server for hosting remote sessions.
Constructors
- RemoteServer({int port = 3100, String? host, String? authToken})
Properties
- authToken → String?
-
final
- clientCount → int
-
Connected client count.
no setter
-
events
→ Stream<
RemoteEvent> -
Event stream.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → String?
-
final
- port → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessions
→ List<
RemoteSessionInfo> -
Active sessions.
no setter
Methods
-
broadcast(
String action, Map< String, dynamic> payload) → void - Broadcast a message to all connected clients.
-
dispose(
) → void - Dispose resources.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendTo(
String clientId, RemoteMessage message) → void - Send a message to a specific client.
-
start(
) → Future< void> - Start the server.
-
stop(
) → Future< void> - Stop the server.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited