SessionRelay class
Relay service for connecting remote sessions through an intermediary.
Constructors
- SessionRelay({required String relayUrl, String? relayToken})
Properties
-
events
→ Stream<
RemoteEvent> -
Event stream.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- relayToken → String?
-
final
- relayUrl → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connectToHost(
String hostId) → Future< void> - Connect to a host through the relay.
-
disconnect(
) → Future< void> - Disconnect from relay.
-
dispose(
) → void - Dispose resources.
-
listHosts(
) → Future< List< Map< >String, dynamic> > - List available hosts on the relay.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerHost(
{required String displayName, Map< String, dynamic> ? capabilities}) → Future<String> - Register this host with the relay.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited