RemoteSessionManager class

Remote session manager — creates and tracks multiple sessions.

Constructors

RemoteSessionManager({required QueryEngine engineFactory()})

Properties

activeSessions List<RemoteSession>
All active sessions.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createSession({String? id}) RemoteSession
Create a new session.
disposeAll() → void
Dispose all sessions.
getSession(String id) RemoteSession?
Get an existing session.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeSession(String id) → void
Remove a session.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited