PluginIdentifier class
Parsed plugin identifier (name + optional marketplace).
Constructors
- PluginIdentifier({required String name, String? marketplace})
-
const
Properties
- fullId → String
-
The full
name@marketplaceidentifier, or just name.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- marketplace → String?
-
Marketplace the plugin belongs to (null for bare names).
final
- name → String
-
Short plugin name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited