PluginTelemetryFields class

Telemetry fields for plugin CLI analytics events.

Constructors

PluginTelemetryFields({String? pluginName, String? marketplaceName, bool isManaged = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isManaged bool
Whether this is a managed (MDM) plugin.
final
marketplaceName String?
Marketplace name.
final
pluginName String?
Short plugin name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
Convert to a metadata map for analytics.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited