PluginUpdateResult class

Result of a plugin update operation.

Constructors

PluginUpdateResult({required bool success, required String message, String? pluginId, String? newVersion, String? oldVersion, bool alreadyUpToDate = false, PluginScope? scope})
const

Properties

alreadyUpToDate bool
Whether the plugin was already at the latest version.
final
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable result or error message.
final
newVersion String?
New version after update.
final
oldVersion String?
Version before the update.
final
pluginId String?
Resolved plugin identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope PluginScope?
Scope the update was applied to.
final
success bool
Whether the update succeeded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited