ProxyRequest class

Represents a request to be forwarded through the proxy.

Constructors

ProxyRequest({required String method, required String path, Map<String, String> headers = const {}, String? body, DateTime? timestamp})

Properties

body String?
final
cacheKey String
Generates a cache key from method, path, and body.
no setter
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
method String
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited