ProxyStats class
Accumulated proxy traffic statistics.
Constructors
Properties
- averageLatency → Duration
-
Average latency per request.
no setter
- bytesTransferred ↔ int
-
getter/setter pair
- cacheHitRatio → double
-
Cache hit ratio as a percentage (0–100).
no setter
- cacheHits ↔ int
-
getter/setter pair
- cacheMisses ↔ int
-
getter/setter pair
- errors ↔ int
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestCount ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalLatency ↔ Duration
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited