RemoteSessionCallbacks class
Callbacks for RemoteSessionManager lifecycle events.
Constructors
-
RemoteSessionCallbacks({required void onMessage(SessionsMessage message), required void onPermissionRequest(Map<
String, dynamic> request, String requestId), void onPermissionCancelled(String requestId, String? toolUseId)?, void onConnected()?, void onDisconnected()?, void onReconnecting()?, void onError(Object error)?}) -
Create callbacks for RemoteSessionManager.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onConnected → void Function()?
-
Called when connection is established.
final
- onDisconnected → void Function()?
-
Called when connection is lost and cannot be restored.
final
- onError → void Function(Object error)?
-
Called on error.
final
- onMessage → void Function(SessionsMessage message)
-
Called when an SDK message is received from the session.
final
- onPermissionCancelled → void Function(String requestId, String? toolUseId)?
-
Called when the server cancels a pending permission request.
final
-
onPermissionRequest
→ void Function(Map<
String, dynamic> request, String requestId) -
Called when a permission request is received from CCR.
final
- onReconnecting → void Function()?
-
Called on transient WS drop while reconnect backoff is in progress.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited