RemoteSessionConfig class
Configuration for a remote CCR session.
Constructors
- RemoteSessionConfig({required String sessionId, required String getAccessToken(), required String orgUuid, bool hasInitialPrompt = false, bool viewerOnly = false})
-
Create a RemoteSessionConfig.
const
Properties
- getAccessToken → String Function()
-
Returns a fresh OAuth access token.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasInitialPrompt → bool
-
True if the session was created with an initial prompt that is being
processed.
final
- orgUuid → String
-
Anthropic organization UUID.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
The CCR session identifier.
final
- viewerOnly → bool
-
When true this client is a pure viewer. Ctrl+C / Escape do NOT send
interrupt to the remote agent; 60 s reconnect timeout is disabled;
session title is never updated. Used by
claude assistant.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited