RemoteSessionManager class
Manages a remote CCR session.
Coordinates:
- WebSocket subscription for receiving messages from CCR
- HTTP POST for sending user messages to CCR
- Permission request / response flow
Constructors
- RemoteSessionManager({required RemoteSessionConfig config, required RemoteSessionCallbacks callbacks})
- Create a RemoteSessionManager.
Properties
Methods
-
cancelSession(
) → void - Send an interrupt signal to cancel the current request on the remote session.
-
connect(
) → void - Connect to the remote session via WebSocket.
-
disconnect(
) → void - Disconnect from the remote session.
-
isConnected(
) → bool - Whether the WebSocket is currently connected.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reconnect(
) → void - Force reconnect the WebSocket.
-
respondToPermissionRequest(
String requestId, RemotePermissionResponse result) → void - Respond to a permission request from CCR.
-
sendMessage(
RemoteMessageContent content, {String? uuid}) → Future< bool> - Send a user message to the remote session via HTTP POST.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited