EventMetadata class
Core event metadata shared across all analytics systems.
Constructors
- EventMetadata({required String model, required String sessionId, required String userType, String? betas, required EnvContext envContext, String? entrypoint, String isInteractive = 'true', String clientType = 'cli', ProcessMetrics? processMetrics, String? subscriptionType, String? repoHash, String? agentId, String? parentSessionId, String? agentType, String? teamName})
-
const
Properties
- agentId → String?
-
final
- agentType → String?
-
final
- betas → String?
-
final
- clientType → String
-
final
- entrypoint → String?
-
final
- envContext → EnvContext
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isInteractive → String
-
final
- model → String
-
final
- parentSessionId → String?
-
final
- processMetrics → ProcessMetrics?
-
final
- repoHash → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
- subscriptionType → String?
-
final
- teamName → String?
-
final
- userType → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited