GrowthBookUserAttributes class

GrowthBook user attributes for targeting.

Constructors

GrowthBookUserAttributes({required String id, required String sessionId, required String deviceId, required String platform, String? apiBaseUrlHost, String? organizationUuid, String? accountUuid, String? userType, String? subscriptionType, String? rateLimitTier, int? firstTokenTime, String? email, String? appVersion})
const

Properties

accountUuid String?
final
apiBaseUrlHost String?
final
appVersion String?
final
deviceId String
final
email String?
final
firstTokenTime int?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
organizationUuid String?
final
platform String
final
rateLimitTier String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
subscriptionType String?
final
userType String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited