AutoDreamConfig class
Auto-dream scheduling thresholds.
Constructors
- AutoDreamConfig({double minHours = 24, int minSessions = 5})
-
const
-
AutoDreamConfig.fromJson(Map<
String, dynamic> ? json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- minHours → double
-
Minimum hours since last consolidation before triggering.
final
- minSessions → int
-
Minimum number of sessions touched since last consolidation.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited