CompletionSuggestion class

A single auto-complete suggestion.

Constructors

CompletionSuggestion({required String value, required String displayText, String? description, required SuggestionType type, String? icon, double score = 0.0, String? detail, String? insertText, int? cursorOffset, Map<String, dynamic>? metadata})
const

Properties

cursorOffset int?
final
description String?
final
detail String?
final
displayText String
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
insertText String?
final
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double
final
type SuggestionType
final
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
withScore(double newScore) CompletionSuggestion

Operators

operator ==(Object other) bool
The equality operator.
inherited