PromptSuggestion class

A prompt suggestion (canned/intelligent prompt).

Constructors

PromptSuggestion({required String text, required String title, String? description, required PromptCategory category, List<String> tags = const [], int usageCount = 0, DateTime? lastUsed, bool isCustom = false, String? requiredContext})
const

Properties

category PromptCategory
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
isCustom bool
final
lastUsed DateTime?
final
requiredContext String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
final
text String
final
title String
final
usageCount int
final

Methods

copyWith({int? usageCount, DateTime? lastUsed}) PromptSuggestion
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited