CompactMessage class

A message in the conversation.

Constructors

CompactMessage({required String uuid, required MessageRole type, String? messageId, List<ContentBlock> contentBlocks = const [], required DateTime timestamp, bool isMeta = false, bool isCompactSummary = false, bool isCompactBoundary = false, Map<String, dynamic>? compactMetadata, bool isVisibleInTranscriptOnly = false, String? toolUseResult, String? sourceToolAssistantUUID, Map<String, dynamic>? summarizeMetadata})
const

Properties

compactMetadata Map<String, dynamic>?
final
contentBlocks List<ContentBlock>
final
hashCode int
The hash code for this object.
no setterinherited
isCompactBoundary bool
final
isCompactSummary bool
final
isMeta bool
final
isVisibleInTranscriptOnly bool
final
messageId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceToolAssistantUUID String?
final
summarizeMetadata Map<String, dynamic>?
final
timestamp DateTime
final
toolUseResult String?
final
type MessageRole
final
uuid String
final

Methods

copyWith({List<ContentBlock>? contentBlocks, Map<String, dynamic>? compactMetadata, bool? isCompactBoundary}) CompactMessage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited