CompactionResult class
Result of a compaction operation.
Constructors
-
CompactionResult({required CompactMessage boundaryMarker, required List<
CompactMessage> summaryMessages, List<CompactMessage> attachments = const [], List<CompactMessage> hookResults = const [], List<CompactMessage> ? messagesToKeep, String? userDisplayMessage, int? preCompactTokenCount, int? postCompactTokenCount, int? truePostCompactTokenCount, Map<String, int> ? compactionUsage}) -
const
Properties
-
attachments
→ List<
CompactMessage> -
final
- boundaryMarker → CompactMessage
-
final
-
compactionUsage
→ Map<
String, int> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hookResults
→ List<
CompactMessage> -
final
-
messagesToKeep
→ List<
CompactMessage> ? -
final
- postCompactTokenCount → int?
-
final
- preCompactTokenCount → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
summaryMessages
→ List<
CompactMessage> -
final
- truePostCompactTokenCount → int?
-
final
- userDisplayMessage → String?
-
final
Methods
-
copyWith(
{int? postCompactTokenCount, int? truePostCompactTokenCount}) → CompactionResult -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited