ContentBlock class
A content block inside a message.
Constructors
- ContentBlock({required ContentBlockType type, String? text, String? id, String? name, String? toolUseId, dynamic input, dynamic content, bool? isError, String? thinking, String? data})
-
const
Properties
- content → dynamic
-
final
- data → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- input → dynamic
-
final
- isError → bool?
-
final
- name → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
final
- thinking → String?
-
final
- toolUseId → String?
-
final
- type → ContentBlockType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited