SessionMemoryCompactConfig class
Configuration for session memory compaction thresholds.
Constructors
- SessionMemoryCompactConfig({int minTokens = 10000, int minTextBlockMessages = 5, int maxTokens = 40000})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxTokens → int
-
Maximum tokens to preserve after compaction (hard cap).
final
- minTextBlockMessages → int
-
Minimum number of messages with text blocks to keep.
final
- minTokens → int
-
Minimum tokens to preserve after compaction.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{int? minTokens, int? minTextBlockMessages, int? maxTokens}) → SessionMemoryCompactConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited