TimeBasedMCConfig class

Configuration for time-based microcompact trigger.

Constructors

TimeBasedMCConfig({bool enabled = false, double gapThresholdMinutes = 15.0, int keepRecent = 5})
const

Properties

enabled bool
final
gapThresholdMinutes double
final
hashCode int
The hash code for this object.
no setterinherited
keepRecent int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited