ConfigSchema class
Describes the expected shape and constraints for configuration.
Constructors
-
ConfigSchema({required Map<
String, ConfigEntry> entries}) -
const
Properties
-
entries
→ Map<
String, ConfigEntry> -
Map of dotted key paths to their schema definitions.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validate(
Map< String, dynamic> config) → ConfigValidation - Validate a flat config map against this schema, returning a ConfigValidation with accumulated errors.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited