ConversationStats class
Conversation stats.
Constructors
-
ConversationStats({required int totalSessions, required int totalMessages, required int totalTokens, required double totalCost, required Duration totalDuration, required Map<
String, int> toolUsageCounts, required Map<String, int> modelUsageCounts, required int averageMessagesPerSession, required double averageCostPerSession}) -
const
Properties
- averageCostPerSession → double
-
final
- averageMessagesPerSession → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
modelUsageCounts
→ Map<
String, int> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
toolUsageCounts
→ Map<
String, int> -
final
- totalCost → double
-
final
- totalDuration → Duration
-
final
- totalMessages → int
-
final
- totalSessions → int
-
final
- totalTokens → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited