CoordinatorService class
Coordinator service — orchestrates multiple agents.
Constructors
- CoordinatorService({required AgentTool agentTool})
Properties
-
activeTasks
→ List<
CoordinatorTask> -
Active tasks.
no setter
- agentTool → AgentTool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Whether coordinator mode is active.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → CoordinatorState
-
Current state.
no setter
-
tasks
→ List<
CoordinatorTask> -
All tracked tasks.
no setter
Methods
-
activate(
) → void - Activate coordinator mode.
-
buildSynthesisPrompt(
) → String - Build a synthesis prompt from completed task results.
-
completeTask(
String taskId, String result) → void - Complete a task with a result.
-
deactivate(
) → void - Deactivate coordinator mode.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
spawnTask(
{required String description, required String prompt, String agentType = 'general-purpose'}) → Future< CoordinatorTask> - Spawn a sub-agent task.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited