CoordinatorTask class

A task assigned to a sub-agent by the coordinator.

Constructors

CoordinatorTask({required String id, required String agentId, required String description, required String prompt, CoordinatorTaskStatus status = CoordinatorTaskStatus.pending})

Properties

agentId String
final
description String
final
endTime DateTime?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
prompt String
final
result String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime
getter/setter pair
status CoordinatorTaskStatus
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited