TaskDecomposer class
Decomposes complex prompts into discrete tasks.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
decompose(
String prompt, {CoordinatorMode mode = CoordinatorMode.sequential}) → List< CoordinatorTask> - Decompose a prompt into tasks based on structure.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited