TaskScheduler class
Schedules tasks to agents based on capability, capacity, and priority.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
areDependenciesMet(
CoordinatorTask task, Map< String, CoordinatorTask> allTasks) → bool - Check if a task's dependencies are all completed.
-
findBestAgent(
CoordinatorTask task, List< CoordinatorAgent> agents) → CoordinatorAgent? - Find the best agent for a task.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
prioritize(
List< CoordinatorTask> tasks) → List<CoordinatorTask> - Order tasks by priority and dependencies.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited