Workflow class

A workflow definition (sequence of coordinated tasks).

Constructors

Workflow({required String id, required String name, required String description, required CoordinatorMode mode, required List<CoordinatorTask> tasks, required DateTime createdAt, DateTime? completedAt, Map<String, dynamic>? config})
const

Properties

completedAt DateTime?
final
completedCount int
no setter
config Map<String, dynamic>?
final
createdAt DateTime
final
description String
final
failedCount int
no setter
hasFailed bool
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
final
isComplete bool
no setter
mode CoordinatorMode
final
name String
final
pendingCount int
no setter
progress double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tasks List<CoordinatorTask>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited