DiffHunk class
A contiguous group of changes in a diff.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- header → String
-
Unified diff header for this hunk.
no setter
-
lines
→ List<
DiffLine> -
The lines composing this hunk.
final
- newCount → int
-
Number of lines from the new file in this hunk.
final
- newStart → int
-
1-based starting line in the new file.
final
- oldCount → int
-
Number of lines from the old file in this hunk.
final
- oldStart → int
-
1-based starting line in the old file.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited