DiffLine class
A single line within a diff hunk.
Constructors
- DiffLine({required DiffLineType type, required String content, int? oldLineNumber, int? newLineNumber})
-
const
Properties
- content → String
-
Text content of the line (without the leading +/- marker).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- newLineNumber → int?
-
1-based line number in the new file (null for removals).
final
- oldLineNumber → int?
-
1-based line number in the old file (null for additions).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → DiffLineType
-
Whether this line is context, an addition, or a removal.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited