FileDiff class

Diff result for a single file.

Constructors

FileDiff({required String path, required String oldPath, required List<DiffHunk> hunks, required DiffStats stats})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hunks List<DiffHunk>
The hunks that compose this diff.
final
isRename bool
Whether the file was renamed.
no setter
oldPath String
Original path if the file was renamed, otherwise same as path.
final
path String
Path of the file (new path if renamed).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats DiffStats
Summary statistics.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited