HistorySearchQuery class
History search query.
Constructors
Properties
- after → DateTime?
-
final
- before → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int
-
final
- maxTokens → int?
-
final
- minTokens → int?
-
final
- offset → int
-
final
-
roles
→ Set<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
final
- sortDescending → bool
-
final
- text → String?
-
final
- toolName → String?
-
final
-
types
→ Set<
HistoryEntryType> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited