SessionSummary class
Summarized view of a session for listing.
Constructors
-
SessionSummary({required String id, String? title, required DateTime startedAt, required DateTime lastActiveAt, required int messageCount, int toolUseCount = 0, int totalInputTokens = 0, int totalOutputTokens = 0, double totalCost = 0.0, required String model, String? gitBranch, String? workingDirectory, List<
String> toolsUsed = const [], bool isActive = false, String? preview}) -
const
-
SessionSummary.fromJson(Map<
String, dynamic> json) -
factory
Properties
- gitBranch → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isActive → bool
-
final
- lastActiveAt → DateTime
-
final
- messageCount → int
-
final
- model → String
-
final
- preview → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt → DateTime
-
final
- title → String?
-
final
-
toolsUsed
→ List<
String> -
final
- toolUseCount → int
-
final
- totalCost → double
-
final
- totalInputTokens → int
-
final
- totalOutputTokens → int
-
final
- workingDirectory → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited