UsageAnalytics class

Usage analytics for a time period.

Constructors

UsageAnalytics({required DateTime periodStart, required DateTime periodEnd, int totalSessions = 0, int totalMessages = 0, int totalToolUses = 0, int totalInputTokens = 0, int totalOutputTokens = 0, int totalCacheReadTokens = 0, double totalCost = 0.0, Duration totalSessionTime = Duration.zero, Map<String, int> toolUsageCounts = const {}, Map<String, int> modelUsageCounts = const {}, Map<String, int> commandUsageCounts = const {}, double averageTokensPerMessage = 0.0, double averageCostPerSession = 0.0, Duration averageSessionDuration = Duration.zero, int peakConcurrentAgents = 0, List<DailyUsage> dailyBreakdown = const []})
const

Properties

averageCostPerSession double
final
averageSessionDuration Duration
final
averageTokensPerMessage double
final
commandUsageCounts Map<String, int>
final
dailyBreakdown List<DailyUsage>
final
hashCode int
The hash code for this object.
no setterinherited
modelUsageCounts Map<String, int>
final
peakConcurrentAgents int
final
periodEnd DateTime
final
periodStart DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolUsageCounts Map<String, int>
final
totalCacheReadTokens int
final
totalCost double
final
totalInputTokens int
final
totalMessages int
final
totalOutputTokens int
final
totalSessions int
final
totalSessionTime Duration
final
totalToolUses int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited