LspServerInstance class
A connected LSP server instance.
Properties
- config → LspServerConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastError ↔ String?
-
getter/setter pair
- restartCount ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
serverCapabilities
↔ Map<
String, dynamic> ? -
getter/setter pair
- state ↔ LspServerState
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onNotification(
String method, void handler(Map< String, dynamic> )) → void - Register a notification handler.
-
sendNotification(
String method, Map< String, dynamic> params) → void - Send a notification (no response expected).
-
sendRequest(
String method, Map< String, dynamic> params) → Future<Map< String, dynamic> > - Send a JSON-RPC request and await response.
-
stop(
) → Future< void> - Stop the server.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited