LspServerManager class
LSP server manager — manages multiple LSP servers and routes requests.
Constructors
-
LspServerManager({required List<
LspServerConfig> configs, void onDiagnostics(List<LspDiagnostic> )?})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onDiagnostics
→ void Function(List<
LspDiagnostic> )? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
servers
→ Map<
String, LspServerInstance> -
All server instances.
no setter
Methods
-
changeFile(
String filePath, String content) → Future< void> - Notify content change (sends textDocument/didChange).
-
closeFile(
String filePath) → void - Close a file (sends textDocument/didClose).
-
configForFile(
String filePath) → LspServerConfig? - Find the config for a file based on extension.
-
ensureServerForFile(
String filePath) → Future< LspServerInstance?> - Ensure a server is started for the given file.
-
isFileOpen(
String filePath) → bool - Check if a file is currently open.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openFile(
String filePath, String content) → Future< void> - Open a file (sends textDocument/didOpen).
-
saveFile(
String filePath) → void - Notify file save (sends textDocument/didSave).
-
sendRequest(
String filePath, String method, Map< String, dynamic> params) → Future<Map< String, dynamic> ?> - Send a request to the server handling a file.
-
shutdown(
) → Future< void> - Shutdown all servers.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited