MemoryCandidate class
A potential memory extracted from some source, awaiting approval.
Constructors
- MemoryCandidate({required String content, required ExtractionSource source, required MemoryCategory category, required double confidence, required String reasoning, DateTime? timestamp})
Properties
- category → MemoryCategory
-
final
- confidence → double
-
Confidence score in
0, 1— how likely this is a useful memory.final - content → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reasoning → String
-
Short explanation of why this was extracted.
final
-
Optional related file path.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → ExtractionSource
-
final
- timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited