AppNotification class

A single notification.

Constructors

AppNotification({required String id, required NotificationType type, NotificationPriority priority = NotificationPriority.normal, required String title, String? body, DateTime? timestamp, bool read = false, bool dismissed = false, List<NotificationAction> actions = const [], Map<String, dynamic> metadata = const {}, String? groupKey, DateTime? expiresAt, double? progress, double? progressTotal})

Properties

actions List<NotificationAction>
final
body String?
final
dismissed bool
getter/setter pair
expiresAt DateTime?
final
groupKey String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isExpired bool
no setter
metadata Map<String, dynamic>
final
priority NotificationPriority
final
progress double?
For progress-type notifications.
getter/setter pair
progressTotal double?
getter/setter pair
read bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
title String
final
type NotificationType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited