NotificationChannel class
A notification channel controlling delivery behaviour.
Constructors
- NotificationChannel({required String id, required String name, String? description, bool enabled = true, bool sound = true, bool vibration = true, NotificationPriority priority = NotificationPriority.normal})
Properties
- description → String?
-
final
- enabled ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- name → String
-
final
- priority ↔ NotificationPriority
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sound ↔ bool
-
getter/setter pair
- vibration ↔ bool
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited