NotificationPreferences class

User-level notification preferences.

Constructors

NotificationPreferences({Map<String, NotificationChannel>? channels, bool doNotDisturb = false, DoNotDisturbSchedule? doNotDisturbSchedule, bool soundEnabled = true, bool groupByType = true})

Properties

channels Map<String, NotificationChannel>
final
doNotDisturb bool
getter/setter pair
doNotDisturbSchedule DoNotDisturbSchedule?
getter/setter pair
groupByType bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isDndActive bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
soundEnabled bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited