OAuthProfileOrganization class

Organization details in the profile response.

Constructors

OAuthProfileOrganization({required String uuid, String? organizationType, RateLimitTier? rateLimitTier, bool? hasExtraUsageEnabled, String? billingType, String? subscriptionCreatedAt})
const
OAuthProfileOrganization.fromJson(Map<String, dynamic> json)
factory

Properties

billingType String?
final
hasExtraUsageEnabled bool?
final
hashCode int
The hash code for this object.
no setterinherited
organizationType String?
final
rateLimitTier RateLimitTier?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionCreatedAt String?
final
uuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited