OAuthTokenAccountInfo class
Account info stored alongside tokens.
Constructors
- OAuthTokenAccountInfo({required String uuid, required String emailAddress, String? organizationUuid})
-
const
Properties
- emailAddress → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- organizationUuid → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uuid → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited