OAuthTokenExchangeResponse class
OAuth token exchange response from the token endpoint.
Constructors
- OAuthTokenExchangeResponse({required String accessToken, required String refreshToken, required int expiresIn, String? scope, OAuthTokenAccount? account, OAuthTokenOrganization? organization})
-
const
-
OAuthTokenExchangeResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- accessToken → String
-
final
- account → OAuthTokenAccount?
-
final
- expiresIn → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- organization → OAuthTokenOrganization?
-
final
- refreshToken → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited