PluginCliService class
CLI command wrappers for plugin operations.
These provide thin wrappers around PluginOperationsService that handle CLI-specific concerns like console output and analytics logging.
Constructors
-
PluginCliService({required PluginOperationsService operations, required void logEvent(String eventName, Map<
String, Object?> metadata), required Set<String> getManagedPluginNames(), required void writeOutput(String message), required void writeError(String message)})
Properties
-
getManagedPluginNames
→ Set<
String> Function() -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
logEvent
→ void Function(String eventName, Map<
String, Object?> metadata) -
final
- operations → PluginOperationsService
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- writeError → void Function(String message)
-
final
- writeOutput → void Function(String message)
-
final
Methods
-
disableAllPlugins(
) → Future< PluginCliResult> - CLI: Disable all plugins.
-
disablePlugin(
String plugin, [PluginScope? scope]) → Future< PluginCliResult> - CLI: Disable a plugin.
-
enablePlugin(
String plugin, [PluginScope? scope]) → Future< PluginCliResult> - CLI: Enable a plugin.
-
installPlugin(
String plugin, [PluginScope scope = PluginScope.user]) → Future< PluginCliResult> - CLI: Install a plugin.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
uninstallPlugin(
String plugin, [PluginScope scope = PluginScope.user, bool keepData = false]) → Future< PluginCliResult> - CLI: Uninstall a plugin.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited