PluginOperationResult class

Result of a plugin operation (install, uninstall, enable, disable).

Constructors

PluginOperationResult({required bool success, required String message, String? pluginId, String? pluginName, PluginScope? scope, List<String>? reverseDependents})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
pluginId String?
final
pluginName String?
final
reverseDependents List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope PluginScope?
final
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited