PluginUpdateResult class
Result of a plugin update operation.
Constructors
- PluginUpdateResult({required bool success, required String message, String? pluginId, String? newVersion, String? oldVersion, bool alreadyUpToDate = false, PluginScope? scope})
-
const
Properties
- alreadyUpToDate → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- newVersion → String?
-
final
- oldVersion → String?
-
final
- pluginId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → PluginScope?
-
final
- success → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited