ProjectFramework enum
Web or application framework detected in the project.
Values
- flutter → const ProjectFramework
- nextjs → const ProjectFramework
- react → const ProjectFramework
- vue → const ProjectFramework
- angular → const ProjectFramework
- django → const ProjectFramework
- rails → const ProjectFramework
- springBoot → const ProjectFramework
- fastapi → const ProjectFramework
- express → const ProjectFramework
- none → const ProjectFramework
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ProjectFramework> - A constant List of the values in this enum, in order of their declaration.