ProjectInfo class

Full description of a detected project.

Constructors

ProjectInfo({required String name, required ProjectType type, ProjectFramework framework = ProjectFramework.none, PackageManager? packageManager, required String rootPath, String? version, String? description, int dependencyCount = 0, int devDependencyCount = 0, List<String> scripts = const [], List<String> entryPoints = const [], String? testCommand, String? buildCommand, String? lintCommand})
const

Properties

buildCommand String?
final
dependencyCount int
final
description String?
final
devDependencyCount int
final
entryPoints List<String>
final
framework ProjectFramework
final
hashCode int
The hash code for this object.
no setterinherited
lintCommand String?
final
name String
final
packageManager PackageManager?
final
rootPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scripts List<String>
final
testCommand String?
final
type ProjectType
final
version String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited