TestFramework enum

Test framework detected in the project.

Inheritance
Available extensions

Values

flutterTest → const TestFramework
jest → const TestFramework
mocha → const TestFramework
vitest → const TestFramework
pytest → const TestFramework
unittest → const TestFramework
goTest → const TestFramework
cargoTest → const TestFramework
rspec → const TestFramework
junit → const TestFramework
xunit → const TestFramework
xctest → const TestFramework
unknown → const TestFramework
none → const TestFramework

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TestFramework>
A constant List of the values in this enum, in order of their declaration.