RemoteSetting class

A single remote setting entry.

Constructors

RemoteSetting({required String key, required dynamic value, required RemoteSettingsSource source, required DateTime lastFetched, DateTime? expiresAt, bool overridable = true})
const
RemoteSetting.fromJson(Map<String, dynamic> json)
factory

Properties

expiresAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
isExpired bool
Whether the cached value has expired.
no setter
key String
final
lastFetched DateTime
final
overridable bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source RemoteSettingsSource
final
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited