RemoteSettingsConfig class

Configuration for the remote settings service.

Constructors

RemoteSettingsConfig({required String endpoint, Duration refreshInterval = const Duration(minutes: 30), bool fallbackToLocal = true, required String cacheDir})
const

Properties

cacheDir String
Directory for the on-disk cache file.
final
endpoint String
HTTP endpoint that returns the settings JSON payload.
final
fallbackToLocal bool
If true, fall back to locally cached settings when the endpoint is unreachable.
final
hashCode int
The hash code for this object.
no setterinherited
refreshInterval Duration
How often to auto-refresh.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited