RemoteVsLocal class

Result of comparing a remote setting against its local counterpart.

Constructors

RemoteVsLocal({required String key, dynamic remoteValue, dynamic localValue, bool isOverridden = false, bool isRemoteOnly = false, bool isLocalOnly = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isLocalOnly bool
final
isOverridden bool
final
isRemoteOnly bool
final
key String
final
localValue → dynamic
final
remoteValue → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited