FileIndex class
An indexed file for fast word-level search.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexedAt → DateTime
-
Timestamp of indexing.
final
- path → String
-
Absolute path of the indexed file.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wordCount → int
-
Number of unique words in the index.
no setter
-
wordPositions
→ Map<
String, List< (int, int)> > -
Map from word to list of (lineNumber, column) positions.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited