SearchHistoryEntry class
A saved search entry for history management.
Constructors
- SearchHistoryEntry({required String pattern, required SearchScope scope, required SearchOptions options, required DateTime timestamp, bool pinned = false})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → SearchOptions
-
final
- pattern → String
-
final
- pinned → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → SearchScope
-
final
- timestamp → DateTime
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited