SearchMatch class

A single match within a file.

Constructors

SearchMatch({required String filePath, required int lineNumber, required int column, required int matchLength, required String lineContent, List<String> beforeContext = const [], List<String> afterContext = const []})
const

Properties

afterContext List<String>
Context lines after the match.
final
beforeContext List<String>
Context lines before the match.
final
column int
0-based column offset of the match within the line.
final
filePath String
Absolute path of the file containing the match.
final
hashCode int
The hash code for this object.
no setterinherited
lineContent String
Full text of the line containing the match.
final
lineNumber int
1-based line number of the match.
final
matchLength int
Length of the matched text.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited