SearchResult class

Aggregated result of a search operation.

Constructors

SearchResult({required List<SearchMatch> matches, required int totalMatches, required int filesSearched, required Duration duration, bool truncated = false})
const

Properties

duration Duration
How long the search took.
final
filesSearched int
Number of files that were searched.
final
hashCode int
The hash code for this object.
no setterinherited
matches List<SearchMatch>
The individual matches.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalMatches int
Total number of matches (may be higher than matches.length if truncated by SearchOptions.maxResults).
final
truncated bool
Whether the results were truncated by a max-results limit.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited