SessionMemoryConfig class

Configuration for session memory extraction thresholds.

Constructors

SessionMemoryConfig({int minimumMessageTokensToInit = 10000, int minimumTokensBetweenUpdate = 5000, int toolCallsBetweenUpdates = 3})
const
SessionMemoryConfig.fromRemote(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
minimumMessageTokensToInit int
Minimum context window tokens before initialising session memory. Uses the same token counting as autocompact (input + output + cache tokens).
final
minimumTokensBetweenUpdate int
Minimum context window growth (in tokens) between session memory updates.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolCallsBetweenUpdates int
Number of tool calls between session memory updates.
final

Methods

copyWith({int? minimumMessageTokensToInit, int? minimumTokensBetweenUpdate, int? toolCallsBetweenUpdates}) SessionMemoryConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited