UserSyncContent class

Content portion of user sync data — flat key-value storage. Keys are opaque strings (typically file paths). Values are UTF-8 string content (JSON, Markdown, etc).

Constructors

UserSyncContent({required Map<String, String> entries})
const
UserSyncContent.fromJson(Map<String, dynamic> json)
factory

Properties

entries Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited