UserSyncData class
Full response from GET /api/neomage/user_settings.
Constructors
- UserSyncData({required String userId, required int version, required String lastModified, required String checksum, required UserSyncContent content})
-
const
-
UserSyncData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- checksum → String
-
final
- content → UserSyncContent
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastModified → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → String
-
final
- version → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited