TaskIsolateRunner class

Constructors

TaskIsolateRunner()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

compute<M, R>(R fn(M), M message) Future<R>
Convenience: run a simple synchronous function in an isolate.
run<M, R>(M message, Future<R> computation(M message), {Duration? timeout}) Future<R>
Runs computation in a separate isolate with the given message. Returns the result. Throws if the computation fails.