ExtractedMemory class
A memory extraction from a conversation.
Constructors
- ExtractedMemory({required String content, required String source, required MemoryCategory category, double confidence = 1.0, String? sessionId, required DateTime extractedAt})
-
const
Properties
- category → MemoryCategory
-
final
- confidence → double
-
final
- content → String
-
final
- extractedAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
final
- source → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited