MemoryCategory enum
Category for extracted memories.
Values
- projectStructure → const MemoryCategory
- codingConventions → const MemoryCategory
- buildInstructions → const MemoryCategory
- testingGuidelines → const MemoryCategory
- deploymentProcess → const MemoryCategory
- teamPreferences → const MemoryCategory
- knownIssues → const MemoryCategory
- architecture → const MemoryCategory
- dependencies → const MemoryCategory
- other → const MemoryCategory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MemoryCategory> - A constant List of the values in this enum, in order of their declaration.