MemoryConflict class

Conflict between local and remote memory.

Constructors

MemoryConflict({required String path, required String localContent, required String remoteContent, String? baseContent, required DateTime localModified, required DateTime remoteModified, String? localAuthor, String? remoteAuthor})
const

Properties

baseContent String?
final
hashCode int
The hash code for this object.
no setterinherited
localAuthor String?
final
localContent String
final
localModified DateTime
final
path String
final
remoteAuthor String?
final
remoteContent String
final
remoteModified DateTime
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited