MemoryFile class
A memory file entry.
Constructors
- MemoryFile({required String path, required MemoryFileType type, required String content, required DateTime lastModified, String? hash, SyncStatus syncStatus = SyncStatus.notTracked, String? remoteHash, String? author, int version = 1})
-
const
-
MemoryFile.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
final
- content → String
-
final
- hash → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastModified → DateTime
-
final
- path → String
-
final
- remoteHash → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- syncStatus → SyncStatus
-
final
- type → MemoryFileType
-
final
- version → int
-
final
Methods
-
copyWith(
{String? content, DateTime? lastModified, String? hash, SyncStatus? syncStatus, String? remoteHash, int? version}) → MemoryFile -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited