MemorySection class

A memory section within a file (parsed from markdown).

Constructors

MemorySection({required String heading, required int level, required String content, List<MemorySection> children = const [], List<String> tags = const [], DateTime? addedAt, String? addedBy})
const

Properties

addedAt DateTime?
final
addedBy String?
final
children List<MemorySection>
final
content String
final
hashCode int
The hash code for this object.
no setterinherited
heading String
final
level int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited