TipHistory class
History tracking for tip display.
Constructors
Properties
- currentSession ← int
-
Set the current session number.
no getter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
export(
) → Map< String, int> - Export history for storage.
-
loadFrom(
Map< String, int> data) → void - Load history from stored data.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recordShown(
String tipId) → void - Record that a tip was shown.
-
sessionsSinceShown(
String tipId) → int - Sessions since tip was last shown. Returns a large number if never shown.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited