TipsService class
Tips service — manages tip selection and display.
Constructors
-
TipsService({required TipHistory history, List<
Tip> ? tips, bool enabled = true})
Properties
- enabled ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- history → TipHistory
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addTip(
Tip tip) → void - Register a custom tip.
-
getTipForSpinner(
) → Tip? - Get a tip to show on spinner, or null if none applicable.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited