defaultTips top-level property
Default built-in tips.
Implementation
final List<Tip> defaultTips = [
Tip(
id: 'plan_mode',
content: () => 'Tip: Use /plan to toggle plan mode — think before acting.',
cooldownSessions: 10,
),
Tip(
id: 'memory',
content: () =>
'Tip: Use /memory to manage persistent memory across sessions.',
cooldownSessions: 10,
),
Tip(
id: 'compact',
content: () =>
'Tip: Use /compact to free up context space while keeping a summary.',
cooldownSessions: 8,
),
Tip(
id: 'context',
content: () =>
'Tip: Use /context to check how much of the context window you\'re using.',
cooldownSessions: 8,
),
Tip(
id: 'model_switch',
content: () =>
'Tip: Use /model to switch between different models on the fly.',
cooldownSessions: 10,
),
Tip(
id: 'keyboard_shortcuts',
content: () => 'Tip: Press Escape to interrupt the current operation.',
cooldownSessions: 15,
),
Tip(
id: 'cost',
content: () => 'Tip: Use /cost to see your session\'s token usage.',
cooldownSessions: 12,
),
Tip(
id: 'commit',
content: () =>
'Tip: Use /commit to create a git commit with an AI-generated message.',
cooldownSessions: 8,
),
Tip(
id: 'review',
content: () =>
'Tip: Use /review to get a code review of your changes or a PR.',
cooldownSessions: 10,
),
Tip(
id: 'help',
content: () => 'Tip: Use /help to see all available commands.',
cooldownSessions: 20,
),
];