PermissionResult class

Permission result from hooks or rules.

Constructors

PermissionResult({required PermissionBehavior behavior, String? message, Map<String, dynamic>? updatedInput, PermissionDecisionReason? decisionReason})
const

Properties

behavior PermissionBehavior
final
decisionReason PermissionDecisionReason?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedInput Map<String, dynamic>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited