ToolBatch class
Partition tool calls into batches where each batch is either:
- A single non-concurrency-safe tool, or
- Multiple consecutive concurrency-safe tools
Constructors
-
ToolBatch({required bool isConcurrencySafe, required List<
ToolUseBlock> blocks}) -
const
Properties
-
blocks
→ List<
ToolUseBlock> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isConcurrencySafe → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited