SttEngine class abstract

Abstract speech-to-text provider.

Implementers

Constructors

SttEngine()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
transcribe(Uint8List audio, VoiceConfig config) Future<TranscriptionResult>
transcribeStream(Stream<Uint8List> audioStream, VoiceConfig config) Future<Stream<String>>

Operators

operator ==(Object other) bool
The equality operator.
inherited