VoiceConfig class
Voice configuration.
Constructors
- VoiceConfig({SttProvider sttProvider = SttProvider.whisper, TtsProvider ttsProvider = TtsProvider.system, SpeechLanguage language = SpeechLanguage.english, String? apiKey, String? baseUrl, String? model = 'whisper-1', String? voice = 'alloy', double speed = 1.0, double silenceThreshold = 2.0, bool autoSend = false, bool continuousMode = false, int sampleRate = 16000, AudioFormat format = AudioFormat.wav})
-
const
Properties
- apiKey → String?
-
final
- autoSend → bool
-
final
- baseUrl → String?
-
final
- continuousMode → bool
-
final
- format → AudioFormat
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- language → SpeechLanguage
-
final
- model → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate → int
-
final
- silenceThreshold → double
-
final
- speed → double
-
final
- sttProvider → SttProvider
-
final
- ttsProvider → TtsProvider
-
final
- voice → String?
-
final
Methods
-
copyWith(
{SttProvider? sttProvider, TtsProvider? ttsProvider, SpeechLanguage? language, String? apiKey, String? baseUrl, String? model, String? voice, double? speed, double? silenceThreshold, bool? autoSend, bool? continuousMode, int? sampleRate, AudioFormat? format}) → VoiceConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited