SessionMemoryConfig class
Configuration for session memory extraction thresholds.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initThresholdTokens → int
-
Minimum token count before first extraction.
final
- maxSectionTokens → int
-
Maximum tokens for extracted summary per section.
final
- maxTotalTokens → int
-
Maximum total tokens for the full summary.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolCallThreshold → int
-
Minimum tool calls between extractions.
final
- updateThresholdTokens → int
-
Minimum tokens between subsequent extractions.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited