SessionMemoryState class
State tracking for session memory extraction.
Constructors
Properties
- extractionCount ↔ int
-
Number of extractions completed this session.
getter/setter pair
- extractionInProgress ↔ bool
-
Whether an extraction is currently running.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized ↔ bool
-
Whether extraction has been initialized.
getter/setter pair
- lastSummarizedMessageId ↔ String?
-
ID of last message that was summarized.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokensSinceLastExtraction ↔ int
-
Total tokens seen since last extraction.
getter/setter pair
- toolCallsSinceLastExtraction ↔ int
-
Total tool calls since last extraction.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited