SkillDefinition class
A loaded skill definition.
Constructors
-
SkillDefinition({required String name, required String description, required String promptContent, required String filePath, String? whenToUse, Set<
String> ? allowedTools, String? model, String? argumentHint, List<String> ? argNames, bool userInvocable = true, bool disableModelInvocation = false, String? context, String? agent, SkillSource source = SkillSource.user}) -
const
Properties
- agent → String?
-
final
-
allowedTools
→ Set<
String> ? -
final
-
argNames
→ List<
String> ? -
final
- argumentHint → String?
-
final
- context → String?
-
final
- description → String
-
final
- disableModelInvocation → bool
-
final
- filePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- model → String?
-
final
- name → String
-
final
- promptContent → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → SkillSource
-
final
- userInvocable → bool
-
final
- whenToUse → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited