SkillDefinition class
A skill definition.
Constructors
-
SkillDefinition({required String name, String? fullName, required String description, required String prompt, SkillSource source = SkillSource.builtin, List<
SkillParameter> parameters = const [], List<String> tools = const [], String? model, String? icon, List<String> tags = const [], String? author, String? version, DateTime? createdAt, DateTime? updatedAt, Map<String, dynamic> ? metadata}) -
const
-
SkillDefinition.fromJson(Map<
String, dynamic> json) -
factory
- SkillDefinition.fromMarkdown(String content, {SkillSource source = SkillSource.project})
-
Parse a skill definition from a markdown file with frontmatter.
factory
Properties
-
final
- createdAt → DateTime?
-
final
- description → String
-
final
- fullName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
final
-
metadata
→ Map<
String, dynamic> ? -
final
- model → String?
-
final
- name → String
-
final
-
parameters
→ List<
SkillParameter> -
final
- prompt → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → SkillSource
-
final
-
final
-
tools
→ List<
String> -
final
- updatedAt → DateTime?
-
final
- version → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolvePrompt(
Map< String, dynamic> args) → String - Resolve the prompt with given arguments.
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited