BashToolOutput class
Bash tool output.
Constructors
- BashToolOutput({required String stdout, String stderr = '', required int exitCode, bool interrupted = false, bool isImage = false, String? backgroundTaskId, bool backgroundedByUser = false, bool assistantAutoBackgrounded = false, String? returnCodeInterpretation, bool noOutputExpected = false, String? persistedOutputPath, int? persistedOutputSize})
-
const
Properties
- assistantAutoBackgrounded → bool
-
final
- backgroundedByUser → bool
-
final
- backgroundTaskId → String?
-
final
- exitCode → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- interrupted → bool
-
final
- isImage → bool
-
final
- noOutputExpected → bool
-
final
- persistedOutputPath → String?
-
final
- persistedOutputSize → int?
-
final
- returnCodeInterpretation → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderr → String
-
final
- stdout → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited