ShellExecOptions class
Shell execution options.
Constructors
Properties
-
environment
→ Map<
String, String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxOutputBytes → int
-
final
- mergeStderr → bool
-
final
- onProgress → void Function(String)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration
-
final
- workingDirectory → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited