InMemorySettingsStore class

In-memory settings store for testing/default usage.

Implemented types

Constructors

InMemorySettingsStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAll() Map<String, dynamic>
Get the full settings map.
override
getValueAtPath(List<String> path) → dynamic
Read a nested value from settings.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setValueAtPath(List<String> path, dynamic value) SettingValidation
Write a nested value to settings.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited