NotebookEditInput class

Constructors

NotebookEditInput({required String notebookPath, required String command, required int cellIndex, String? content, String? cellType, int? targetIndex})
NotebookEditInput.fromJson(Map<String, dynamic> json)
factory

Properties

cellIndex int
final
cellType String?
final
command String
final
content String?
final
hashCode int
The hash code for this object.
no setterinherited
notebookPath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetIndex int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited