FileEditOutput class

Output data from a file edit operation.

Constructors

FileEditOutput({required bool success, required String message, String filePath = '', String oldString = '', String newString = '', String originalFile = '', bool userModified = false, bool replaceAll = false, int linesChanged = 0, String? backupPath, int occurrencesReplaced = 0, String? diff})
const

Properties

backupPath String?
final
diff String?
final
filePath String
final
hashCode int
The hash code for this object.
no setterinherited
linesChanged int
final
message String
final
newString String
final
occurrencesReplaced int
final
oldString String
final
originalFile String
final
replaceAll bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
final
userModified bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMetadata() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited