SnippetResult class
Gets a snippet from a file showing the context around a single edit.
Constructors
- SnippetResult({required String snippet, required int startLine})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited