appliedLimit property
Only set when truncation actually occurred, so the model knows there may be more results and can paginate with offset.
Implementation
final int? appliedLimit;
Only set when truncation actually occurred, so the model knows there may be more results and can paginate with offset.
final int? appliedLimit;