LspDocumentSymbol class
LSP DocumentSymbol (hierarchical).
Constructors
-
LspDocumentSymbol({required String name, required int kind, String? detail, required LspRange range, required LspRange selectionRange, List<
LspDocumentSymbol> children = const []}) -
const
-
LspDocumentSymbol.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
children
→ List<
LspDocumentSymbol> -
final
- detail → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → int
-
final
- name → String
-
final
- range → LspRange
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectionRange → LspRange
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited