LspLocationLink class

LSP LocationLink.

Constructors

LspLocationLink({required String targetUri, required LspRange targetRange, required LspRange targetSelectionRange, LspRange? originSelectionRange})
const
LspLocationLink.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
originSelectionRange LspRange?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetRange LspRange
final
targetSelectionRange LspRange
final
targetUri String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLocation() LspLocation
Convert to a Location for uniform handling.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited