LspOperation enum
All supported LSP operations.
Values
- goToDefinition → const LspOperation
- findReferences → const LspOperation
- hover → const LspOperation
- documentSymbol → const LspOperation
- workspaceSymbol → const LspOperation
- goToImplementation → const LspOperation
- prepareCallHierarchy → const LspOperation
- incomingCalls → const LspOperation
- outgoingCalls → const LspOperation
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- method → String
-
Convert to the LSP method string.
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromString(
String s) → LspOperation? - Parse from string.
Constants
-
values
→ const List<
LspOperation> - A constant List of the values in this enum, in order of their declaration.