LspToolInput class
Input for the LSP tool.
Constructors
- LspToolInput({required LspOperation operation, required String filePath, required int line, required int character})
-
const
-
LspToolInput.fromJson(Map<
String, dynamic> json) -
factory
Properties
- character → int
-
final
- filePath → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- line → int
-
final
- lspPosition → LspPosition
-
Get 0-based position for the LSP protocol.
no setter
- operation → LspOperation
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited