prompt property

  1. @override
String get prompt
override

Detailed prompt text sent in the system prompt for this tool.

Implementation

@override
String get prompt =>
    'Edit Jupyter notebook (.ipynb) cells.\n\n'
    'Operations:\n'
    '- add: Insert a new cell at cell_index with the given source and '
    'cell_type (default: code).\n'
    '- edit: Replace the source of the cell at cell_index. Optionally '
    'change cell_type.\n'
    '- delete: Remove the cell at cell_index.\n'
    '- move: Move the cell at cell_index to new_index.\n\n'
    'The notebook_path must be an absolute path to a .ipynb file. '
    'Cell indices are 0-based.';