PlanModeState class

Tracks the current plan mode state across tools.

Constructors

PlanModeState()

Properties

currentPlan String?
no setter
enteredAt DateTime?
no setter
hashCode int
The hash code for this object.
no setterinherited
isInPlanMode bool
no setter
planHistory List<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enterPlanMode(String reason) → void
exitPlanMode(String summary) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited