PowerShellOutput class
Result of a PowerShell command execution.
Constructors
- PowerShellOutput({required int exitCode, required String stdout, required String stderr, required Duration duration})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMetadata(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited