SkillCommand class

Represents a skill/slash command.

Constructors

SkillCommand({required String name, required String description, String? whenToUse, String type = 'prompt', String source = 'local', String? loadedFrom, String? kind, String? context, bool disableModelInvocation = false, List<String> aliases = const [], String? model, String? effort, List<String>? allowedTools, PluginInfo? pluginInfo, String? userFacingName, bool isEnabled = true, bool isHidden = false, int? contentLength, String? progressMessage, String? skillRoot, String? agent})
const
SkillCommand.fromJson(Map<String, dynamic> json)
factory

Properties

agent String?
final
aliases List<String>
final
allowedTools List<String>?
final
contentLength int?
final
context String?
final
description String
final
disableModelInvocation bool
final
effort String?
final
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
final
isHidden bool
final
kind String?
final
loadedFrom String?
final
model String?
final
name String
final
pluginInfo PluginInfo?
final
progressMessage String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skillRoot String?
final
source String
final
type String
final
userFacingName String?
final
whenToUse String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited