SkillToolInlineOutput class

Output for inline skill execution.

Constructors

SkillToolInlineOutput({required bool success, required String commandName, List<String>? allowedTools, String? model, String status = 'inline'})
const

Properties

allowedTools List<String>?
final
commandName String
final
hashCode int
The hash code for this object.
no setterinherited
model String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited