TaskStore class abstract
Abstract task storage interface.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
blockTask(
String taskListId, String taskId, String blockedTaskId) → Future< void> - Add a blocking relationship: taskId blocks blockedTaskId.
-
deleteTask(
String taskListId, String taskId) → Future< bool> - Delete a task.
-
getTask(
String taskListId, String taskId) → Future< Task?> - Get a task by ID.
-
getTaskListId(
) → String - Get the current task list ID.
-
listTasks(
String taskListId) → Future< List< Task> > - List all tasks.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateTask(
String taskListId, String taskId, Map< String, dynamic> updates) → Future<void> - Update a task.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited