ToolResult class
Result of executing a tool.
Constructors
-
ToolResult({required String content, bool isError = false, Map<
String, dynamic> ? metadata, List<Map< ? newMessages})String, dynamic> > -
const
- ToolResult.error(String message)
-
factory
-
ToolResult.success(String content, {Map<
String, dynamic> ? metadata}) -
factory
Properties
- content → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool
-
final
-
metadata
→ Map<
String, dynamic> ? -
final
-
newMessages
→ List<
Map< ?String, dynamic> > -
Additional messages to inject into conversation after tool execution.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited