ToolCategory enum
Logical category for grouping tools.
Values
- file → const ToolCategory
-
File read/write/edit operations.
- search → const ToolCategory
-
Search and pattern-matching (Glob, Grep).
- web → const ToolCategory
-
Web access (fetch, search).
- agent → const ToolCategory
-
Agent / sub-agent tools.
- system → const ToolCategory
-
System commands (Bash, PowerShell).
- editor → const ToolCategory
-
Editor-specific tools (NotebookEdit, TodoWrite).
- custom → const ToolCategory
-
User-defined / plugin tools.
- mcp → const ToolCategory
-
MCP (Model Context Protocol) server tools.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ToolCategory> - A constant List of the values in this enum, in order of their declaration.