WebSearchOutput class
Web search output.
Constructors
- WebSearchOutput({required String query, required List results, required double durationSeconds, int searchCount = 1})
-
const
Properties
- durationSeconds → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- query → String
-
final
- results → List
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchCount → int
-
final
Methods
-
format(
) → String - Format for display.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited