CliEntrypoint class

CLI entrypoint — parses arguments and produces a CliConfig.

Constructors

CliEntrypoint()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

helpText() String
Generate formatted help text for all CLI flags.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(List<String> args) CliConfig
Parse command-line arguments into a CliConfig.
toString() String
A string representation of this object.
inherited
validateConfig(CliConfig config) List<String>
Validate a parsed config and return a list of errors (empty if valid).
versionText() String
Generate version text.

Operators

operator ==(Object other) bool
The equality operator.
inherited