EmbeddedSession class

An active embedded session.

Properties

config EmbeddedConfig
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool
Whether the session is active.
no setter
messages Stream<Message>
Stream of messages from the session.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

detach() → void
Detach and dispose the embedded session.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage(String text) Future<Message>
Send a message to the embedded session.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited