McpEntrypointConfig class
Configuration for the MCP server entrypoint.
Constructors
-
McpEntrypointConfig({required String name, required String version, McpCapabilities capabilities = const McpCapabilities(), List<
McpServerTool> tools = const [], List<McpServerResource> resources = const [], List<McpServerPrompt> prompts = const []}) -
const
Properties
- capabilities → McpCapabilities
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
prompts
→ List<
McpServerPrompt> -
final
-
resources
→ List<
McpServerResource> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tools
→ List<
McpServerTool> -
final
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited