McpServerPrompt class
MCP prompt definition.
Constructors
-
McpServerPrompt({required String name, String? description, List<
McpPromptArgument> arguments = const [], required Future<String> generator(Map<String, String> args)}) -
const
Properties
-
arguments
→ List<
McpPromptArgument> -
final
- description → String?
-
final
-
generator
→ Future<
String> Function(Map<String, String> args) -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited