PipedConfig class
Configuration for piped mode (stdin -> stdout pipeline).
Constructors
-
PipedConfig({Stream<
List< ? inputStream, IOSink? outputSink, HeadlessFormat format = HeadlessFormat.text, String? model, String? systemPrompt, bool lineByLine = false, String? delimiter})int> > -
const
Properties
- delimiter → String?
-
Delimiter for separating input chunks (if not line-by-line).
final
- format → HeadlessFormat
-
Output format.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputStream
→ Stream<
List< ?int> > -
Input stream (defaults to stdin).
final
- lineByLine → bool
-
Whether to process input line-by-line or as a single batch.
final
- model → String?
-
Model override.
final
- outputSink → IOSink?
-
Output sink (defaults to stdout).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemPrompt → String?
-
System prompt.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited