AgentHook class
Agent hook — runs an agentic verifier.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ifFilter → String?
-
Permission rule filter (e.g., "Bash(git *)").
final
- model → String?
-
final
- once → bool
-
Run once and remove.
final
- prompt → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusMessage → String?
-
Custom spinner message during execution.
final
- timeout → int?
-
Timeout in seconds.
final
- type → String
-
Hook type discriminator.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited