HookConfig class abstract

Base properties shared by all hook types.

Implementers

Constructors

HookConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
ifFilter String?
Permission rule filter (e.g., "Bash(git *)").
no setter
once bool
Run once and remove.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusMessage String?
Custom spinner message during execution.
no setter
timeout int?
Timeout in seconds.
no setter
type String
Hook type discriminator.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited