HttpHook class

HTTP webhook — sends a POST request to an endpoint.

Implemented types

Constructors

HttpHook({required String url, Map<String, String> headers = const {}, String? ifFilter, int? timeout, String? statusMessage, bool once = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
ifFilter String?
Permission rule filter (e.g., "Bash(git *)").
final
once bool
Run once and remove.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusMessage String?
Custom spinner message during execution.
final
timeout int?
Timeout in seconds.
final
type String
Hook type discriminator.
no setteroverride
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited