HookCallback class
Hook callback definition.
Constructors
-
HookCallback({required String name, required HookEventType event, required Future<
HookResult> callback(Map<String, dynamic> context), Duration? timeout, bool internal = false}) -
const
Properties
-
callback
→ Future<
HookResult> Function(Map<String, dynamic> context) -
final
- event → HookEventType
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- internal → bool
-
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout → Duration?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited