PromptRequest class

A prompt request for user elicitation.

Constructors

PromptRequest({required String type, String? message, List<String>? options, String? defaultValue})
const

Properties

defaultValue String?
final
hashCode int
The hash code for this object.
no setterinherited
message String?
final
options List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited