FileAttributionState class

Per-file Neomage contribution tracking.

Constructors

FileAttributionState({required String filePath, required int totalCharacters, required int neomageCharacters, required DateTime lastModified})
const

Properties

attributionPercentage double
no setter
filePath String
final
hashCode int
The hash code for this object.
no setterinherited
lastModified DateTime
final
neomageCharacters int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCharacters int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited