LogOption class
Session log option with metadata.
Constructors
Properties
- agentId → AgentId?
-
final
- created → DateTime
-
final
- fileSize → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageCount → int
-
final
- modified → DateTime
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → String?
-
final
-
final
- teamName → String?
-
final
- title → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited