SerializedMessage class

Serialized message with session metadata.

Constructors

SerializedMessage({required Message message, String? cwd, String? userType, SessionId? sessionId, DateTime? timestamp, String? gitBranch, String? slug, String? entrypoint, String? parentUuid, bool? isSidechain})
const

Properties

cwd String?
final
entrypoint String?
final
gitBranch String?
final
hashCode int
The hash code for this object.
no setterinherited
isSidechain bool?
final
message Message
final
parentUuid String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId SessionId?
final
slug String?
final
timestamp DateTime?
final
userType String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited