ToolUseBlock class
A tool invocation content block.
- Inheritance
-
- Object
- ContentBlock
- ToolUseBlock
Constructors
-
ToolUseBlock({required String id, required String name, required Map<
String, dynamic> input}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this tool call.
final
-
input
→ Map<
String, dynamic> -
JSON input parameters for the tool.
final
- name → String
-
Name of the tool being invoked.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited