PermissionRule class
A permission rule with source, behavior, and value.
Constructors
- PermissionRule({required PermissionRuleSource source, required PermissionBehavior behavior, required PermissionRuleValue value})
-
const
Properties
- behavior → PermissionBehavior
-
Whether to allow, deny, or ask.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → PermissionRuleSource
-
Where this rule originated from.
final
- value → PermissionRuleValue
-
The tool and optional pattern this rule targets.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited