PermissionRuleSource enum
Source of a permission rule.
Values
- commandLine → const PermissionRuleSource
-
Rule specified via CLI flags.
- user → const PermissionRuleSource
-
Rule set interactively by the user.
- neomageMd → const PermissionRuleSource
-
Rule defined in a .neomage.md configuration file.
- autoAllow → const PermissionRuleSource
-
Rule auto-allowed by the system.
- mcpServer → const PermissionRuleSource
-
Rule from an MCP server configuration.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PermissionRuleSource> - A constant List of the values in this enum, in order of their declaration.