PermissionRuleValue class
Specification of tool name and optional rule content.
Constructors
- PermissionRuleValue({required String toolName, String? ruleContent})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ruleContent → String?
-
Optional content pattern or constraint for the rule.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolName → String
-
The tool this rule applies to.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited