YoloClassifierResult class
Full classifier result with detailed telemetry.
Constructors
- YoloClassifierResult({required ClassifierResult result, ClassifierUsage? usage, Duration? duration, String? requestId, int? stage})
-
const
Properties
- duration → Duration?
-
How long the classifier took.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestId → String?
-
API request ID for debugging.
final
- result → ClassifierResult
-
The classification result.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stage → int?
-
Which classification stage produced this result.
final
- usage → ClassifierUsage?
-
Token usage for the classifier call.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited