PluginLoadResult class

Result of loading plugins.

Constructors

PluginLoadResult({List<LoadedPlugin> enabled = const [], List<LoadedPlugin> disabled = const [], List<PluginError> errors = const []})
const

Properties

disabled List<LoadedPlugin>
final
enabled List<LoadedPlugin>
final
errors List<PluginError>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited