PluginManifest class
Plugin manifest — describes a plugin's capabilities.
Constructors
Properties
-
final
-
commands
→ List<
String> -
final
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
hooks
→ List<
String> -
final
-
mcpServers
→ List<
String> -
final
- name → String
-
final
-
outputStyles
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
skills
→ List<
String> -
final
- version → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited