PluginActivationPlan class
Resolved activation plan for a set of plugins.
Determines the order in which plugins should be initialized based on dependency resolution.
Constructors
-
PluginActivationPlan({required List<
PluginSetupDescriptor> orderedPlugins, List<PluginActivationError> errors = const [], int totalSteps = 0}) -
const
Properties
-
errors
→ List<
PluginActivationError> -
Plugins that could not be resolved (circular deps, missing deps).
final
- hasErrors → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
orderedPlugins
→ List<
PluginSetupDescriptor> -
Plugins in resolved activation order.
final
- pluginCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalSteps → int
-
Total setup steps across all plugins.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited