PluginActivationService class abstract
Service contract for plugin activation planning.
Resolves plugin dependencies and produces an ordered activation plan that respects setup step requirements.
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
listSetupCliBackendIds(
List< PluginSetupDescriptor> descriptors) → List<String> - Extract CLI backend IDs from a set of descriptors.
-
listSetupProviderIds(
List< PluginSetupDescriptor> descriptors) → List<String> - Extract provider IDs from a set of descriptors.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
List< PluginSetupDescriptor> descriptors) → PluginActivationPlan - Resolve descriptors into an ordered activation plan.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited