InferenceStats class

Constructors

InferenceStats({required Duration loadDuration, required Duration promptEvalDuration, required Duration totalDuration, required int promptTokens, required int completionTokens, required double tokensPerSecond})
const
InferenceStats.fromOllamaResponse(Map<String, dynamic> json)
factory

Properties

completionTokens int
final
hashCode int
The hash code for this object.
no setterinherited
loadDuration Duration
final
promptEvalDuration Duration
final
promptTokens int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokensPerSecond double
final
totalDuration Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited