EditorState class

Constructors

EditorState({bool vimModeEnabled = false, String keybindingScheme = 'default', int tabSize = 2, bool useSoftTabs = true, bool wordWrap = true, bool lineNumbers = true, bool minimap = false, String theme = 'dark', double fontSize = 14.0, String fontFamily = 'JetBrains Mono', bool bracketMatching = true, bool autoIndent = true, bool highlightCurrentLine = true, Map<String, String>? customKeybindings})
EditorState.fromJson(Map<String, dynamic> json)
factory

Properties

autoIndent bool
getter/setter pair
bracketMatching bool
getter/setter pair
customKeybindings Map<String, String>
final
fontFamily String
getter/setter pair
fontSize double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
highlightCurrentLine bool
getter/setter pair
keybindingScheme String
getter/setter pair
lineNumbers bool
getter/setter pair
minimap bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabSize int
getter/setter pair
theme String
getter/setter pair
useSoftTabs bool
getter/setter pair
vimModeEnabled bool
getter/setter pair
wordWrap bool
getter/setter pair

Methods

getAction(String key) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setKeybinding(String key, String action) → void
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited