SessionMessage class

Constructors

SessionMessage({required String role, required String content, DateTime? timestamp, int inputTokens = 0, int outputTokens = 0, double cost = 0.0, Map<String, dynamic>? metadata})

Properties

content String
final
cost double
final
hashCode int
The hash code for this object.
no setterinherited
inputTokens int
final
metadata Map<String, dynamic>?
final
outputTokens int
final
role String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited