StateSnapshot class
Constructors
-
StateSnapshot({required DateTime timestamp, required Map<
String, dynamic> session, required Map<String, dynamic> editor, required String currentView, required Map<String, dynamic> featureFlags, String? workingDirectory, String? model, String? provider, required String permissionMode}) -
const
-
StateSnapshot.fromJson(Map<
String, dynamic> json) -
factory
Properties
- currentView → String
-
final
-
editor
→ Map<
String, dynamic> -
final
-
featureFlags
→ Map<
String, dynamic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- model → String?
-
final
- permissionMode → String
-
final
- provider → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
session
→ Map<
String, dynamic> -
final
- timestamp → DateTime
-
final
- workingDirectory → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited