BuddyConfig class

Configuration for the buddy system.

Constructors

BuddyConfig({BuddyPersonality personality = BuddyPersonality.helpful, bool enabled = true, bool showTips = true, bool showShortcuts = true, int maxSuggestionsPerSession = 20})
const

Properties

enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
maxSuggestionsPerSession int
final
personality BuddyPersonality
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showShortcuts bool
final
showTips bool
final

Methods

copyWith({BuddyPersonality? personality, bool? enabled, bool? showTips, bool? showShortcuts, int? maxSuggestionsPerSession}) BuddyConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited