BuddySuggestion class
A single suggestion the buddy can show.
Constructors
- BuddySuggestion({required String text, required SuggestionCategory category, int priority = 0, bool dismissible = true, DateTime? createdAt})
Properties
- category → SuggestionCategory
-
final
- createdAt → DateTime
-
final
- dismissible → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- priority → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited