KeybindingContext enum
Keybinding contexts.
Values
- global → const KeybindingContext
- chat → const KeybindingContext
- autocomplete → const KeybindingContext
- commandPalette → const KeybindingContext
- permissionDialog → const KeybindingContext
- input → const KeybindingContext
- diffView → const KeybindingContext
- filePreview → const KeybindingContext
- planMode → const KeybindingContext
- agentView → const KeybindingContext
- settingsView → const KeybindingContext
- confirmation → const KeybindingContext
- help → const KeybindingContext
- transcript → const KeybindingContext
- historySearch → const KeybindingContext
- task → const KeybindingContext
- themePicker → const KeybindingContext
- settings → const KeybindingContext
- tabs → const KeybindingContext
- attachments → const KeybindingContext
- messageSelector → const KeybindingContext
- diffDialog → const KeybindingContext
- modelPicker → const KeybindingContext
- select → const KeybindingContext
- plugin → const KeybindingContext
- scroll → const KeybindingContext
- messageActions → const KeybindingContext
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
KeybindingContext> - A constant List of the values in this enum, in order of their declaration.