SettingItem class
Constructors
-
SettingItem({required String id, required String label, String? searchText, required SettingType type, required dynamic value, List<
String> ? options, ValueChanged? onChange}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- label → String
-
final
- onChange → ValueChanged?
-
final
-
options
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchText → String?
-
final
- type → SettingType
-
final
- value → dynamic
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited