OutputTheme class
Color palette for themed output rendering.
Each field holds an ANSI escape code string (e.g. '\x1B[32m').
Constructors
Properties
- code → String
-
final
- error → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- highlight → String
-
final
- info → String
-
final
- muted → String
-
final
- number → String
-
final
- path → String
-
final
- reset → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → String
-
final
- warning → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- none → const OutputTheme
- A theme with no ANSI codes (plain text).