NeomageComponentTheme class
Dimensional constants for common UI components.
Constructors
- NeomageComponentTheme({double buttonHeight = 40.0, double buttonRadius = 8.0, double cardRadius = 12.0, double cardElevation = 1.0, double inputHeight = 40.0, double inputRadius = 8.0, double chipHeight = 32.0, double badgeSize = 20.0, double tooltipRadius = 6.0, double dialogRadius = 16.0, double statusBarHeight = 28.0, double sidebarWidth = 260.0, double panelMinWidth = 200.0})
-
const
Properties
- badgeSize → double
-
final
-
final
-
final
- cardElevation → double
-
final
- cardRadius → double
-
final
- chipHeight → double
-
final
- dialogRadius → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputHeight → double
-
final
- inputRadius → double
-
final
- panelMinWidth → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
final
- statusBarHeight → double
-
final
- tooltipRadius → double
-
final
Methods
-
copyWith(
{double? buttonHeight, double? buttonRadius, double? cardRadius, double? cardElevation, double? inputHeight, double? inputRadius, double? chipHeight, double? badgeSize, double? tooltipRadius, double? dialogRadius, double? statusBarHeight, double? sidebarWidth, double? panelMinWidth}) → NeomageComponentTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, double> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited