VimState class
Constructors
- VimState()
Properties
- commandBuffer ↔ String
-
getter/setter pair
- count ↔ int
-
getter/setter pair
- cursor ↔ CursorPosition
-
getter/setter pair
- effectiveCount → int
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastChange ↔ String
-
getter/setter pair
- lastSearch ↔ String
-
getter/setter pair
- lastSearchForward ↔ bool
-
getter/setter pair
- mode ↔ VimMode
-
getter/setter pair
- pendingOperator ↔ VimOperator?
-
getter/setter pair
- pendingRegister ↔ String?
-
getter/setter pair
- register → VimRegister
-
final
- replaceMode ↔ bool
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visualAnchor ↔ CursorPosition?
-
getter/setter pair
Methods
-
beginUndoGroup(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
popRedo(
) → _UndoEntry? -
popUndo(
) → _UndoEntry? -
pushRedo(
List< String> lines, CursorPosition pos) → void -
pushUndo(
List< String> lines, CursorPosition pos) → void -
resetPartial(
) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited