ui/widgets/background_tasks_panel library

Functions

describeTeammateActivity(BackgroundTaskState task) String
Derives a human-readable activity string for an in-process teammate.
getTaskStatusColor(BuildContext context, TaskStatus status, {bool isIdle = false, bool awaitingApproval = false, bool hasError = false, bool shutdownRequested = false}) Color
Returns the appropriate semantic color for a task based on status and state flags.
getTaskStatusIcon(TaskStatus status, {bool isIdle = false, bool awaitingApproval = false, bool hasError = false, bool shutdownRequested = false}) IconData
Returns the appropriate icon for a task based on status and state flags.
isTerminalStatus(TaskStatus status) bool
Returns true if the given task status represents a terminal (finished) state.
shouldHideTasksFooter(Map<String, BackgroundTaskState> tasks, bool showSpinnerTree) bool
Returns true when the background tasks footer should be hidden because the spinner tree is active and every visible background task is a teammate.