BackgroundTaskState class
Constructors
- BackgroundTaskState({required String id, required BackgroundTaskType type, required TaskStatus status, required String description, String? command, String? title, String? summary, required DateTime startTime, bool isIdle = false, bool awaitingApproval = false, bool shutdownRequested = false, bool hasError = false, bool notified = true, bool isRemoteReview = false, bool isUltraplan = false, String? sessionId, TeammateIdentity? identity, TaskProgress? progress, String? kind})
-
const
Properties
- awaitingApproval → bool
-
final
- command → String?
-
final
- description → String
-
final
- hasError → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- identity → TeammateIdentity?
-
final
- isIdle → bool
-
final
- isRemoteReview → bool
-
final
- isRunning → bool
-
no setter
- isTerminal → bool
-
no setter
- isUltraplan → bool
-
final
- kind → String?
-
final
- notified → bool
-
final
- progress → TaskProgress?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
final
- shutdownRequested → bool
-
final
- startTime → DateTime
-
final
- status → TaskStatus
-
final
- summary → String?
-
final
- title → String?
-
final
- type → BackgroundTaskType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited