TaskListItem class
Constructors
- TaskListItem({required String id, BackgroundTaskType? type, required String label, required TaskStatus status, BackgroundTaskState? task, bool isLeader = false})
-
const
- TaskListItem.leader({String name = 'main'})
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- isLeader → bool
-
final
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → TaskStatus
-
final
- task → BackgroundTaskState?
-
final
- type → BackgroundTaskType?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited