PaletteEntry class
Single entry in the command palette.
Constructors
- PaletteEntry({required String id, required String label, String? description, String? detail, required PaletteEntryType type, IconData? icon, String? shortcut, int priority = 0, VoidCallback? action})
-
const
Properties
- action → VoidCallback?
-
final
- description → String?
-
final
- detail → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → IconData?
-
final
- id → String
-
final
- label → String
-
final
- priority → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortcut → String?
-
final
- type → PaletteEntryType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited