OptionMapItem<T> class
Linked-list map of options for efficient navigation. Port of OptionMap class from option-map.ts.
Constructors
-
OptionMapItem({required Widget label, required T value, String? description, OptionMapItem<
T> ? previous, OptionMapItem<T> ? next, required int index})
Properties
- description → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
final
- label → Widget
-
final
-
next
↔ OptionMapItem<
T> ? -
getter/setter pair
-
previous
↔ OptionMapItem<
T> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → T
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited