NeomageColors class

Full color palette for the Neomage design system (dark and light themes).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

agentHaiku → const Color
agentNeomage → const Color
agentOpus → const Color
agentSonnet → const Color
amber → const Color
amberDark → const Color
amberLight → const Color
codeBg → const Color
codeComment → const Color
codeFunction → const Color
codeGreen → const Color
codeKeyword → const Color
codeRed → const Color
codeString → const Color
codeText → const Color
codeYellow → const Color
darkBg → const Color
darkBorder → const Color
darkBorderSubtle → const Color
darkCard → const Color
darkElevated → const Color
darkSurface → const Color
darkTextDisabled → const Color
darkTextPrimary → const Color
darkTextSecondary → const Color
darkTextTertiary → const Color
error → const Color
errorBg → const Color
errorLightBg → const Color
info → const Color
infoBg → const Color
infoLightBg → const Color
lightBg → const Color
lightBorder → const Color
lightBorderSubtle → const Color
lightCard → const Color
lightElevated → const Color
lightSurface → const Color
lightTextDisabled → const Color
lightTextPrimary → const Color
lightTextSecondary → const Color
lightTextTertiary → const Color
success → const Color
successBg → const Color
successLightBg → const Color
warning → const Color
warningBg → const Color
warningLightBg → const Color