NeomageSpacing class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- cardPadding → const EdgeInsets
- Standard card content padding.
- compactPadding → const EdgeInsets
- Compact inner padding for dense UI areas.
- itemGap → const SizedBox
- Vertical gap between items in a list.
- lg → const double
- md → const double
- pagePadding → const EdgeInsets
- Standard horizontal padding for page content.
- sectionGap → const SizedBox
- Vertical gap between sections.
- sm → const double
- xl → const double
- xs → const double
- xxl → const double
- xxs → const double
- xxxl → const double