NeomageTypography class
Text style definitions.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- bodyLarge → const TextStyle
- bodyMedium → const TextStyle
- bodySmall → const TextStyle
- caption → const TextStyle
- codeLarge → const TextStyle
- codeMedium → const TextStyle
- codeSmall → const TextStyle
- heading1 → const TextStyle
- heading2 → const TextStyle
- heading3 → const TextStyle
- heading4 → const TextStyle
- label → const TextStyle
- overline → const TextStyle