DiffColors class
Colors for diff rendering.
Constructors
- DiffColors({Color addedBackground = const Color(0xFF1A3A1A), Color addedText = const Color(0xFF4EC94E), Color removedBackground = const Color(0xFF3A1A1A), Color removedText = const Color(0xFFE06060), Color contextText = const Color(0xFFBBBBBB), Color gutterText = const Color(0xFF666666), Color gutterBackground = const Color(0xFF1E1E2E), Color headerBackground = const Color(0xFF2A2A3A), Color headerText = const Color(0xFF8888CC)})
-
const
- DiffColors.light()
-
factory
Properties
- addedBackground → Color
-
final
- addedText → Color
-
final
- contextText → Color
-
final
- gutterBackground → Color
-
final
- gutterText → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerBackground → Color
-
final
- headerText → Color
-
final
- removedBackground → Color
-
final
- removedText → Color
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited