FeedbackSurveyConfig class
Constructors
-
FeedbackSurveyConfig({Duration minTimeBeforeFeedback = const Duration(minutes: 10), Duration minTimeBetweenFeedback = const Duration(hours: 1), Duration minTimeBetweenGlobalFeedback = const Duration(days: 1), int minUserTurnsBeforeFeedback = 5, int minUserTurnsBetweenFeedback = 10, Duration hideThanksAfter = const Duration(seconds: 3), List<
String> onForModels = const ['*'], double probability = 0.005}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideThanksAfter → Duration
-
final
- minTimeBeforeFeedback → Duration
-
final
- minTimeBetweenFeedback → Duration
-
final
- minTimeBetweenGlobalFeedback → Duration
-
final
- minUserTurnsBeforeFeedback → int
-
final
- minUserTurnsBetweenFeedback → int
-
final
-
onForModels
→ List<
String> -
final
- probability → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited