InputAttachment class

Attachment data ready to send with a message.

Constructors

InputAttachment({required String name, required String mimeType, required Uint8List bytes, required AttachmentKind kind})
const

Properties

base64Data String
Base64-encoded content for API payloads.
no setter
bytes Uint8List
final
hashCode int
The hash code for this object.
no setterinherited
isImage bool
no setter
kind AttachmentKind
final
mimeType String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited