LogBuffer class

Circular buffer that retains the last maxEntries log entries and exposes a stream for new entries as they arrive.

Constructors

LogBuffer({int maxEntries = 50000})

Properties

entries List<LogEntry>
no setter
hashCode int
The hash code for this object.
no setterinherited
length int
no setter
maxEntries int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<LogEntry>
no setter

Methods

add(LogEntry entry) → void
clear() → void
dispose() → void
export() String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited