LogBuffer class
Circular buffer that retains the last maxEntries log entries and exposes a stream for new entries as they arrive.
Properties
Methods
-
add(
LogEntry entry) → void -
clear(
) → void -
dispose(
) → void -
export(
) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited