LogEntry class

A single log entry with all associated metadata.

Constructors

LogEntry({required DateTime timestamp, required LogLevel level, required String source, required String message, String? stackTrace, Map<String, String>? metadata})

Properties

formattedTime String
no setter
hashCode int
The hash code for this object.
no setterinherited
level LogLevel
final
message String
final
metadata Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
stackTrace String?
final
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toExportLine() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited