LogFilter class

Filter configuration for the log panel.

Constructors

LogFilter({Set<LogLevel>? levels, Set<String>? sources, String? searchPattern, DateTimeRange<DateTime>? timeRange})

Properties

hashCode int
The hash code for this object.
no setterinherited
levels Set<LogLevel>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchPattern String?
final
sources Set<String>
final
timeRange DateTimeRange<DateTime>?
final

Methods

matches(LogEntry entry) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited