McpServerInfo class
MCP server info model.
Constructors
-
McpServerInfo({required String name, String? uri, McpServerStatus status = McpServerStatus.disconnected, McpServerCapabilities capabilities = const McpServerCapabilities(), List<
McpToolInfo> tools = const [], List<String> warnings = const [], String? errorMessage, String serverType = 'stdio', String? command, List<String> ? args}) -
const
Properties
-
args
→ List<
String> ? -
final
- capabilities → McpServerCapabilities
-
final
- command → String?
-
final
- errorMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverType → String
-
final
- status → McpServerStatus
-
final
-
tools
→ List<
McpToolInfo> -
final
- uri → String?
-
final
-
warnings
→ List<
String> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited