PermissionRuleDisplay class

Display info for a permission rule.

Constructors

PermissionRuleDisplay({required String pattern, required String behavior, required String scope, required String source, String? description, DateTime? createdAt, int hitCount = 0})
const

Properties

behavior String
final
createdAt DateTime?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
hitCount int
final
pattern String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
final
source String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited