ui/widgets/plan_mode_view library
Classes
- Plan
- Top-level plan model.
- PlanModeView
- Displays and controls the execution of a Plan with phases, steps, substeps, dependency indicators, drag-to-reorder, and status controls.
- PlanPhase
- A phase groups related steps.
- PlanStep
- A single step in the plan, possibly with substeps and dependencies.
Enums
- PlanStepStatus
- Status of a plan step.
Typedefs
- PlanStepCallback = void Function(PlanStep step)
- PlanStepReorderCallback = void Function(PlanPhase phase, int oldIndex, int newIndex)