PlanPhase class

A phase groups related steps.

Constructors

PlanPhase({required String name, required List<PlanStep> steps})

Properties

completedCount int
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
final
progress double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<PlanStep>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited