NetworkRestrictionConfig class

Network restriction config.

Constructors

NetworkRestrictionConfig({List<String> allowedHosts = const [], List<String> deniedHosts = const []})
const

Properties

allowedHosts List<String>
final
deniedHosts List<String>
final
hashCode int
The hash code for this object.
no setterinherited
hasRestrictions bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited