SandboxConfigSnapshot class

Full sandbox configuration snapshot used by the Config tab.

Constructors

SandboxConfigSnapshot({List<String> excludedCommands = const [], FsReadConfig fsReadConfig = const FsReadConfig(), FsWriteConfig fsWriteConfig = const FsWriteConfig(), NetworkRestrictionConfig networkConfig = const NetworkRestrictionConfig(), List<String> allowUnixSockets = const [], List<String> globPatternWarnings = const [], bool isManagedDomainsOnly = false})
const

Properties

allowUnixSockets List<String>
final
excludedCommands List<String>
final
fsReadConfig FsReadConfig
final
fsWriteConfig FsWriteConfig
final
globPatternWarnings List<String>
final
hashCode int
The hash code for this object.
no setterinherited
isManagedDomainsOnly bool
final
networkConfig NetworkRestrictionConfig
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited