StatusBarData class
Status bar data.
Constructors
- StatusBarData({required String model, int inputTokens = 0, int outputTokens = 0, int cacheReadTokens = 0, int cacheCreationTokens = 0, double cost = 0.0, String? gitBranch, String? gitStatus, ConnectionStatus apiStatus = ConnectionStatus.connected, int activeMcpServers = 0, int totalMcpServers = 0, int activeAgents = 0, int pendingTasks = 0, String? permissionMode, bool vimMode = false, String? workingDirectory, Duration? sessionDuration})
-
const
Properties
- activeAgents → int
-
final
- activeMcpServers → int
-
final
- apiStatus → ConnectionStatus
-
final
- cacheCreationTokens → int
-
final
- cacheReadTokens → int
-
final
- cost → double
-
final
- gitBranch → String?
-
final
- gitStatus → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputTokens → int
-
final
- model → String
-
final
- outputTokens → int
-
final
- pendingTasks → int
-
final
- permissionMode → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionDuration → Duration?
-
final
- totalMcpServers → int
-
final
- vimMode → bool
-
final
- workingDirectory → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited