StatusNoticeContext class
Context for evaluating status notices.
Constructors
-
StatusNoticeContext({required Map<
String, dynamic> config, List<MemoryFileInfo> memoryFiles = const [], int? agentDescriptionTokens, String? authTokenSource, String? apiKeySource, bool isSubscriber = false}) -
const
Properties
- agentDescriptionTokens → int?
-
final
- apiKeySource → String?
-
final
- authTokenSource → String?
-
final
-
config
→ Map<
String, dynamic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSubscriber → bool
-
final
-
memoryFiles
→ List<
MemoryFileInfo> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited