ToolActivity class
Describes a tool use activity for display in task detail views.
Constructors
-
ToolActivity({required String toolName, Map<
String, dynamic> input = const {}}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited