EnvironmentResource class

A remote environment resource.

Constructors

EnvironmentResource({required EnvironmentKind kind, required String environmentId, required String name, required String createdAt, required EnvironmentState state})
const
EnvironmentResource.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt String
final
environmentId String
final
hashCode int
The hash code for this object.
no setterinherited
kind EnvironmentKind
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state EnvironmentState
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited