SessionResource class

A session resource from the Sessions API.

Constructors

SessionResource({required String id, String? title, required SessionStatus sessionStatus, required String environmentId, required String createdAt, required String updatedAt, required SessionContext sessionContext})
const
SessionResource.fromJson(Map<String, dynamic> json)
factory

Properties

branch String?
Extracts the first branch name from session's git repository outcomes.
no setter
createdAt String
final
environmentId String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionContext SessionContext
final
sessionStatus SessionStatus
final
title String?
final
updatedAt String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited