TeleportController class
Controller for teleport / remote session operations.
- Inheritance
-
- Object
- Listenable
- ListNotifier
- SintController
- TeleportController
Constructors
Properties
- environmentLabel → String
-
Determine the display label for the selected environment.
no setter
-
environments
→ RxList<
EnvironmentResource> -
final
-
errorMessage
→ Rx<
String?> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized → bool
-
Checks whether the controller has already been initialized.
no setterinherited
- isClosed → bool
-
Checks whether the controller has already been closed.
no setterinherited
- isDisposed → bool
-
no setterinherited
- isLoading → RxBool
-
final
- isPolling → RxBool
-
final
-
lastEventId
→ Rx<
String?> -
final
- listenersLength → int
-
no setterinherited
-
localErrors
→ RxSet<
TeleportLocalErrorType> -
final
- progressLabel → String
-
Format a progress step for display.
no setter
- progressMessage → RxString
-
final
-
progressStep
→ Rx<
TeleportProgressStep?> -
final
-
repoValidation
→ Rx<
RepoValidationResult?> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectedEnvironment
→ Rx<
EnvironmentResource?> -
final
-
selectedSessionId
→ Rx<
String?> -
final
-
sessions
→ RxList<
CodeSession> -
final
-
sessionStatus
→ Rx<
SessionStatus?> -
final
Methods
-
addListener(
SintStateUpdate listener) → Disposer -
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(
Object? key, SintStateUpdate listener) → Disposer -
inherited
-
clearError(
) → void - Clear any error state.
-
containsListener(
SintStateUpdate listener) → bool -
inherited
-
debounce<
T> (RxInterface< T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void -
Calls
callbackafterrxstops changing forduration. Useful for search-as-you-type, form validation, etc.inherited -
dispose(
) → void -
inherited
-
ever<
T> (RxInterface< T> rx, void callback(T)) → void -
Calls
callbackevery timerxchanges. Auto-cancels on controller disposal.inherited -
interval<
T> (RxInterface< T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void -
Calls
callbackat most once perduration, ignoring intermediate changes. Useful for rate-limiting UI updates.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
once<
T> (RxInterface< T> rx, void callback(T)) → void -
Calls
callbackonly the first timerxchanges, then cancels.inherited -
onClose(
) → void -
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
override
-
onDelete(
) → void -
inherited
-
onInit(
) → void -
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
inherited
-
onReady(
) → void -
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
onStart(
) → void -
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclasses.
This method should be internal and is required to define the
lifetime cycle of the subclass.
inherited
-
refresh(
) → void -
inherited
-
refreshGroup(
Object id) → void -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(
Object id, VoidCallback listener) → void -
inherited
-
reportAdd(
VoidCallback disposer) → void -
inherited
-
reportRead(
) → void -
inherited
-
selectEnvironment(
String environmentId) → void - Select an environment by ID.
-
setError(
String message) → void - Set error message and stop loading.
-
setProgress(
TeleportProgressStep step, [String message = '']) → void - Update progress with a step and optional message.
-
startPolling(
String sessionId, {Duration interval = const Duration(seconds: 3)}) → void - Start polling for remote session events.
-
stopPolling(
) → void - Stop polling.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
[List< Object> ? ids, bool condition = true]) → void -
Notifies listeners to update the UI.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited