TerminalLine class
A single line in the terminal output.
Constructors
- TerminalLine({required String rawText, TerminalLineType type = TerminalLineType.stdout, DateTime? timestamp})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- plainText → String
-
no setter
- rawText → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
spans
→ List<
StyledSpan> -
no setter
- timestamp → DateTime
-
final
- type → TerminalLineType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited