ContextCategory class
A category of context usage.
Constructors
- ContextCategory({required String name, required int tokens, required String color, bool isDeferred = false})
-
const
Properties
- color → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDeferred → bool
-
When true, these tokens are deferred and don't count toward context usage.
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokens → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited