ContextData class

Complete context analysis data.

Constructors

ContextData({required List<ContextCategory> categories, required int totalTokens, required int maxTokens, required int rawMaxTokens, required int percentage, required List<List<GridSquare>> gridRows, required String model, required List<MemoryFile> memoryFiles, required List<McpTool> mcpTools, List<DeferredBuiltinTool>? deferredBuiltinTools, List<SystemToolDetail>? systemTools, List<SystemPromptSectionDetail>? systemPromptSections, required List<AgentInfo> agents, SlashCommandInfo? slashCommands, SkillInfo? skills, int? autoCompactThreshold, required bool isAutoCompactEnabled, MessageBreakdown? messageBreakdown, ApiUsage? apiUsage})
const

Properties

agents List<AgentInfo>
final
apiUsage ApiUsage?
final
autoCompactThreshold int?
final
categories List<ContextCategory>
final
deferredBuiltinTools List<DeferredBuiltinTool>?
final
gridRows List<List<GridSquare>>
final
hashCode int
The hash code for this object.
no setterinherited
isAutoCompactEnabled bool
final
maxTokens int
final
mcpTools List<McpTool>
final
memoryFiles List<MemoryFile>
final
messageBreakdown MessageBreakdown?
final
model String
final
percentage int
final
rawMaxTokens int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skills SkillInfo?
final
slashCommands SlashCommandInfo?
final
systemPromptSections List<SystemPromptSectionDetail>?
final
systemTools List<SystemToolDetail>?
final
totalTokens int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited