GridSquare class

A single square in the context grid visualization.

Constructors

GridSquare({required String color, required bool isFilled, required String categoryName, required int tokens, required int percentage, required double squareFullness})
const

Properties

categoryName String
final
color String
final
hashCode int
The hash code for this object.
no setterinherited
isFilled bool
final
percentage int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
squareFullness double
0-1 representing how full this individual square is.
final
tokens int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited