MessageBreakdown class

Message breakdown detail.

Constructors

MessageBreakdown({required int toolCallTokens, required int toolResultTokens, required int attachmentTokens, required int assistantMessageTokens, required int userMessageTokens, required List<ToolCallsByType> toolCallsByType, required List<AttachmentsByType> attachmentsByType})
const

Properties

assistantMessageTokens int
final
attachmentsByType List<AttachmentsByType>
final
attachmentTokens int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolCallsByType List<ToolCallsByType>
final
toolCallTokens int
final
toolResultTokens int
final
userMessageTokens int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited