SlashCommandInfo class
Slash command info for context display.
Constructors
- SlashCommandInfo({required int totalCommands, required int includedCommands, required int tokens})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- includedCommands → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokens → int
-
final
- totalCommands → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited