Attachment class abstract
Base attachment type.
- Implementers
- BudgetUsdAttachment
- CompactFileReferenceAttachment
- DateChangeAttachment
- DiagnosticsAttachment
- DirectoryAttachment
- EditedTextFileAttachment
- FileAttachment
- HookAttachment
- MaxTurnsReachedAttachment
- McpResourceAttachment
- OpenedFileInIdeAttachment
- OutputStyleAttachment
- PDFReferenceAttachment
- PlanModeAttachment
- QueuedCommandAttachment
- RelevantMemoriesAttachment
- SelectedLinesInIdeAttachment
- TodoReminderAttachment
- TokenUsageAttachment
Constructors
Properties
Methods
-
normalizeForAPI(
) → List< UserMessage> - Normalize this attachment into user messages for the API.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited