DiagnosticsAttachment class
Diagnostics attachment (LSP or other diagnostic files).
- Inheritance
-
- Object
- Attachment
- DiagnosticsAttachment
Constructors
-
DiagnosticsAttachment({required List<
Map< files, bool isNew = false})String, dynamic> >
Properties
Methods
-
normalizeForAPI(
) → List< UserMessage> -
Normalize this attachment into user messages for the API.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited