HookSuccessAttachment class
Hook success attachment.
- Inheritance
-
- Object
- Attachment
- HookAttachment
- HookSuccessAttachment
Constructors
Properties
- command → String?
-
final
- content → String
-
final
- durationMs → int?
-
final
- exitCode → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hookEvent → String
-
final
- hookName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stderr → String?
-
final
- stdout → String?
-
final
- toolUseID → String
-
final
- type → String
-
no setteroverride
Methods
-
normalizeForAPI(
) → List< UserMessage> -
Normalize this attachment into user messages for the API.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited