QueuedCommandAttachment class

Queued command attachment (user typed while model was working).

Inheritance

Constructors

QueuedCommandAttachment({required dynamic prompt, String? sourceUuid, List<int>? imagePasteIds, String? commandMode, MessageOrigin? origin, bool? isMeta})

Properties

commandMode String?
final
hashCode int
The hash code for this object.
no setterinherited
imagePasteIds List<int>?
final
isMeta bool?
final
origin MessageOrigin?
final
prompt → dynamic
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceUuid String?
final
type String
no setteroverride

Methods

normalizeForAPI() List<UserMessage>
Normalize this attachment into user messages for the API.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited