OAuthTokens class
OAuth tokens representation.
Constructors
Properties
- accessToken → String
-
final
- expiresAt → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rateLimitTier → String?
-
final
- refreshToken → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ List<
String> -
final
- subscriptionType → String?
-
final
Methods
-
copyWith(
{String? accessToken, String? refreshToken, int? expiresAt, List< String> ? scopes, String? subscriptionType, String? rateLimitTier}) → OAuthTokens -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited