ModelCosts class
Cost structure for a model (per million tokens). @see https://platform.neomage.com/docs/en/about-claude/pricing
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputTokens → double
-
final
- outputTokens → double
-
final
- promptCacheReadTokens → double
-
final
- promptCacheWriteTokens → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webSearchRequests → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited