RawTokenCounts class

Raw token counts for cost calculation without a full usage object.

Constructors

RawTokenCounts({required int inputTokens, required int outputTokens, required int cacheReadInputTokens, required int cacheCreationInputTokens})
const

Properties

cacheCreationInputTokens int
final
cacheReadInputTokens int
final
hashCode int
The hash code for this object.
no setterinherited
inputTokens int
final
outputTokens int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited