TokenUsageInfo class

Token usage from an API response.

Constructors

TokenUsageInfo({required int inputTokens, required int outputTokens, int? cacheReadInputTokens, int? cacheCreationInputTokens, int? webSearchRequestCount, String? speed})
const

Properties

cacheCreationInputTokens int?
final
cacheReadInputTokens int?
final
hashCode int
The hash code for this object.
no setterinherited
inputTokens int
final
outputTokens int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed String?
final
webSearchRequestCount int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited