CollapsedReadSearchGroup class
A collapsed group of read/search operations.
Constructors
-
CollapsedReadSearchGroup({required String uuid, DateTime? timestamp, int searchCount = 0, int readCount = 0, int listCount = 0, int replCount = 0, int memorySearchCount = 0, int memoryReadCount = 0, int memoryWriteCount = 0, int? teamMemorySearchCount, int? teamMemoryReadCount, int? teamMemoryWriteCount, List<
String> readFilePaths = const [], List<String> searchArgs = const [], String? latestDisplayHint, List<RenderableMessage> messages = const [], RenderableMessage? displayMessage, int? mcpCallCount, List<String> ? mcpServerNames, int? bashCount, int? gitOpBashCount, List<DetectedCommit> ? commits, List<DetectedPush> ? pushes, List<DetectedBranch> ? branches, List<DetectedPr> ? prs, int? hookTotalMs, int? hookCount, List<StopHookInfo> ? hookInfos, List<Map< ? relevantMemories})String, dynamic> >
Properties
- bashCount → int?
-
final
-
branches
→ List<
DetectedBranch> ? -
final
-
commits
→ List<
DetectedCommit> ? -
final
- displayMessage → RenderableMessage?
-
final
- gitOpBashCount → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hookCount → int?
-
final
-
hookInfos
→ List<
StopHookInfo> ? -
final
- hookTotalMs → int?
-
final
- latestDisplayHint → String?
-
final
- listCount → int
-
final
- mcpCallCount → int?
-
final
-
mcpServerNames
→ List<
String> ? -
final
- memoryReadCount → int
-
final
- memorySearchCount → int
-
final
- memoryWriteCount → int
-
final
-
messages
→ List<
RenderableMessage> -
final
-
prs
→ List<
DetectedPr> ? -
final
-
pushes
→ List<
DetectedPush> ? -
final
- readCount → int
-
final
-
readFilePaths
→ List<
String> -
final
-
relevantMemories
→ List<
Map< ?String, dynamic> > -
final
- replCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchArgs
→ List<
String> -
final
- searchCount → int
-
final
- teamMemoryReadCount → int?
-
final
- teamMemorySearchCount → int?
-
final
- teamMemoryWriteCount → int?
-
final
- timestamp → DateTime?
-
final
- uuid → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited