SearchOrReadResult class
Result of checking if a tool use is a search or read operation.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAbsorbedSilently → bool
-
True for meta-operations that should be absorbed into a collapse group
without incrementing any count (Snip, ToolSearch).
final
- isBash → bool?
-
Bash command that is NOT a search/read (under fullscreen mode).
final
- isCollapsible → bool
-
final
- isList → bool
-
final
- isMemoryWrite → bool
-
True if this is a Write/Edit targeting a memory file.
final
- isRead → bool
-
final
- isREPL → bool
-
final
- isSearch → bool
-
final
- mcpServerName → String?
-
MCP server name when this is an MCP tool.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited