AttributionData class
Full attribution data for git notes JSON.
Constructors
-
AttributionData({int version = 1, required AttributionSummary summary, required Map<
String, FileAttribution> files, required Map<String, SurfaceBreakdownEntry> surfaceBreakdown, required List<String> excludedGenerated, required List<String> sessions}) -
const
Properties
-
excludedGenerated
→ List<
String> -
final
-
files
→ Map<
String, FileAttribution> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessions
→ List<
String> -
final
- summary → AttributionSummary
-
final
-
surfaceBreakdown
→ Map<
String, SurfaceBreakdownEntry> -
final
- version → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited