AttributionSnapshotMessage class
Attribution snapshot message for persistence.
Constructors
-
AttributionSnapshotMessage({String type = 'attribution-snapshot', required String messageId, required String surface, required Map<
String, FileAttributionState> fileStates, int promptCount = 0, int promptCountAtLastCommit = 0, int permissionPromptCount = 0, int permissionPromptCountAtLastCommit = 0, int escapeCount = 0, int escapeCountAtLastCommit = 0}) -
const
-
AttributionSnapshotMessage.fromJson(Map<
String, dynamic> json) -
factory
Properties
- escapeCount → int
-
final
- escapeCountAtLastCommit → int
-
final
-
fileStates
→ Map<
String, FileAttributionState> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → String
-
final
- permissionPromptCount → int
-
final
- permissionPromptCountAtLastCommit → int
-
final
- promptCount → int
-
final
- promptCountAtLastCommit → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surface → String
-
final
- type → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited