ComputerExecutor class abstract
Abstract interface for computer use operations.
- Implementers
Constructors
Properties
- capabilities → ComputerUseCapabilities
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appUnderPoint(
double x, double y) → Future< Map< String, String> ?> -
click(
double x, double y, String button, int count, [List< String> ? modifiers]) → Future<void> -
drag(
Map< String, double> ? from, Map<String, double> to) → Future<void> -
findWindowDisplays(
List< String> bundleIds) → Future<List< Map< >String, dynamic> > -
getAppIcon(
String path) → Future< String?> -
getCursorPosition(
) → Future< Map< String, double> > -
getDisplaySize(
[int? displayId]) → Future< DisplayGeometry> -
getFrontmostApp(
) → Future< FrontmostApp?> -
holdKey(
List< String> keyNames, int durationMs) → Future<void> -
key(
String keySequence, [int? repeat]) → Future< void> -
listDisplays(
) → Future< List< DisplayGeometry> > -
listInstalledApps(
) → Future< List< InstalledApp> > -
listRunningApps(
) → Future< List< RunningApp> > -
mouseDown(
) → Future< void> -
mouseUp(
) → Future< void> -
moveMouse(
double x, double y) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
openApp(
String bundleId) → Future< void> -
prepareForAction(
List< String> allowlistBundleIds, [int? displayId]) → Future<List< String> > -
previewHideSet(
List< String> allowlistBundleIds, [int? displayId]) → Future<List< Map< >String, String> > -
readClipboard(
) → Future< String> -
resolvePrepareCapture(
{required List< String> allowedBundleIds, int? preferredDisplayId, required bool autoResolve, bool? doHide}) → Future<ResolvePrepareCaptureResult> -
screenshot(
{required List< String> allowedBundleIds, int? displayId}) → Future<ScreenshotResult> -
scroll(
double x, double y, double dx, double dy) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
-
type(
String text, {required bool viaClipboard}) → Future< void> -
writeClipboard(
String text) → Future< void> -
zoom(
{required Map< String, num> regionLogical, required List<String> allowedBundleIds, int? displayId}) → Future<ScreenshotResult>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited