ComputerUseLockManager class

Manages computer use session locking.

Constructors

ComputerUseLockManager({required String configHomeDir, required String sessionId})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkComputerUseLock() Future<CheckResult>
Check lock state without acquiring.
isLockHeldLocally() bool
Zero-syscall check: does THIS process believe it holds the lock?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
releaseComputerUseLock() Future<bool>
Release the computer-use lock if the current session owns it.
toString() String
A string representation of this object.
inherited
tryAcquireComputerUseLock() Future<AcquireResult>
Try to acquire the computer-use lock for the current session.

Operators

operator ==(Object other) bool
The equality operator.
inherited