ModelUsageMetrics class

Constructors

ModelUsageMetrics({int inputTokens = 0, int outputTokens = 0, int cacheReadInputTokens = 0, int cacheCreationInputTokens = 0, int webSearchRequests = 0, double costUSD = 0.0})
const
ModelUsageMetrics.fromJson(Map<String, dynamic> json)
factory

Properties

cacheCreationInputTokens int
final
cacheReadInputTokens int
final
costUSD double
final
hashCode int
The hash code for this object.
no setterinherited
inputTokens int
final
outputTokens int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webSearchRequests int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited