utils/config/config_manager library

Classes

AccountInfo
Account info from OAuth.
ConfigManager
Manages reading and writing the global config file (~/.neomage.json).
GlobalConfig
Application-wide configuration.
HistoryEntry
History entry for prompt history.
ImageDimensions
Image dimensions.
PastedContent
Image dimension info for coordinate mapping.
ProjectConfig
Per-project configuration.

Enums

DiffTool
Diff tool preference.
EditorMode
Editor mode.
InstallMethod
Install method for the CLI.
NotificationChannel
Notification channel preference.
ReleaseChannel
Release channel for auto-updates.
ThemeSetting
Theme setting.

Constants

globalConfigKeys → const List<String>
Keys that are safe to expose in the global config UI.
projectConfigKeys → const List<String>
Keys that are safe for project config UI.

Functions

isGlobalConfigKey(String key) bool
Check if a key is a global config key.
isProjectConfigKey(String key) bool
Check if a key is a project config key.