SpinnerVerbsConfig class

Configuration for customizing spinner verbs via settings.

Constructors

SpinnerVerbsConfig({required SpinnerVerbsMode mode, required List<String> verbs})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
mode SpinnerVerbsMode
How custom verbs interact with the defaults.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbs List<String>
Custom verb strings to replace or append.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited