CronScheduler class
A running cron scheduler.
Constructors
- CronScheduler(CronSchedulerOptions _options)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextFireTime → int?
-
Epoch ms of the soonest scheduled fire, or null if nothing is scheduled.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessionTasks
→ List<
CronTask> -
Session-scoped tasks (runtime-only, never written to disk).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setScheduledTasksEnabled(
bool value) → void - Enable scheduled tasks externally.
-
start(
) → void - Start the scheduler.
-
stop(
) → void - Stop the scheduler.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited