SecureStorage class
Platform-aware secure storage using system keychains.
- macOS: uses the
securitycommand (Keychain Access) - Linux: uses
secret-tool(GNOME Keyring / libsecret)
Constructors
- SecureStorage({String serviceName = 'neomage'})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceName → String
-
final
Methods
-
delete(
String key) → Future< bool> - Delete a value from the system keychain.
-
has(
String key) → Future< bool> - Check if a key exists in the keychain.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String key) → Future< String?> - Read a value from the system keychain.
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
String key, String value) → Future< bool> - Store a value in the system keychain.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited