PatchSet class
A set of hunks that together describe a transformation.
Properties
Methods
-
apply(
String text) → PatchResult -
Apply this patch to
text. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reverse(
) → PatchSet - Create a reversed patch that undoes this patch.
-
serialize(
) → String - Serialize to a string representation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
deserialize(
String text) → PatchSet - Deserialize from a unified diff string.