EffortConfig class

Configuration callbacks for effort management.

Constructors

EffortConfig({required String getApiProvider(), required bool isEnvTruthy(String name), required String? getUserType(), required bool? get3PModelCapabilityOverride(String model, String capability), required String getCanonicalName(String model), required Map<String, dynamic> getInitialSettings(), required Map<String, dynamic>? getSettingsForSource(String source), required ({List<String> errors, Map<String, dynamic> settings}) getSettingsWithErrors(), required T getFeatureValue<T>(String key, T defaultValue), required bool isProSubscriber(), required bool isMaxSubscriber(), required bool isTeamSubscriber(), required bool isUltrathinkEnabled(), required Map<String, dynamic>? resolveAntModel(String model), required Map<String, dynamic>? getAntModelOverrideConfig()})
const

Properties

get3PModelCapabilityOverride bool? Function(String model, String capability)
Get 3P model capability override.
final
getAntModelOverrideConfig Map<String, dynamic>? Function()
Get ant model override config.
final
getApiProvider String Function()
Get the API provider.
final
getCanonicalName String Function(String model)
Get the canonical name for a model.
final
getFeatureValue → T Function<T>(String key, T defaultValue)
Get a cached feature value from remote config.
final
getInitialSettings Map<String, dynamic> Function()
Get initial settings.
final
getSettingsForSource Map<String, dynamic>? Function(String source)
Get settings for a specific source.
final
getSettingsWithErrors → ({List<String> errors, Map<String, dynamic> settings}) Function()
Get settings with errors.
final
getUserType String? Function()
Get the user type (e.g., 'ant').
final
hashCode int
The hash code for this object.
no setterinherited
isEnvTruthy bool Function(String name)
Check if an env var is truthy.
final
isMaxSubscriber bool Function()
Check if the user is a Max subscriber.
final
isProSubscriber bool Function()
Check if the user is a Pro subscriber.
final
isTeamSubscriber bool Function()
Check if the user is a Team subscriber.
final
isUltrathinkEnabled bool Function()
Check if ultrathink is enabled.
final
resolveAntModel Map<String, dynamic>? Function(String model)
Resolve ant-internal model overrides. Returns null if not an ant model.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited