EffortNumericValue class

A numeric effort value (ant-only feature).

Inheritance

Constructors

EffortNumericValue(int value)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toLevel({bool isAnt = false}) EffortLevel
Get the effort level this value represents.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override