EffortValue class sealed
Effort value can be either a named level or a numeric value.
- Implementers
Constructors
- EffortValue.level(EffortLevel level)
-
Create from a named level.
constfactory
- EffortValue.numeric(int value)
-
Create from a numeric value.
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toLevel(
{bool isAnt = false}) → EffortLevel - Get the effort level this value represents.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited