ThinkingManager class
Thinking support manager. Separate from effort to avoid circular deps.
Constructors
- ThinkingManager(EffortConfig _config)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
findThinkingTriggerPositions(
String text) → List< ({int end, int start, String word})> - Find positions of "ultrathink" keyword in text (for UI highlighting).
-
hasUltrathinkKeyword(
String text) → bool - Check if text contains the "ultrathink" keyword.
-
isUltrathinkEnabled(
) → bool - Build-time gate + runtime gate for ultrathink.
-
modelSupportsAdaptiveThinking(
String model) → bool - Check if a model supports adaptive thinking.
-
modelSupportsThinking(
String model) → bool - Check if a model supports extended thinking.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldEnableThinkingByDefault(
) → bool - Check if thinking should be enabled by default.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited