ConfigError class
Configuration errors.
- Inheritance
-
- Object
- NeomageError
- ConfigError
Constructors
- ConfigError({required String message, String? configPath, String errorId = 'config_error', String? suggestion})
Properties
- configPath → String?
-
final
-
context
→ Map<
String, dynamic> -
no setteroverride
- errorId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestion → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited