FileSystemError class
File system errors.
- Inheritance
-
- Object
- NeomageError
- FileSystemError
Constructors
- FileSystemError({required String message, required String path, required String operation, String errorId = 'fs_error', String? suggestion})
- FileSystemError.accessDenied(String path)
-
factory
- FileSystemError.notFound(String path)
-
factory
- FileSystemError.tooLarge(String path, int size)
-
factory
Properties
-
context
→ Map<
String, dynamic> -
no setteroverride
- errorId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- operation → String
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestion → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited