Notebook class
Parsed Jupyter notebook.
Constructors
-
Notebook({required Map<
String, dynamic> metadata, required int nbformat, required int nbformatMinor, required List<NotebookCell> cells}) -
Notebook.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
cells
↔ List<
NotebookCell> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
↔ Map<
String, dynamic> -
getter/setter pair
- nbformat ↔ int
-
getter/setter pair
- nbformatMinor ↔ int
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toJsonString(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited