NotebookCell class

Jupyter notebook cell.

Constructors

NotebookCell({required String cellType, required List<String> source, Map<String, dynamic>? metadata, List<Map<String, dynamic>>? outputs, int? executionCount})
NotebookCell.fromJson(Map<String, dynamic> json)
factory

Properties

cellType String
getter/setter pair
executionCount int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
getter/setter pair
outputs List<Map<String, dynamic>>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source List<String>
getter/setter pair
text String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited