DartFsOperations class
Concrete filesystem implementation using dart:io.
- Inheritance
-
- Object
- FsOperations
- DartFsOperations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appendFileSync(
String path, String data, {int? mode}) → void -
Appends string to file.
override
-
copyFileSync(
String src, String dest) → void -
Copies file from source to destination.
override
-
cwd(
) → String -
Gets the current working directory.
override
-
existsSync(
String path) → bool -
Checks if a file or directory exists.
override
-
isDirEmptySync(
String dirPath) → bool -
Checks if the directory is empty.
override
-
linkSync(
String target, String path) → void -
Creates hard link.
override
-
lstatSync(
String fsPath) → FileStat -
Gets file stats without following symlinks.
override
-
mkdir(
String dirPath, {int? mode}) → Future< void> -
Creates directory recursively asynchronously.
override
-
mkdirSync(
String dirPath, {int? mode}) → void -
Creates directory recursively. Mode defaults to 0o777 & ~umask if not specified.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readdir(
String fsPath) → Future< List< Dirent> > -
Lists directory contents with file type information asynchronously.
override
-
readdirStringSync(
String dirPath) → List< String> -
Lists directory contents as strings.
override
-
readdirSync(
String dirPath) → List< Dirent> -
Lists directory contents with file type information.
override
-
readFile(
String fsPath, {String encoding = 'utf-8'}) → Future< String> -
Reads file content as string asynchronously.
override
-
readFileBytes(
String fsPath, {int? maxBytes}) → Future< Uint8List> -
Reads raw file bytes as Uint8List asynchronously.
When maxBytes is set, only reads up to that many bytes.
override
-
readFileBytesSync(
String fsPath) → Uint8List -
Reads raw file bytes as Uint8List.
override
-
readFileSync(
String fsPath, {String encoding = 'utf-8'}) → String -
Reads file content as string with specified encoding.
override
-
readlinkSync(
String path) → String -
Reads symbolic link.
override
-
readSync(
String fsPath, {required int length}) → ReadSyncResult -
Reads specified number of bytes from file start.
override
-
realpathSync(
String path) → String -
Resolves symbolic links and returns the canonical pathname.
override
-
rename(
String oldPath, String newPath) → Future< void> -
Renames/moves file asynchronously.
override
-
renameSync(
String oldPath, String newPath) → void -
Renames/moves file.
override
-
rm(
String fsPath, {bool recursive = false, bool force = false}) → Future< void> -
Removes files and directories asynchronously (with recursive option).
override
-
rmdir(
String fsPath) → Future< void> -
Removes an empty directory asynchronously.
override
-
rmdirSync(
String dirPath) → void -
Removes an empty directory.
override
-
rmSync(
String path, {bool recursive = false, bool force = false}) → void -
Removes files and directories (with recursive option).
override
-
stat(
String fsPath) → Future< FileStat> -
Gets file stats asynchronously.
override
-
statSync(
String fsPath) → FileStat -
Gets file stats.
override
-
symlinkSync(
String target, String path, {String? type}) → void -
Creates symbolic link.
override
-
toString(
) → String -
A string representation of this object.
inherited
-
unlink(
String fsPath) → Future< void> -
Deletes file asynchronously.
override
-
unlinkSync(
String path) → void -
Deletes file.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited