FileStat class
File stat result mirroring Node's fs.Stats.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDirectory → bool
-
no setter
- isFile → bool
-
no setter
- isSymbolicLink → bool
-
no setter
- isSymLink → bool
-
final
- modified → DateTime
-
final
- mtimeMs → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
final
- type → FileSystemEntityType
-
final
Methods
-
isBlockDevice(
) → bool - Returns true if this is a block device.
-
isCharacterDevice(
) → bool - Returns true if this is a character device.
-
isFIFO(
) → bool - Returns true if this is a FIFO (named pipe).
-
isSocket(
) → bool - Returns true if this is a socket.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited