PerFileStats class
Per-file diff statistics.
Constructors
- PerFileStats({required int added, required int removed, required bool isBinary, bool isUntracked = false})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited