PreservedGitState class
Preserved git state for issue submission.
Constructors
-
PreservedGitState({required String? remoteBaseSha, required String? remoteBase, required String patch, required List<
UntrackedFile> untrackedFiles, required String? formatPatch, required String? headSha, required String? branchName}) -
const
Properties
- branchName → String?
-
final
- formatPatch → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headSha → String?
-
final
- patch → String
-
final
- remoteBase → String?
-
final
- remoteBaseSha → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
untrackedFiles
→ List<
UntrackedFile> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited