CodeIndexingTool enum

Known code indexing tool identifiers.

Inheritance
Available extensions

Values

sourcegraph → const CodeIndexingTool
hound → const CodeIndexingTool
seagoat → const CodeIndexingTool
bloop → const CodeIndexingTool
gitloop → const CodeIndexingTool
cody → const CodeIndexingTool
aider → const CodeIndexingTool
continueAi → const CodeIndexingTool
githubCopilot → const CodeIndexingTool
cursor → const CodeIndexingTool
tabby → const CodeIndexingTool
codeium → const CodeIndexingTool
tabnine → const CodeIndexingTool
augment → const CodeIndexingTool
windsurf → const CodeIndexingTool
aide → const CodeIndexingTool
pieces → const CodeIndexingTool
qodo → const CodeIndexingTool
amazonQ → const CodeIndexingTool
gemini → const CodeIndexingTool
neomageContext → const CodeIndexingTool
codeIndexMcp → const CodeIndexingTool
localCodeSearch → const CodeIndexingTool
autodevCodebase → const CodeIndexingTool
openctx → const CodeIndexingTool

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CodeIndexingTool>
A constant List of the values in this enum, in order of their declaration.