PlanController class
Controller for plan file management.
Manages plan slugs, plan file reading/writing, and plan recovery from message history.
- Inheritance
-
- Object
- Listenable
- ListNotifier
- SintController
- PlanController
Constructors
- PlanController({required String plansDirectory, required String configHomeDir, required String cwd, String generateWordSlug()?})
Properties
- configHomeDir → String
-
The config home directory.
final
- cwd → String
-
The current working directory.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialized → bool
-
Checks whether the controller has already been initialized.
no setterinherited
- isClosed → bool
-
Checks whether the controller has already been closed.
no setterinherited
- isDisposed → bool
-
no setterinherited
- listenersLength → int
-
no setterinherited
- plansDirectory → String
-
The plans directory path.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
SintStateUpdate listener) → Disposer -
Register a closure to be called when the object notifies its listeners.
inherited
-
addListenerId(
Object? key, SintStateUpdate listener) → Disposer -
inherited
-
clearAllPlanSlugs(
) → void - Clear ALL plan slug entries (all sessions).
-
clearPlanSlug(
String sessionId) → void - Clear the plan slug for the given session.
-
containsListener(
SintStateUpdate listener) → bool -
inherited
-
copyPlanForFork(
{required LogOption log, required String targetSessionId}) → Future< bool> - Copy a plan file for a forked session.
-
copyPlanForResume(
{required LogOption log, required String targetSessionId, bool isRemoteSession = false}) → Future< bool> - Restore plan slug from a resumed session.
-
debounce<
T> (RxInterface< T> rx, void callback(T), {Duration duration = const Duration(milliseconds: 400)}) → void -
Calls
callbackafterrxstops changing forduration. Useful for search-as-you-type, form validation, etc.inherited -
dispose(
) → void -
inherited
-
ever<
T> (RxInterface< T> rx, void callback(T)) → void -
Calls
callbackevery timerxchanges. Auto-cancels on controller disposal.inherited -
getPlan(
{required String sessionId, String? agentId}) → String? - Get the plan content for a session.
-
getPlanFilePath(
{required String sessionId, String? agentId}) → String - Get the file path for a session's plan.
-
getPlanSlug(
String sessionId) → String - Get or generate a word slug for the given session's plan.
-
interval<
T> (RxInterface< T> rx, void callback(T), {Duration duration = const Duration(seconds: 1)}) → void -
Calls
callbackat most once perduration, ignoring intermediate changes. Useful for rate-limiting UI updates.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
once<
T> (RxInterface< T> rx, void callback(T)) → void -
Calls
callbackonly the first timerxchanges, then cancels.inherited -
onClose(
) → void -
Called before onDelete method. onClose might be used to
dispose resources used by the controller. Like closing events,
or streams before the controller is destroyed.
Or dispose objects that can potentially create some memory leaks,
like TextEditingControllers, AnimationControllers.
Might be useful as well to persist some data on disk.
inherited
-
onDelete(
) → void -
inherited
-
onInit(
) → void -
Called immediately after the widget is allocated in memory.
You might use this to initialize something for the controller.
inherited
-
onReady(
) → void -
Called 1 frame after onInit(). It is the perfect place to enter
navigation events, like snackbar, dialogs, or a new route, or
async request.
inherited
-
onStart(
) → void -
Called at the exact moment the widget is allocated in memory.
It uses an internal "callable" type, to avoid any @overrides in subclasses.
This method should be internal and is required to define the
lifetime cycle of the subclass.
inherited
-
refresh(
) → void -
inherited
-
refreshGroup(
Object id) → void -
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that the
object notifies.
inherited
-
removeListenerId(
Object id, VoidCallback listener) → void -
inherited
-
reportAdd(
VoidCallback disposer) → void -
inherited
-
reportRead(
) → void -
inherited
-
setPlanSlug(
String sessionId, String slug) → void - Set a specific plan slug for a session (used when resuming).
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
[List< Object> ? ids, bool condition = true]) → void -
Notifies listeners to update the UI.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited