HookEventEmitter class
Hook event emission manager.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clear(
) → void -
emitHookProgress(
{required String hookId, required String hookName, required String hookEvent, required String stdout, required String stderr, required String output}) → void -
emitHookResponse(
{required String hookId, required String hookName, required String hookEvent, required String output, required String stdout, required String stderr, int? exitCode, required String outcome}) → void -
emitHookStarted(
String hookId, String hookName, String hookEvent) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerHandler(
HookEventHandler? handler) → void -
setAllHookEventsEnabled(
bool enabled) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited