HookResponseEvent class

Emitted when a hook finishes executing.

Implemented types

Constructors

HookResponseEvent({required String hookId, required String hookName, required String hookEvent, required String output, required String stdout, required String stderr, int? exitCode, required String outcome})
const

Properties

exitCode int?
final
hashCode int
The hash code for this object.
no setterinherited
hookEvent String
final
hookId String
final
hookName String
final
outcome String
final
output String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr String
final
stdout String
final
type HookExecutionEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited