IndividualHookConfig class
A single hook configuration with its source and event info.
Constructors
- IndividualHookConfig({required HookEvent event, required HookCommand config, String? matcher, required HookSource source, String? pluginName})
-
const
Properties
- config → HookCommand
-
final
- event → HookEvent
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- matcher → String?
-
final
- pluginName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → HookSource
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited