SessionHookEntry class
An entry pairing a hook with its optional success callback.
Constructors
- SessionHookEntry({required HookCommand hook, void onHookSuccess(HookCommand hook, AggregatedHookResult result)?})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hook → HookCommand
-
final
- onHookSuccess → void Function(HookCommand hook, AggregatedHookResult result)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited