SessionHookMatcher class
A single matcher entry in the session hook store.
Constructors
-
SessionHookMatcher({required String matcher, String? skillRoot, required List<
SessionHookEntry> hooks})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited