WindowsToWSLConverter class
Converts Windows paths to WSL-accessible local paths.
Constructors
- WindowsToWSLConverter(String? wslDistroName)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wslDistroName → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toLocalPath(
String windowsPath) → String - Convert a Windows path to a WSL local path.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited