ParsedUserInput class
Parsed user input.
Constructors
-
ParsedUserInput({required String rawInput, required List<
InputSegment> segments, required List<String> mentionedFiles, required List<String> mentionedUrls, required bool isCommand, String? commandName, String? commandArgs, required bool isEmpty, required bool isMultiline, required int lineCount}) -
const
Properties
-
allFileReferences
→ List<
String> -
All implicit + explicit file references found in input.
no setter
- commandArgs → String?
-
final
- commandName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCommand → bool
-
final
- isEmpty → bool
-
final
- isMultiline → bool
-
final
- lineCount → int
-
final
-
mentionedFiles
→ List<
String> -
final
-
mentionedUrls
→ List<
String> -
final
- plainText → String
-
Plain text content with mentions removed.
no setter
- rawInput → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
segments
→ List<
InputSegment> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited