MdElementType enum
Parsed markdown element types.
Values
- paragraph → const MdElementType
- heading1 → const MdElementType
- heading2 → const MdElementType
- heading3 → const MdElementType
- heading4 → const MdElementType
- heading5 → const MdElementType
- heading6 → const MdElementType
- codeBlock → const MdElementType
- codeSpan → const MdElementType
- blockquote → const MdElementType
- unorderedList → const MdElementType
- orderedList → const MdElementType
- listItem → const MdElementType
- horizontalRule → const MdElementType
- link → const MdElementType
- image → const MdElementType
- bold → const MdElementType
- italic → const MdElementType
- strikethrough → const MdElementType
- table → const MdElementType
- tableRow → const MdElementType
- tableCell → const MdElementType
- lineBreak → const MdElementType
- html → const MdElementType
- taskListItem → const MdElementType
- footnote → const MdElementType
- definition → const MdElementType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MdElementType> - A constant List of the values in this enum, in order of their declaration.