GroupedToolUseMessage class

A grouped tool use message for rendering.

Constructors

GroupedToolUseMessage({String type = 'grouped_tool_use', required String toolName, required List<NormalizedMessage> messages, required List<NormalizedMessage> results, required NormalizedMessage displayMessage, required String uuid, required DateTime timestamp, required String messageId})
const

Properties

displayMessage NormalizedMessage
final
hashCode int
The hash code for this object.
no setterinherited
messageId String
final
messages List<NormalizedMessage>
final
results List<NormalizedMessage>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
toolName String
final
type String
final
uuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited