Signal class
A simple signal for notifying subscribers of changes.
Constructors
- Signal()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
emit(
) → void - Emit the signal, notifying all subscribers.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
subscribe(
void listener()) → void Function() - Subscribe to the signal. Returns an unsubscribe function.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited