ToolResultContentBlock class
A tool result content block.
- Inheritance
-
- Object
- ContentBlock
- ToolResultContentBlock
Constructors
-
ToolResultContentBlock({required String toolUseId, List<
ContentBlock> content = const []}) -
const
Properties
-
content
→ List<
ContentBlock> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolUseId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited