ToolUseInfo class

Information about a tool use extracted from a normalized message.

Constructors

ToolUseInfo({required String messageId, required String toolUseId, required String toolName})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
messageId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolName String
final
toolUseId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited