AssistantMessage class

Assistant message.

Inheritance

Constructors

AssistantMessage({String? uuid, String? timestamp, String? messageId, String model = syntheticModel, required List<ContentBlock> content, Usage usage = const Usage(), String? stopReason = 'stop_sequence', String? requestId, bool isApiErrorMessage = false, bool? isVirtual, Map<String, dynamic>? apiError, Map<String, dynamic>? error, String? errorDetails, String? advisorModel})

Properties

advisorModel String?
final
apiError Map<String, dynamic>?
final
content List<ContentBlock>
final
error Map<String, dynamic>?
final
errorDetails String?
final
hashCode int
The hash code for this object.
no setterinherited
isApiErrorMessage bool
final
isVirtual bool?
final
messageId String
final
model String
final
requestId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopReason String?
final
timestamp String
final
type MessageType
no setteroverride
usage Usage
final
uuid String
final

Methods

copyWith({String? uuid, String? timestamp, String? messageId, String? model, List<ContentBlock>? content, Usage? usage, String? requestId, bool? isApiErrorMessage, bool? isVirtual}) AssistantMessage
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited