MessageLookups class

Pre-computed lookups for O(1) access to message relationships.

Constructors

MessageLookups({Map<String, Set<String>> siblingToolUseIDs = const {}, Map<String, List<ProgressMessage>> progressMessagesByToolUseID = const {}, Map<String, Map<HookEvent, int>> inProgressHookCounts = const {}, Map<String, Map<HookEvent, int>> resolvedHookCounts = const {}, Map<String, NormalizedMessage> toolResultByToolUseID = const {}, Map<String, ToolUseBlock> toolUseByToolUseID = const {}, int normalizedMessageCount = 0, Set<String> resolvedToolUseIDs = const {}, Set<String> erroredToolUseIDs = const {}})
const

Properties

erroredToolUseIDs Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
inProgressHookCounts Map<String, Map<HookEvent, int>>
final
normalizedMessageCount int
final
progressMessagesByToolUseID Map<String, List<ProgressMessage>>
final
resolvedHookCounts Map<String, Map<HookEvent, int>>
final
resolvedToolUseIDs Set<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
siblingToolUseIDs Map<String, Set<String>>
final
toolResultByToolUseID Map<String, NormalizedMessage>
final
toolUseByToolUseID Map<String, ToolUseBlock>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

empty → const MessageLookups