NormalizedMessage class

A normalized message with exactly one content block.

Constructors

NormalizedMessage(Message original)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
original Message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp String
no setter
type MessageType
no setter
uuid String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited