SystemMessage class

System message.

Inheritance

Constructors

SystemMessage({String? uuid, String? timestamp, required SystemMessageSubtype subtype, SystemMessageLevel level = SystemMessageLevel.info, required String content, Map<String, dynamic>? metadata})

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
level SystemMessageLevel
final
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtype SystemMessageSubtype
final
timestamp String
final
type MessageType
no setteroverride
uuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited