ToolResultBlock class

Tool result content block.

Inheritance

Constructors

ToolResultBlock({required String toolUseId, dynamic content, bool isError = false})

Properties

content → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
isError bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolUseId String
final
type String
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited