UserMessage class
User message.
Constructors
-
UserMessage({String? uuid, String? timestamp, required dynamic content, bool? isMeta, bool? isVisibleInTranscriptOnly, bool? isVirtual, bool? isCompactSummary, dynamic toolUseResult, Map<
String, dynamic> ? mcpMeta, List<int> ? imagePasteIds, String? sourceToolAssistantUUID, PermissionMode? permissionMode, MessageOrigin? origin, Map<String, dynamic> ? summarizeMetadata})
Properties
- content → dynamic
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
imagePasteIds
→ List<
int> ? -
final
- isCompactSummary → bool?
-
final
- isMeta → bool?
-
final
- isVirtual → bool?
-
final
- isVisibleInTranscriptOnly → bool?
-
final
-
mcpMeta
→ Map<
String, dynamic> ? -
final
- origin → MessageOrigin?
-
final
- permissionMode → PermissionMode?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceToolAssistantUUID → String?
-
final
-
summarizeMetadata
→ Map<
String, dynamic> ? -
final
- timestamp → String
-
final
- toolUseResult → dynamic
-
final
- type → MessageType
-
no setteroverride
- uuid → String
-
final
Methods
-
copyWith(
{String? uuid, String? timestamp, dynamic content, bool? isMeta, bool? isVirtual, List< int> ? imagePasteIds, MessageOrigin? origin}) → UserMessage -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited