buildClassifierUnavailableMessage function

String buildClassifierUnavailableMessage(
  1. String toolName,
  2. String classifierModel
)

Build a message for when the classifier is temporarily unavailable.

Implementation

String buildClassifierUnavailableMessage(
  String toolName,
  String classifierModel,
) {
  return '$classifierModel is temporarily unavailable, so auto mode cannot '
      'determine the safety of $toolName right now. Wait briefly and then '
      'try this action again. If it keeps failing, continue with other '
      "tasks that don't require this action and come back to it later. "
      'Note: reading files, searching code, and other read-only operations '
      'do not require the classifier and can still be used.';
}