denialWorkaroundGuidance top-level constant
String
const denialWorkaroundGuidance
Implementation
const String denialWorkaroundGuidance =
'IMPORTANT: You *may* attempt to accomplish this action using other tools '
'that might naturally be used to accomplish this goal, e.g. using head '
'instead of cat. But you *should not* attempt to work around this denial '
'in malicious ways, e.g. do not use your ability to run tests to execute '
'non-test actions. You should only try to work around this restriction '
'in reasonable ways that do not attempt to bypass the intent behind this '
'denial. If you believe this capability is essential to complete the '
"user's request, STOP and explain to the user what you were trying to do "
'and why you need this permission. Let the user decide how to proceed.';