SemVer class

Parse a semantic version string.

Implemented types

Constructors

SemVer(int major, int minor, int patch, [String? preRelease])
const
SemVer.parse(String version)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
major int
final
minor int
final
patch int
final
preRelease String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

compareTo(SemVer other) int
Compares this object to another object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator <(SemVer other) bool
operator <=(SemVer other) bool
operator ==(Object other) bool
The equality operator.
inherited
operator >(SemVer other) bool
operator >=(SemVer other) bool