TokenUsage class

Token usage for cost calculation.

Constructors

TokenUsage({int inputTokens = 0, int outputTokens = 0, int cacheCreationTokens = 0, int cacheReadTokens = 0})
const

Properties

cacheCreationTokens int
final
cacheReadTokens int
final
hashCode int
The hash code for this object.
no setterinherited
inputTokens int
final
outputTokens int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTokens int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator +(TokenUsage other) TokenUsage
operator ==(Object other) bool
The equality operator.
inherited