SetupMessage class

A message generated during the setup/installation process.

Constructors

SetupMessage({required String message, required bool userActionRequired, required SetupMessageType type})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SetupMessageType
final
userActionRequired bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited