ProcessOutput class

The result of running a process.

Constructors

ProcessOutput({required int exitCode, String stdout = '', String stderr = '', required Duration duration, required int pid, bool killed = false})
const

Properties

duration Duration
final
exitCode int
final
hashCode int
The hash code for this object.
no setterinherited
isSuccess bool
Whether the process exited successfully (exit code 0).
no setter
killed bool
final
pid int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr String
final
stdout String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited