ProcessPool class
A pool that limits concurrent process execution.
Constructors
- ProcessPool({required int maxConcurrency, ProcessManager? manager})
Properties
- activeCount → int
-
Number of currently active processes.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isClosed → bool
-
Whether the pool is closed.
no setter
- maxConcurrency → int
-
final
- queueLength → int
-
Number of queued processes waiting for a slot.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
close(
) → Future< void> - Close the pool. No new submissions will be accepted.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
submit(
ProcessConfig config) → Future< ProcessOutput> - Submit a process config for execution.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited