SystemPromptBlock class

A block of system prompt text with cache scope.

Constructors

SystemPromptBlock({required String text, CacheScope? cacheScope})
const

Properties

cacheScope CacheScope?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited