ParsedProxyUrl class

Parse a proxy URL into its components.

Constructors

ParsedProxyUrl({required String scheme, required String host, required int port, String? username, String? password})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
host String
final
password String?
final
port int
final
requiresAuth bool
Whether this proxy requires authentication.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheme String
final
urlWithCredentials String
The full URL with credentials.
no setter
urlWithoutCredentials String
The full URL without credentials.
no setter
username String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited