CacheSafeParams class

Cache-safe parameters for query execution.

Constructors

CacheSafeParams({required List<String> systemPrompt, required Map<String, String> userContext, required Map<String, String> systemContext, required Map<String, dynamic> toolUseContext, required List<Map<String, dynamic>> forkContextMessages})

Properties

forkContextMessages List<Map<String, dynamic>>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
systemContext Map<String, String>
final
systemPrompt List<String>
final
toolUseContext Map<String, dynamic>
final
userContext Map<String, String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited