AutoUpdaterResult class
Result of an auto-update operation.
Constructors
-
AutoUpdaterResult({String? version, required AutoUpdateInstallStatus status, List<
String> ? notifications}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
notifications
→ List<
String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → AutoUpdateInstallStatus
-
final
- version → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited