CoreUserData class
Core user data used as base for all analytics providers.
Constructors
- CoreUserData({required String deviceId, required String sessionId, String? email, required String appVersion, required String platform, String? organizationUuid, String? accountUuid, String? userType, String? subscriptionType, String? rateLimitTier, int? firstTokenTime, GitHubActionsMetadata? githubActionsMetadata})
-
const
Properties
- accountUuid → String?
-
final
- appVersion → String
-
final
- deviceId → String
-
final
- email → String?
-
final
- firstTokenTime → int?
-
final
- githubActionsMetadata → GitHubActionsMetadata?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- organizationUuid → String?
-
final
- platform → String
-
final
- rateLimitTier → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
final
- subscriptionType → String?
-
final
- userType → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited