MaxVersionConfig class
Configuration for maximum allowed version (server-side kill switch).
Constructors
- MaxVersionConfig({String? external, String? ant, String? externalMessage, String? antMessage})
-
const
Properties
- ant → String?
-
final
- antMessage → String?
-
final
- external → String?
-
final
- externalMessage → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited