SessionExternalMetadata class
External metadata keys for CCR push / GetSession.
Constructors
- SessionExternalMetadata({String? permissionMode, bool? isUltraplanMode, String? model, RequiresActionDetails? pendingAction, Object? postTurnSummary, String? taskSummary})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isUltraplanMode → bool?
-
final
- model → String?
-
final
- pendingAction → RequiresActionDetails?
-
final
- permissionMode → String?
-
final
- postTurnSummary → Object?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskSummary → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited