SettingsJson class

Full settings JSON structure.

Constructors

SettingsJson({String? model, PermissionSettings permissions = const PermissionSettings(), SandboxSettings sandbox = const SandboxSettings(), Map<String, dynamic>? hooks, List<String> installedPlugins = const [], Map<String, String> environmentVariables = const {}, Map<String, String> modelOverrides = const {}, List<String> availableModels = const [], bool allowManagedPermissionRulesOnly = false, bool syntaxHighlightingEnabled = true, String? theme, String? outputStyle, Map<String, dynamic> raw = const {}})
const
SettingsJson.fromJson(Map<String, dynamic> json)
factory

Properties

allowManagedPermissionRulesOnly bool
final
availableModels List<String>
final
environmentVariables Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
hooks Map<String, dynamic>?
final
installedPlugins List<String>
final
model String?
final
modelOverrides Map<String, String>
final
outputStyle String?
final
permissions PermissionSettings
final
raw Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sandbox SandboxSettings
final
syntaxHighlightingEnabled bool
final
theme String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited