SettingsPaths class
Get standard settings file paths.
Constructors
- SettingsPaths({required String projectDir, required String configDir})
-
const
Properties
- configDir → String
-
final
- credentials → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- keybindings → String
-
no setter
- localSettings → String
-
no setter
- mcpConfig → String
-
no setter
- projectDir → String
-
final
- projectMcpConfig → String
-
no setter
- projectSettings → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userSettings → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited