DailyModelTokens class

Daily token usage per model for charts.

Constructors

DailyModelTokens({required String date, Map<String, int>? tokensByModel})
DailyModelTokens.fromJson(Map<String, dynamic> json)
factory

Properties

date String
Date in YYYY-MM-DD format.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tokensByModel Map<String, int>
Total tokens (input + output) per model name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited