DynamicTeamContext class
Dynamic team context for runtime team joining.
Constructors
Properties
- agentId → String
-
final
- agentName → String
-
final
- color → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- parentSessionId → String?
-
final
- planModeRequired → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- teamName → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited