PermissionRequestMessage class
Permission request from worker to leader via mailbox.
Constructors
-
PermissionRequestMessage({required String requestId, required String agentId, required String toolName, required String toolUseId, required String description, required Map<
String, dynamic> input, List permissionSuggestions = const []}) -
PermissionRequestMessage.fromJson(Map<
String, dynamic> json) -
factory
Properties
- agentId → String
-
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
→ Map<
String, dynamic> -
final
- permissionSuggestions → List
-
final
- requestId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolName → String
-
final
- toolUseId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- messageType → const String