TaskAssignmentMessage class
Task assignment message.
Constructors
- TaskAssignmentMessage({required String taskId, required String subject, required String description, required String assignedBy, required String timestamp})
-
TaskAssignmentMessage.fromJson(Map<
String, dynamic> json) -
factory
Properties
- assignedBy → String
-
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String
-
final
- taskId → String
-
final
- timestamp → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- messageType → const String