HttpTelemetrySink class

Posts event batches to a remote HTTP endpoint.

Implemented types

Constructors

HttpTelemetrySink({String? endpoint, int timeoutSeconds = 10, String? authToken, int maxRetries = 2})

Properties

authToken String?
final
endpoint String
final
hashCode int
The hash code for this object.
no setterinherited
maxRetries int
final
name String
Human-readable name of this sink.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeoutSeconds int
final

Methods

dispose() Future<void>
Perform any necessary cleanup.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(List<TelemetryEvent> events) Future<bool>
Send a batch of events. Returns true on success.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited