TelemetryConfig class

Configuration for the telemetry subsystem.

Constructors

TelemetryConfig({bool enabled = true, bool scrubPiiEnabled = true, int batchSize = 100, int flushIntervalSeconds = 30, List<TelemetrySink>? sinks, Set<TelemetryEventType>? disabledEventTypes})
TelemetryConfig.development()
Create a sensible default configuration for development.
factory
TelemetryConfig.production({String? httpEndpoint, String? authToken})
Create a production configuration with file + HTTP sinks.
factory

Properties

batchSize int
Maximum number of events per batch before an automatic flush.
getter/setter pair
disabledEventTypes Set<TelemetryEventType>
Event types that should be silently dropped.
final
enabled bool
Master switch for all telemetry collection.
getter/setter pair
flushIntervalSeconds int
Interval in seconds between automatic flushes.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrubPiiEnabled bool
When true, PII is scrubbed from event properties before sending.
getter/setter pair
sinks List<TelemetrySink>
Sinks that receive event batches.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited