TelemetryEvent class

A single telemetry event with associated metadata.

Constructors

TelemetryEvent({required String name, required TelemetryEventType type, Map<String, dynamic>? properties, DateTime? timestamp, String? sessionId})
TelemetryEvent.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
final
properties Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
final
timestamp DateTime
final
type TelemetryEventType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited